""" Cisco_IOS_XR_ipv4_ospf_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-ospf package configuration.

This module contains definitions
for the following management objects\:
  ospf\: OSPF configuration data

This YANG module augments the
  Cisco\-IOS\-XR\-snmp\-agent\-cfg
module with configuration data.

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BfdEnableMode(Enum):
    """
    BfdEnableMode

    Bfd enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Default BFD behavior

    .. data:: strict = 2

    	Strict Mode - Hold down adj until BFD sesion up

    """

    disable = Enum.YLeaf(0, "disable")

    default = Enum.YLeaf(1, "default")

    strict = Enum.YLeaf(2, "strict")


class Nsr(Enum):
    """
    Nsr

    Nsr

    .. data:: true = 1

    	Enable non-stop routing

    .. data:: false = 2

    	Disable non-stop routing

    """

    true = Enum.YLeaf(1, "true")

    false = Enum.YLeaf(2, "false")


class OspfAddressFamily(Enum):
    """
    OspfAddressFamily

    Ospf address family

    .. data:: ipv4 = 1

    	IPv4

    """

    ipv4 = Enum.YLeaf(1, "ipv4")


class OspfAuthentication(Enum):
    """
    OspfAuthentication

    Ospf authentication

    .. data:: none = 0

    	No Authentication

    .. data:: plain = 1

    	Plain Text Authentication

    .. data:: md5 = 2

    	MD5 Message Digest

    """

    none = Enum.YLeaf(0, "none")

    plain = Enum.YLeaf(1, "plain")

    md5 = Enum.YLeaf(2, "md5")


class OspfCiscoNsf(Enum):
    """
    OspfCiscoNsf

    Ospf cisco nsf

    .. data:: always = 1

    	Do not require all neighbors to run NSF

    .. data:: require_nsf_neighbors = 2

    	Require all neighbors to run NSF

    """

    always = Enum.YLeaf(1, "always")

    require_nsf_neighbors = Enum.YLeaf(2, "require-nsf-neighbors")


class OspfDistListProtocol(Enum):
    """
    OspfDistListProtocol

    Ospf dist list protocol

    .. data:: all = 0

    	Default

    .. data:: connected = 1

    	Connected Routes

    .. data:: static = 3

    	Static Routes

    .. data:: bgp = 4

    	BGP

    .. data:: ospf = 7

    	OSPF

    .. data:: dagr = 9

    	DAGR

    """

    all = Enum.YLeaf(0, "all")

    connected = Enum.YLeaf(1, "connected")

    static = Enum.YLeaf(3, "static")

    bgp = Enum.YLeaf(4, "bgp")

    ospf = Enum.YLeaf(7, "ospf")

    dagr = Enum.YLeaf(9, "dagr")


class OspfDomainId(Enum):
    """
    OspfDomainId

    Ospf domain id

    .. data:: type0005 = 5

    	Type 0x0005

    .. data:: type0105 = 261

    	Type 0x0105

    .. data:: type0205 = 517

    	Type 0x0205

    .. data:: type8005 = 32773

    	Type 0x8005

    """

    type0005 = Enum.YLeaf(5, "type0005")

    type0105 = Enum.YLeaf(261, "type0105")

    type0205 = Enum.YLeaf(517, "type0205")

    type8005 = Enum.YLeaf(32773, "type8005")


class OspfEigrpRoute(Enum):
    """
    OspfEigrpRoute

    Ospf eigrp route

    .. data:: internal = 0

    	EIGRP Internal Type

    .. data:: external = 1

    	EIGRP External Type

    """

    internal = Enum.YLeaf(0, "internal")

    external = Enum.YLeaf(1, "external")


class OspfFastReroute(Enum):
    """
    OspfFastReroute

    Ospf fast reroute

    .. data:: none = 0

    	None

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = Enum.YLeaf(0, "none")

    per_link = Enum.YLeaf(1, "per-link")

    per_prefix = Enum.YLeaf(2, "per-prefix")


class OspfFastReroutePriority(Enum):
    """
    OspfFastReroutePriority

    Ospf fast reroute priority

    .. data:: critical = 0

    	Critical

    .. data:: high = 2

    	High

    .. data:: medium = 4

    	Medium

    .. data:: low = 6

    	low

    """

    critical = Enum.YLeaf(0, "critical")

    high = Enum.YLeaf(2, "high")

    medium = Enum.YLeaf(4, "medium")

    low = Enum.YLeaf(6, "low")


class OspfFastRerouteTiebreakers(Enum):
    """
    OspfFastRerouteTiebreakers

    Ospf fast reroute tiebreakers

    .. data:: downstream = 0

    	Downstream

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: lowest_metric = 2

    	Lowest metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondar path

    .. data:: srlg_disjoint = 6

    	SRLG

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    lowest_metric = Enum.YLeaf(2, "lowest-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")


class OspfFastRerouteTiebreakersIntf(Enum):
    """
    OspfFastRerouteTiebreakersIntf

    Ospf fast reroute tiebreakers intf

    .. data:: downstream = 0

    	Downstream

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: lowest_metric = 2

    	Lowest metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondar path

    .. data:: srlg_disjoint = 6

    	SRLG

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    lowest_metric = Enum.YLeaf(2, "lowest-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")


class OspfFrrRlfaTunnel(Enum):
    """
    OspfFrrRlfaTunnel

    Ospf frr rlfa tunnel

    .. data:: none = 0

    	Disabled

    .. data:: mpls_ldp = 1

    	MPLS LDP

    """

    none = Enum.YLeaf(0, "none")

    mpls_ldp = Enum.YLeaf(1, "mpls-ldp")


class OspfIetfNsf(Enum):
    """
    OspfIetfNsf

    Ospf ietf nsf

    .. data:: all = 3

    	Use IETF NSF in planned and unplanned cases

    """

    all = Enum.YLeaf(3, "all")


class OspfIetfNsfSupport(Enum):
    """
    OspfIetfNsfSupport

    Ospf ietf nsf support

    .. data:: never = 0

    	Do not perform IETF NSF helper role

    """

    never = Enum.YLeaf(0, "never")


class OspfKeychainAuth(Enum):
    """
    OspfKeychainAuth

    Ospf keychain auth

    .. data:: none = 0

    	No Keychain Authentication

    .. data:: keychain = 3

    	Keychain Authentication

    """

    none = Enum.YLeaf(0, "none")

    keychain = Enum.YLeaf(3, "keychain")


class OspfLinkStateMetric(Enum):
    """
    OspfLinkStateMetric

    Ospf link state metric

    .. data:: type1 = 1

    	Type 1 External

    .. data:: type2 = 2

    	Type 2 External

    """

    type1 = Enum.YLeaf(1, "type1")

    type2 = Enum.YLeaf(2, "type2")


class OspfLogAdj(Enum):
    """
    OspfLogAdj

    Ospf log adj

    .. data:: brief = 0

    	Limited output

    .. data:: detail = 1

    	Verbose output

    .. data:: suppress = 2

    	No output

    """

    brief = Enum.YLeaf(0, "brief")

    detail = Enum.YLeaf(1, "detail")

    suppress = Enum.YLeaf(2, "suppress")


class OspfNetwork(Enum):
    """
    OspfNetwork

    Ospf network

    .. data:: broadcast = 1

    	Broadcast

    .. data:: non_broadcast = 2

    	NonBroadcast

    .. data:: point_to_point = 3

    	Point to Point

    .. data:: point_to_multipoint = 4

    	Point to Multipoint

    .. data:: non_broadcast_point_to_multipoint = 5

    	NonBroadcast Point to Multipoint

    """

    broadcast = Enum.YLeaf(1, "broadcast")

    non_broadcast = Enum.YLeaf(2, "non-broadcast")

    point_to_point = Enum.YLeaf(3, "point-to-point")

    point_to_multipoint = Enum.YLeaf(4, "point-to-multipoint")

    non_broadcast_point_to_multipoint = Enum.YLeaf(5, "non-broadcast-point-to-multipoint")


class OspfProcFastReroute(Enum):
    """
    OspfProcFastReroute

    Ospf proc fast reroute

    .. data:: none = 0

    	None

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = Enum.YLeaf(0, "none")

    per_link = Enum.YLeaf(1, "per-link")

    per_prefix = Enum.YLeaf(2, "per-prefix")


class OspfProcFrrRlfaTunnel(Enum):
    """
    OspfProcFrrRlfaTunnel

    Ospf proc frr rlfa tunnel

    .. data:: none = 0

    	Disabled

    .. data:: mpls_ldp = 1

    	MPLS LDP

    """

    none = Enum.YLeaf(0, "none")

    mpls_ldp = Enum.YLeaf(1, "mpls-ldp")


class OspfRedistLsa(Enum):
    """
    OspfRedistLsa

    Ospf redist lsa

    .. data:: summary = 3

    	Type 3 (summary) LSA

    .. data:: external = 5

    	Type 5 (external) LSA

    """

    summary = Enum.YLeaf(3, "summary")

    external = Enum.YLeaf(5, "external")


class OspfRedistProtocol(Enum):
    """
    OspfRedistProtocol

    Ospf redist protocol

    .. data:: all = 0

    	Default

    .. data:: connected = 1

    	Connected Routes

    .. data:: static = 3

    	Static Routes

    .. data:: bgp = 4

    	BGP

    .. data:: rip = 5

    	RIP

    .. data:: isis = 6

    	ISIS

    .. data:: ospf = 7

    	OSPF

    .. data:: eigrp = 8

    	EIGRP

    .. data:: dagr = 9

    	DAGR

    .. data:: subscriber = 10

    	Subscriber Routes

    .. data:: application = 11

    	Application Routes

    .. data:: mobile = 12

    	Mobile Routes

    """

    all = Enum.YLeaf(0, "all")

    connected = Enum.YLeaf(1, "connected")

    static = Enum.YLeaf(3, "static")

    bgp = Enum.YLeaf(4, "bgp")

    rip = Enum.YLeaf(5, "rip")

    isis = Enum.YLeaf(6, "isis")

    ospf = Enum.YLeaf(7, "ospf")

    eigrp = Enum.YLeaf(8, "eigrp")

    dagr = Enum.YLeaf(9, "dagr")

    subscriber = Enum.YLeaf(10, "subscriber")

    application = Enum.YLeaf(11, "application")

    mobile = Enum.YLeaf(12, "mobile")


class OspfRouteLevel(Enum):
    """
    OspfRouteLevel

    Ospf route level

    .. data:: type1 = 1

    	Type 1 only

    .. data:: type2 = 2

    	Type 2 only

    .. data:: type1_and2 = 3

    	Both Type 1 and Type 2

    """

    type1 = Enum.YLeaf(1, "type1")

    type2 = Enum.YLeaf(2, "type2")

    type1_and2 = Enum.YLeaf(3, "type1-and2")


class OspfSegmentRouting(Enum):
    """
    OspfSegmentRouting

    Ospf segment routing

    .. data:: disable = 0

    	Disable

    .. data:: mpls = 1

    	Mpls

    """

    disable = Enum.YLeaf(0, "disable")

    mpls = Enum.YLeaf(1, "mpls")


class OspfSegmentRoutingForwarding(Enum):
    """
    OspfSegmentRoutingForwarding

    Ospf segment routing forwarding

    .. data:: disable = 0

    	Disable

    .. data:: mpls = 1

    	Mpls

    """

    disable = Enum.YLeaf(0, "disable")

    mpls = Enum.YLeaf(1, "mpls")


class OspfShutdown(Enum):
    """
    OspfShutdown

    Ospf shutdown

    .. data:: full = 1

    	Full graceful shutdown

    .. data:: hostmode = 2

    	Enter host only mode

    .. data:: onreload = 3

    	Full graceful shutdown post reload

    """

    full = Enum.YLeaf(1, "full")

    hostmode = Enum.YLeaf(2, "hostmode")

    onreload = Enum.YLeaf(3, "onreload")


class OspfSid(Enum):
    """
    OspfSid

    Ospf sid

    .. data:: index = 0

    	Index

    .. data:: absolute = 1

    	Absolute

    """

    index = Enum.YLeaf(0, "index")

    absolute = Enum.YLeaf(1, "absolute")


class OspfSubAddressFamily(Enum):
    """
    OspfSubAddressFamily

    Ospf sub address family

    .. data:: unicast = 1

    	Unicast

    """

    unicast = Enum.YLeaf(1, "unicast")


class OspfTraceBufSize(Enum):
    """
    OspfTraceBufSize

    Ospf trace buf size

    .. data:: size0 = 0

    	Disable trace

    .. data:: size256 = 256

    	Buffer size 256

    .. data:: size512 = 512

    	Buffer size 512

    .. data:: size1024 = 1024

    	Buffer size 1024

    .. data:: size2048 = 2048

    	Buffer size 2048

    .. data:: size4096 = 4096

    	Buffer size 4096

    .. data:: size8192 = 8192

    	Buffer size 8192

    .. data:: size16384 = 16384

    	Buffer size 16384

    .. data:: size32768 = 32768

    	Buffer size 32768

    .. data:: size65536 = 65536

    	Buffer size 65536

    """

    size0 = Enum.YLeaf(0, "size0")

    size256 = Enum.YLeaf(256, "size256")

    size512 = Enum.YLeaf(512, "size512")

    size1024 = Enum.YLeaf(1024, "size1024")

    size2048 = Enum.YLeaf(2048, "size2048")

    size4096 = Enum.YLeaf(4096, "size4096")

    size8192 = Enum.YLeaf(8192, "size8192")

    size16384 = Enum.YLeaf(16384, "size16384")

    size32768 = Enum.YLeaf(32768, "size32768")

    size65536 = Enum.YLeaf(65536, "size65536")


class OspfUloopAvoidance(Enum):
    """
    OspfUloopAvoidance

    Ospf uloop avoidance

    .. data:: protected = 1

    	Protected prefixes only

    .. data:: all = 2

    	All prefixes

    .. data:: segment_routing = 3

    	Microloop avoidance using Segment Routing

    """

    protected = Enum.YLeaf(1, "protected")

    all = Enum.YLeaf(2, "all")

    segment_routing = Enum.YLeaf(3, "segment-routing")



class Ospf(Entity):
    """
    OSPF configuration data
    
    .. attribute:: global_
    
    	OSPF global configuration data
    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Global_>`
    
    .. attribute:: processes
    
    	Process related configuration
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes>`
    
    

    """

    _prefix = 'ipv4-ospf-cfg'
    _revision = '2017-07-14'

    def __init__(self):
        super(Ospf, self).__init__()
        self._top_entity = None

        self.yang_name = "ospf"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-ospf-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"global" : ("global_", Ospf.Global_), "processes" : ("processes", Ospf.Processes)}
        self._child_list_classes = {}

        self.global_ = Ospf.Global_()
        self.global_.parent = self
        self._children_name_map["global_"] = "global"
        self._children_yang_names.add("global")

        self.processes = Ospf.Processes()
        self.processes.parent = self
        self._children_name_map["processes"] = "processes"
        self._children_yang_names.add("processes")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-ospf-cfg:ospf"


    class Global_(Entity):
        """
        OSPF global configuration data
        
        .. attribute:: dns_name_lookup
        
        	Display OSPF router ids as DNS names
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        

        """

        _prefix = 'ipv4-ospf-cfg'
        _revision = '2017-07-14'

        def __init__(self):
            super(Ospf.Global_, self).__init__()

            self.yang_name = "global"
            self.yang_parent_name = "ospf"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.dns_name_lookup = YLeaf(YType.empty, "dns-name-lookup")
            self._segment_path = lambda: "global"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-ospf-cfg:ospf/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Ospf.Global_, ['dns_name_lookup'], name, value)


    class Processes(Entity):
        """
        Process related configuration
        
        .. attribute:: process
        
        	Configuration for a particular OSPF process and associated default VRF
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process>`
        
        

        """

        _prefix = 'ipv4-ospf-cfg'
        _revision = '2017-07-14'

        def __init__(self):
            super(Ospf.Processes, self).__init__()

            self.yang_name = "processes"
            self.yang_parent_name = "ospf"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"process" : ("process", Ospf.Processes.Process)}

            self.process = YList(self)
            self._segment_path = lambda: "processes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-ospf-cfg:ospf/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Ospf.Processes, [], name, value)


        class Process(Entity):
            """
            Configuration for a particular OSPF process and
            associated default VRF
            
            .. attribute:: process_name  <key>
            
            	Name for this OSPF process
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: default_vrf
            
            	Default VRF related configuration
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf>`
            
            .. attribute:: distribute
            
            	Enable distribution of link\-state database services
            	**type**\:   :py:class:`Distribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Distribute>`
            
            	**presence node**\: True
            
            .. attribute:: graceful_shutdown_timers
            
            	Adjust routing timers
            	**type**\:   :py:class:`GracefulShutdownTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.GracefulShutdownTimers>`
            
            .. attribute:: nsr
            
            	Enable non\-stop routing
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Nsr>`
            
            	**default value**\: true
            
            .. attribute:: protocol_shutdown
            
            	Type of protocol shutdown
            	**type**\:   :py:class:`OspfShutdown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfShutdown>`
            
            .. attribute:: running
            
            	Enable routing on an IP network
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: snmp
            
            	OSPF SNMP configuration
            	**type**\:   :py:class:`Snmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Snmp>`
            
            .. attribute:: start
            
            	Start OSPF configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: trace_bufs
            
            	Configuration to change size of trace buffer
            	**type**\:   :py:class:`TraceBufs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.TraceBufs>`
            
            .. attribute:: vrfs
            
            	VRF related configuration
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv4-ospf-cfg'
            _revision = '2017-07-14'

            def __init__(self):
                super(Ospf.Processes.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "processes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"default-vrf" : ("default_vrf", Ospf.Processes.Process.DefaultVrf), "distribute" : ("distribute", Ospf.Processes.Process.Distribute), "graceful-shutdown-timers" : ("graceful_shutdown_timers", Ospf.Processes.Process.GracefulShutdownTimers), "snmp" : ("snmp", Ospf.Processes.Process.Snmp), "trace-bufs" : ("trace_bufs", Ospf.Processes.Process.TraceBufs), "vrfs" : ("vrfs", Ospf.Processes.Process.Vrfs)}
                self._child_list_classes = {}

                self.process_name = YLeaf(YType.str, "process-name")

                self.nsr = YLeaf(YType.enumeration, "nsr")

                self.protocol_shutdown = YLeaf(YType.enumeration, "protocol-shutdown")

                self.running = YLeaf(YType.empty, "running")

                self.start = YLeaf(YType.empty, "start")

                self.default_vrf = Ospf.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.distribute = None
                self._children_name_map["distribute"] = "distribute"
                self._children_yang_names.add("distribute")

                self.graceful_shutdown_timers = Ospf.Processes.Process.GracefulShutdownTimers()
                self.graceful_shutdown_timers.parent = self
                self._children_name_map["graceful_shutdown_timers"] = "graceful-shutdown-timers"
                self._children_yang_names.add("graceful-shutdown-timers")

                self.snmp = Ospf.Processes.Process.Snmp()
                self.snmp.parent = self
                self._children_name_map["snmp"] = "snmp"
                self._children_yang_names.add("snmp")

                self.trace_bufs = Ospf.Processes.Process.TraceBufs()
                self.trace_bufs.parent = self
                self._children_name_map["trace_bufs"] = "trace-bufs"
                self._children_yang_names.add("trace-bufs")

                self.vrfs = Ospf.Processes.Process.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")
                self._segment_path = lambda: "process" + "[process-name='" + self.process_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-ospf-cfg:ospf/processes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Ospf.Processes.Process, ['process_name', 'nsr', 'protocol_shutdown', 'running', 'start'], name, value)


            class DefaultVrf(Entity):
                """
                Default VRF related configuration
                
                .. attribute:: adjacency_changes
                
                	Log changes in adjacency state
                	**type**\:   :py:class:`OspfLogAdj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLogAdj>`
                
                .. attribute:: adjacency_stagger
                
                	Staggering OSPF adjacency bring up
                	**type**\:   :py:class:`AdjacencyStagger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AdjacencyStagger>`
                
                .. attribute:: af
                
                	OSPF address family
                	**type**\:   :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Af>`
                
                	**presence node**\: True
                
                .. attribute:: area_addresses
                
                	Area configuration
                	**type**\:   :py:class:`AreaAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses>`
                
                .. attribute:: auto_cost
                
                	Controls automatic cost based on bandwidth
                	**type**\:   :py:class:`AutoCost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AutoCost>`
                
                .. attribute:: default_information
                
                	Control distribution of default information
                	**type**\:   :py:class:`DefaultInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.DefaultInformation>`
                
                .. attribute:: default_metric
                
                	Set default metric of redistributed routes
                	**type**\:  int
                
                	**range:** 1..16777214
                
                	**default value**\: 1
                
                .. attribute:: distance
                
                	Administrative distance configuration
                	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance>`
                
                .. attribute:: fast_reroute
                
                	Fast\-reroute instance scoped parameters
                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute>`
                
                .. attribute:: ignore_mospf
                
                	Ignore MOSPF (Type 6) LSAs
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: max_lsa
                
                	Set max\-lsa configuration
                	**type**\:   :py:class:`MaxLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxLsa>`
                
                	**presence node**\: True
                
                .. attribute:: max_metric
                
                	Set maximum metric configuration
                	**type**\:   :py:class:`MaxMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric>`
                
                .. attribute:: maximum_interfaces
                
                	Max number of interfaces allowed to be configured
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                	**default value**\: 1024
                
                .. attribute:: maximum_paths
                
                	Forward packets over multiple paths (number of paths)
                	**type**\:  int
                
                	**range:** 1..64
                
                .. attribute:: maximum_redistribute_prefix
                
                	Maximum number of prefixes redistributed into OSPF
                	**type**\:   :py:class:`MaximumRedistributePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix>`
                
                .. attribute:: microloop
                
                	Microloop configuration
                	**type**\:   :py:class:`Microloop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Microloop>`
                
                .. attribute:: monitor_convergence
                
                	Enable convergence monitoring
                	**type**\:   :py:class:`MonitorConvergence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MonitorConvergence>`
                
                .. attribute:: mpls
                
                	Configure MPLS routing protocol parameters
                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Mpls>`
                
                .. attribute:: no_opaque
                
                	Disable opaque LSAs
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: nsf
                
                	Non Stop Forwarding configuration
                	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Nsf>`
                
                .. attribute:: outgoing_route_updates
                
                	Filter outgoing routing updates
                	**type**\:   :py:class:`OutgoingRouteUpdates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates>`
                
                .. attribute:: process_scope
                
                	Process scope configuration
                	**type**\:   :py:class:`ProcessScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope>`
                
                .. attribute:: queue
                
                	Adjust OSPF input queue sizes and processing quantums
                	**type**\:   :py:class:`Queue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Queue>`
                
                .. attribute:: redistribution
                
                	Redistribute configurations
                	**type**\:   :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution>`
                
                .. attribute:: router_id
                
                	Router ID for this OSPF process. Enter an IP Address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: segment_routing
                
                	Segment Routing instance scoped parameters
                	**type**\:   :py:class:`SegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SegmentRouting>`
                
                .. attribute:: snmp_context
                
                	OSPF SNMP context configuration
                	**type**\:  str
                
                .. attribute:: spf_prefix_priority
                
                	Configure a route\-policy for prioritizing RIB route install
                	**type**\:  str
                
                .. attribute:: summary_prefixes
                
                	Configure IP prefix summary
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                .. attribute:: timers
                
                	Adjust routing timers
                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Timers>`
                
                .. attribute:: type7
                
                	Prefer type7 externals over type5
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ucmp
                
                	Unequal Cost Multi\-ptah configuration
                	**type**\:   :py:class:`Ucmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp>`
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-07-14'

                def __init__(self):
                    super(Ospf.Processes.Process.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"adjacency-stagger" : ("adjacency_stagger", Ospf.Processes.Process.DefaultVrf.AdjacencyStagger), "af" : ("af", Ospf.Processes.Process.DefaultVrf.Af), "area-addresses" : ("area_addresses", Ospf.Processes.Process.DefaultVrf.AreaAddresses), "auto-cost" : ("auto_cost", Ospf.Processes.Process.DefaultVrf.AutoCost), "default-information" : ("default_information", Ospf.Processes.Process.DefaultVrf.DefaultInformation), "distance" : ("distance", Ospf.Processes.Process.DefaultVrf.Distance), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.FastReroute), "max-lsa" : ("max_lsa", Ospf.Processes.Process.DefaultVrf.MaxLsa), "max-metric" : ("max_metric", Ospf.Processes.Process.DefaultVrf.MaxMetric), "maximum-redistribute-prefix" : ("maximum_redistribute_prefix", Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix), "microloop" : ("microloop", Ospf.Processes.Process.DefaultVrf.Microloop), "monitor-convergence" : ("monitor_convergence", Ospf.Processes.Process.DefaultVrf.MonitorConvergence), "mpls" : ("mpls", Ospf.Processes.Process.DefaultVrf.Mpls), "nsf" : ("nsf", Ospf.Processes.Process.DefaultVrf.Nsf), "outgoing-route-updates" : ("outgoing_route_updates", Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates), "process-scope" : ("process_scope", Ospf.Processes.Process.DefaultVrf.ProcessScope), "queue" : ("queue", Ospf.Processes.Process.DefaultVrf.Queue), "redistribution" : ("redistribution", Ospf.Processes.Process.DefaultVrf.Redistribution), "segment-routing" : ("segment_routing", Ospf.Processes.Process.DefaultVrf.SegmentRouting), "summary-prefixes" : ("summary_prefixes", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes), "timers" : ("timers", Ospf.Processes.Process.DefaultVrf.Timers), "ucmp" : ("ucmp", Ospf.Processes.Process.DefaultVrf.Ucmp)}
                    self._child_list_classes = {}

                    self.adjacency_changes = YLeaf(YType.enumeration, "adjacency-changes")

                    self.default_metric = YLeaf(YType.uint32, "default-metric")

                    self.ignore_mospf = YLeaf(YType.empty, "ignore-mospf")

                    self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                    self.maximum_paths = YLeaf(YType.uint32, "maximum-paths")

                    self.no_opaque = YLeaf(YType.empty, "no-opaque")

                    self.router_id = YLeaf(YType.str, "router-id")

                    self.snmp_context = YLeaf(YType.str, "snmp-context")

                    self.spf_prefix_priority = YLeaf(YType.str, "spf-prefix-priority")

                    self.type7 = YLeaf(YType.empty, "type7")

                    self.adjacency_stagger = Ospf.Processes.Process.DefaultVrf.AdjacencyStagger()
                    self.adjacency_stagger.parent = self
                    self._children_name_map["adjacency_stagger"] = "adjacency-stagger"
                    self._children_yang_names.add("adjacency-stagger")

                    self.af = None
                    self._children_name_map["af"] = "af"
                    self._children_yang_names.add("af")

                    self.area_addresses = Ospf.Processes.Process.DefaultVrf.AreaAddresses()
                    self.area_addresses.parent = self
                    self._children_name_map["area_addresses"] = "area-addresses"
                    self._children_yang_names.add("area-addresses")

                    self.auto_cost = Ospf.Processes.Process.DefaultVrf.AutoCost()
                    self.auto_cost.parent = self
                    self._children_name_map["auto_cost"] = "auto-cost"
                    self._children_yang_names.add("auto-cost")

                    self.default_information = Ospf.Processes.Process.DefaultVrf.DefaultInformation()
                    self.default_information.parent = self
                    self._children_name_map["default_information"] = "default-information"
                    self._children_yang_names.add("default-information")

                    self.distance = Ospf.Processes.Process.DefaultVrf.Distance()
                    self.distance.parent = self
                    self._children_name_map["distance"] = "distance"
                    self._children_yang_names.add("distance")

                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.FastReroute()
                    self.fast_reroute.parent = self
                    self._children_name_map["fast_reroute"] = "fast-reroute"
                    self._children_yang_names.add("fast-reroute")

                    self.max_lsa = None
                    self._children_name_map["max_lsa"] = "max-lsa"
                    self._children_yang_names.add("max-lsa")

                    self.max_metric = Ospf.Processes.Process.DefaultVrf.MaxMetric()
                    self.max_metric.parent = self
                    self._children_name_map["max_metric"] = "max-metric"
                    self._children_yang_names.add("max-metric")

                    self.maximum_redistribute_prefix = Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix()
                    self.maximum_redistribute_prefix.parent = self
                    self._children_name_map["maximum_redistribute_prefix"] = "maximum-redistribute-prefix"
                    self._children_yang_names.add("maximum-redistribute-prefix")

                    self.microloop = Ospf.Processes.Process.DefaultVrf.Microloop()
                    self.microloop.parent = self
                    self._children_name_map["microloop"] = "microloop"
                    self._children_yang_names.add("microloop")

                    self.monitor_convergence = Ospf.Processes.Process.DefaultVrf.MonitorConvergence()
                    self.monitor_convergence.parent = self
                    self._children_name_map["monitor_convergence"] = "monitor-convergence"
                    self._children_yang_names.add("monitor-convergence")

                    self.mpls = Ospf.Processes.Process.DefaultVrf.Mpls()
                    self.mpls.parent = self
                    self._children_name_map["mpls"] = "mpls"
                    self._children_yang_names.add("mpls")

                    self.nsf = Ospf.Processes.Process.DefaultVrf.Nsf()
                    self.nsf.parent = self
                    self._children_name_map["nsf"] = "nsf"
                    self._children_yang_names.add("nsf")

                    self.outgoing_route_updates = Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates()
                    self.outgoing_route_updates.parent = self
                    self._children_name_map["outgoing_route_updates"] = "outgoing-route-updates"
                    self._children_yang_names.add("outgoing-route-updates")

                    self.process_scope = Ospf.Processes.Process.DefaultVrf.ProcessScope()
                    self.process_scope.parent = self
                    self._children_name_map["process_scope"] = "process-scope"
                    self._children_yang_names.add("process-scope")

                    self.queue = Ospf.Processes.Process.DefaultVrf.Queue()
                    self.queue.parent = self
                    self._children_name_map["queue"] = "queue"
                    self._children_yang_names.add("queue")

                    self.redistribution = Ospf.Processes.Process.DefaultVrf.Redistribution()
                    self.redistribution.parent = self
                    self._children_name_map["redistribution"] = "redistribution"
                    self._children_yang_names.add("redistribution")

                    self.segment_routing = Ospf.Processes.Process.DefaultVrf.SegmentRouting()
                    self.segment_routing.parent = self
                    self._children_name_map["segment_routing"] = "segment-routing"
                    self._children_yang_names.add("segment-routing")

                    self.summary_prefixes = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self._children_name_map["summary_prefixes"] = "summary-prefixes"
                    self._children_yang_names.add("summary-prefixes")

                    self.timers = Ospf.Processes.Process.DefaultVrf.Timers()
                    self.timers.parent = self
                    self._children_name_map["timers"] = "timers"
                    self._children_yang_names.add("timers")

                    self.ucmp = Ospf.Processes.Process.DefaultVrf.Ucmp()
                    self.ucmp.parent = self
                    self._children_name_map["ucmp"] = "ucmp"
                    self._children_yang_names.add("ucmp")
                    self._segment_path = lambda: "default-vrf"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf, ['adjacency_changes', 'default_metric', 'ignore_mospf', 'maximum_interfaces', 'maximum_paths', 'no_opaque', 'router_id', 'snmp_context', 'spf_prefix_priority', 'type7'], name, value)


                class AdjacencyStagger(Entity):
                    """
                    Staggering OSPF adjacency bring up
                    
                    .. attribute:: disable
                    
                    	Disable OSPF adjacency stagger
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: initial_nbr
                    
                    	Adjacency Stagger\: Initial number of neighbors to bring up per area
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**default value**\: 2
                    
                    .. attribute:: max_nbr
                    
                    	Adjacency Stagger\: Subsequent simultaneous number of neighbors to bring up
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**default value**\: 64
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyStagger, self).__init__()

                        self.yang_name = "adjacency-stagger"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.disable = YLeaf(YType.empty, "disable")

                        self.initial_nbr = YLeaf(YType.uint32, "initial-nbr")

                        self.max_nbr = YLeaf(YType.uint32, "max-nbr")
                        self._segment_path = lambda: "adjacency-stagger"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyStagger, ['disable', 'initial_nbr', 'max_nbr'], name, value)


                class Af(Entity):
                    """
                    OSPF address family
                    
                    .. attribute:: af_name
                    
                    	Address family
                    	**type**\:   :py:class:`OspfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAddressFamily>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: saf_name
                    
                    	Sub\-Address family
                    	**type**\:   :py:class:`OspfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSubAddressFamily>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.af_name = YLeaf(YType.enumeration, "af-name")

                        self.saf_name = YLeaf(YType.enumeration, "saf-name")
                        self._segment_path = lambda: "af"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Af, ['af_name', 'saf_name'], name, value)


                class AreaAddresses(Entity):
                    """
                    Area configuration
                    
                    .. attribute:: area_address
                    
                    	Configuration for a particular area
                    	**type**\: list of    :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress>`
                    
                    .. attribute:: area_area_id
                    
                    	Configuration for a particular area
                    	**type**\: list of    :py:class:`AreaAreaId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses, self).__init__()

                        self.yang_name = "area-addresses"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"area-address" : ("area_address", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress), "area-area-id" : ("area_area_id", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId)}

                        self.area_address = YList(self)
                        self.area_area_id = YList(self)
                        self._segment_path = lambda: "area-addresses"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses, [], name, value)


                    class AreaAddress(Entity):
                        """
                        Configuration for a particular area
                        
                        .. attribute:: address  <key>
                        
                        	Area ID if in IP address format
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: area_ranges
                        
                        	Summarize routes matching address/mask (border routers only)
                        	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges>`
                        
                        .. attribute:: area_scope
                        
                        	Area scope configuration
                        	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope>`
                        
                        .. attribute:: default_cost
                        
                        	Set the summary default\-cost of a NSSA/stub area
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        	**default value**\: 1
                        
                        .. attribute:: external_out
                        
                        	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                        	**type**\:  bool
                        
                        .. attribute:: mpls_traffic_eng
                        
                        	Configure an OSPF area to run MPLS Traffic Engineering
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multi_area_interface_scopes
                        
                        	Multi Area Interface scope configurations
                        	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes>`
                        
                        .. attribute:: name_scopes
                        
                        	Name scope configurations
                        	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes>`
                        
                        .. attribute:: nssa
                        
                        	Specify area as a NSSA area
                        	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa>`
                        
                        .. attribute:: route_policy_in
                        
                        	Configure a route policy for inbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: route_policy_out
                        
                        	Configure a route policy for outbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: running
                        
                        	Enable routing on an IP network
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: segment_routing
                        
                        	segment\-routing configuration Applicable only in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                        
                        .. attribute:: sham_link_scopes
                        
                        	Sham Link scope configurations
                        	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes>`
                        
                        .. attribute:: stub
                        
                        	Specify the area as a stub area (send summary LSA stub area)
                        	**type**\:  bool
                        
                        .. attribute:: summary_in
                        
                        	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                        	**type**\:  bool
                        
                        .. attribute:: virtual_link_scopes
                        
                        	Virtual Link scope configurations
                        	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress, self).__init__()

                            self.yang_name = "area-address"
                            self.yang_parent_name = "area-addresses"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"area-ranges" : ("area_ranges", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges), "area-scope" : ("area_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope), "multi-area-interface-scopes" : ("multi_area_interface_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes), "name-scopes" : ("name_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes), "nssa" : ("nssa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa), "sham-link-scopes" : ("sham_link_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes), "virtual-link-scopes" : ("virtual_link_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.default_cost = YLeaf(YType.uint32, "default-cost")

                            self.external_out = YLeaf(YType.boolean, "external-out")

                            self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                            self.running = YLeaf(YType.empty, "running")

                            self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                            self.stub = YLeaf(YType.boolean, "stub")

                            self.summary_in = YLeaf(YType.boolean, "summary-in")

                            self.area_ranges = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges()
                            self.area_ranges.parent = self
                            self._children_name_map["area_ranges"] = "area-ranges"
                            self._children_yang_names.add("area-ranges")

                            self.area_scope = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope()
                            self.area_scope.parent = self
                            self._children_name_map["area_scope"] = "area-scope"
                            self._children_yang_names.add("area-scope")

                            self.multi_area_interface_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes()
                            self.multi_area_interface_scopes.parent = self
                            self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                            self._children_yang_names.add("multi-area-interface-scopes")

                            self.name_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes()
                            self.name_scopes.parent = self
                            self._children_name_map["name_scopes"] = "name-scopes"
                            self._children_yang_names.add("name-scopes")

                            self.nssa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa()
                            self.nssa.parent = self
                            self._children_name_map["nssa"] = "nssa"
                            self._children_yang_names.add("nssa")

                            self.sham_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes()
                            self.sham_link_scopes.parent = self
                            self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                            self._children_yang_names.add("sham-link-scopes")

                            self.virtual_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes()
                            self.virtual_link_scopes.parent = self
                            self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                            self._children_yang_names.add("virtual-link-scopes")
                            self._segment_path = lambda: "area-address" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress, ['address', 'default_cost', 'external_out', 'mpls_traffic_eng', 'route_policy_in', 'route_policy_out', 'running', 'segment_routing', 'stub', 'summary_in'], name, value)


                        class AreaRanges(Entity):
                            """
                            Summarize routes matching address/mask (border
                            routers only)
                            
                            .. attribute:: area_range
                            
                            	Ordering index
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges, self).__init__()

                                self.yang_name = "area-ranges"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-range" : ("area_range", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange)}

                                self.area_range = YList(self)
                                self._segment_path = lambda: "area-ranges"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges, [], name, value)


                            class AreaRange(Entity):
                                """
                                Ordering index
                                
                                .. attribute:: address  <key>
                                
                                	IP address to match
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: netmask  <key>
                                
                                	IP netmask for address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: not_advertise
                                
                                	Do not advertise this range
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "area-ranges"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address = YLeaf(YType.str, "address")

                                    self.netmask = YLeaf(YType.str, "netmask")

                                    self.not_advertise = YLeaf(YType.boolean, "not-advertise")
                                    self._segment_path = lambda: "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, ['address', 'netmask', 'not_advertise'], name, value)


                        class AreaScope(Entity):
                            """
                            Area scope configuration
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication>`
                            
                            .. attribute:: bfd
                            
                            	BFD configuration
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd>`
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: cost_fallback
                            
                            	Interface fallback cost
                            	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback>`
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: dead_interval_minimal
                            
                            	Interval after which a neighbor is declared dead
                            	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal>`
                            
                            .. attribute:: demand_circuit
                            
                            	Enable/Disable OSPF demand circuit
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: distribute_list
                            
                            	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                            	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fast_reroute
                            
                            	Fast\-reroute configuration
                            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute>`
                            
                            .. attribute:: flood_reduction
                            
                            	Enable/Disable OSPF flood reduction
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: hello_interval
                            
                            	Interval between HELLO packets in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ldp_auto_config
                            
                            	Enable MPLS LDP Auto Config
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ldp_sync
                            
                            	Enable/Disable MPLS LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: ldp_sync_igp_shortcuts
                            
                            	Enable/Disable MPLS LDP sync for igp\-shortcuts
                            	**type**\:  bool
                            
                            .. attribute:: link_down_fast_detect
                            
                            	Enable/Disable registration for early interface down notifications
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: loopback_stub_network
                            
                            	Enable/Disable advertising loopback as a stub network
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: mtu_ignore
                            
                            	Enable/Disable ignoring of MTU in DBD packets
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: network_type
                            
                            	Type of attached network
                            	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                            
                            .. attribute:: packet_size
                            
                            	Customize size of OSPF packets upto MTU
                            	**type**\:  int
                            
                            	**range:** 576..10000
                            
                            .. attribute:: passive
                            
                            	When enabled, prevent sending HELLO packets over link
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_primary
                            
                            	Enable/Disable prefix suppression for primary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_secondary
                            
                            	Enable/Disable prefix suppression for secondary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: priority
                            
                            	Router priority for DR and BDR election
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**default value**\: 1
                            
                            .. attribute:: retransmit_interval
                            
                            	Time in seconds between retransmitting lost link state advertisements
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 5
                            
                            .. attribute:: security
                            
                            	Container class for security related configuration parameters
                            	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security>`
                            
                            .. attribute:: segment_routing_forwarding
                            
                            	segment\-routing forwarding configuration Applicableonly in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                            
                            .. attribute:: transmit_delay
                            
                            	Number of seconds to delay transmission of LSAs
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope, self).__init__()

                                self.yang_name = "area-scope"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute), "security" : ("security", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security)}
                                self._child_list_classes = {}

                                self.cost = YLeaf(YType.uint32, "cost")

                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.packet_size = YLeaf(YType.uint32, "packet-size")

                                self.passive = YLeaf(YType.boolean, "passive")

                                self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._children_yang_names.add("authentication")

                                self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback()
                                self.cost_fallback.parent = self
                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                self._children_yang_names.add("cost-fallback")

                                self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal()
                                self.dead_interval_minimal.parent = self
                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                self._children_yang_names.add("dead-interval-minimal")

                                self.distribute_list = None
                                self._children_name_map["distribute_list"] = "distribute-list"
                                self._children_yang_names.add("distribute-list")

                                self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                self._children_yang_names.add("fast-reroute")

                                self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security()
                                self.security.parent = self
                                self._children_name_map["security"] = "security"
                                self._children_yang_names.add("security")
                                self._segment_path = lambda: "area-scope"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope, ['cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: key
                                
                                	Authentication key configuration
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: message_digest_keies
                                
                                	Message digest authentication password (key) configurations, first 16 chars used
                                	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies>`
                                
                                .. attribute:: type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type)}
                                    self._child_list_classes = {}

                                    self.key = YLeaf(YType.str, "key")

                                    self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies()
                                    self.message_digest_keies.parent = self
                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                    self._children_yang_names.add("message-digest-keies")

                                    self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type()
                                    self.type.parent = self
                                    self._children_name_map["type"] = "type"
                                    self._children_yang_names.add("type")
                                    self._segment_path = lambda: "authentication"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication, ['key'], name, value)


                                class MessageDigestKeies(Entity):
                                    """
                                    Message digest authentication password (key)
                                    configurations, first 16 chars used
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Message digest authentication password (key) configuration
                                    	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                        self.yang_name = "message-digest-keies"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                        self.message_digest_key = YList(self)
                                        self._segment_path = lambda: "message-digest-keies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, [], name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configuration
                                        
                                        .. attribute:: key_id  <key>
                                        
                                        	Key ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: password
                                        
                                        	Password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "message-digest-keies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.key_id = YLeaf(YType.uint32, "key-id")

                                            self.password = YLeaf(YType.str, "password")
                                            self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                class Type(Entity):
                                    """
                                    Authentication type
                                    
                                    .. attribute:: authen_type
                                    
                                    	Authentication type code 
                                    	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                    
                                    .. attribute:: keychain_authen_type
                                    
                                    	Keychain authentication type
                                    	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Keychain name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__init__()

                                        self.yang_name = "type"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                        self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                            class Bfd(Entity):
                                """
                                BFD configuration
                                
                                .. attribute:: detection_multiplier
                                
                                	Detection multiplier for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 2..50
                                
                                .. attribute:: fast_detect_mode
                                
                                	 use of Bidirectional Forwarding Detection
                                	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                
                                .. attribute:: interval
                                
                                	Hello interval for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                    self.interval = YLeaf(YType.uint32, "interval")
                                    self._segment_path = lambda: "bfd"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                            class CostFallback(Entity):
                                """
                                Interface fallback cost
                                
                                .. attribute:: cost
                                
                                	Fallback cost of link
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: threshold
                                
                                	Bandwidth threshold
                                	**type**\:  int
                                
                                	**range:** 1..4294967
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__init__()

                                    self.yang_name = "cost-fallback"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.threshold = YLeaf(YType.uint32, "threshold")
                                    self._segment_path = lambda: "cost-fallback"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, ['cost', 'threshold'], name, value)


                            class DeadIntervalMinimal(Entity):
                                """
                                Interval after which a neighbor is declared dead
                                
                                .. attribute:: interval
                                
                                	Interval size in seconds after which a neighbor is declared dead
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: multiplier
                                
                                	Number of Hellos in one second
                                	**type**\:  int
                                
                                	**range:** 3..20
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__init__()

                                    self.yang_name = "dead-interval-minimal"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interval = YLeaf(YType.uint32, "interval")

                                    self.multiplier = YLeaf(YType.uint32, "multiplier")
                                    self._segment_path = lambda: "dead-interval-minimal"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                            class DistributeList(Entity):
                                """
                                Filter networks intalled to RIB (disable as ACL
                                name means filtering is disabled)
                                
                                .. attribute:: access_list_name
                                
                                	Access Control List name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_name
                                
                                	Route Policy name
                                	**type**\:  str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.access_list_name = YLeaf(YType.str, "access-list-name")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                    self._segment_path = lambda: "distribute-list"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                            class FastReroute(Entity):
                                """
                                Fast\-reroute configuration
                                
                                .. attribute:: fast_reroute_enable
                                
                                	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                
                                .. attribute:: per_link
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink>`
                                
                                .. attribute:: per_prefix
                                
                                	Fast\-reroute per\-prefix global configuration
                                	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__init__()

                                    self.yang_name = "fast-reroute"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix)}
                                    self._child_list_classes = {}

                                    self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                    self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self._children_name_map["per_link"] = "per-link"
                                    self._children_yang_names.add("per-link")

                                    self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self
                                    self._children_name_map["per_prefix"] = "per-prefix"
                                    self._children_yang_names.add("per-prefix")
                                    self._segment_path = lambda: "fast-reroute"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, ['fast_reroute_enable'], name, value)


                                class PerLink(Entity):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__init__()

                                        self.yang_name = "per-link"
                                        self.yang_parent_name = "fast-reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")
                                        self._segment_path = lambda: "per-link"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                            self.candidate_interface = YList(self)
                                            self._segment_path = lambda: "candidate-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                            self.exclude_interface = YList(self)
                                            self._segment_path = lambda: "exclude-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                class PerPrefix(Entity):
                                    """
                                    Fast\-reroute per\-prefix global configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: remote_lfa
                                    
                                    	Remote LFA configuration
                                    	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                    
                                    .. attribute:: tiebreakers
                                    
                                    	Fast\-reroute tiebreakers configurations
                                    	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                    
                                    .. attribute:: topology_independent_lfa
                                    
                                    	Topology Independet LFA configuration
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__init__()

                                        self.yang_name = "per-prefix"
                                        self.yang_parent_name = "fast-reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")

                                        self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                        self.remote_lfa.parent = self
                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                        self._children_yang_names.add("remote-lfa")

                                        self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                        self.tiebreakers.parent = self
                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                        self._children_yang_names.add("tiebreakers")
                                        self._segment_path = lambda: "per-prefix"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                            self.candidate_interface = YList(self)
                                            self._segment_path = lambda: "candidate-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                            self.exclude_interface = YList(self)
                                            self._segment_path = lambda: "exclude-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class RemoteLfa(Entity):
                                        """
                                        Remote LFA configuration
                                        
                                        .. attribute:: maximum_cost
                                        
                                        	Maximum path cost to remote LFA
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel
                                        
                                        	Enable/Disable remote LFA computation
                                        	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                            self.yang_name = "remote-lfa"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                            self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                            self._segment_path = lambda: "remote-lfa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                    class Tiebreakers(Entity):
                                        """
                                        Fast\-reroute tiebreakers configurations
                                        
                                        .. attribute:: tiebreaker
                                        
                                        	Fast\-reroute tiebreakers configuration
                                        	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                            self.yang_name = "tiebreakers"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                            self.tiebreaker = YList(self)
                                            self._segment_path = lambda: "tiebreakers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                        class Tiebreaker(Entity):
                                            """
                                            Fast\-reroute tiebreakers configuration
                                            
                                            .. attribute:: tiebreaker_type  <key>
                                            
                                            	Tiebreaker type
                                            	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                            
                                            .. attribute:: tiebreaker_index
                                            
                                            	Index value for a tiebreaker, 0 to disable
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                self.yang_name = "tiebreaker"
                                                self.yang_parent_name = "tiebreakers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                            class Security(Entity):
                                """
                                Container class for security related
                                configuration parameters
                                
                                .. attribute:: ttl
                                
                                	Enabling turns on TTL security
                                	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security, self).__init__()

                                    self.yang_name = "security"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl)}
                                    self._child_list_classes = {}

                                    self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl()
                                    self.ttl.parent = self
                                    self._children_name_map["ttl"] = "ttl"
                                    self._children_yang_names.add("ttl")
                                    self._segment_path = lambda: "security"


                                class Ttl(Entity):
                                    """
                                    Enabling turns on TTL security
                                    
                                    .. attribute:: enable
                                    
                                    	Enable TTL security
                                    	**type**\:  bool
                                    
                                    .. attribute:: hop_count
                                    
                                    	Hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__init__()

                                        self.yang_name = "ttl"
                                        self.yang_parent_name = "security"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.boolean, "enable")

                                        self.hop_count = YLeaf(YType.uint32, "hop-count")
                                        self._segment_path = lambda: "ttl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                        class MultiAreaInterfaceScopes(Entity):
                            """
                            Multi Area Interface scope configurations
                            
                            .. attribute:: multi_area_interface_scope
                            
                            	Multi Area Interface configuration
                            	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__init__()

                                self.yang_name = "multi-area-interface-scopes"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"multi-area-interface-scope" : ("multi_area_interface_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope)}

                                self.multi_area_interface_scope = YList(self)
                                self._segment_path = lambda: "multi-area-interface-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, [], name, value)


                            class MultiAreaInterfaceScope(Entity):
                                """
                                Multi Area Interface configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Multi Area Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                    self.yang_name = "multi-area-interface-scope"
                                    self.yang_parent_name = "multi-area-interface-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")
                                    self._segment_path = lambda: "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, ['interface_name', 'cost', 'database_filter', 'hello_interval', 'mtu_ignore', 'packet_size', 'passive', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")
                                        self._segment_path = lambda: "cost-fallback"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, ['cost', 'threshold'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "distribute-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")
                                        self._segment_path = lambda: "fast-reroute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, ['fast_reroute_enable'], name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")
                                            self._segment_path = lambda: "per-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")
                                            self._segment_path = lambda: "per-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                self.tiebreaker = YList(self)
                                                self._segment_path = lambda: "tiebreakers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor)}

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                        class NameScopes(Entity):
                            """
                            Name scope configurations
                            
                            .. attribute:: name_scope
                            
                            	Name scope configuration
                            	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes, self).__init__()

                                self.yang_name = "name-scopes"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"name-scope" : ("name_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope)}

                                self.name_scope = YList(self)
                                self._segment_path = lambda: "name-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes, [], name, value)


                            class NameScope(Entity):
                                """
                                Name scope configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors>`
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_sid
                                
                                	Prefix SID
                                	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_sid_strict
                                
                                	Strict Prefix SID
                                	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__init__()

                                    self.yang_name = "name-scope"
                                    self.yang_parent_name = "name-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors), "prefix-sid" : ("prefix_sid", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid), "prefix-sid-strict" : ("prefix_sid_strict", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict), "security" : ("security", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")

                                    self.prefix_sid = None
                                    self._children_name_map["prefix_sid"] = "prefix-sid"
                                    self._children_yang_names.add("prefix-sid")

                                    self.prefix_sid_strict = None
                                    self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                    self._children_yang_names.add("prefix-sid-strict")

                                    self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")
                                    self._segment_path = lambda: "name-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope, ['interface_name', 'cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'running', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")
                                        self._segment_path = lambda: "bfd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")
                                        self._segment_path = lambda: "cost-fallback"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, ['cost', 'threshold'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "distribute-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")
                                        self._segment_path = lambda: "fast-reroute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, ['fast_reroute_enable'], name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")
                                            self._segment_path = lambda: "per-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")
                                            self._segment_path = lambda: "per-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                self.tiebreaker = YList(self)
                                                self._segment_path = lambda: "tiebreakers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor)}

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                                class PrefixSid(Entity):
                                    """
                                    Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__init__()

                                        self.yang_name = "prefix-sid"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")
                                        self._segment_path = lambda: "prefix-sid"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                class PrefixSidStrict(Entity):
                                    """
                                    Strict Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                        self.yang_name = "prefix-sid-strict"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")
                                        self._segment_path = lambda: "prefix-sid-strict"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl)}
                                        self._child_list_classes = {}

                                        self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")
                                        self._segment_path = lambda: "security"


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")
                                            self._segment_path = lambda: "ttl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                        class Nssa(Entity):
                            """
                            Specify area as a NSSA area
                            
                            .. attribute:: default_info_originate
                            
                            	Originate Type 7 default into NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: metric_type
                            
                            	OSPF External metric type
                            	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                            
                            	**default value**\: type2
                            
                            .. attribute:: no_redistribution
                            
                            	No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: no_summary
                            
                            	Do not send summary LSA into NSSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: nssa_def_metric
                            
                            	OSPF default metric
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa, self).__init__()

                                self.yang_name = "nssa"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                self.no_summary = YLeaf(YType.boolean, "no-summary")

                                self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")
                                self._segment_path = lambda: "nssa"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.Nssa, ['default_info_originate', 'metric_type', 'no_redistribution', 'no_summary', 'nssa_def_metric'], name, value)


                        class ShamLinkScopes(Entity):
                            """
                            Sham Link scope configurations
                            
                            .. attribute:: sham_link_scope
                            
                            	Sham Link configuration
                            	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__init__()

                                self.yang_name = "sham-link-scopes"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"sham-link-scope" : ("sham_link_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope)}

                                self.sham_link_scope = YList(self)
                                self._segment_path = lambda: "sham-link-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes, [], name, value)


                            class ShamLinkScope(Entity):
                                """
                                Sham Link configuration
                                
                                .. attribute:: source_address  <key>
                                
                                	Address of the local sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_address  <key>
                                
                                	Address of the remote sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: source
                                
                                	Address of the local sham\-link endpoint. Enter an IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__init__()

                                    self.yang_name = "sham-link-scope"
                                    self.yang_parent_name = "sham-link-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal)}
                                    self._child_list_classes = {}

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.destination_address = YLeaf(YType.str, "destination-address")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.source = YLeaf(YType.str, "source")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")
                                    self._segment_path = lambda: "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, ['source_address', 'destination_address', 'cost', 'hello_interval', 'retransmit_interval', 'running', 'source', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "sham-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "sham-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                        class VirtualLinkScopes(Entity):
                            """
                            Virtual Link scope configurations
                            
                            .. attribute:: virtual_link_scope
                            
                            	Virtual Link configuration
                            	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__init__()

                                self.yang_name = "virtual-link-scopes"
                                self.yang_parent_name = "area-address"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"virtual-link-scope" : ("virtual_link_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope)}

                                self.virtual_link_scope = YList(self)
                                self._segment_path = lambda: "virtual-link-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes, [], name, value)


                            class VirtualLinkScope(Entity):
                                """
                                Virtual Link configuration
                                
                                .. attribute:: address  <key>
                                
                                	Router ID of virtual link neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                    self.yang_name = "virtual-link-scope"
                                    self.yang_parent_name = "virtual-link-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal)}
                                    self._child_list_classes = {}

                                    self.address = YLeaf(YType.str, "address")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")
                                    self._segment_path = lambda: "virtual-link-scope" + "[address='" + self.address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, ['address', 'hello_interval', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "virtual-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                    class AreaAreaId(Entity):
                        """
                        Configuration for a particular area
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID if in integer format
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_ranges
                        
                        	Summarize routes matching address/mask (border routers only)
                        	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges>`
                        
                        .. attribute:: area_scope
                        
                        	Area scope configuration
                        	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope>`
                        
                        .. attribute:: default_cost
                        
                        	Set the summary default\-cost of a NSSA/stub area
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        	**default value**\: 1
                        
                        .. attribute:: external_out
                        
                        	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                        	**type**\:  bool
                        
                        .. attribute:: mpls_traffic_eng
                        
                        	Configure an OSPF area to run MPLS Traffic Engineering
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: multi_area_interface_scopes
                        
                        	Multi Area Interface scope configurations
                        	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes>`
                        
                        .. attribute:: name_scopes
                        
                        	Name scope configurations
                        	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes>`
                        
                        .. attribute:: nssa
                        
                        	Specify area as a NSSA area
                        	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa>`
                        
                        .. attribute:: route_policy_in
                        
                        	Configure a route policy for inbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: route_policy_out
                        
                        	Configure a route policy for outbound type\-3 lsa filtering
                        	**type**\:  str
                        
                        .. attribute:: running
                        
                        	Enable routing on an IP network
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: segment_routing
                        
                        	segment\-routing configuration Applicable only in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                        
                        .. attribute:: sham_link_scopes
                        
                        	Sham Link scope configurations
                        	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes>`
                        
                        .. attribute:: stub
                        
                        	Specify the area as a stub area (send summary LSA stub area)
                        	**type**\:  bool
                        
                        .. attribute:: summary_in
                        
                        	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                        	**type**\:  bool
                        
                        .. attribute:: virtual_link_scopes
                        
                        	Virtual Link scope configurations
                        	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId, self).__init__()

                            self.yang_name = "area-area-id"
                            self.yang_parent_name = "area-addresses"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"area-ranges" : ("area_ranges", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges), "area-scope" : ("area_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope), "multi-area-interface-scopes" : ("multi_area_interface_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes), "name-scopes" : ("name_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes), "nssa" : ("nssa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa), "sham-link-scopes" : ("sham_link_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes), "virtual-link-scopes" : ("virtual_link_scopes", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes)}
                            self._child_list_classes = {}

                            self.area_id = YLeaf(YType.uint32, "area-id")

                            self.default_cost = YLeaf(YType.uint32, "default-cost")

                            self.external_out = YLeaf(YType.boolean, "external-out")

                            self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                            self.running = YLeaf(YType.empty, "running")

                            self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                            self.stub = YLeaf(YType.boolean, "stub")

                            self.summary_in = YLeaf(YType.boolean, "summary-in")

                            self.area_ranges = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges()
                            self.area_ranges.parent = self
                            self._children_name_map["area_ranges"] = "area-ranges"
                            self._children_yang_names.add("area-ranges")

                            self.area_scope = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope()
                            self.area_scope.parent = self
                            self._children_name_map["area_scope"] = "area-scope"
                            self._children_yang_names.add("area-scope")

                            self.multi_area_interface_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes()
                            self.multi_area_interface_scopes.parent = self
                            self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                            self._children_yang_names.add("multi-area-interface-scopes")

                            self.name_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes()
                            self.name_scopes.parent = self
                            self._children_name_map["name_scopes"] = "name-scopes"
                            self._children_yang_names.add("name-scopes")

                            self.nssa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa()
                            self.nssa.parent = self
                            self._children_name_map["nssa"] = "nssa"
                            self._children_yang_names.add("nssa")

                            self.sham_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes()
                            self.sham_link_scopes.parent = self
                            self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                            self._children_yang_names.add("sham-link-scopes")

                            self.virtual_link_scopes = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes()
                            self.virtual_link_scopes.parent = self
                            self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                            self._children_yang_names.add("virtual-link-scopes")
                            self._segment_path = lambda: "area-area-id" + "[area-id='" + self.area_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId, ['area_id', 'default_cost', 'external_out', 'mpls_traffic_eng', 'route_policy_in', 'route_policy_out', 'running', 'segment_routing', 'stub', 'summary_in'], name, value)


                        class AreaRanges(Entity):
                            """
                            Summarize routes matching address/mask (border
                            routers only)
                            
                            .. attribute:: area_range
                            
                            	Ordering index
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges, self).__init__()

                                self.yang_name = "area-ranges"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-range" : ("area_range", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange)}

                                self.area_range = YList(self)
                                self._segment_path = lambda: "area-ranges"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges, [], name, value)


                            class AreaRange(Entity):
                                """
                                Ordering index
                                
                                .. attribute:: address  <key>
                                
                                	IP address to match
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: netmask  <key>
                                
                                	IP netmask for address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: not_advertise
                                
                                	Do not advertise this range
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "area-ranges"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address = YLeaf(YType.str, "address")

                                    self.netmask = YLeaf(YType.str, "netmask")

                                    self.not_advertise = YLeaf(YType.boolean, "not-advertise")
                                    self._segment_path = lambda: "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, ['address', 'netmask', 'not_advertise'], name, value)


                        class AreaScope(Entity):
                            """
                            Area scope configuration
                            
                            .. attribute:: authentication
                            
                            	Authentication
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication>`
                            
                            .. attribute:: bfd
                            
                            	BFD configuration
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd>`
                            
                            .. attribute:: cost
                            
                            	Interface cost
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: cost_fallback
                            
                            	Interface fallback cost
                            	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback>`
                            
                            .. attribute:: database_filter
                            
                            	Filter OSPF LSA during synchronization and flooding
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: dead_interval_minimal
                            
                            	Interval after which a neighbor is declared dead
                            	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal>`
                            
                            .. attribute:: demand_circuit
                            
                            	Enable/Disable OSPF demand circuit
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: distribute_list
                            
                            	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                            	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: fast_reroute
                            
                            	Fast\-reroute configuration
                            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute>`
                            
                            .. attribute:: flood_reduction
                            
                            	Enable/Disable OSPF flood reduction
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: hello_interval
                            
                            	Interval between HELLO packets in seconds
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: ldp_auto_config
                            
                            	Enable MPLS LDP Auto Config
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: ldp_sync
                            
                            	Enable/Disable MPLS LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: ldp_sync_igp_shortcuts
                            
                            	Enable/Disable MPLS LDP sync for igp\-shortcuts
                            	**type**\:  bool
                            
                            .. attribute:: link_down_fast_detect
                            
                            	Enable/Disable registration for early interface down notifications
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: loopback_stub_network
                            
                            	Enable/Disable advertising loopback as a stub network
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: mtu_ignore
                            
                            	Enable/Disable ignoring of MTU in DBD packets
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: network_type
                            
                            	Type of attached network
                            	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                            
                            .. attribute:: packet_size
                            
                            	Customize size of OSPF packets upto MTU
                            	**type**\:  int
                            
                            	**range:** 576..10000
                            
                            .. attribute:: passive
                            
                            	When enabled, prevent sending HELLO packets over link
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_primary
                            
                            	Enable/Disable prefix suppression for primary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: prefix_suppression_secondary
                            
                            	Enable/Disable prefix suppression for secondary addresses
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: priority
                            
                            	Router priority for DR and BDR election
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**default value**\: 1
                            
                            .. attribute:: retransmit_interval
                            
                            	Time in seconds between retransmitting lost link state advertisements
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 5
                            
                            .. attribute:: security
                            
                            	Container class for security related configuration parameters
                            	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security>`
                            
                            .. attribute:: segment_routing_forwarding
                            
                            	segment\-routing forwarding configuration Applicableonly in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                            
                            .. attribute:: transmit_delay
                            
                            	Number of seconds to delay transmission of LSAs
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope, self).__init__()

                                self.yang_name = "area-scope"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute), "security" : ("security", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security)}
                                self._child_list_classes = {}

                                self.cost = YLeaf(YType.uint32, "cost")

                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.packet_size = YLeaf(YType.uint32, "packet-size")

                                self.passive = YLeaf(YType.boolean, "passive")

                                self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                self.priority = YLeaf(YType.uint32, "priority")

                                self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._children_yang_names.add("authentication")

                                self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback()
                                self.cost_fallback.parent = self
                                self._children_name_map["cost_fallback"] = "cost-fallback"
                                self._children_yang_names.add("cost-fallback")

                                self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal()
                                self.dead_interval_minimal.parent = self
                                self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                self._children_yang_names.add("dead-interval-minimal")

                                self.distribute_list = None
                                self._children_name_map["distribute_list"] = "distribute-list"
                                self._children_yang_names.add("distribute-list")

                                self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                self.fast_reroute.parent = self
                                self._children_name_map["fast_reroute"] = "fast-reroute"
                                self._children_yang_names.add("fast-reroute")

                                self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security()
                                self.security.parent = self
                                self._children_name_map["security"] = "security"
                                self._children_yang_names.add("security")
                                self._segment_path = lambda: "area-scope"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope, ['cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                            class Authentication(Entity):
                                """
                                Authentication
                                
                                .. attribute:: key
                                
                                	Authentication key configuration
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                .. attribute:: message_digest_keies
                                
                                	Message digest authentication password (key) configurations, first 16 chars used
                                	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies>`
                                
                                .. attribute:: type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type)}
                                    self._child_list_classes = {}

                                    self.key = YLeaf(YType.str, "key")

                                    self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies()
                                    self.message_digest_keies.parent = self
                                    self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                    self._children_yang_names.add("message-digest-keies")

                                    self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type()
                                    self.type.parent = self
                                    self._children_name_map["type"] = "type"
                                    self._children_yang_names.add("type")
                                    self._segment_path = lambda: "authentication"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, ['key'], name, value)


                                class MessageDigestKeies(Entity):
                                    """
                                    Message digest authentication password (key)
                                    configurations, first 16 chars used
                                    
                                    .. attribute:: message_digest_key
                                    
                                    	Message digest authentication password (key) configuration
                                    	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                        self.yang_name = "message-digest-keies"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                        self.message_digest_key = YList(self)
                                        self._segment_path = lambda: "message-digest-keies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, [], name, value)


                                    class MessageDigestKey(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configuration
                                        
                                        .. attribute:: key_id  <key>
                                        
                                        	Key ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        .. attribute:: password
                                        
                                        	Password
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                            self.yang_name = "message-digest-key"
                                            self.yang_parent_name = "message-digest-keies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.key_id = YLeaf(YType.uint32, "key-id")

                                            self.password = YLeaf(YType.str, "password")
                                            self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                class Type(Entity):
                                    """
                                    Authentication type
                                    
                                    .. attribute:: authen_type
                                    
                                    	Authentication type code 
                                    	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                    
                                    .. attribute:: keychain_authen_type
                                    
                                    	Keychain authentication type
                                    	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Keychain name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__init__()

                                        self.yang_name = "type"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                        self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                            class Bfd(Entity):
                                """
                                BFD configuration
                                
                                .. attribute:: detection_multiplier
                                
                                	Detection multiplier for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 2..50
                                
                                .. attribute:: fast_detect_mode
                                
                                	 use of Bidirectional Forwarding Detection
                                	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                
                                .. attribute:: interval
                                
                                	Hello interval for BFD sessions created by OSPF
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                    self.interval = YLeaf(YType.uint32, "interval")
                                    self._segment_path = lambda: "bfd"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                            class CostFallback(Entity):
                                """
                                Interface fallback cost
                                
                                .. attribute:: cost
                                
                                	Fallback cost of link
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: threshold
                                
                                	Bandwidth threshold
                                	**type**\:  int
                                
                                	**range:** 1..4294967
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__init__()

                                    self.yang_name = "cost-fallback"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.threshold = YLeaf(YType.uint32, "threshold")
                                    self._segment_path = lambda: "cost-fallback"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, ['cost', 'threshold'], name, value)


                            class DeadIntervalMinimal(Entity):
                                """
                                Interval after which a neighbor is declared dead
                                
                                .. attribute:: interval
                                
                                	Interval size in seconds after which a neighbor is declared dead
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: multiplier
                                
                                	Number of Hellos in one second
                                	**type**\:  int
                                
                                	**range:** 3..20
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__init__()

                                    self.yang_name = "dead-interval-minimal"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interval = YLeaf(YType.uint32, "interval")

                                    self.multiplier = YLeaf(YType.uint32, "multiplier")
                                    self._segment_path = lambda: "dead-interval-minimal"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                            class DistributeList(Entity):
                                """
                                Filter networks intalled to RIB (disable as ACL
                                name means filtering is disabled)
                                
                                .. attribute:: access_list_name
                                
                                	Access Control List name
                                	**type**\:  str
                                
                                .. attribute:: route_policy_name
                                
                                	Route Policy name
                                	**type**\:  str
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__init__()

                                    self.yang_name = "distribute-list"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.access_list_name = YLeaf(YType.str, "access-list-name")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                    self._segment_path = lambda: "distribute-list"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                            class FastReroute(Entity):
                                """
                                Fast\-reroute configuration
                                
                                .. attribute:: fast_reroute_enable
                                
                                	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                
                                .. attribute:: per_link
                                
                                	Fast\-reroute per\-link configuration
                                	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink>`
                                
                                .. attribute:: per_prefix
                                
                                	Fast\-reroute per\-prefix global configuration
                                	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__init__()

                                    self.yang_name = "fast-reroute"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix)}
                                    self._child_list_classes = {}

                                    self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                    self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                    self.per_link.parent = self
                                    self._children_name_map["per_link"] = "per-link"
                                    self._children_yang_names.add("per-link")

                                    self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                    self.per_prefix.parent = self
                                    self._children_name_map["per_prefix"] = "per-prefix"
                                    self._children_yang_names.add("per-prefix")
                                    self._segment_path = lambda: "fast-reroute"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, ['fast_reroute_enable'], name, value)


                                class PerLink(Entity):
                                    """
                                    Fast\-reroute per\-link configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__init__()

                                        self.yang_name = "per-link"
                                        self.yang_parent_name = "fast-reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")
                                        self._segment_path = lambda: "per-link"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                            self.candidate_interface = YList(self)
                                            self._segment_path = lambda: "candidate-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                            self.exclude_interface = YList(self)
                                            self._segment_path = lambda: "exclude-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                class PerPrefix(Entity):
                                    """
                                    Fast\-reroute per\-prefix global configuration
                                    
                                    .. attribute:: candidate_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                    	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                    
                                    .. attribute:: exclude_interfaces
                                    
                                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                    
                                    .. attribute:: fast_reroute_use_candidate_only
                                    
                                    	Use only interfaces on the candidate list as a backup path
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: remote_lfa
                                    
                                    	Remote LFA configuration
                                    	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                    
                                    .. attribute:: tiebreakers
                                    
                                    	Fast\-reroute tiebreakers configurations
                                    	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                    
                                    .. attribute:: topology_independent_lfa
                                    
                                    	Topology Independet LFA configuration
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__init__()

                                        self.yang_name = "per-prefix"
                                        self.yang_parent_name = "fast-reroute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                        self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                        self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                        self.candidate_interfaces.parent = self
                                        self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                        self._children_yang_names.add("candidate-interfaces")

                                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                        self.exclude_interfaces.parent = self
                                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                        self._children_yang_names.add("exclude-interfaces")

                                        self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                        self.remote_lfa.parent = self
                                        self._children_name_map["remote_lfa"] = "remote-lfa"
                                        self._children_yang_names.add("remote-lfa")

                                        self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                        self.tiebreakers.parent = self
                                        self._children_name_map["tiebreakers"] = "tiebreakers"
                                        self._children_yang_names.add("tiebreakers")
                                        self._segment_path = lambda: "per-prefix"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                    class CandidateInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix candidate
                                        interface configuration
                                        
                                        .. attribute:: candidate_interface
                                        
                                        	Candidate backup interface
                                        	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                            self.yang_name = "candidate-interfaces"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                            self.candidate_interface = YList(self)
                                            self._segment_path = lambda: "candidate-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                        class CandidateInterface(Entity):
                                            """
                                            Candidate backup interface
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                self.yang_name = "candidate-interface"
                                                self.yang_parent_name = "candidate-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                    class ExcludeInterfaces(Entity):
                                        """
                                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                        interface configuration
                                        
                                        .. attribute:: exclude_interface
                                        
                                        	Exclude an interface from becoming a backup or UCMP
                                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                            self.yang_name = "exclude-interfaces"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                            self.exclude_interface = YList(self)
                                            self._segment_path = lambda: "exclude-interfaces"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                        class ExcludeInterface(Entity):
                                            """
                                            Exclude an interface from becoming a backup or
                                            UCMP
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                self.yang_name = "exclude-interface"
                                                self.yang_parent_name = "exclude-interfaces"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")
                                                self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class RemoteLfa(Entity):
                                        """
                                        Remote LFA configuration
                                        
                                        .. attribute:: maximum_cost
                                        
                                        	Maximum path cost to remote LFA
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel
                                        
                                        	Enable/Disable remote LFA computation
                                        	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                            self.yang_name = "remote-lfa"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                            self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                            self._segment_path = lambda: "remote-lfa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                    class Tiebreakers(Entity):
                                        """
                                        Fast\-reroute tiebreakers configurations
                                        
                                        .. attribute:: tiebreaker
                                        
                                        	Fast\-reroute tiebreakers configuration
                                        	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                            self.yang_name = "tiebreakers"
                                            self.yang_parent_name = "per-prefix"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                            self.tiebreaker = YList(self)
                                            self._segment_path = lambda: "tiebreakers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                        class Tiebreaker(Entity):
                                            """
                                            Fast\-reroute tiebreakers configuration
                                            
                                            .. attribute:: tiebreaker_type  <key>
                                            
                                            	Tiebreaker type
                                            	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                            
                                            .. attribute:: tiebreaker_index
                                            
                                            	Index value for a tiebreaker, 0 to disable
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                self.yang_name = "tiebreaker"
                                                self.yang_parent_name = "tiebreakers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                            class Security(Entity):
                                """
                                Container class for security related
                                configuration parameters
                                
                                .. attribute:: ttl
                                
                                	Enabling turns on TTL security
                                	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security, self).__init__()

                                    self.yang_name = "security"
                                    self.yang_parent_name = "area-scope"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl)}
                                    self._child_list_classes = {}

                                    self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl()
                                    self.ttl.parent = self
                                    self._children_name_map["ttl"] = "ttl"
                                    self._children_yang_names.add("ttl")
                                    self._segment_path = lambda: "security"


                                class Ttl(Entity):
                                    """
                                    Enabling turns on TTL security
                                    
                                    .. attribute:: enable
                                    
                                    	Enable TTL security
                                    	**type**\:  bool
                                    
                                    .. attribute:: hop_count
                                    
                                    	Hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..254
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__init__()

                                        self.yang_name = "ttl"
                                        self.yang_parent_name = "security"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.boolean, "enable")

                                        self.hop_count = YLeaf(YType.uint32, "hop-count")
                                        self._segment_path = lambda: "ttl"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                        class MultiAreaInterfaceScopes(Entity):
                            """
                            Multi Area Interface scope configurations
                            
                            .. attribute:: multi_area_interface_scope
                            
                            	Multi Area Interface configuration
                            	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__init__()

                                self.yang_name = "multi-area-interface-scopes"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"multi-area-interface-scope" : ("multi_area_interface_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope)}

                                self.multi_area_interface_scope = YList(self)
                                self._segment_path = lambda: "multi-area-interface-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, [], name, value)


                            class MultiAreaInterfaceScope(Entity):
                                """
                                Multi Area Interface configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Multi Area Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                    self.yang_name = "multi-area-interface-scope"
                                    self.yang_parent_name = "multi-area-interface-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")
                                    self._segment_path = lambda: "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, ['interface_name', 'cost', 'database_filter', 'hello_interval', 'mtu_ignore', 'packet_size', 'passive', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")
                                        self._segment_path = lambda: "cost-fallback"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, ['cost', 'threshold'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "distribute-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")
                                        self._segment_path = lambda: "fast-reroute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, ['fast_reroute_enable'], name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")
                                            self._segment_path = lambda: "per-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")
                                            self._segment_path = lambda: "per-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                self.tiebreaker = YList(self)
                                                self._segment_path = lambda: "tiebreakers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "multi-area-interface-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor)}

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                        class NameScopes(Entity):
                            """
                            Name scope configurations
                            
                            .. attribute:: name_scope
                            
                            	Name scope configuration
                            	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes, self).__init__()

                                self.yang_name = "name-scopes"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"name-scope" : ("name_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope)}

                                self.name_scope = YList(self)
                                self._segment_path = lambda: "name-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes, [], name, value)


                            class NameScope(Entity):
                                """
                                Name scope configuration
                                
                                .. attribute:: interface_name  <key>
                                
                                	Name of Interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: neighbors
                                
                                	Neighbor router configuration information
                                	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors>`
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_sid
                                
                                	Prefix SID
                                	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_sid_strict
                                
                                	Strict Prefix SID
                                	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__init__()

                                    self.yang_name = "name-scope"
                                    self.yang_parent_name = "name-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors), "prefix-sid" : ("prefix_sid", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid), "prefix-sid-strict" : ("prefix_sid_strict", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict), "security" : ("security", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security)}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.neighbors = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors()
                                    self.neighbors.parent = self
                                    self._children_name_map["neighbors"] = "neighbors"
                                    self._children_yang_names.add("neighbors")

                                    self.prefix_sid = None
                                    self._children_name_map["prefix_sid"] = "prefix-sid"
                                    self._children_yang_names.add("prefix-sid")

                                    self.prefix_sid_strict = None
                                    self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                    self._children_yang_names.add("prefix-sid-strict")

                                    self.security = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")
                                    self._segment_path = lambda: "name-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, ['interface_name', 'cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'running', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")
                                        self._segment_path = lambda: "bfd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")
                                        self._segment_path = lambda: "cost-fallback"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, ['cost', 'threshold'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "distribute-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")
                                        self._segment_path = lambda: "fast-reroute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, ['fast_reroute_enable'], name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")
                                            self._segment_path = lambda: "per-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")
                                            self._segment_path = lambda: "per-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                self.tiebreaker = YList(self)
                                                self._segment_path = lambda: "tiebreakers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                class Neighbors(Entity):
                                    """
                                    Neighbor router configuration information
                                    
                                    .. attribute:: neighbor
                                    
                                    	Router configuration information for a particular neighbor
                                    	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__init__()

                                        self.yang_name = "neighbors"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor)}

                                        self.neighbor = YList(self)
                                        self._segment_path = lambda: "neighbors"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, [], name, value)


                                    class Neighbor(Entity):
                                        """
                                        Router configuration information for a
                                        particular neighbor
                                        
                                        .. attribute:: neighbor_address  <key>
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: cost
                                        
                                        	OSPF cost for point\-to\-multipoint neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: database_filter
                                        
                                        	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: poll_interval
                                        
                                        	OSPF dead router poll\-interval in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        	**default value**\: 40
                                        
                                        .. attribute:: priority
                                        
                                        	OSPF priority of non\-broadcast neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                            self.yang_name = "neighbor"
                                            self.yang_parent_name = "neighbors"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                                            self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                            self.priority = YLeaf(YType.uint32, "priority")
                                            self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                                class PrefixSid(Entity):
                                    """
                                    Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__init__()

                                        self.yang_name = "prefix-sid"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")
                                        self._segment_path = lambda: "prefix-sid"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                class PrefixSidStrict(Entity):
                                    """
                                    Strict Prefix SID
                                    
                                    .. attribute:: explicit_null
                                    
                                    	Force Penultimate Hop To Send Explicit\-Null Label
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: n_flag_clear
                                    
                                    	Not a node SID
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: sid_value
                                    
                                    	SID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..1048575
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: type
                                    
                                    	OSPF SID Type
                                    	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                        self.yang_name = "prefix-sid-strict"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                        self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                        self.sid_value = YLeaf(YType.uint32, "sid-value")

                                        self.type = YLeaf(YType.enumeration, "type")
                                        self._segment_path = lambda: "prefix-sid-strict"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "name-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl)}
                                        self._child_list_classes = {}

                                        self.ttl = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")
                                        self._segment_path = lambda: "security"


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")
                                            self._segment_path = lambda: "ttl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                        class Nssa(Entity):
                            """
                            Specify area as a NSSA area
                            
                            .. attribute:: default_info_originate
                            
                            	Originate Type 7 default into NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: metric_type
                            
                            	OSPF External metric type
                            	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                            
                            	**default value**\: type2
                            
                            .. attribute:: no_redistribution
                            
                            	No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: no_summary
                            
                            	Do not send summary LSA into NSSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: nssa_def_metric
                            
                            	OSPF default metric
                            	**type**\:  int
                            
                            	**range:** 1..16777214
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa, self).__init__()

                                self.yang_name = "nssa"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                self.no_summary = YLeaf(YType.boolean, "no-summary")

                                self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")
                                self._segment_path = lambda: "nssa"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.Nssa, ['default_info_originate', 'metric_type', 'no_redistribution', 'no_summary', 'nssa_def_metric'], name, value)


                        class ShamLinkScopes(Entity):
                            """
                            Sham Link scope configurations
                            
                            .. attribute:: sham_link_scope
                            
                            	Sham Link configuration
                            	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__init__()

                                self.yang_name = "sham-link-scopes"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"sham-link-scope" : ("sham_link_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope)}

                                self.sham_link_scope = YList(self)
                                self._segment_path = lambda: "sham-link-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes, [], name, value)


                            class ShamLinkScope(Entity):
                                """
                                Sham Link configuration
                                
                                .. attribute:: source_address  <key>
                                
                                	Address of the local sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: destination_address  <key>
                                
                                	Address of the remote sham\-link endpoint
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: source
                                
                                	Address of the local sham\-link endpoint. Enter an IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__init__()

                                    self.yang_name = "sham-link-scope"
                                    self.yang_parent_name = "sham-link-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal)}
                                    self._child_list_classes = {}

                                    self.source_address = YLeaf(YType.str, "source-address")

                                    self.destination_address = YLeaf(YType.str, "destination-address")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.source = YLeaf(YType.str, "source")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")
                                    self._segment_path = lambda: "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, ['source_address', 'destination_address', 'cost', 'hello_interval', 'retransmit_interval', 'running', 'source', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "sham-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "sham-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                        class VirtualLinkScopes(Entity):
                            """
                            Virtual Link scope configurations
                            
                            .. attribute:: virtual_link_scope
                            
                            	Virtual Link configuration
                            	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__init__()

                                self.yang_name = "virtual-link-scopes"
                                self.yang_parent_name = "area-area-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"virtual-link-scope" : ("virtual_link_scope", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope)}

                                self.virtual_link_scope = YList(self)
                                self._segment_path = lambda: "virtual-link-scopes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, [], name, value)


                            class VirtualLinkScope(Entity):
                                """
                                Virtual Link configuration
                                
                                .. attribute:: address  <key>
                                
                                	Router ID of virtual link neighbor
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: running
                                
                                	Enable routing on an IP network
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                    self.yang_name = "virtual-link-scope"
                                    self.yang_parent_name = "virtual-link-scopes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal)}
                                    self._child_list_classes = {}

                                    self.address = YLeaf(YType.str, "address")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.running = YLeaf(YType.empty, "running")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")
                                    self._segment_path = lambda: "virtual-link-scope" + "[address='" + self.address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, ['address', 'hello_interval', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "virtual-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "virtual-link-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                class AutoCost(Entity):
                    """
                    Controls automatic cost based on bandwidth
                    
                    .. attribute:: bandwidth
                    
                    	The reference bandwidth in terms of Mbits per second
                    	**type**\:  int
                    
                    	**range:** 1..4294967
                    
                    	**units**\: Mbit/s
                    
                    	**default value**\: 100
                    
                    .. attribute:: disable
                    
                    	Disabling auto costing
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AutoCost, self).__init__()

                        self.yang_name = "auto-cost"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.disable = YLeaf(YType.boolean, "disable")
                        self._segment_path = lambda: "auto-cost"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AutoCost, ['bandwidth', 'disable'], name, value)


                class DefaultInformation(Entity):
                    """
                    Control distribution of default information
                    
                    .. attribute:: always_advertise
                    
                    	Always advertise default route
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: metric
                    
                    	OSPF metric
                    	**type**\:  int
                    
                    	**range:** 1..16777214
                    
                    	**default value**\: 1
                    
                    .. attribute:: metric_type
                    
                    	OSPF External metric type
                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                    
                    	**default value**\: type2
                    
                    .. attribute:: route_policy_name
                    
                    	Routing policy name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.DefaultInformation, self).__init__()

                        self.yang_name = "default-information"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.always_advertise = YLeaf(YType.boolean, "always-advertise")

                        self.metric = YLeaf(YType.uint32, "metric")

                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                        self._segment_path = lambda: "default-information"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.DefaultInformation, ['always_advertise', 'metric', 'metric_type', 'route_policy_name'], name, value)


                class Distance(Entity):
                    """
                    Administrative distance configuration
                    
                    .. attribute:: admin_distance
                    
                    	Define an administrative distance
                    	**type**\:  int
                    
                    	**range:** 1..255
                    
                    	**default value**\: 110
                    
                    .. attribute:: ip_distances
                    
                    	IP specific administrative distance configuration
                    	**type**\:   :py:class:`IpDistances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance.IpDistances>`
                    
                    .. attribute:: ospf_distance
                    
                    	OSPF distance configuration
                    	**type**\:   :py:class:`OspfDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Distance, self).__init__()

                        self.yang_name = "distance"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ip-distances" : ("ip_distances", Ospf.Processes.Process.DefaultVrf.Distance.IpDistances), "ospf-distance" : ("ospf_distance", Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance)}
                        self._child_list_classes = {}

                        self.admin_distance = YLeaf(YType.uint32, "admin-distance")

                        self.ip_distances = Ospf.Processes.Process.DefaultVrf.Distance.IpDistances()
                        self.ip_distances.parent = self
                        self._children_name_map["ip_distances"] = "ip-distances"
                        self._children_yang_names.add("ip-distances")

                        self.ospf_distance = Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance()
                        self.ospf_distance.parent = self
                        self._children_name_map["ospf_distance"] = "ospf-distance"
                        self._children_yang_names.add("ospf-distance")
                        self._segment_path = lambda: "distance"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Distance, ['admin_distance'], name, value)


                    class IpDistances(Entity):
                        """
                        IP specific administrative distance
                        configuration
                        
                        .. attribute:: ip_distance
                        
                        	Administrative distance configuration for a particular IP address
                        	**type**\: list of    :py:class:`IpDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances, self).__init__()

                            self.yang_name = "ip-distances"
                            self.yang_parent_name = "distance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ip-distance" : ("ip_distance", Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance)}

                            self.ip_distance = YList(self)
                            self._segment_path = lambda: "ip-distances"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances, [], name, value)


                        class IpDistance(Entity):
                            """
                            Administrative distance configuration for a
                            particular IP address
                            
                            .. attribute:: address  <key>
                            
                            	IP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: wildcard  <key>
                            
                            	IP wild card bits \-\- inverted mask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: access_list_name
                            
                            	Access Control List name
                            	**type**\:  str
                            
                            .. attribute:: distance
                            
                            	Administrative distance
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance, self).__init__()

                                self.yang_name = "ip-distance"
                                self.yang_parent_name = "ip-distances"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.address = YLeaf(YType.str, "address")

                                self.wildcard = YLeaf(YType.str, "wildcard")

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.distance = YLeaf(YType.uint32, "distance")
                                self._segment_path = lambda: "ip-distance" + "[address='" + self.address.get() + "']" + "[wildcard='" + self.wildcard.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Distance.IpDistances.IpDistance, ['address', 'wildcard', 'access_list_name', 'distance'], name, value)


                    class OspfDistance(Entity):
                        """
                        OSPF distance configuration
                        
                        .. attribute:: external_routes
                        
                        	Distance for external type 5 and type 7 routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        .. attribute:: inter_area
                        
                        	Distance for inter\-area routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        .. attribute:: intra_area
                        
                        	Distance for intra\-area routes
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance, self).__init__()

                            self.yang_name = "ospf-distance"
                            self.yang_parent_name = "distance"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.external_routes = YLeaf(YType.uint32, "external-routes")

                            self.inter_area = YLeaf(YType.uint32, "inter-area")

                            self.intra_area = YLeaf(YType.uint32, "intra-area")
                            self._segment_path = lambda: "ospf-distance"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Distance.OspfDistance, ['external_routes', 'inter_area', 'intra_area'], name, value)


                class FastReroute(Entity):
                    """
                    Fast\-reroute instance scoped parameters
                    
                    .. attribute:: per_link
                    
                    	Fast\-reroute per\-link global configuration
                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink>`
                    
                    .. attribute:: per_prefix
                    
                    	Fast\-reroute per\-prefix global configuration
                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.FastReroute, self).__init__()

                        self.yang_name = "fast-reroute"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix)}
                        self._child_list_classes = {}

                        self.per_link = Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink()
                        self.per_link.parent = self
                        self._children_name_map["per_link"] = "per-link"
                        self._children_yang_names.add("per-link")

                        self.per_prefix = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix()
                        self.per_prefix.parent = self
                        self._children_name_map["per_prefix"] = "per-prefix"
                        self._children_yang_names.add("per-prefix")
                        self._segment_path = lambda: "fast-reroute"


                    class PerLink(Entity):
                        """
                        Fast\-reroute per\-link global configuration
                        
                        .. attribute:: priority
                        
                        	Fast\-reroute per\-link/per\-prefix priority\-limit command
                        	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink, self).__init__()

                            self.yang_name = "per-link"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.priority = YLeaf(YType.enumeration, "priority")
                            self._segment_path = lambda: "per-link"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.PerLink, ['priority'], name, value)


                    class PerPrefix(Entity):
                        """
                        Fast\-reroute per\-prefix global configuration
                        
                        .. attribute:: load_sharing_disable
                        
                        	Disable load sharing between multiple backups
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: priority
                        
                        	Fast\-reroute per\-link/per\-prefix priority\-limit command
                        	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                        
                        .. attribute:: tiebreakers
                        
                        	Fast\-reroute tiebreakers configurations
                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix, self).__init__()

                            self.yang_name = "per-prefix"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"tiebreakers" : ("tiebreakers", Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers)}
                            self._child_list_classes = {}

                            self.load_sharing_disable = YLeaf(YType.empty, "load-sharing-disable")

                            self.priority = YLeaf(YType.enumeration, "priority")

                            self.tiebreakers = Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers()
                            self.tiebreakers.parent = self
                            self._children_name_map["tiebreakers"] = "tiebreakers"
                            self._children_yang_names.add("tiebreakers")
                            self._segment_path = lambda: "per-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix, ['load_sharing_disable', 'priority'], name, value)


                        class Tiebreakers(Entity):
                            """
                            Fast\-reroute tiebreakers configurations
                            
                            .. attribute:: tiebreaker
                            
                            	Fast\-reroute tiebreakers configuration
                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                self.yang_name = "tiebreakers"
                                self.yang_parent_name = "per-prefix"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                self.tiebreaker = YList(self)
                                self._segment_path = lambda: "tiebreakers"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                            class Tiebreaker(Entity):
                                """
                                Fast\-reroute tiebreakers configuration
                                
                                .. attribute:: tiebreaker_type  <key>
                                
                                	Tiebreaker type
                                	**type**\:   :py:class:`OspfFastRerouteTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakers>`
                                
                                .. attribute:: tiebreaker_index
                                
                                	Index value for a tiebreaker, 0 to disable
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                    self.yang_name = "tiebreaker"
                                    self.yang_parent_name = "tiebreakers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                class MaxLsa(Entity):
                    """
                    Set max\-lsa configuration
                    
                    .. attribute:: max_lsa_ignore_count
                    
                    	Set count on how many times adjacencies can be suppressed
                    	**type**\:  int
                    
                    	**range:** 1..4294967294
                    
                    .. attribute:: max_lsa_ignore_time
                    
                    	Set time during which all adjacencies are suppressed
                    	**type**\:  int
                    
                    	**range:** 1..35791394
                    
                    .. attribute:: max_lsa_limit
                    
                    	Set maximum number of non self\-generated LSAs
                    	**type**\:  int
                    
                    	**range:** 1..4294967294
                    
                    	**mandatory**\: True
                    
                    .. attribute:: max_lsa_reset_time
                    
                    	Set number of minutes after which ignore\-count is reset to zero
                    	**type**\:  int
                    
                    	**range:** 2..71582788
                    
                    	**units**\: minute
                    
                    .. attribute:: max_lsa_threshold
                    
                    	Set max\-lsa threshold for generating a warning message
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    .. attribute:: max_lsa_warning_only
                    
                    	Only give warning message when limit is exceeded
                    	**type**\:  bool
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MaxLsa, self).__init__()

                        self.yang_name = "max-lsa"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                        self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                        self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                        self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                        self.max_lsa_threshold = YLeaf(YType.uint32, "max-lsa-threshold")

                        self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")
                        self._segment_path = lambda: "max-lsa"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxLsa, ['max_lsa_ignore_count', 'max_lsa_ignore_time', 'max_lsa_limit', 'max_lsa_reset_time', 'max_lsa_threshold', 'max_lsa_warning_only'], name, value)


                class MaxMetric(Entity):
                    """
                    Set maximum metric configuration
                    
                    .. attribute:: max_metric_always
                    
                    	Set maximum metric always configuration
                    	**type**\:   :py:class:`MaxMetricAlways <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways>`
                    
                    .. attribute:: max_metric_no_abr_off
                    
                    	Block ABR\-disable mode entry while in max\-metric mode
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_metric_on_proc_migration
                    
                    	Set maximum metric on\-proc\-migration configuration
                    	**type**\:   :py:class:`MaxMetricOnProcMigration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration>`
                    
                    .. attribute:: max_metric_on_proc_restart
                    
                    	Set maximum metric on\-proc\-restart configuration
                    	**type**\:   :py:class:`MaxMetricOnProcRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart>`
                    
                    .. attribute:: max_metric_on_startup
                    
                    	Set maximum metric on\-startup configuration
                    	**type**\:   :py:class:`MaxMetricOnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup>`
                    
                    .. attribute:: max_metric_on_switchover
                    
                    	Set maximum metric on\-switchover configuration
                    	**type**\:   :py:class:`MaxMetricOnSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MaxMetric, self).__init__()

                        self.yang_name = "max-metric"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"max-metric-always" : ("max_metric_always", Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways), "max-metric-on-proc-migration" : ("max_metric_on_proc_migration", Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration), "max-metric-on-proc-restart" : ("max_metric_on_proc_restart", Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart), "max-metric-on-startup" : ("max_metric_on_startup", Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup), "max-metric-on-switchover" : ("max_metric_on_switchover", Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover)}
                        self._child_list_classes = {}

                        self.max_metric_no_abr_off = YLeaf(YType.empty, "max-metric-no-abr-off")

                        self.max_metric_always = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways()
                        self.max_metric_always.parent = self
                        self._children_name_map["max_metric_always"] = "max-metric-always"
                        self._children_yang_names.add("max-metric-always")

                        self.max_metric_on_proc_migration = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration()
                        self.max_metric_on_proc_migration.parent = self
                        self._children_name_map["max_metric_on_proc_migration"] = "max-metric-on-proc-migration"
                        self._children_yang_names.add("max-metric-on-proc-migration")

                        self.max_metric_on_proc_restart = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart()
                        self.max_metric_on_proc_restart.parent = self
                        self._children_name_map["max_metric_on_proc_restart"] = "max-metric-on-proc-restart"
                        self._children_yang_names.add("max-metric-on-proc-restart")

                        self.max_metric_on_startup = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup()
                        self.max_metric_on_startup.parent = self
                        self._children_name_map["max_metric_on_startup"] = "max-metric-on-startup"
                        self._children_yang_names.add("max-metric-on-startup")

                        self.max_metric_on_switchover = Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover()
                        self.max_metric_on_switchover.parent = self
                        self._children_name_map["max_metric_on_switchover"] = "max-metric-on-switchover"
                        self._children_yang_names.add("max-metric-on-switchover")
                        self._segment_path = lambda: "max-metric"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxMetric, ['max_metric_no_abr_off'], name, value)


                    class MaxMetricAlways(Entity):
                        """
                        Set maximum metric always configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways, self).__init__()

                            self.yang_name = "max-metric-always"
                            self.yang_parent_name = "max-metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")
                            self._segment_path = lambda: "max-metric-always"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricAlways, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'summary_lsa', 'summary_lsa_maximum_metric'], name, value)


                    class MaxMetricOnProcMigration(Entity):
                        """
                        Set maximum metric on\-proc\-migration
                        configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration, self).__init__()

                            self.yang_name = "max-metric-on-proc-migration"
                            self.yang_parent_name = "max-metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                            self._segment_path = lambda: "max-metric-on-proc-migration"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcMigration, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                    class MaxMetricOnProcRestart(Entity):
                        """
                        Set maximum metric on\-proc\-restart
                        configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart, self).__init__()

                            self.yang_name = "max-metric-on-proc-restart"
                            self.yang_parent_name = "max-metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                            self._segment_path = lambda: "max-metric-on-proc-restart"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnProcRestart, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                    class MaxMetricOnStartup(Entity):
                        """
                        Set maximum metric on\-startup configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup, self).__init__()

                            self.yang_name = "max-metric-on-startup"
                            self.yang_parent_name = "max-metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                            self._segment_path = lambda: "max-metric-on-startup"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnStartup, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                    class MaxMetricOnSwitchover(Entity):
                        """
                        Set maximum metric on\-switchover configuration
                        
                        .. attribute:: external_lsa
                        
                        	Override external\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: external_lsa_maximum_metric
                        
                        	Overriding metric in external\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: include_stub
                        
                        	Set maximum metric for stub links in router\-LSAs
                        	**type**\:  bool
                        
                        .. attribute:: startup_max
                        
                        	Time in seconds to originate router\-LSA with max\-metric
                        	**type**\:  int
                        
                        	**range:** 5..86400
                        
                        	**units**\: second
                        
                        .. attribute:: summary_lsa
                        
                        	Override summary\-lsa metric with max\-metric value
                        	**type**\:  bool
                        
                        .. attribute:: summary_lsa_maximum_metric
                        
                        	Overriding metric in summary\-LSAs (default 16711680)
                        	**type**\:  int
                        
                        	**range:** 1..16777215
                        
                        .. attribute:: wait_for_bgp
                        
                        	Let BGP decide when to originate router\-LSA with normal metric
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover, self).__init__()

                            self.yang_name = "max-metric-on-switchover"
                            self.yang_parent_name = "max-metric"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                            self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                            self.include_stub = YLeaf(YType.boolean, "include-stub")

                            self.startup_max = YLeaf(YType.uint32, "startup-max")

                            self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                            self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                            self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                            self._segment_path = lambda: "max-metric-on-switchover"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaxMetric.MaxMetricOnSwitchover, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                class MaximumRedistributePrefix(Entity):
                    """
                    Maximum number of prefixes redistributed into
                    OSPF
                    
                    .. attribute:: number_of_prefixes
                    
                    	Maximum number of prefixes redistributed
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: threshold
                    
                    	Threshold value (%) at which to generate a warning msg
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    .. attribute:: warning_only
                    
                    	Only give warning messsage when limit is exceeded
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix, self).__init__()

                        self.yang_name = "maximum-redistribute-prefix"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.number_of_prefixes = YLeaf(YType.uint32, "number-of-prefixes")

                        self.threshold = YLeaf(YType.uint32, "threshold")

                        self.warning_only = YLeaf(YType.boolean, "warning-only")
                        self._segment_path = lambda: "maximum-redistribute-prefix"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MaximumRedistributePrefix, ['number_of_prefixes', 'threshold', 'warning_only'], name, value)


                class Microloop(Entity):
                    """
                    Microloop configuration
                    
                    .. attribute:: avoidance
                    
                    	Microloop avoidance configuration
                    	**type**\:   :py:class:`Avoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Microloop, self).__init__()

                        self.yang_name = "microloop"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"avoidance" : ("avoidance", Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance)}
                        self._child_list_classes = {}

                        self.avoidance = Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance()
                        self.avoidance.parent = self
                        self._children_name_map["avoidance"] = "avoidance"
                        self._children_yang_names.add("avoidance")
                        self._segment_path = lambda: "microloop"


                    class Avoidance(Entity):
                        """
                        Microloop avoidance configuration
                        
                        .. attribute:: enable
                        
                        	MicroLoop avoidance feature enable configuration
                        	**type**\:   :py:class:`OspfUloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfUloopAvoidance>`
                        
                        	**default value**\: all
                        
                        .. attribute:: rib_update_delay
                        
                        	Delay to introduce between SPF and RIB update in msecs
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 5000
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance, self).__init__()

                            self.yang_name = "avoidance"
                            self.yang_parent_name = "microloop"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.enable = YLeaf(YType.enumeration, "enable")

                            self.rib_update_delay = YLeaf(YType.uint32, "rib-update-delay")
                            self._segment_path = lambda: "avoidance"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Microloop.Avoidance, ['enable', 'rib_update_delay'], name, value)


                class MonitorConvergence(Entity):
                    """
                    Enable convergence monitoring
                    
                    .. attribute:: enable
                    
                    	Enable convergence monitoring
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prefix_list
                    
                    	Enable the monitoring of individual prefixes (prefix list name)
                    	**type**\:  str
                    
                    .. attribute:: track_external_routes
                    
                    	Enable the monitoring of External routes
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: track_ip_frr
                    
                    	Enable the Tracking of IP\-Frr Convergence
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: track_summary_routes
                    
                    	Enable the monitoring of Summary routes
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MonitorConvergence, self).__init__()

                        self.yang_name = "monitor-convergence"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.enable = YLeaf(YType.empty, "enable")

                        self.prefix_list = YLeaf(YType.str, "prefix-list")

                        self.track_external_routes = YLeaf(YType.empty, "track-external-routes")

                        self.track_ip_frr = YLeaf(YType.empty, "track-ip-frr")

                        self.track_summary_routes = YLeaf(YType.empty, "track-summary-routes")
                        self._segment_path = lambda: "monitor-convergence"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MonitorConvergence, ['enable', 'prefix_list', 'track_external_routes', 'track_ip_frr', 'track_summary_routes'], name, value)


                class Mpls(Entity):
                    """
                    Configure MPLS routing protocol parameters
                    
                    .. attribute:: autoroute_exclude
                    
                    	Exclude IP destinations from using TE tunnels
                    	**type**\:  str
                    
                    .. attribute:: igp_intact
                    
                    	Enable igp\-intact mode in OSPF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ldp_sync_update
                    
                    	Enable LDP sync induced metric propagation
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: mpls_router_id
                    
                    	MPLS\-TE stable loopback address for this OSPF process.Enter either as IP Address or Interface name, but not both. Unused field must be nil
                    	**type**\:   :py:class:`MplsRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId>`
                    
                    .. attribute:: multicast_intact
                    
                    	Enable multicast\-intact mode in OSPF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Mpls, self).__init__()

                        self.yang_name = "mpls"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"mpls-router-id" : ("mpls_router_id", Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId)}
                        self._child_list_classes = {}

                        self.autoroute_exclude = YLeaf(YType.str, "autoroute-exclude")

                        self.igp_intact = YLeaf(YType.empty, "igp-intact")

                        self.ldp_sync_update = YLeaf(YType.empty, "ldp-sync-update")

                        self.multicast_intact = YLeaf(YType.empty, "multicast-intact")

                        self.mpls_router_id = Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId()
                        self.mpls_router_id.parent = self
                        self._children_name_map["mpls_router_id"] = "mpls-router-id"
                        self._children_yang_names.add("mpls-router-id")
                        self._segment_path = lambda: "mpls"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Mpls, ['autoroute_exclude', 'igp_intact', 'ldp_sync_update', 'multicast_intact'], name, value)


                    class MplsRouterId(Entity):
                        """
                        MPLS\-TE stable loopback address for this
                        OSPF process.Enter either as IP Address or
                        Interface name, but not both. Unused field
                        must be nil
                        
                        .. attribute:: address
                        
                        	MPLS\-TE stable IP address for this OSPF process
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_name
                        
                        	MPLS\-TE stable loopback interface for this OSPF process
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId, self).__init__()

                            self.yang_name = "mpls-router-id"
                            self.yang_parent_name = "mpls"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.interface_name = YLeaf(YType.str, "interface-name")
                            self._segment_path = lambda: "mpls-router-id"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Mpls.MplsRouterId, ['address', 'interface_name'], name, value)


                class Nsf(Entity):
                    """
                    Non Stop Forwarding configuration
                    
                    .. attribute:: cisco
                    
                    	Enable Cisco Non Stop Forwarding
                    	**type**\:   :py:class:`OspfCiscoNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfCiscoNsf>`
                    
                    .. attribute:: flush_delay_time
                    
                    	Maximum time allowed for external route learning (seconds)
                    	**type**\:  int
                    
                    	**range:** 1..3600
                    
                    	**units**\: second
                    
                    	**default value**\: 60
                    
                    .. attribute:: ietf
                    
                    	Enable IETF Non Stop Forwarding
                    	**type**\:   :py:class:`OspfIetfNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsf>`
                    
                    .. attribute:: ietf_strict_lsa_checking
                    
                    	Enable Strict LSA checking of IETF NSF
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ietf_support_role
                    
                    	Disable helper support role for IETF Non Stop Forwarding
                    	**type**\:   :py:class:`OspfIetfNsfSupport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsfSupport>`
                    
                    .. attribute:: interval
                    
                    	Minimum interval between Non Stop Forwarding restarts in seconds
                    	**type**\:  int
                    
                    	**range:** 90..3600
                    
                    	**units**\: second
                    
                    	**default value**\: 90
                    
                    .. attribute:: lifetime
                    
                    	Maximum route lifetime following restart in seconds
                    	**type**\:  int
                    
                    	**range:** 90..1800
                    
                    	**units**\: second
                    
                    	**default value**\: 90
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Nsf, self).__init__()

                        self.yang_name = "nsf"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.cisco = YLeaf(YType.enumeration, "cisco")

                        self.flush_delay_time = YLeaf(YType.uint32, "flush-delay-time")

                        self.ietf = YLeaf(YType.enumeration, "ietf")

                        self.ietf_strict_lsa_checking = YLeaf(YType.empty, "ietf-strict-lsa-checking")

                        self.ietf_support_role = YLeaf(YType.enumeration, "ietf-support-role")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")
                        self._segment_path = lambda: "nsf"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Nsf, ['cisco', 'flush_delay_time', 'ietf', 'ietf_strict_lsa_checking', 'ietf_support_role', 'interval', 'lifetime'], name, value)


                class OutgoingRouteUpdates(Entity):
                    """
                    Filter outgoing routing updates
                    
                    .. attribute:: outgoing_route_update
                    
                    	Filter outgoing routing updates for a particular protocol
                    	**type**\: list of    :py:class:`OutgoingRouteUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates, self).__init__()

                        self.yang_name = "outgoing-route-updates"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"outgoing-route-update" : ("outgoing_route_update", Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate)}

                        self.outgoing_route_update = YList(self)
                        self._segment_path = lambda: "outgoing-route-updates"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates, [], name, value)


                    class OutgoingRouteUpdate(Entity):
                        """
                        Filter outgoing routing updates for a
                        particular protocol
                        
                        .. attribute:: protocol_name  <key>
                        
                        	Distribute list protocol type
                        	**type**\:   :py:class:`OspfDistListProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDistListProtocol>`
                        
                        .. attribute:: access_list_name
                        
                        	Access Control List name
                        	**type**\:  str
                        
                        .. attribute:: as_xx
                        
                        	First half of BGP AS number in XX.YY format.  Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_yy
                        
                        	Second half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ospf_process_name
                        
                        	OSPF process name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__init__()

                            self.yang_name = "outgoing-route-update"
                            self.yang_parent_name = "outgoing-route-updates"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                            self.as_xx = YLeaf(YType.uint32, "as-xx")

                            self.as_yy = YLeaf(YType.uint32, "as-yy")

                            self.ospf_process_name = YLeaf(YType.str, "ospf-process-name")
                            self._segment_path = lambda: "outgoing-route-update" + "[protocol-name='" + self.protocol_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.OutgoingRouteUpdates.OutgoingRouteUpdate, ['protocol_name', 'access_list_name', 'as_xx', 'as_yy', 'ospf_process_name'], name, value)


                class ProcessScope(Entity):
                    """
                    Process scope configuration
                    
                    .. attribute:: authentication
                    
                    	Authentication
                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication>`
                    
                    .. attribute:: bfd
                    
                    	BFD configuration
                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd>`
                    
                    .. attribute:: cost
                    
                    	Interface cost
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: cost_fallback
                    
                    	Interface fallback cost
                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback>`
                    
                    .. attribute:: database_filter
                    
                    	Filter OSPF LSA during synchronization and flooding
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: dead_interval_minimal
                    
                    	Interval after which a neighbor is declared dead
                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal>`
                    
                    .. attribute:: demand_circuit
                    
                    	Enable/Disable OSPF demand circuit
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: distribute_list
                    
                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: external_out
                    
                    	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                    	**type**\:  bool
                    
                    .. attribute:: fast_reroute
                    
                    	Fast\-reroute configuration
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute>`
                    
                    .. attribute:: flood_reduction
                    
                    	Enable/Disable OSPF flood reduction
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: hello_interval
                    
                    	Interval between HELLO packets in seconds
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    .. attribute:: ldp_auto_config
                    
                    	Enable MPLS LDP Auto Config
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ldp_sync
                    
                    	Enable/Disable MPLS LDP sync
                    	**type**\:  bool
                    
                    .. attribute:: ldp_sync_igp_shortcuts
                    
                    	Enable/Disable MPLS LDP sync for igp\-shortcuts
                    	**type**\:  bool
                    
                    .. attribute:: link_down_fast_detect
                    
                    	Enable/Disable registration for early interface down notifications
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: loopback_stub_network
                    
                    	Enable/Disable advertising loopback as a stub network
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: mtu_ignore
                    
                    	Enable/Disable ignoring of MTU in DBD packets
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: network_type
                    
                    	Type of attached network
                    	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                    
                    .. attribute:: packet_size
                    
                    	Customize size of OSPF packets upto MTU
                    	**type**\:  int
                    
                    	**range:** 576..10000
                    
                    .. attribute:: passive
                    
                    	When enabled, prevent sending HELLO packets over link
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: prefix_suppression_primary
                    
                    	Enable/Disable prefix suppression for primary addresses
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: prefix_suppression_secondary
                    
                    	Enable/Disable prefix suppression for secondary addresses
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: priority
                    
                    	Router priority for DR and BDR election
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**default value**\: 1
                    
                    .. attribute:: retransmit_interval
                    
                    	Time in seconds between retransmitting lost link state advertisements
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    	**default value**\: 5
                    
                    .. attribute:: security
                    
                    	Container class for security related configuration parameters
                    	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Security>`
                    
                    .. attribute:: segment_routing
                    
                    	segment\-routing configuration Applicable only in Default VRF
                    	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                    
                    .. attribute:: segment_routing_forwarding
                    
                    	segment\-routing forwarding configuration Applicableonly in Default VRF
                    	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                    
                    .. attribute:: srgb
                    
                    	Segment Routing Global Block configuration
                    	**type**\:   :py:class:`Srgb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: summary_in
                    
                    	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                    	**type**\:  bool
                    
                    .. attribute:: transmit_delay
                    
                    	Number of seconds to delay transmission of LSAs
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**units**\: second
                    
                    	**default value**\: 1
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope, self).__init__()

                        self.yang_name = "process-scope"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute), "security" : ("security", Ospf.Processes.Process.DefaultVrf.ProcessScope.Security), "srgb" : ("srgb", Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb)}
                        self._child_list_classes = {}

                        self.cost = YLeaf(YType.uint32, "cost")

                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                        self.external_out = YLeaf(YType.boolean, "external-out")

                        self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                        self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                        self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                        self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                        self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                        self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                        self.network_type = YLeaf(YType.enumeration, "network-type")

                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                        self.passive = YLeaf(YType.boolean, "passive")

                        self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                        self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                        self.priority = YLeaf(YType.uint32, "priority")

                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                        self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                        self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                        self.summary_in = YLeaf(YType.boolean, "summary-in")

                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                        self.authentication = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication()
                        self.authentication.parent = self
                        self._children_name_map["authentication"] = "authentication"
                        self._children_yang_names.add("authentication")

                        self.bfd = Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd()
                        self.bfd.parent = self
                        self._children_name_map["bfd"] = "bfd"
                        self._children_yang_names.add("bfd")

                        self.cost_fallback = Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback()
                        self.cost_fallback.parent = self
                        self._children_name_map["cost_fallback"] = "cost-fallback"
                        self._children_yang_names.add("cost-fallback")

                        self.dead_interval_minimal = Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal()
                        self.dead_interval_minimal.parent = self
                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                        self._children_yang_names.add("dead-interval-minimal")

                        self.distribute_list = None
                        self._children_name_map["distribute_list"] = "distribute-list"
                        self._children_yang_names.add("distribute-list")

                        self.fast_reroute = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                        self._children_yang_names.add("fast-reroute")

                        self.security = Ospf.Processes.Process.DefaultVrf.ProcessScope.Security()
                        self.security.parent = self
                        self._children_name_map["security"] = "security"
                        self._children_yang_names.add("security")

                        self.srgb = None
                        self._children_name_map["srgb"] = "srgb"
                        self._children_yang_names.add("srgb")
                        self._segment_path = lambda: "process-scope"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope, ['cost', 'database_filter', 'demand_circuit', 'external_out', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'segment_routing', 'segment_routing_forwarding', 'summary_in', 'transmit_delay'], name, value)


                    class Authentication(Entity):
                        """
                        Authentication
                        
                        .. attribute:: key
                        
                        	Authentication key configuration
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: message_digest_keies
                        
                        	Message digest authentication password (key) configurations, first 16 chars used
                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies>`
                        
                        .. attribute:: type
                        
                        	Authentication type
                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication, self).__init__()

                            self.yang_name = "authentication"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type)}
                            self._child_list_classes = {}

                            self.key = YLeaf(YType.str, "key")

                            self.message_digest_keies = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies()
                            self.message_digest_keies.parent = self
                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                            self._children_yang_names.add("message-digest-keies")

                            self.type = Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type()
                            self.type.parent = self
                            self._children_name_map["type"] = "type"
                            self._children_yang_names.add("type")
                            self._segment_path = lambda: "authentication"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication, ['key'], name, value)


                        class MessageDigestKeies(Entity):
                            """
                            Message digest authentication password (key)
                            configurations, first 16 chars used
                            
                            .. attribute:: message_digest_key
                            
                            	Message digest authentication password (key) configuration
                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies, self).__init__()

                                self.yang_name = "message-digest-keies"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                self.message_digest_key = YList(self)
                                self._segment_path = lambda: "message-digest-keies"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies, [], name, value)


                            class MessageDigestKey(Entity):
                                """
                                Message digest authentication password (key)
                                configuration
                                
                                .. attribute:: key_id  <key>
                                
                                	Key ID
                                	**type**\:  int
                                
                                	**range:** 1..255
                                
                                .. attribute:: password
                                
                                	Password
                                	**type**\:  str
                                
                                	**pattern:** (!.+)\|([^!].+)
                                
                                	**mandatory**\: True
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                    self.yang_name = "message-digest-key"
                                    self.yang_parent_name = "message-digest-keies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                    self.password = YLeaf(YType.str, "password")
                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                        class Type(Entity):
                            """
                            Authentication type
                            
                            .. attribute:: authen_type
                            
                            	Authentication type code 
                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                            
                            .. attribute:: keychain_authen_type
                            
                            	Keychain authentication type
                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                            
                            .. attribute:: keychain_name
                            
                            	Keychain name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type, self).__init__()

                                self.yang_name = "type"
                                self.yang_parent_name = "authentication"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                self._segment_path = lambda: "type"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                    class Bfd(Entity):
                        """
                        BFD configuration
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection multiplier for BFD sessions created by OSPF
                        	**type**\:  int
                        
                        	**range:** 2..50
                        
                        .. attribute:: fast_detect_mode
                        
                        	 use of Bidirectional Forwarding Detection
                        	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                        
                        .. attribute:: interval
                        
                        	Hello interval for BFD sessions created by OSPF
                        	**type**\:  int
                        
                        	**range:** 3..30000
                        
                        	**units**\: millisecond
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd, self).__init__()

                            self.yang_name = "bfd"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                            self.interval = YLeaf(YType.uint32, "interval")
                            self._segment_path = lambda: "bfd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                    class CostFallback(Entity):
                        """
                        Interface fallback cost
                        
                        .. attribute:: cost
                        
                        	Fallback cost of link
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: threshold
                        
                        	Bandwidth threshold
                        	**type**\:  int
                        
                        	**range:** 1..4294967
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback, self).__init__()

                            self.yang_name = "cost-fallback"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.cost = YLeaf(YType.uint32, "cost")

                            self.threshold = YLeaf(YType.uint32, "threshold")
                            self._segment_path = lambda: "cost-fallback"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.CostFallback, ['cost', 'threshold'], name, value)


                    class DeadIntervalMinimal(Entity):
                        """
                        Interval after which a neighbor is declared dead
                        
                        .. attribute:: interval
                        
                        	Interval size in seconds after which a neighbor is declared dead
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: multiplier
                        
                        	Number of Hellos in one second
                        	**type**\:  int
                        
                        	**range:** 3..20
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal, self).__init__()

                            self.yang_name = "dead-interval-minimal"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.interval = YLeaf(YType.uint32, "interval")

                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                            self._segment_path = lambda: "dead-interval-minimal"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                    class DistributeList(Entity):
                        """
                        Filter networks intalled to RIB (disable as ACL
                        name means filtering is disabled)
                        
                        .. attribute:: access_list_name
                        
                        	Access Control List name
                        	**type**\:  str
                        
                        .. attribute:: route_policy_name
                        
                        	Route Policy name
                        	**type**\:  str
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList, self).__init__()

                            self.yang_name = "distribute-list"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                            self._segment_path = lambda: "distribute-list"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                    class FastReroute(Entity):
                        """
                        Fast\-reroute configuration
                        
                        .. attribute:: fast_reroute_enable
                        
                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                        	**type**\:   :py:class:`OspfProcFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFastReroute>`
                        
                        .. attribute:: per_link
                        
                        	Fast\-reroute per\-link configuration
                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink>`
                        
                        .. attribute:: per_prefix
                        
                        	Fast\-reroute per\-prefix configuration
                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix)}
                            self._child_list_classes = {}

                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                            self.per_link = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink()
                            self.per_link.parent = self
                            self._children_name_map["per_link"] = "per-link"
                            self._children_yang_names.add("per-link")

                            self.per_prefix = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._children_yang_names.add("per-prefix")
                            self._segment_path = lambda: "fast-reroute"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute, ['fast_reroute_enable'], name, value)


                        class PerLink(Entity):
                            """
                            Fast\-reroute per\-link configuration
                            
                            .. attribute:: candidate_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces>`
                            
                            .. attribute:: exclude_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces>`
                            
                            .. attribute:: fast_reroute_use_candidate_only
                            
                            	Use only interfaces on the candidate list as a backup path
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink, self).__init__()

                                self.yang_name = "per-link"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces)}
                                self._child_list_classes = {}

                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                self.candidate_interfaces.parent = self
                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                self._children_yang_names.add("candidate-interfaces")

                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                self._children_yang_names.add("exclude-interfaces")
                                self._segment_path = lambda: "per-link"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                            class CandidateInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix candidate
                                interface configuration
                                
                                .. attribute:: candidate_interface
                                
                                	Candidate backup interface
                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                    self.yang_name = "candidate-interfaces"
                                    self.yang_parent_name = "per-link"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                    self.candidate_interface = YList(self)
                                    self._segment_path = lambda: "candidate-interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                class CandidateInterface(Entity):
                                    """
                                    Candidate backup interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                        self.yang_name = "candidate-interface"
                                        self.yang_parent_name = "candidate-interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                            class ExcludeInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                interface configuration
                                
                                .. attribute:: exclude_interface
                                
                                	Exclude an interface from becoming a backup or UCMP
                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                    self.yang_name = "exclude-interfaces"
                                    self.yang_parent_name = "per-link"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                    self.exclude_interface = YList(self)
                                    self._segment_path = lambda: "exclude-interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                class ExcludeInterface(Entity):
                                    """
                                    Exclude an interface from becoming a backup or
                                    UCMP
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                        self.yang_name = "exclude-interface"
                                        self.yang_parent_name = "exclude-interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                        class PerPrefix(Entity):
                            """
                            Fast\-reroute per\-prefix configuration
                            
                            .. attribute:: candidate_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces>`
                            
                            .. attribute:: exclude_interfaces
                            
                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                            
                            .. attribute:: fast_reroute_use_candidate_only
                            
                            	Use only interfaces on the candidate list as a backup path
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: remote_lfa
                            
                            	Remote LFA configuration
                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa>`
                            
                            .. attribute:: topology_independent_lfa
                            
                            	Topology Independet LFA configuration
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa)}
                                self._child_list_classes = {}

                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                self.candidate_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                self.candidate_interfaces.parent = self
                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                self._children_yang_names.add("candidate-interfaces")

                                self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                self.exclude_interfaces.parent = self
                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                self._children_yang_names.add("exclude-interfaces")

                                self.remote_lfa = Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa()
                                self.remote_lfa.parent = self
                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                self._children_yang_names.add("remote-lfa")
                                self._segment_path = lambda: "per-prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                            class CandidateInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix candidate
                                interface configuration
                                
                                .. attribute:: candidate_interface
                                
                                	Candidate backup interface
                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                    self.yang_name = "candidate-interfaces"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                    self.candidate_interface = YList(self)
                                    self._segment_path = lambda: "candidate-interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                class CandidateInterface(Entity):
                                    """
                                    Candidate backup interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                        self.yang_name = "candidate-interface"
                                        self.yang_parent_name = "candidate-interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                            class ExcludeInterfaces(Entity):
                                """
                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                interface configuration
                                
                                .. attribute:: exclude_interface
                                
                                	Exclude an interface from becoming a backup or UCMP
                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                    self.yang_name = "exclude-interfaces"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                    self.exclude_interface = YList(self)
                                    self._segment_path = lambda: "exclude-interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                class ExcludeInterface(Entity):
                                    """
                                    Exclude an interface from becoming a backup or
                                    UCMP
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                        self.yang_name = "exclude-interface"
                                        self.yang_parent_name = "exclude-interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                            class RemoteLfa(Entity):
                                """
                                Remote LFA configuration
                                
                                .. attribute:: maximum_cost
                                
                                	Maximum path cost to remote LFA
                                	**type**\:  int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: tunnel
                                
                                	Enable/Disable remote LFA computation
                                	**type**\:   :py:class:`OspfProcFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFrrRlfaTunnel>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                    self.yang_name = "remote-lfa"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                    self._segment_path = lambda: "remote-lfa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                    class Security(Entity):
                        """
                        Container class for security related
                        configuration parameters
                        
                        .. attribute:: ttl
                        
                        	Enabling turns on TTL security
                        	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security, self).__init__()

                            self.yang_name = "security"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl)}
                            self._child_list_classes = {}

                            self.ttl = Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl()
                            self.ttl.parent = self
                            self._children_name_map["ttl"] = "ttl"
                            self._children_yang_names.add("ttl")
                            self._segment_path = lambda: "security"


                        class Ttl(Entity):
                            """
                            Enabling turns on TTL security
                            
                            .. attribute:: enable
                            
                            	Enable TTL security
                            	**type**\:  bool
                            
                            .. attribute:: hop_count
                            
                            	Hop count
                            	**type**\:  int
                            
                            	**range:** 1..254
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl, self).__init__()

                                self.yang_name = "ttl"
                                self.yang_parent_name = "security"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.enable = YLeaf(YType.boolean, "enable")

                                self.hop_count = YLeaf(YType.uint32, "hop-count")
                                self._segment_path = lambda: "ttl"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                    class Srgb(Entity):
                        """
                        Segment Routing Global Block configuration
                        
                        .. attribute:: lower_bound
                        
                        	The lower bound of the SRGB
                        	**type**\:  int
                        
                        	**range:** 16000..1048575
                        
                        	**mandatory**\: True
                        
                        .. attribute:: upper_bound
                        
                        	The upper bound of the SRGB
                        	**type**\:  int
                        
                        	**range:** 16000..1048575
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb, self).__init__()

                            self.yang_name = "srgb"
                            self.yang_parent_name = "process-scope"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.lower_bound = YLeaf(YType.uint32, "lower-bound")

                            self.upper_bound = YLeaf(YType.uint32, "upper-bound")
                            self._segment_path = lambda: "srgb"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessScope.Srgb, ['lower_bound', 'upper_bound'], name, value)


                class Queue(Entity):
                    """
                    Adjust OSPF input queue sizes and processing
                    quantums
                    
                    .. attribute:: dispatch_incoming
                    
                    	Maximum number of continuous incoming packet\-related events processed
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 300
                    
                    .. attribute:: dispatch_rate_limited
                    
                    	Maximum number of continuous rate\-limited LSAs processed
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 150
                    
                    .. attribute:: dispatch_rate_limited_flush
                    
                    	Maximum number of continuous rate\-limited LSAs processed for FLUSH
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 150
                    
                    .. attribute:: dispatch_spf_lsa_limit
                    
                    	Maximum number of continuous summary or external LSAs processed
                    	**type**\:  int
                    
                    	**range:** 30..3000
                    
                    	**default value**\: 150
                    
                    .. attribute:: limit_high
                    
                    	Hello events are dropped when incoming event queue exceeds this
                    	**type**\:  int
                    
                    	**range:** 1000..30000
                    
                    	**default value**\: 9500
                    
                    .. attribute:: limit_low
                    
                    	DBDs/Updates are dropped when incoming event queue exceeds this
                    	**type**\:  int
                    
                    	**range:** 1000..30000
                    
                    	**default value**\: 8000
                    
                    .. attribute:: limit_medium
                    
                    	LSA ACKs are dropped when incoming event queue exceeds this
                    	**type**\:  int
                    
                    	**range:** 1000..30000
                    
                    	**default value**\: 9000
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Queue, self).__init__()

                        self.yang_name = "queue"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.dispatch_incoming = YLeaf(YType.uint32, "dispatch-incoming")

                        self.dispatch_rate_limited = YLeaf(YType.uint32, "dispatch-rate-limited")

                        self.dispatch_rate_limited_flush = YLeaf(YType.uint32, "dispatch-rate-limited-flush")

                        self.dispatch_spf_lsa_limit = YLeaf(YType.uint32, "dispatch-spf-lsa-limit")

                        self.limit_high = YLeaf(YType.uint32, "limit-high")

                        self.limit_low = YLeaf(YType.uint32, "limit-low")

                        self.limit_medium = YLeaf(YType.uint32, "limit-medium")
                        self._segment_path = lambda: "queue"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Queue, ['dispatch_incoming', 'dispatch_rate_limited', 'dispatch_rate_limited_flush', 'dispatch_spf_lsa_limit', 'limit_high', 'limit_low', 'limit_medium'], name, value)


                class Redistribution(Entity):
                    """
                    Redistribute configurations
                    
                    .. attribute:: redistributes
                    
                    	Redistribute information from another routing protocol
                    	**type**\:   :py:class:`Redistributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Redistribution, self).__init__()

                        self.yang_name = "redistribution"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"redistributes" : ("redistributes", Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes)}
                        self._child_list_classes = {}

                        self.redistributes = Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes()
                        self.redistributes.parent = self
                        self._children_name_map["redistributes"] = "redistributes"
                        self._children_yang_names.add("redistributes")
                        self._segment_path = lambda: "redistribution"


                    class Redistributes(Entity):
                        """
                        Redistribute information from another routing
                        protocol
                        
                        .. attribute:: redistribute
                        
                        	Redistribute information from another routing protocol
                        	**type**\: list of    :py:class:`Redistribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes, self).__init__()

                            self.yang_name = "redistributes"
                            self.yang_parent_name = "redistribution"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redistribute" : ("redistribute", Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute)}

                            self.redistribute = YList(self)
                            self._segment_path = lambda: "redistributes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes, [], name, value)


                        class Redistribute(Entity):
                            """
                            Redistribute information from another routing
                            protocol
                            
                            .. attribute:: protocol_name  <key>
                            
                            	Distribute list protocol type
                            	**type**\:   :py:class:`OspfRedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistProtocol>`
                            
                            .. attribute:: application_or_isis_or_ospf
                            
                            	application or isis or ospf
                            	**type**\: list of    :py:class:`ApplicationOrIsisOrOspf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf>`
                            
                            .. attribute:: bgp
                            
                            	bgp
                            	**type**\: list of    :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp>`
                            
                            .. attribute:: connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip
                            
                            	connected or static or dagr or subscriber or mobile or rip
                            	**type**\:   :py:class:`ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: eigrp
                            
                            	eigrp
                            	**type**\: list of    :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute, self).__init__()

                                self.yang_name = "redistribute"
                                self.yang_parent_name = "redistributes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip" : ("connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip", Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip)}
                                self._child_list_classes = {"application-or-isis-or-ospf" : ("application_or_isis_or_ospf", Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf), "bgp" : ("bgp", Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp), "eigrp" : ("eigrp", Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp)}

                                self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                                self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip = None
                                self._children_name_map["connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip"] = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                self._children_yang_names.add("connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip")

                                self.application_or_isis_or_ospf = YList(self)
                                self.bgp = YList(self)
                                self.eigrp = YList(self)
                                self._segment_path = lambda: "redistribute" + "[protocol-name='" + self.protocol_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute, ['protocol_name'], name, value)


                            class ApplicationOrIsisOrOspf(Entity):
                                """
                                application or isis or ospf
                                
                                .. attribute:: instance_name  <key>
                                
                                	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__init__()

                                    self.yang_name = "application-or-isis-or-ospf"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.uint32, "tag")
                                    self._segment_path = lambda: "application-or-isis-or-ospf" + "[instance-name='" + self.instance_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, ['instance_name', 'bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                            class Bgp(Entity):
                                """
                                bgp
                                
                                .. attribute:: instance_name  <key>
                                
                                	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: as_xx  <key>
                                
                                	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_yy  <key>
                                
                                	Second half of BGP AS number in XX.YY format . Mandatory if Protocol is BGP or EIGRP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp, self).__init__()

                                    self.yang_name = "bgp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.as_yy = YLeaf(YType.uint32, "as-yy")

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.uint32, "tag")
                                    self._segment_path = lambda: "bgp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Bgp, ['instance_name', 'as_xx', 'as_yy', 'bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                            class ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip(Entity):
                                """
                                connected or static or dagr or subscriber or
                                mobile or rip
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__init__()

                                    self.yang_name = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.uint32, "tag")
                                    self._segment_path = lambda: "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, ['bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                            class Eigrp(Entity):
                                """
                                eigrp
                                
                                .. attribute:: instance_name  <key>
                                
                                	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: as_xx  <key>
                                
                                	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: bgp_preserve_default_info
                                
                                	Preserve Metric and Metric Type of BGP Default Route
                                	**type**\:  bool
                                
                                .. attribute:: bgp_preserve_med
                                
                                	Preserve MED of BGP routes
                                	**type**\:  bool
                                
                                .. attribute:: classful
                                
                                	Disallow subnetting
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: default_redistributed_route_metric
                                
                                	Default metric for routes being redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                .. attribute:: eigrp_route_type
                                
                                	EIGRP route type
                                	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                
                                .. attribute:: isis_levels
                                
                                	Levels of ISIS routes
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: metric_type
                                
                                	Set OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                .. attribute:: ospf_external
                                
                                	OSPF external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_internal
                                
                                	OSPF\_Internal route type
                                	**type**\:  bool
                                
                                .. attribute:: ospf_nssa_level
                                
                                	OSPF NSSA external route types
                                	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                
                                .. attribute:: ospf_redist_lsa_type
                                
                                	LSA type for redistributed routes
                                	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                
                                	**default value**\: external
                                
                                .. attribute:: ospfnssa_only
                                
                                	Only redistribute to NSSA areas
                                	**type**\:  bool
                                
                                .. attribute:: route_policy_name
                                
                                	Routing policy name
                                	**type**\:  str
                                
                                .. attribute:: tag
                                
                                	Set tag for routes redistributed into OSPF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__init__()

                                    self.yang_name = "eigrp"
                                    self.yang_parent_name = "redistribute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                    self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                    self.classful = YLeaf(YType.boolean, "classful")

                                    self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                    self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                    self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                    self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                    self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                    self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                    self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                    self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                    self.tag = YLeaf(YType.uint32, "tag")
                                    self._segment_path = lambda: "eigrp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Redistribution.Redistributes.Redistribute.Eigrp, ['instance_name', 'as_xx', 'bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                class SegmentRouting(Entity):
                    """
                    Segment Routing instance scoped parameters
                    
                    .. attribute:: prefix_sid_map_advertise_local
                    
                    	Enable advertisement of local SRMS entries
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: prefix_sid_map_receive_disable
                    
                    	Disable prefix\-SID mapping client
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: sr_prefer
                    
                    	Prefer segment routing labels over LDP labels
                    	**type**\:   :py:class:`SrPrefer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer>`
                    
                    .. attribute:: strict_spf_disable
                    
                    	Strict\-SPF support and SID advertisement
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.SegmentRouting, self).__init__()

                        self.yang_name = "segment-routing"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sr-prefer" : ("sr_prefer", Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer)}
                        self._child_list_classes = {}

                        self.prefix_sid_map_advertise_local = YLeaf(YType.empty, "prefix-sid-map-advertise-local")

                        self.prefix_sid_map_receive_disable = YLeaf(YType.empty, "prefix-sid-map-receive-disable")

                        self.strict_spf_disable = YLeaf(YType.empty, "strict-spf-disable")

                        self.sr_prefer = Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer()
                        self.sr_prefer.parent = self
                        self._children_name_map["sr_prefer"] = "sr-prefer"
                        self._children_yang_names.add("sr-prefer")
                        self._segment_path = lambda: "segment-routing"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SegmentRouting, ['prefix_sid_map_advertise_local', 'prefix_sid_map_receive_disable', 'strict_spf_disable'], name, value)


                    class SrPrefer(Entity):
                        """
                        Prefer segment routing labels over LDP
                        labels
                        
                        .. attribute:: enable
                        
                        	Enable SR labels to be preferred over LDP labels
                        	**type**\:  bool
                        
                        .. attribute:: prefix_list_name
                        
                        	Name of the Prefix List
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer, self).__init__()

                            self.yang_name = "sr-prefer"
                            self.yang_parent_name = "segment-routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.enable = YLeaf(YType.boolean, "enable")

                            self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")
                            self._segment_path = lambda: "sr-prefer"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SegmentRouting.SrPrefer, ['enable', 'prefix_list_name'], name, value)


                class SummaryPrefixes(Entity):
                    """
                    Configure IP prefix summary
                    
                    .. attribute:: netmask
                    
                    	keys\: netmask
                    	**type**\: list of    :py:class:`Netmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask>`
                    
                    .. attribute:: prefix
                    
                    	keys\: prefix
                    	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix>`
                    
                    .. attribute:: prefix_and_netmask
                    
                    	keys\: prefix, netmask
                    	**type**\: list of    :py:class:`PrefixAndNetmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask>`
                    
                    .. attribute:: summary_prefix_data
                    
                    	Data container
                    	**type**\:   :py:class:`SummaryPrefixData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__init__()

                        self.yang_name = "summary-prefixes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"summary-prefix-data" : ("summary_prefix_data", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData)}
                        self._child_list_classes = {"netmask" : ("netmask", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask), "prefix" : ("prefix", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix), "prefix-and-netmask" : ("prefix_and_netmask", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask)}

                        self.summary_prefix_data = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData()
                        self.summary_prefix_data.parent = self
                        self._children_name_map["summary_prefix_data"] = "summary-prefix-data"
                        self._children_yang_names.add("summary-prefix-data")

                        self.netmask = YList(self)
                        self.prefix = YList(self)
                        self.prefix_and_netmask = YList(self)
                        self._segment_path = lambda: "summary-prefixes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, [], name, value)


                    class Netmask(Entity):
                        """
                        keys\: netmask
                        
                        .. attribute:: netmask  <key>
                        
                        	Summary netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask, self).__init__()

                            self.yang_name = "netmask"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.uint32, "tag")
                            self._segment_path = lambda: "netmask" + "[netmask='" + self.netmask.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Netmask, ['netmask', 'not_advertise', 'tag'], name, value)


                    class Prefix(Entity):
                        """
                        keys\: prefix
                        
                        .. attribute:: prefix  <key>
                        
                        	IP summary prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix, self).__init__()

                            self.yang_name = "prefix"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.uint32, "tag")
                            self._segment_path = lambda: "prefix" + "[prefix='" + self.prefix.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.Prefix, ['prefix', 'not_advertise', 'tag'], name, value)


                    class PrefixAndNetmask(Entity):
                        """
                        keys\: prefix, netmask
                        
                        .. attribute:: prefix  <key>
                        
                        	IP summary prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: netmask  <key>
                        
                        	Summary netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask, self).__init__()

                            self.yang_name = "prefix-and-netmask"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.uint32, "tag")
                            self._segment_path = lambda: "prefix-and-netmask" + "[prefix='" + self.prefix.get() + "']" + "[netmask='" + self.netmask.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.PrefixAndNetmask, ['prefix', 'netmask', 'not_advertise', 'tag'], name, value)


                    class SummaryPrefixData(Entity):
                        """
                        Data container.
                        
                        .. attribute:: not_advertise
                        
                        	Do not advertise when translating OSPF type\-7 LSA
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: tag
                        
                        	32\-bit tag value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData, self).__init__()

                            self.yang_name = "summary-prefix-data"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                            self.tag = YLeaf(YType.uint32, "tag")
                            self._segment_path = lambda: "summary-prefix-data"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefixData, ['not_advertise', 'tag'], name, value)


                class Timers(Entity):
                    """
                    Adjust routing timers
                    
                    .. attribute:: fast_reroute_timer
                    
                    	Number of ms between end of SPF and start of IPFRR computation
                    	**type**\:  int
                    
                    	**range:** 50..600000
                    
                    	**units**\: millisecond
                    
                    	**default value**\: 500
                    
                    .. attribute:: lsa_generation_timer
                    
                    	OSPF LSA timers (in milliseconds)
                    	**type**\:   :py:class:`LsaGenerationTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer>`
                    
                    .. attribute:: lsa_group_pacing
                    
                    	LSA group pacing timer (Seconds between group of LSAs being refreshed or maxaged)
                    	**type**\:  int
                    
                    	**range:** 10..1800
                    
                    	**units**\: second
                    
                    	**default value**\: 240
                    
                    .. attribute:: lsa_min_arrival
                    
                    	MinLSArrival timer (minimum interval in milliseconds between accepting the same LSA)
                    	**type**\:  int
                    
                    	**range:** 0..600000
                    
                    	**units**\: millisecond
                    
                    	**default value**\: 100
                    
                    .. attribute:: lsa_pacing_flood
                    
                    	Seconds between group of LSAs being refreshed or maxaged
                    	**type**\:  int
                    
                    	**range:** 5..100
                    
                    	**units**\: second
                    
                    .. attribute:: lsa_refresh
                    
                    	How often self\-originated LSAs should be refreshed
                    	**type**\:  int
                    
                    	**range:** 1800..2700
                    
                    	**units**\: second
                    
                    	**default value**\: 1800
                    
                    .. attribute:: spf_timer
                    
                    	OSPF SPF timers (in milliseconds)
                    	**type**\:   :py:class:`SpfTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Timers, self).__init__()

                        self.yang_name = "timers"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"lsa-generation-timer" : ("lsa_generation_timer", Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer), "spf-timer" : ("spf_timer", Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer)}
                        self._child_list_classes = {}

                        self.fast_reroute_timer = YLeaf(YType.uint32, "fast-reroute-timer")

                        self.lsa_group_pacing = YLeaf(YType.uint32, "lsa-group-pacing")

                        self.lsa_min_arrival = YLeaf(YType.uint32, "lsa-min-arrival")

                        self.lsa_pacing_flood = YLeaf(YType.uint32, "lsa-pacing-flood")

                        self.lsa_refresh = YLeaf(YType.uint32, "lsa-refresh")

                        self.lsa_generation_timer = Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer()
                        self.lsa_generation_timer.parent = self
                        self._children_name_map["lsa_generation_timer"] = "lsa-generation-timer"
                        self._children_yang_names.add("lsa-generation-timer")

                        self.spf_timer = Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer()
                        self.spf_timer.parent = self
                        self._children_name_map["spf_timer"] = "spf-timer"
                        self._children_yang_names.add("spf-timer")
                        self._segment_path = lambda: "timers"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Timers, ['fast_reroute_timer', 'lsa_group_pacing', 'lsa_min_arrival', 'lsa_pacing_flood', 'lsa_refresh'], name, value)


                    class LsaGenerationTimer(Entity):
                        """
                        OSPF LSA timers (in milliseconds)
                        
                        .. attribute:: backoff_increment
                        
                        	Number of milliseconds delay between successive LSA builds
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 200
                        
                        .. attribute:: initial_delay
                        
                        	Number of milliseconds before generating first LSA
                        	**type**\:  int
                        
                        	**range:** 0..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 50
                        
                        .. attribute:: max_delay
                        
                        	Max number of milliseconds between consecutive LSA builds 
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 200
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer, self).__init__()

                            self.yang_name = "lsa-generation-timer"
                            self.yang_parent_name = "timers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                            self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                            self.max_delay = YLeaf(YType.uint32, "max-delay")
                            self._segment_path = lambda: "lsa-generation-timer"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Timers.LsaGenerationTimer, ['backoff_increment', 'initial_delay', 'max_delay'], name, value)


                    class SpfTimer(Entity):
                        """
                        OSPF SPF timers (in milliseconds)
                        
                        .. attribute:: backoff_increment
                        
                        	Number of milliseconds delay between successive SPF runs
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 10000
                        
                        .. attribute:: initial_delay
                        
                        	Number of milliseconds before first SPF run
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 5000
                        
                        .. attribute:: max_delay
                        
                        	Max number of milliseconds between consecutive SPF calculations
                        	**type**\:  int
                        
                        	**range:** 1..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 10000
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer, self).__init__()

                            self.yang_name = "spf-timer"
                            self.yang_parent_name = "timers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                            self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                            self.max_delay = YLeaf(YType.uint32, "max-delay")
                            self._segment_path = lambda: "spf-timer"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Timers.SpfTimer, ['backoff_increment', 'initial_delay', 'max_delay'], name, value)


                class Ucmp(Entity):
                    """
                    Unequal Cost Multi\-ptah configuration
                    
                    .. attribute:: delay_interval
                    
                    	Delay in msecs between primary SPF and UCMP computation
                    	**type**\:  int
                    
                    	**range:** 1..5000
                    
                    	**units**\: millisecond
                    
                    	**default value**\: 100
                    
                    .. attribute:: enable
                    
                    	UCMP feature enable configuration
                    	**type**\:   :py:class:`Enable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp.Enable>`
                    
                    .. attribute:: exclude_interfaces
                    
                    	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                    	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Ucmp, self).__init__()

                        self.yang_name = "ucmp"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"enable" : ("enable", Ospf.Processes.Process.DefaultVrf.Ucmp.Enable), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces)}
                        self._child_list_classes = {}

                        self.delay_interval = YLeaf(YType.uint32, "delay-interval")

                        self.enable = Ospf.Processes.Process.DefaultVrf.Ucmp.Enable()
                        self.enable.parent = self
                        self._children_name_map["enable"] = "enable"
                        self._children_yang_names.add("enable")

                        self.exclude_interfaces = Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces()
                        self.exclude_interfaces.parent = self
                        self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                        self._children_yang_names.add("exclude-interfaces")
                        self._segment_path = lambda: "ucmp"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Ucmp, ['delay_interval'], name, value)


                    class Enable(Entity):
                        """
                        UCMP feature enable configuration
                        
                        .. attribute:: prefix_list_name
                        
                        	Name of the Prefix List
                        	**type**\:  str
                        
                        .. attribute:: variance
                        
                        	Value of variance
                        	**type**\:  int
                        
                        	**range:** 101..10000
                        
                        	**default value**\: 200
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Ucmp.Enable, self).__init__()

                            self.yang_name = "enable"
                            self.yang_parent_name = "ucmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                            self.variance = YLeaf(YType.uint32, "variance")
                            self._segment_path = lambda: "enable"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Ucmp.Enable, ['prefix_list_name', 'variance'], name, value)


                    class ExcludeInterfaces(Entity):
                        """
                        Fast\-reroute per\-link/per\-prefix or UCMP exclude
                        interface configuration
                        
                        .. attribute:: exclude_interface
                        
                        	Exclude an interface from becoming a backup or UCMP
                        	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces, self).__init__()

                            self.yang_name = "exclude-interfaces"
                            self.yang_parent_name = "ucmp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface)}

                            self.exclude_interface = YList(self)
                            self._segment_path = lambda: "exclude-interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces, [], name, value)


                        class ExcludeInterface(Entity):
                            """
                            Exclude an interface from becoming a backup or
                            UCMP
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                self.yang_name = "exclude-interface"
                                self.yang_parent_name = "exclude-interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.interface_name = YLeaf(YType.str, "interface-name")
                                self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Ucmp.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


            class Distribute(Entity):
                """
                Enable distribution of link\-state database
                services
                
                .. attribute:: instance_id
                
                	Instance ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: throttle
                
                	Seconds
                	**type**\:  int
                
                	**range:** 1..3600
                
                	**units**\: second
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-07-14'

                def __init__(self):
                    super(Ospf.Processes.Process.Distribute, self).__init__()

                    self.yang_name = "distribute"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.instance_id = YLeaf(YType.uint32, "instance-id")

                    self.throttle = YLeaf(YType.uint32, "throttle")
                    self._segment_path = lambda: "distribute"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospf.Processes.Process.Distribute, ['instance_id', 'throttle'], name, value)


            class GracefulShutdownTimers(Entity):
                """
                Adjust routing timers
                
                .. attribute:: graceful_shutdown_initial_delay
                
                	Number of seconds to delay before beginning graceful shutdown
                	**type**\:  int
                
                	**range:** 0..90
                
                	**units**\: second
                
                	**default value**\: 5
                
                .. attribute:: graceful_shutdown_retain_routes
                
                	Time to keep OSPF routes active after graceful shutdown(in seconds)
                	**type**\:  int
                
                	**range:** 0..90
                
                	**units**\: second
                
                	**default value**\: 5
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-07-14'

                def __init__(self):
                    super(Ospf.Processes.Process.GracefulShutdownTimers, self).__init__()

                    self.yang_name = "graceful-shutdown-timers"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.graceful_shutdown_initial_delay = YLeaf(YType.uint32, "graceful-shutdown-initial-delay")

                    self.graceful_shutdown_retain_routes = YLeaf(YType.uint32, "graceful-shutdown-retain-routes")
                    self._segment_path = lambda: "graceful-shutdown-timers"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospf.Processes.Process.GracefulShutdownTimers, ['graceful_shutdown_initial_delay', 'graceful_shutdown_retain_routes'], name, value)


            class Snmp(Entity):
                """
                OSPF SNMP configuration
                
                .. attribute:: trap_rate_limit
                
                	Per OSPF process SNMP trap rate\-limit
                	**type**\:   :py:class:`TrapRateLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Snmp.TrapRateLimit>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-07-14'

                def __init__(self):
                    super(Ospf.Processes.Process.Snmp, self).__init__()

                    self.yang_name = "snmp"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"trap-rate-limit" : ("trap_rate_limit", Ospf.Processes.Process.Snmp.TrapRateLimit)}
                    self._child_list_classes = {}

                    self.trap_rate_limit = None
                    self._children_name_map["trap_rate_limit"] = "trap-rate-limit"
                    self._children_yang_names.add("trap-rate-limit")
                    self._segment_path = lambda: "snmp"


                class TrapRateLimit(Entity):
                    """
                    Per OSPF process SNMP trap rate\-limit
                    
                    .. attribute:: max_window_traps
                    
                    	Max number of traps to send in window time
                    	**type**\:  int
                    
                    	**range:** 0..300
                    
                    	**mandatory**\: True
                    
                    .. attribute:: window_size
                    
                    	Trap rate limit sliding window size
                    	**type**\:  int
                    
                    	**range:** 2..60
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.Snmp.TrapRateLimit, self).__init__()

                        self.yang_name = "trap-rate-limit"
                        self.yang_parent_name = "snmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.max_window_traps = YLeaf(YType.uint32, "max-window-traps")

                        self.window_size = YLeaf(YType.uint32, "window-size")
                        self._segment_path = lambda: "trap-rate-limit"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.Snmp.TrapRateLimit, ['max_window_traps', 'window_size'], name, value)


            class TraceBufs(Entity):
                """
                Configuration to change size of trace buffer
                
                .. attribute:: trace_buf
                
                	Changes the size of the specified trace buffer
                	**type**\: list of    :py:class:`TraceBuf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.TraceBufs.TraceBuf>`
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-07-14'

                def __init__(self):
                    super(Ospf.Processes.Process.TraceBufs, self).__init__()

                    self.yang_name = "trace-bufs"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"trace-buf" : ("trace_buf", Ospf.Processes.Process.TraceBufs.TraceBuf)}

                    self.trace_buf = YList(self)
                    self._segment_path = lambda: "trace-bufs"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospf.Processes.Process.TraceBufs, [], name, value)


                class TraceBuf(Entity):
                    """
                    Changes the size of the specified trace
                    buffer
                    
                    .. attribute:: trace_buf_name  <key>
                    
                    	Name for this trace buffer
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: bufsize
                    
                    	Buffer size
                    	**type**\:   :py:class:`OspfTraceBufSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfTraceBufSize>`
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.TraceBufs.TraceBuf, self).__init__()

                        self.yang_name = "trace-buf"
                        self.yang_parent_name = "trace-bufs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.trace_buf_name = YLeaf(YType.str, "trace-buf-name")

                        self.bufsize = YLeaf(YType.enumeration, "bufsize")
                        self._segment_path = lambda: "trace-buf" + "[trace-buf-name='" + self.trace_buf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.TraceBufs.TraceBuf, ['trace_buf_name', 'bufsize'], name, value)


            class Vrfs(Entity):
                """
                VRF related configuration
                
                .. attribute:: vrf
                
                	Configuration for a particular OSPF vrf
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv4-ospf-cfg'
                _revision = '2017-07-14'

                def __init__(self):
                    super(Ospf.Processes.Process.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"vrf" : ("vrf", Ospf.Processes.Process.Vrfs.Vrf)}

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospf.Processes.Process.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Configuration for a particular OSPF vrf
                    
                    .. attribute:: vrf_name  <key>
                    
                    	Name for this vrf
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: adjacency_changes
                    
                    	Log changes in adjacency state
                    	**type**\:   :py:class:`OspfLogAdj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLogAdj>`
                    
                    .. attribute:: adjacency_stagger
                    
                    	Staggering OSPF adjacency bring up
                    	**type**\:   :py:class:`AdjacencyStagger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger>`
                    
                    .. attribute:: af
                    
                    	OSPF address family
                    	**type**\:   :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Af>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: area_addresses
                    
                    	Area configuration
                    	**type**\:   :py:class:`AreaAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses>`
                    
                    .. attribute:: auto_cost
                    
                    	Controls automatic cost based on bandwidth
                    	**type**\:   :py:class:`AutoCost <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AutoCost>`
                    
                    .. attribute:: default_information
                    
                    	Control distribution of default information
                    	**type**\:   :py:class:`DefaultInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation>`
                    
                    .. attribute:: default_metric
                    
                    	Set default metric of redistributed routes
                    	**type**\:  int
                    
                    	**range:** 1..16777214
                    
                    	**default value**\: 1
                    
                    .. attribute:: disable_dn_bit_check
                    
                    	Disable DN bit check
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: distance
                    
                    	Administrative distance configuration
                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance>`
                    
                    .. attribute:: domain_id
                    
                    	OSPF Domain ID
                    	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId>`
                    
                    .. attribute:: domain_tag
                    
                    	32 bit Domain tag value
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: fast_reroute
                    
                    	Fast\-reroute instance scoped parameters
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute>`
                    
                    .. attribute:: ignore_mospf
                    
                    	Ignore MOSPF (Type 6) LSAs
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: max_lsa
                    
                    	Set max\-lsa configuration
                    	**type**\:   :py:class:`MaxLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxLsa>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: max_metric
                    
                    	Set maximum metric configuration
                    	**type**\:   :py:class:`MaxMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric>`
                    
                    .. attribute:: maximum_interfaces
                    
                    	Max number of interfaces allowed to be configured
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    	**default value**\: 1024
                    
                    .. attribute:: maximum_paths
                    
                    	Forward packets over multiple paths (number of paths)
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    .. attribute:: maximum_redistribute_prefix
                    
                    	Maximum number of prefixes redistributed into OSPF
                    	**type**\:   :py:class:`MaximumRedistributePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix>`
                    
                    .. attribute:: microloop
                    
                    	Microloop configuration
                    	**type**\:   :py:class:`Microloop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Microloop>`
                    
                    .. attribute:: no_opaque
                    
                    	Disable opaque LSAs
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: nsf
                    
                    	Non Stop Forwarding configuration
                    	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Nsf>`
                    
                    .. attribute:: outgoing_route_updates
                    
                    	Filter outgoing routing updates
                    	**type**\:   :py:class:`OutgoingRouteUpdates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates>`
                    
                    .. attribute:: process_scope
                    
                    	Process scope configuration
                    	**type**\:   :py:class:`ProcessScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope>`
                    
                    .. attribute:: queue
                    
                    	Adjust OSPF input queue sizes and processing quantums
                    	**type**\:   :py:class:`Queue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Queue>`
                    
                    .. attribute:: redistribution
                    
                    	Redistribute configurations
                    	**type**\:   :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution>`
                    
                    .. attribute:: router_id
                    
                    	Router ID for this OSPF process. Enter an IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: snmp_context
                    
                    	OSPF SNMP context configuration
                    	**type**\:  str
                    
                    .. attribute:: snmp_trap_enabled
                    
                    	Enable/disable OSPF SNMP trap
                    	**type**\:  bool
                    
                    	**default value**\: false
                    
                    .. attribute:: spf_prefix_priority
                    
                    	Configure a route\-policy for prioritizing RIB route install
                    	**type**\:  str
                    
                    .. attribute:: summary_prefixes
                    
                    	Configure IP prefix summary
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    .. attribute:: timers
                    
                    	Adjust routing timers
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Timers>`
                    
                    .. attribute:: type7
                    
                    	Prefer type7 externals over type5
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ucmp
                    
                    	Unequal Cost Multi\-ptah configuration
                    	**type**\:   :py:class:`Ucmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp>`
                    
                    .. attribute:: vrf_lite
                    
                    	VRF lite capability
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: vrf_start
                    
                    	Start OSPF VRF configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-cfg'
                    _revision = '2017-07-14'

                    def __init__(self):
                        super(Ospf.Processes.Process.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"adjacency-stagger" : ("adjacency_stagger", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger), "af" : ("af", Ospf.Processes.Process.Vrfs.Vrf.Af), "area-addresses" : ("area_addresses", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses), "auto-cost" : ("auto_cost", Ospf.Processes.Process.Vrfs.Vrf.AutoCost), "default-information" : ("default_information", Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation), "distance" : ("distance", Ospf.Processes.Process.Vrfs.Vrf.Distance), "domain-id" : ("domain_id", Ospf.Processes.Process.Vrfs.Vrf.DomainId), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.FastReroute), "max-lsa" : ("max_lsa", Ospf.Processes.Process.Vrfs.Vrf.MaxLsa), "max-metric" : ("max_metric", Ospf.Processes.Process.Vrfs.Vrf.MaxMetric), "maximum-redistribute-prefix" : ("maximum_redistribute_prefix", Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix), "microloop" : ("microloop", Ospf.Processes.Process.Vrfs.Vrf.Microloop), "nsf" : ("nsf", Ospf.Processes.Process.Vrfs.Vrf.Nsf), "outgoing-route-updates" : ("outgoing_route_updates", Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates), "process-scope" : ("process_scope", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope), "queue" : ("queue", Ospf.Processes.Process.Vrfs.Vrf.Queue), "redistribution" : ("redistribution", Ospf.Processes.Process.Vrfs.Vrf.Redistribution), "summary-prefixes" : ("summary_prefixes", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes), "timers" : ("timers", Ospf.Processes.Process.Vrfs.Vrf.Timers), "ucmp" : ("ucmp", Ospf.Processes.Process.Vrfs.Vrf.Ucmp)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.adjacency_changes = YLeaf(YType.enumeration, "adjacency-changes")

                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                        self.disable_dn_bit_check = YLeaf(YType.empty, "disable-dn-bit-check")

                        self.domain_tag = YLeaf(YType.uint32, "domain-tag")

                        self.ignore_mospf = YLeaf(YType.empty, "ignore-mospf")

                        self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                        self.maximum_paths = YLeaf(YType.uint32, "maximum-paths")

                        self.no_opaque = YLeaf(YType.empty, "no-opaque")

                        self.router_id = YLeaf(YType.str, "router-id")

                        self.snmp_context = YLeaf(YType.str, "snmp-context")

                        self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                        self.spf_prefix_priority = YLeaf(YType.str, "spf-prefix-priority")

                        self.type7 = YLeaf(YType.empty, "type7")

                        self.vrf_lite = YLeaf(YType.empty, "vrf-lite")

                        self.vrf_start = YLeaf(YType.empty, "vrf-start")

                        self.adjacency_stagger = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger()
                        self.adjacency_stagger.parent = self
                        self._children_name_map["adjacency_stagger"] = "adjacency-stagger"
                        self._children_yang_names.add("adjacency-stagger")

                        self.af = None
                        self._children_name_map["af"] = "af"
                        self._children_yang_names.add("af")

                        self.area_addresses = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses()
                        self.area_addresses.parent = self
                        self._children_name_map["area_addresses"] = "area-addresses"
                        self._children_yang_names.add("area-addresses")

                        self.auto_cost = Ospf.Processes.Process.Vrfs.Vrf.AutoCost()
                        self.auto_cost.parent = self
                        self._children_name_map["auto_cost"] = "auto-cost"
                        self._children_yang_names.add("auto-cost")

                        self.default_information = Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation()
                        self.default_information.parent = self
                        self._children_name_map["default_information"] = "default-information"
                        self._children_yang_names.add("default-information")

                        self.distance = Ospf.Processes.Process.Vrfs.Vrf.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"
                        self._children_yang_names.add("distance")

                        self.domain_id = Ospf.Processes.Process.Vrfs.Vrf.DomainId()
                        self.domain_id.parent = self
                        self._children_name_map["domain_id"] = "domain-id"
                        self._children_yang_names.add("domain-id")

                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                        self._children_yang_names.add("fast-reroute")

                        self.max_lsa = None
                        self._children_name_map["max_lsa"] = "max-lsa"
                        self._children_yang_names.add("max-lsa")

                        self.max_metric = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric()
                        self.max_metric.parent = self
                        self._children_name_map["max_metric"] = "max-metric"
                        self._children_yang_names.add("max-metric")

                        self.maximum_redistribute_prefix = Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix()
                        self.maximum_redistribute_prefix.parent = self
                        self._children_name_map["maximum_redistribute_prefix"] = "maximum-redistribute-prefix"
                        self._children_yang_names.add("maximum-redistribute-prefix")

                        self.microloop = Ospf.Processes.Process.Vrfs.Vrf.Microloop()
                        self.microloop.parent = self
                        self._children_name_map["microloop"] = "microloop"
                        self._children_yang_names.add("microloop")

                        self.nsf = Ospf.Processes.Process.Vrfs.Vrf.Nsf()
                        self.nsf.parent = self
                        self._children_name_map["nsf"] = "nsf"
                        self._children_yang_names.add("nsf")

                        self.outgoing_route_updates = Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates()
                        self.outgoing_route_updates.parent = self
                        self._children_name_map["outgoing_route_updates"] = "outgoing-route-updates"
                        self._children_yang_names.add("outgoing-route-updates")

                        self.process_scope = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope()
                        self.process_scope.parent = self
                        self._children_name_map["process_scope"] = "process-scope"
                        self._children_yang_names.add("process-scope")

                        self.queue = Ospf.Processes.Process.Vrfs.Vrf.Queue()
                        self.queue.parent = self
                        self._children_name_map["queue"] = "queue"
                        self._children_yang_names.add("queue")

                        self.redistribution = Ospf.Processes.Process.Vrfs.Vrf.Redistribution()
                        self.redistribution.parent = self
                        self._children_name_map["redistribution"] = "redistribution"
                        self._children_yang_names.add("redistribution")

                        self.summary_prefixes = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        self._children_yang_names.add("summary-prefixes")

                        self.timers = Ospf.Processes.Process.Vrfs.Vrf.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._children_yang_names.add("timers")

                        self.ucmp = Ospf.Processes.Process.Vrfs.Vrf.Ucmp()
                        self.ucmp.parent = self
                        self._children_name_map["ucmp"] = "ucmp"
                        self._children_yang_names.add("ucmp")
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf, ['vrf_name', 'adjacency_changes', 'default_metric', 'disable_dn_bit_check', 'domain_tag', 'ignore_mospf', 'maximum_interfaces', 'maximum_paths', 'no_opaque', 'router_id', 'snmp_context', 'snmp_trap_enabled', 'spf_prefix_priority', 'type7', 'vrf_lite', 'vrf_start'], name, value)


                    class AdjacencyStagger(Entity):
                        """
                        Staggering OSPF adjacency bring up
                        
                        .. attribute:: disable
                        
                        	Disable OSPF adjacency stagger
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: initial_nbr
                        
                        	Adjacency Stagger\: Initial number of neighbors to bring up per area
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**default value**\: 2
                        
                        .. attribute:: max_nbr
                        
                        	Adjacency Stagger\: Subsequent simultaneous number of neighbors to bring up
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**default value**\: 64
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger, self).__init__()

                            self.yang_name = "adjacency-stagger"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.disable = YLeaf(YType.empty, "disable")

                            self.initial_nbr = YLeaf(YType.uint32, "initial-nbr")

                            self.max_nbr = YLeaf(YType.uint32, "max-nbr")
                            self._segment_path = lambda: "adjacency-stagger"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyStagger, ['disable', 'initial_nbr', 'max_nbr'], name, value)


                    class Af(Entity):
                        """
                        OSPF address family
                        
                        .. attribute:: af_name
                        
                        	Address family
                        	**type**\:   :py:class:`OspfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAddressFamily>`
                        
                        	**mandatory**\: True
                        
                        .. attribute:: saf_name
                        
                        	Sub\-Address family
                        	**type**\:   :py:class:`OspfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSubAddressFamily>`
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Af, self).__init__()

                            self.yang_name = "af"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.saf_name = YLeaf(YType.enumeration, "saf-name")
                            self._segment_path = lambda: "af"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Af, ['af_name', 'saf_name'], name, value)


                    class AreaAddresses(Entity):
                        """
                        Area configuration
                        
                        .. attribute:: area_address
                        
                        	Configuration for a particular area
                        	**type**\: list of    :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress>`
                        
                        .. attribute:: area_area_id
                        
                        	Configuration for a particular area
                        	**type**\: list of    :py:class:`AreaAreaId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses, self).__init__()

                            self.yang_name = "area-addresses"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area-address" : ("area_address", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress), "area-area-id" : ("area_area_id", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId)}

                            self.area_address = YList(self)
                            self.area_area_id = YList(self)
                            self._segment_path = lambda: "area-addresses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses, [], name, value)


                        class AreaAddress(Entity):
                            """
                            Configuration for a particular area
                            
                            .. attribute:: address  <key>
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_ranges
                            
                            	Summarize routes matching address/mask (border routers only)
                            	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges>`
                            
                            .. attribute:: area_scope
                            
                            	Area scope configuration
                            	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            	**default value**\: 1
                            
                            .. attribute:: external_out
                            
                            	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                            	**type**\:  bool
                            
                            .. attribute:: mpls_traffic_eng
                            
                            	Configure an OSPF area to run MPLS Traffic Engineering
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: multi_area_interface_scopes
                            
                            	Multi Area Interface scope configurations
                            	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes>`
                            
                            .. attribute:: name_scopes
                            
                            	Name scope configurations
                            	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes>`
                            
                            .. attribute:: nssa
                            
                            	Specify area as a NSSA area
                            	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa>`
                            
                            .. attribute:: route_policy_in
                            
                            	Configure a route policy for inbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: route_policy_out
                            
                            	Configure a route policy for outbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: running
                            
                            	Enable routing on an IP network
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: segment_routing
                            
                            	segment\-routing configuration Applicable only in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                            
                            .. attribute:: sham_link_scopes
                            
                            	Sham Link scope configurations
                            	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes>`
                            
                            .. attribute:: stub
                            
                            	Specify the area as a stub area (send summary LSA stub area)
                            	**type**\:  bool
                            
                            .. attribute:: summary_in
                            
                            	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_scopes
                            
                            	Virtual Link scope configurations
                            	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress, self).__init__()

                                self.yang_name = "area-address"
                                self.yang_parent_name = "area-addresses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"area-ranges" : ("area_ranges", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges), "area-scope" : ("area_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope), "multi-area-interface-scopes" : ("multi_area_interface_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes), "name-scopes" : ("name_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes), "nssa" : ("nssa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa), "sham-link-scopes" : ("sham_link_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes), "virtual-link-scopes" : ("virtual_link_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes)}
                                self._child_list_classes = {}

                                self.address = YLeaf(YType.str, "address")

                                self.default_cost = YLeaf(YType.uint32, "default-cost")

                                self.external_out = YLeaf(YType.boolean, "external-out")

                                self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                self.running = YLeaf(YType.empty, "running")

                                self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                                self.stub = YLeaf(YType.boolean, "stub")

                                self.summary_in = YLeaf(YType.boolean, "summary-in")

                                self.area_ranges = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges()
                                self.area_ranges.parent = self
                                self._children_name_map["area_ranges"] = "area-ranges"
                                self._children_yang_names.add("area-ranges")

                                self.area_scope = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope()
                                self.area_scope.parent = self
                                self._children_name_map["area_scope"] = "area-scope"
                                self._children_yang_names.add("area-scope")

                                self.multi_area_interface_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes()
                                self.multi_area_interface_scopes.parent = self
                                self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                self._children_yang_names.add("multi-area-interface-scopes")

                                self.name_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes()
                                self.name_scopes.parent = self
                                self._children_name_map["name_scopes"] = "name-scopes"
                                self._children_yang_names.add("name-scopes")

                                self.nssa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa()
                                self.nssa.parent = self
                                self._children_name_map["nssa"] = "nssa"
                                self._children_yang_names.add("nssa")

                                self.sham_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes()
                                self.sham_link_scopes.parent = self
                                self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                self._children_yang_names.add("sham-link-scopes")

                                self.virtual_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes()
                                self.virtual_link_scopes.parent = self
                                self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                self._children_yang_names.add("virtual-link-scopes")
                                self._segment_path = lambda: "area-address" + "[address='" + self.address.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress, ['address', 'default_cost', 'external_out', 'mpls_traffic_eng', 'route_policy_in', 'route_policy_out', 'running', 'segment_routing', 'stub', 'summary_in'], name, value)


                            class AreaRanges(Entity):
                                """
                                Summarize routes matching address/mask (border
                                routers only)
                                
                                .. attribute:: area_range
                                
                                	Ordering index
                                	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges, self).__init__()

                                    self.yang_name = "area-ranges"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-range" : ("area_range", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange)}

                                    self.area_range = YList(self)
                                    self._segment_path = lambda: "area-ranges"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges, [], name, value)


                                class AreaRange(Entity):
                                    """
                                    Ordering index
                                    
                                    .. attribute:: address  <key>
                                    
                                    	IP address to match
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: netmask  <key>
                                    
                                    	IP netmask for address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: not_advertise
                                    
                                    	Do not advertise this range
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, self).__init__()

                                        self.yang_name = "area-range"
                                        self.yang_parent_name = "area-ranges"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address = YLeaf(YType.str, "address")

                                        self.netmask = YLeaf(YType.str, "netmask")

                                        self.not_advertise = YLeaf(YType.boolean, "not-advertise")
                                        self._segment_path = lambda: "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaRanges.AreaRange, ['address', 'netmask', 'not_advertise'], name, value)


                            class AreaScope(Entity):
                                """
                                Area scope configuration
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope, self).__init__()

                                    self.yang_name = "area-scope"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute), "security" : ("security", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security)}
                                    self._child_list_classes = {}

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")
                                    self._segment_path = lambda: "area-scope"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope, ['cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")
                                        self._segment_path = lambda: "bfd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")
                                        self._segment_path = lambda: "cost-fallback"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.CostFallback, ['cost', 'threshold'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "distribute-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")
                                        self._segment_path = lambda: "fast-reroute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute, ['fast_reroute_enable'], name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")
                                            self._segment_path = lambda: "per-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")
                                            self._segment_path = lambda: "per-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                self.tiebreaker = YList(self)
                                                self._segment_path = lambda: "tiebreakers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl)}
                                        self._child_list_classes = {}

                                        self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")
                                        self._segment_path = lambda: "security"


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")
                                            self._segment_path = lambda: "ttl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.AreaScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                            class MultiAreaInterfaceScopes(Entity):
                                """
                                Multi Area Interface scope configurations
                                
                                .. attribute:: multi_area_interface_scope
                                
                                	Multi Area Interface configuration
                                	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, self).__init__()

                                    self.yang_name = "multi-area-interface-scopes"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"multi-area-interface-scope" : ("multi_area_interface_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope)}

                                    self.multi_area_interface_scope = YList(self)
                                    self._segment_path = lambda: "multi-area-interface-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes, [], name, value)


                                class MultiAreaInterfaceScope(Entity):
                                    """
                                    Multi Area Interface configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Multi Area Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                        self.yang_name = "multi-area-interface-scope"
                                        self.yang_parent_name = "multi-area-interface-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")
                                        self._segment_path = lambda: "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, ['interface_name', 'cost', 'database_filter', 'hello_interval', 'mtu_ignore', 'packet_size', 'passive', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")
                                            self._segment_path = lambda: "cost-fallback"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, ['cost', 'threshold'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "distribute-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")
                                            self._segment_path = lambda: "fast-reroute"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, ['fast_reroute_enable'], name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")
                                                self._segment_path = lambda: "per-link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")
                                                self._segment_path = lambda: "per-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                    self.tiebreaker = YList(self)
                                                    self._segment_path = lambda: "tiebreakers"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                        self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor)}

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "neighbors"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")
                                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                            class NameScopes(Entity):
                                """
                                Name scope configurations
                                
                                .. attribute:: name_scope
                                
                                	Name scope configuration
                                	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes, self).__init__()

                                    self.yang_name = "name-scopes"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"name-scope" : ("name_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope)}

                                    self.name_scope = YList(self)
                                    self._segment_path = lambda: "name-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes, [], name, value)


                                class NameScope(Entity):
                                    """
                                    Name scope configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication>`
                                    
                                    .. attribute:: bfd
                                    
                                    	BFD configuration
                                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	Enable/Disable OSPF demand circuit
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute>`
                                    
                                    .. attribute:: flood_reduction
                                    
                                    	Enable/Disable OSPF flood reduction
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ldp_auto_config
                                    
                                    	Enable MPLS LDP Auto Config
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ldp_sync
                                    
                                    	Enable/Disable MPLS LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_sync_igp_shortcuts
                                    
                                    	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                    	**type**\:  bool
                                    
                                    .. attribute:: link_down_fast_detect
                                    
                                    	Enable/Disable registration for early interface down notifications
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: loopback_stub_network
                                    
                                    	Enable/Disable advertising loopback as a stub network
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors>`
                                    
                                    .. attribute:: network_type
                                    
                                    	Type of attached network
                                    	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_sid
                                    
                                    	Prefix SID
                                    	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_sid_strict
                                    
                                    	Strict Prefix SID
                                    	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_suppression_primary
                                    
                                    	Enable/Disable prefix suppression for primary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_suppression_secondary
                                    
                                    	Enable/Disable prefix suppression for secondary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: priority
                                    
                                    	Router priority for DR and BDR election
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 1
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: security
                                    
                                    	Container class for security related configuration parameters
                                    	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security>`
                                    
                                    .. attribute:: segment_routing_forwarding
                                    
                                    	segment\-routing forwarding configuration Applicableonly in Default VRF
                                    	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope, self).__init__()

                                        self.yang_name = "name-scope"
                                        self.yang_parent_name = "name-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors), "prefix-sid" : ("prefix_sid", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid), "prefix-sid-strict" : ("prefix_sid_strict", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict), "security" : ("security", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                        self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                        self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                        self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                        self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                        self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                        self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                        self.priority = YLeaf(YType.uint32, "priority")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                        self._children_yang_names.add("bfd")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")

                                        self.prefix_sid = None
                                        self._children_name_map["prefix_sid"] = "prefix-sid"
                                        self._children_yang_names.add("prefix-sid")

                                        self.prefix_sid_strict = None
                                        self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                        self._children_yang_names.add("prefix-sid-strict")

                                        self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security()
                                        self.security.parent = self
                                        self._children_name_map["security"] = "security"
                                        self._children_yang_names.add("security")
                                        self._segment_path = lambda: "name-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope, ['interface_name', 'cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'running', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class Bfd(Entity):
                                        """
                                        BFD configuration
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	Detection multiplier for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 2..50
                                        
                                        .. attribute:: fast_detect_mode
                                        
                                        	 use of Bidirectional Forwarding Detection
                                        	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, self).__init__()

                                            self.yang_name = "bfd"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                            self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                            self.interval = YLeaf(YType.uint32, "interval")
                                            self._segment_path = lambda: "bfd"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")
                                            self._segment_path = lambda: "cost-fallback"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.CostFallback, ['cost', 'threshold'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "distribute-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")
                                            self._segment_path = lambda: "fast-reroute"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute, ['fast_reroute_enable'], name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")
                                                self._segment_path = lambda: "per-link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")
                                                self._segment_path = lambda: "per-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                    self.tiebreaker = YList(self)
                                                    self._segment_path = lambda: "tiebreakers"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                        self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor)}

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "neighbors"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")
                                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                                    class PrefixSid(Entity):
                                        """
                                        Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, self).__init__()

                                            self.yang_name = "prefix-sid"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")
                                            self._segment_path = lambda: "prefix-sid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSid, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                    class PrefixSidStrict(Entity):
                                        """
                                        Strict Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                            self.yang_name = "prefix-sid-strict"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")
                                            self._segment_path = lambda: "prefix-sid-strict"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.PrefixSidStrict, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                    class Security(Entity):
                                        """
                                        Container class for security related
                                        configuration parameters
                                        
                                        .. attribute:: ttl
                                        
                                        	Enabling turns on TTL security
                                        	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security, self).__init__()

                                            self.yang_name = "security"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl)}
                                            self._child_list_classes = {}

                                            self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl()
                                            self.ttl.parent = self
                                            self._children_name_map["ttl"] = "ttl"
                                            self._children_yang_names.add("ttl")
                                            self._segment_path = lambda: "security"


                                        class Ttl(Entity):
                                            """
                                            Enabling turns on TTL security
                                            
                                            .. attribute:: enable
                                            
                                            	Enable TTL security
                                            	**type**\:  bool
                                            
                                            .. attribute:: hop_count
                                            
                                            	Hop count
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, self).__init__()

                                                self.yang_name = "ttl"
                                                self.yang_parent_name = "security"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.hop_count = YLeaf(YType.uint32, "hop-count")
                                                self._segment_path = lambda: "ttl"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.NameScopes.NameScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                            class Nssa(Entity):
                                """
                                Specify area as a NSSA area
                                
                                .. attribute:: default_info_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: metric_type
                                
                                	OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                	**default value**\: type2
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: nssa_def_metric
                                
                                	OSPF default metric
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                    self.no_summary = YLeaf(YType.boolean, "no-summary")

                                    self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")
                                    self._segment_path = lambda: "nssa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.Nssa, ['default_info_originate', 'metric_type', 'no_redistribution', 'no_summary', 'nssa_def_metric'], name, value)


                            class ShamLinkScopes(Entity):
                                """
                                Sham Link scope configurations
                                
                                .. attribute:: sham_link_scope
                                
                                	Sham Link configuration
                                	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes, self).__init__()

                                    self.yang_name = "sham-link-scopes"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sham-link-scope" : ("sham_link_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope)}

                                    self.sham_link_scope = YList(self)
                                    self._segment_path = lambda: "sham-link-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes, [], name, value)


                                class ShamLinkScope(Entity):
                                    """
                                    Sham Link configuration
                                    
                                    .. attribute:: source_address  <key>
                                    
                                    	Address of the local sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_address  <key>
                                    
                                    	Address of the remote sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: source
                                    
                                    	Address of the local sham\-link endpoint. Enter an IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, self).__init__()

                                        self.yang_name = "sham-link-scope"
                                        self.yang_parent_name = "sham-link-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal)}
                                        self._child_list_classes = {}

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.source = YLeaf(YType.str, "source")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")
                                        self._segment_path = lambda: "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope, ['source_address', 'destination_address', 'cost', 'hello_interval', 'retransmit_interval', 'running', 'source', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "sham-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "sham-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                            class VirtualLinkScopes(Entity):
                                """
                                Virtual Link scope configurations
                                
                                .. attribute:: virtual_link_scope
                                
                                	Virtual Link configuration
                                	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes, self).__init__()

                                    self.yang_name = "virtual-link-scopes"
                                    self.yang_parent_name = "area-address"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"virtual-link-scope" : ("virtual_link_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope)}

                                    self.virtual_link_scope = YList(self)
                                    self._segment_path = lambda: "virtual-link-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes, [], name, value)


                                class VirtualLinkScope(Entity):
                                    """
                                    Virtual Link configuration
                                    
                                    .. attribute:: address  <key>
                                    
                                    	Router ID of virtual link neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                        self.yang_name = "virtual-link-scope"
                                        self.yang_parent_name = "virtual-link-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal)}
                                        self._child_list_classes = {}

                                        self.address = YLeaf(YType.str, "address")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")
                                        self._segment_path = lambda: "virtual-link-scope" + "[address='" + self.address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope, ['address', 'hello_interval', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "virtual-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "virtual-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAddress.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                        class AreaAreaId(Entity):
                            """
                            Configuration for a particular area
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_ranges
                            
                            	Summarize routes matching address/mask (border routers only)
                            	**type**\:   :py:class:`AreaRanges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges>`
                            
                            .. attribute:: area_scope
                            
                            	Area scope configuration
                            	**type**\:   :py:class:`AreaScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope>`
                            
                            .. attribute:: default_cost
                            
                            	Set the summary default\-cost of a NSSA/stub area
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            	**default value**\: 1
                            
                            .. attribute:: external_out
                            
                            	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                            	**type**\:  bool
                            
                            .. attribute:: mpls_traffic_eng
                            
                            	Configure an OSPF area to run MPLS Traffic Engineering
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: multi_area_interface_scopes
                            
                            	Multi Area Interface scope configurations
                            	**type**\:   :py:class:`MultiAreaInterfaceScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes>`
                            
                            .. attribute:: name_scopes
                            
                            	Name scope configurations
                            	**type**\:   :py:class:`NameScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes>`
                            
                            .. attribute:: nssa
                            
                            	Specify area as a NSSA area
                            	**type**\:   :py:class:`Nssa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa>`
                            
                            .. attribute:: route_policy_in
                            
                            	Configure a route policy for inbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: route_policy_out
                            
                            	Configure a route policy for outbound type\-3 lsa filtering
                            	**type**\:  str
                            
                            .. attribute:: running
                            
                            	Enable routing on an IP network
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: segment_routing
                            
                            	segment\-routing configuration Applicable only in Default VRF
                            	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                            
                            .. attribute:: sham_link_scopes
                            
                            	Sham Link scope configurations
                            	**type**\:   :py:class:`ShamLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes>`
                            
                            .. attribute:: stub
                            
                            	Specify the area as a stub area (send summary LSA stub area)
                            	**type**\:  bool
                            
                            .. attribute:: summary_in
                            
                            	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_scopes
                            
                            	Virtual Link scope configurations
                            	**type**\:   :py:class:`VirtualLinkScopes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId, self).__init__()

                                self.yang_name = "area-area-id"
                                self.yang_parent_name = "area-addresses"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"area-ranges" : ("area_ranges", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges), "area-scope" : ("area_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope), "multi-area-interface-scopes" : ("multi_area_interface_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes), "name-scopes" : ("name_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes), "nssa" : ("nssa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa), "sham-link-scopes" : ("sham_link_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes), "virtual-link-scopes" : ("virtual_link_scopes", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes)}
                                self._child_list_classes = {}

                                self.area_id = YLeaf(YType.uint32, "area-id")

                                self.default_cost = YLeaf(YType.uint32, "default-cost")

                                self.external_out = YLeaf(YType.boolean, "external-out")

                                self.mpls_traffic_eng = YLeaf(YType.empty, "mpls-traffic-eng")

                                self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                self.running = YLeaf(YType.empty, "running")

                                self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                                self.stub = YLeaf(YType.boolean, "stub")

                                self.summary_in = YLeaf(YType.boolean, "summary-in")

                                self.area_ranges = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges()
                                self.area_ranges.parent = self
                                self._children_name_map["area_ranges"] = "area-ranges"
                                self._children_yang_names.add("area-ranges")

                                self.area_scope = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope()
                                self.area_scope.parent = self
                                self._children_name_map["area_scope"] = "area-scope"
                                self._children_yang_names.add("area-scope")

                                self.multi_area_interface_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes()
                                self.multi_area_interface_scopes.parent = self
                                self._children_name_map["multi_area_interface_scopes"] = "multi-area-interface-scopes"
                                self._children_yang_names.add("multi-area-interface-scopes")

                                self.name_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes()
                                self.name_scopes.parent = self
                                self._children_name_map["name_scopes"] = "name-scopes"
                                self._children_yang_names.add("name-scopes")

                                self.nssa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa()
                                self.nssa.parent = self
                                self._children_name_map["nssa"] = "nssa"
                                self._children_yang_names.add("nssa")

                                self.sham_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes()
                                self.sham_link_scopes.parent = self
                                self._children_name_map["sham_link_scopes"] = "sham-link-scopes"
                                self._children_yang_names.add("sham-link-scopes")

                                self.virtual_link_scopes = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes()
                                self.virtual_link_scopes.parent = self
                                self._children_name_map["virtual_link_scopes"] = "virtual-link-scopes"
                                self._children_yang_names.add("virtual-link-scopes")
                                self._segment_path = lambda: "area-area-id" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId, ['area_id', 'default_cost', 'external_out', 'mpls_traffic_eng', 'route_policy_in', 'route_policy_out', 'running', 'segment_routing', 'stub', 'summary_in'], name, value)


                            class AreaRanges(Entity):
                                """
                                Summarize routes matching address/mask (border
                                routers only)
                                
                                .. attribute:: area_range
                                
                                	Ordering index
                                	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges, self).__init__()

                                    self.yang_name = "area-ranges"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-range" : ("area_range", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange)}

                                    self.area_range = YList(self)
                                    self._segment_path = lambda: "area-ranges"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges, [], name, value)


                                class AreaRange(Entity):
                                    """
                                    Ordering index
                                    
                                    .. attribute:: address  <key>
                                    
                                    	IP address to match
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: netmask  <key>
                                    
                                    	IP netmask for address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: not_advertise
                                    
                                    	Do not advertise this range
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, self).__init__()

                                        self.yang_name = "area-range"
                                        self.yang_parent_name = "area-ranges"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.address = YLeaf(YType.str, "address")

                                        self.netmask = YLeaf(YType.str, "netmask")

                                        self.not_advertise = YLeaf(YType.boolean, "not-advertise")
                                        self._segment_path = lambda: "area-range" + "[address='" + self.address.get() + "']" + "[netmask='" + self.netmask.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaRanges.AreaRange, ['address', 'netmask', 'not_advertise'], name, value)


                            class AreaScope(Entity):
                                """
                                Area scope configuration
                                
                                .. attribute:: authentication
                                
                                	Authentication
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication>`
                                
                                .. attribute:: bfd
                                
                                	BFD configuration
                                	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd>`
                                
                                .. attribute:: cost
                                
                                	Interface cost
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                .. attribute:: cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback>`
                                
                                .. attribute:: database_filter
                                
                                	Filter OSPF LSA during synchronization and flooding
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: dead_interval_minimal
                                
                                	Interval after which a neighbor is declared dead
                                	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal>`
                                
                                .. attribute:: demand_circuit
                                
                                	Enable/Disable OSPF demand circuit
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: distribute_list
                                
                                	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: fast_reroute
                                
                                	Fast\-reroute configuration
                                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute>`
                                
                                .. attribute:: flood_reduction
                                
                                	Enable/Disable OSPF flood reduction
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: hello_interval
                                
                                	Interval between HELLO packets in seconds
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                .. attribute:: ldp_auto_config
                                
                                	Enable MPLS LDP Auto Config
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ldp_sync
                                
                                	Enable/Disable MPLS LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: ldp_sync_igp_shortcuts
                                
                                	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: link_down_fast_detect
                                
                                	Enable/Disable registration for early interface down notifications
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: loopback_stub_network
                                
                                	Enable/Disable advertising loopback as a stub network
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: mtu_ignore
                                
                                	Enable/Disable ignoring of MTU in DBD packets
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: network_type
                                
                                	Type of attached network
                                	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                
                                .. attribute:: packet_size
                                
                                	Customize size of OSPF packets upto MTU
                                	**type**\:  int
                                
                                	**range:** 576..10000
                                
                                .. attribute:: passive
                                
                                	When enabled, prevent sending HELLO packets over link
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_primary
                                
                                	Enable/Disable prefix suppression for primary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: prefix_suppression_secondary
                                
                                	Enable/Disable prefix suppression for secondary addresses
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: priority
                                
                                	Router priority for DR and BDR election
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**default value**\: 1
                                
                                .. attribute:: retransmit_interval
                                
                                	Time in seconds between retransmitting lost link state advertisements
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 5
                                
                                .. attribute:: security
                                
                                	Container class for security related configuration parameters
                                	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security>`
                                
                                .. attribute:: segment_routing_forwarding
                                
                                	segment\-routing forwarding configuration Applicableonly in Default VRF
                                	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                
                                .. attribute:: transmit_delay
                                
                                	Number of seconds to delay transmission of LSAs
                                	**type**\:  int
                                
                                	**range:** 1..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 1
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope, self).__init__()

                                    self.yang_name = "area-scope"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute), "security" : ("security", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security)}
                                    self._child_list_classes = {}

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.database_filter = YLeaf(YType.boolean, "database-filter")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                    self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                    self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                    self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                    self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                    self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.packet_size = YLeaf(YType.uint32, "packet-size")

                                    self.passive = YLeaf(YType.boolean, "passive")

                                    self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                    self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                    self.priority = YLeaf(YType.uint32, "priority")

                                    self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                    self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                    self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                    self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication()
                                    self.authentication.parent = self
                                    self._children_name_map["authentication"] = "authentication"
                                    self._children_yang_names.add("authentication")

                                    self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd()
                                    self.bfd.parent = self
                                    self._children_name_map["bfd"] = "bfd"
                                    self._children_yang_names.add("bfd")

                                    self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback()
                                    self.cost_fallback.parent = self
                                    self._children_name_map["cost_fallback"] = "cost-fallback"
                                    self._children_yang_names.add("cost-fallback")

                                    self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal()
                                    self.dead_interval_minimal.parent = self
                                    self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                    self._children_yang_names.add("dead-interval-minimal")

                                    self.distribute_list = None
                                    self._children_name_map["distribute_list"] = "distribute-list"
                                    self._children_yang_names.add("distribute-list")

                                    self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute()
                                    self.fast_reroute.parent = self
                                    self._children_name_map["fast_reroute"] = "fast-reroute"
                                    self._children_yang_names.add("fast-reroute")

                                    self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security()
                                    self.security.parent = self
                                    self._children_name_map["security"] = "security"
                                    self._children_yang_names.add("security")
                                    self._segment_path = lambda: "area-scope"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope, ['cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                                class Authentication(Entity):
                                    """
                                    Authentication
                                    
                                    .. attribute:: key
                                    
                                    	Authentication key configuration
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: message_digest_keies
                                    
                                    	Message digest authentication password (key) configurations, first 16 chars used
                                    	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies>`
                                    
                                    .. attribute:: type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, self).__init__()

                                        self.yang_name = "authentication"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type)}
                                        self._child_list_classes = {}

                                        self.key = YLeaf(YType.str, "key")

                                        self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies()
                                        self.message_digest_keies.parent = self
                                        self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                        self._children_yang_names.add("message-digest-keies")

                                        self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type()
                                        self.type.parent = self
                                        self._children_name_map["type"] = "type"
                                        self._children_yang_names.add("type")
                                        self._segment_path = lambda: "authentication"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication, ['key'], name, value)


                                    class MessageDigestKeies(Entity):
                                        """
                                        Message digest authentication password (key)
                                        configurations, first 16 chars used
                                        
                                        .. attribute:: message_digest_key
                                        
                                        	Message digest authentication password (key) configuration
                                        	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, self).__init__()

                                            self.yang_name = "message-digest-keies"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                            self.message_digest_key = YList(self)
                                            self._segment_path = lambda: "message-digest-keies"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies, [], name, value)


                                        class MessageDigestKey(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configuration
                                            
                                            .. attribute:: key_id  <key>
                                            
                                            	Key ID
                                            	**type**\:  int
                                            
                                            	**range:** 1..255
                                            
                                            .. attribute:: password
                                            
                                            	Password
                                            	**type**\:  str
                                            
                                            	**pattern:** (!.+)\|([^!].+)
                                            
                                            	**mandatory**\: True
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                self.yang_name = "message-digest-key"
                                                self.yang_parent_name = "message-digest-keies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.key_id = YLeaf(YType.uint32, "key-id")

                                                self.password = YLeaf(YType.str, "password")
                                                self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                    class Type(Entity):
                                        """
                                        Authentication type
                                        
                                        .. attribute:: authen_type
                                        
                                        	Authentication type code 
                                        	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                        
                                        .. attribute:: keychain_authen_type
                                        
                                        	Keychain authentication type
                                        	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                        
                                        .. attribute:: keychain_name
                                        
                                        	Keychain name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, self).__init__()

                                            self.yang_name = "type"
                                            self.yang_parent_name = "authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                            self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                            self.keychain_name = YLeaf(YType.str, "keychain-name")
                                            self._segment_path = lambda: "type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                class Bfd(Entity):
                                    """
                                    BFD configuration
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	Detection multiplier for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 2..50
                                    
                                    .. attribute:: fast_detect_mode
                                    
                                    	 use of Bidirectional Forwarding Detection
                                    	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                    
                                    .. attribute:: interval
                                    
                                    	Hello interval for BFD sessions created by OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 3..30000
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, self).__init__()

                                        self.yang_name = "bfd"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                        self.interval = YLeaf(YType.uint32, "interval")
                                        self._segment_path = lambda: "bfd"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                                class CostFallback(Entity):
                                    """
                                    Interface fallback cost
                                    
                                    .. attribute:: cost
                                    
                                    	Fallback cost of link
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: threshold
                                    
                                    	Bandwidth threshold
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, self).__init__()

                                        self.yang_name = "cost-fallback"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.threshold = YLeaf(YType.uint32, "threshold")
                                        self._segment_path = lambda: "cost-fallback"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.CostFallback, ['cost', 'threshold'], name, value)


                                class DeadIntervalMinimal(Entity):
                                    """
                                    Interval after which a neighbor is declared dead
                                    
                                    .. attribute:: interval
                                    
                                    	Interval size in seconds after which a neighbor is declared dead
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: multiplier
                                    
                                    	Number of Hellos in one second
                                    	**type**\:  int
                                    
                                    	**range:** 3..20
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, self).__init__()

                                        self.yang_name = "dead-interval-minimal"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interval = YLeaf(YType.uint32, "interval")

                                        self.multiplier = YLeaf(YType.uint32, "multiplier")
                                        self._segment_path = lambda: "dead-interval-minimal"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                class DistributeList(Entity):
                                    """
                                    Filter networks intalled to RIB (disable as ACL
                                    name means filtering is disabled)
                                    
                                    .. attribute:: access_list_name
                                    
                                    	Access Control List name
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route Policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, self).__init__()

                                        self.yang_name = "distribute-list"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.access_list_name = YLeaf(YType.str, "access-list-name")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "distribute-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                class FastReroute(Entity):
                                    """
                                    Fast\-reroute configuration
                                    
                                    .. attribute:: fast_reroute_enable
                                    
                                    	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                    	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                    
                                    .. attribute:: per_link
                                    
                                    	Fast\-reroute per\-link configuration
                                    	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink>`
                                    
                                    .. attribute:: per_prefix
                                    
                                    	Fast\-reroute per\-prefix global configuration
                                    	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, self).__init__()

                                        self.yang_name = "fast-reroute"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix)}
                                        self._child_list_classes = {}

                                        self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                        self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink()
                                        self.per_link.parent = self
                                        self._children_name_map["per_link"] = "per-link"
                                        self._children_yang_names.add("per-link")

                                        self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix()
                                        self.per_prefix.parent = self
                                        self._children_name_map["per_prefix"] = "per-prefix"
                                        self._children_yang_names.add("per-prefix")
                                        self._segment_path = lambda: "fast-reroute"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute, ['fast_reroute_enable'], name, value)


                                    class PerLink(Entity):
                                        """
                                        Fast\-reroute per\-link configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, self).__init__()

                                            self.yang_name = "per-link"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")
                                            self._segment_path = lambda: "per-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                    class PerPrefix(Entity):
                                        """
                                        Fast\-reroute per\-prefix global configuration
                                        
                                        .. attribute:: candidate_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                        	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                        
                                        .. attribute:: exclude_interfaces
                                        
                                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                        
                                        .. attribute:: fast_reroute_use_candidate_only
                                        
                                        	Use only interfaces on the candidate list as a backup path
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: remote_lfa
                                        
                                        	Remote LFA configuration
                                        	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa>`
                                        
                                        .. attribute:: tiebreakers
                                        
                                        	Fast\-reroute tiebreakers configurations
                                        	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers>`
                                        
                                        .. attribute:: topology_independent_lfa
                                        
                                        	Topology Independet LFA configuration
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, self).__init__()

                                            self.yang_name = "per-prefix"
                                            self.yang_parent_name = "fast-reroute"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                            self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                            self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces()
                                            self.candidate_interfaces.parent = self
                                            self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                            self._children_yang_names.add("candidate-interfaces")

                                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                            self.exclude_interfaces.parent = self
                                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                            self._children_yang_names.add("exclude-interfaces")

                                            self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa()
                                            self.remote_lfa.parent = self
                                            self._children_name_map["remote_lfa"] = "remote-lfa"
                                            self._children_yang_names.add("remote-lfa")

                                            self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers()
                                            self.tiebreakers.parent = self
                                            self._children_name_map["tiebreakers"] = "tiebreakers"
                                            self._children_yang_names.add("tiebreakers")
                                            self._segment_path = lambda: "per-prefix"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                        class CandidateInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix candidate
                                            interface configuration
                                            
                                            .. attribute:: candidate_interface
                                            
                                            	Candidate backup interface
                                            	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                self.yang_name = "candidate-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                self.candidate_interface = YList(self)
                                                self._segment_path = lambda: "candidate-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                            class CandidateInterface(Entity):
                                                """
                                                Candidate backup interface
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                    self.yang_name = "candidate-interface"
                                                    self.yang_parent_name = "candidate-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                        class ExcludeInterfaces(Entity):
                                            """
                                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                            interface configuration
                                            
                                            .. attribute:: exclude_interface
                                            
                                            	Exclude an interface from becoming a backup or UCMP
                                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                self.yang_name = "exclude-interfaces"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                self.exclude_interface = YList(self)
                                                self._segment_path = lambda: "exclude-interfaces"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                            class ExcludeInterface(Entity):
                                                """
                                                Exclude an interface from becoming a backup or
                                                UCMP
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                    self.yang_name = "exclude-interface"
                                                    self.yang_parent_name = "exclude-interfaces"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class RemoteLfa(Entity):
                                            """
                                            Remote LFA configuration
                                            
                                            .. attribute:: maximum_cost
                                            
                                            	Maximum path cost to remote LFA
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel
                                            
                                            	Enable/Disable remote LFA computation
                                            	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                self.yang_name = "remote-lfa"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                self._segment_path = lambda: "remote-lfa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                        class Tiebreakers(Entity):
                                            """
                                            Fast\-reroute tiebreakers configurations
                                            
                                            .. attribute:: tiebreaker
                                            
                                            	Fast\-reroute tiebreakers configuration
                                            	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                self.yang_name = "tiebreakers"
                                                self.yang_parent_name = "per-prefix"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                self.tiebreaker = YList(self)
                                                self._segment_path = lambda: "tiebreakers"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                            class Tiebreaker(Entity):
                                                """
                                                Fast\-reroute tiebreakers configuration
                                                
                                                .. attribute:: tiebreaker_type  <key>
                                                
                                                	Tiebreaker type
                                                	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                
                                                .. attribute:: tiebreaker_index
                                                
                                                	Index value for a tiebreaker, 0 to disable
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                    self.yang_name = "tiebreaker"
                                                    self.yang_parent_name = "tiebreakers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                    self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                class Security(Entity):
                                    """
                                    Container class for security related
                                    configuration parameters
                                    
                                    .. attribute:: ttl
                                    
                                    	Enabling turns on TTL security
                                    	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security, self).__init__()

                                        self.yang_name = "security"
                                        self.yang_parent_name = "area-scope"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl)}
                                        self._child_list_classes = {}

                                        self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl()
                                        self.ttl.parent = self
                                        self._children_name_map["ttl"] = "ttl"
                                        self._children_yang_names.add("ttl")
                                        self._segment_path = lambda: "security"


                                    class Ttl(Entity):
                                        """
                                        Enabling turns on TTL security
                                        
                                        .. attribute:: enable
                                        
                                        	Enable TTL security
                                        	**type**\:  bool
                                        
                                        .. attribute:: hop_count
                                        
                                        	Hop count
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, self).__init__()

                                            self.yang_name = "ttl"
                                            self.yang_parent_name = "security"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.enable = YLeaf(YType.boolean, "enable")

                                            self.hop_count = YLeaf(YType.uint32, "hop-count")
                                            self._segment_path = lambda: "ttl"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.AreaScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                            class MultiAreaInterfaceScopes(Entity):
                                """
                                Multi Area Interface scope configurations
                                
                                .. attribute:: multi_area_interface_scope
                                
                                	Multi Area Interface configuration
                                	**type**\: list of    :py:class:`MultiAreaInterfaceScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, self).__init__()

                                    self.yang_name = "multi-area-interface-scopes"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"multi-area-interface-scope" : ("multi_area_interface_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope)}

                                    self.multi_area_interface_scope = YList(self)
                                    self._segment_path = lambda: "multi-area-interface-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes, [], name, value)


                                class MultiAreaInterfaceScope(Entity):
                                    """
                                    Multi Area Interface configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Multi Area Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, self).__init__()

                                        self.yang_name = "multi-area-interface-scope"
                                        self.yang_parent_name = "multi-area-interface-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")
                                        self._segment_path = lambda: "multi-area-interface-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope, ['interface_name', 'cost', 'database_filter', 'hello_interval', 'mtu_ignore', 'packet_size', 'passive', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")
                                            self._segment_path = lambda: "cost-fallback"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.CostFallback, ['cost', 'threshold'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "distribute-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")
                                            self._segment_path = lambda: "fast-reroute"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute, ['fast_reroute_enable'], name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")
                                                self._segment_path = lambda: "per-link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")
                                                self._segment_path = lambda: "per-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                    self.tiebreaker = YList(self)
                                                    self._segment_path = lambda: "tiebreakers"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                        self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "multi-area-interface-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor)}

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "neighbors"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")
                                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.MultiAreaInterfaceScopes.MultiAreaInterfaceScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                            class NameScopes(Entity):
                                """
                                Name scope configurations
                                
                                .. attribute:: name_scope
                                
                                	Name scope configuration
                                	**type**\: list of    :py:class:`NameScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes, self).__init__()

                                    self.yang_name = "name-scopes"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"name-scope" : ("name_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope)}

                                    self.name_scope = YList(self)
                                    self._segment_path = lambda: "name-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes, [], name, value)


                                class NameScope(Entity):
                                    """
                                    Name scope configuration
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Name of Interface to configure
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication>`
                                    
                                    .. attribute:: bfd
                                    
                                    	BFD configuration
                                    	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback>`
                                    
                                    .. attribute:: database_filter
                                    
                                    	Filter OSPF LSA during synchronization and flooding
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	Enable/Disable OSPF demand circuit
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: distribute_list
                                    
                                    	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                                    	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: fast_reroute
                                    
                                    	Fast\-reroute configuration
                                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute>`
                                    
                                    .. attribute:: flood_reduction
                                    
                                    	Enable/Disable OSPF flood reduction
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: ldp_auto_config
                                    
                                    	Enable MPLS LDP Auto Config
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ldp_sync
                                    
                                    	Enable/Disable MPLS LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_sync_igp_shortcuts
                                    
                                    	Enable/Disable MPLS LDP sync for igp\-shortcuts
                                    	**type**\:  bool
                                    
                                    .. attribute:: link_down_fast_detect
                                    
                                    	Enable/Disable registration for early interface down notifications
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: loopback_stub_network
                                    
                                    	Enable/Disable advertising loopback as a stub network
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: mtu_ignore
                                    
                                    	Enable/Disable ignoring of MTU in DBD packets
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: neighbors
                                    
                                    	Neighbor router configuration information
                                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors>`
                                    
                                    .. attribute:: network_type
                                    
                                    	Type of attached network
                                    	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                                    
                                    .. attribute:: packet_size
                                    
                                    	Customize size of OSPF packets upto MTU
                                    	**type**\:  int
                                    
                                    	**range:** 576..10000
                                    
                                    .. attribute:: passive
                                    
                                    	When enabled, prevent sending HELLO packets over link
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_sid
                                    
                                    	Prefix SID
                                    	**type**\:   :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_sid_strict
                                    
                                    	Strict Prefix SID
                                    	**type**\:   :py:class:`PrefixSidStrict <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: prefix_suppression_primary
                                    
                                    	Enable/Disable prefix suppression for primary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: prefix_suppression_secondary
                                    
                                    	Enable/Disable prefix suppression for secondary addresses
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: priority
                                    
                                    	Router priority for DR and BDR election
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**default value**\: 1
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: security
                                    
                                    	Container class for security related configuration parameters
                                    	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security>`
                                    
                                    .. attribute:: segment_routing_forwarding
                                    
                                    	segment\-routing forwarding configuration Applicableonly in Default VRF
                                    	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, self).__init__()

                                        self.yang_name = "name-scope"
                                        self.yang_parent_name = "name-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute), "neighbors" : ("neighbors", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors), "prefix-sid" : ("prefix_sid", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid), "prefix-sid-strict" : ("prefix_sid_strict", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict), "security" : ("security", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security)}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.database_filter = YLeaf(YType.boolean, "database-filter")

                                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                        self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                                        self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                                        self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                                        self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                                        self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                                        self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.packet_size = YLeaf(YType.uint32, "packet-size")

                                        self.passive = YLeaf(YType.boolean, "passive")

                                        self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                                        self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                                        self.priority = YLeaf(YType.uint32, "priority")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.bfd = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd()
                                        self.bfd.parent = self
                                        self._children_name_map["bfd"] = "bfd"
                                        self._children_yang_names.add("bfd")

                                        self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback()
                                        self.cost_fallback.parent = self
                                        self._children_name_map["cost_fallback"] = "cost-fallback"
                                        self._children_yang_names.add("cost-fallback")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")

                                        self.distribute_list = None
                                        self._children_name_map["distribute_list"] = "distribute-list"
                                        self._children_yang_names.add("distribute-list")

                                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute()
                                        self.fast_reroute.parent = self
                                        self._children_name_map["fast_reroute"] = "fast-reroute"
                                        self._children_yang_names.add("fast-reroute")

                                        self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors()
                                        self.neighbors.parent = self
                                        self._children_name_map["neighbors"] = "neighbors"
                                        self._children_yang_names.add("neighbors")

                                        self.prefix_sid = None
                                        self._children_name_map["prefix_sid"] = "prefix-sid"
                                        self._children_yang_names.add("prefix-sid")

                                        self.prefix_sid_strict = None
                                        self._children_name_map["prefix_sid_strict"] = "prefix-sid-strict"
                                        self._children_yang_names.add("prefix-sid-strict")

                                        self.security = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security()
                                        self.security.parent = self
                                        self._children_name_map["security"] = "security"
                                        self._children_yang_names.add("security")
                                        self._segment_path = lambda: "name-scope" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope, ['interface_name', 'cost', 'database_filter', 'demand_circuit', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'running', 'segment_routing_forwarding', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class Bfd(Entity):
                                        """
                                        BFD configuration
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	Detection multiplier for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 2..50
                                        
                                        .. attribute:: fast_detect_mode
                                        
                                        	 use of Bidirectional Forwarding Detection
                                        	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                                        
                                        .. attribute:: interval
                                        
                                        	Hello interval for BFD sessions created by OSPF
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, self).__init__()

                                            self.yang_name = "bfd"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                            self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                            self.interval = YLeaf(YType.uint32, "interval")
                                            self._segment_path = lambda: "bfd"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                                    class CostFallback(Entity):
                                        """
                                        Interface fallback cost
                                        
                                        .. attribute:: cost
                                        
                                        	Fallback cost of link
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        .. attribute:: threshold
                                        
                                        	Bandwidth threshold
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, self).__init__()

                                            self.yang_name = "cost-fallback"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.cost = YLeaf(YType.uint32, "cost")

                                            self.threshold = YLeaf(YType.uint32, "threshold")
                                            self._segment_path = lambda: "cost-fallback"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.CostFallback, ['cost', 'threshold'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                                    class DistributeList(Entity):
                                        """
                                        Filter networks intalled to RIB (disable as ACL
                                        name means filtering is disabled)
                                        
                                        .. attribute:: access_list_name
                                        
                                        	Access Control List name
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route Policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, self).__init__()

                                            self.yang_name = "distribute-list"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.access_list_name = YLeaf(YType.str, "access-list-name")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "distribute-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                                    class FastReroute(Entity):
                                        """
                                        Fast\-reroute configuration
                                        
                                        .. attribute:: fast_reroute_enable
                                        
                                        	Enable/Disable Fast\-reroute per\-link or per\-prefix
                                        	**type**\:   :py:class:`OspfFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroute>`
                                        
                                        .. attribute:: per_link
                                        
                                        	Fast\-reroute per\-link configuration
                                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink>`
                                        
                                        .. attribute:: per_prefix
                                        
                                        	Fast\-reroute per\-prefix global configuration
                                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, self).__init__()

                                            self.yang_name = "fast-reroute"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix)}
                                            self._child_list_classes = {}

                                            self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink()
                                            self.per_link.parent = self
                                            self._children_name_map["per_link"] = "per-link"
                                            self._children_yang_names.add("per-link")

                                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix()
                                            self.per_prefix.parent = self
                                            self._children_name_map["per_prefix"] = "per-prefix"
                                            self._children_yang_names.add("per-prefix")
                                            self._segment_path = lambda: "fast-reroute"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute, ['fast_reroute_enable'], name, value)


                                        class PerLink(Entity):
                                            """
                                            Fast\-reroute per\-link configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, self).__init__()

                                                self.yang_name = "per-link"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")
                                                self._segment_path = lambda: "per-link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                        class PerPrefix(Entity):
                                            """
                                            Fast\-reroute per\-prefix global configuration
                                            
                                            .. attribute:: candidate_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                            	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                            
                                            .. attribute:: exclude_interfaces
                                            
                                            	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                            	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                            
                                            .. attribute:: fast_reroute_use_candidate_only
                                            
                                            	Use only interfaces on the candidate list as a backup path
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: remote_lfa
                                            
                                            	Remote LFA configuration
                                            	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa>`
                                            
                                            .. attribute:: tiebreakers
                                            
                                            	Fast\-reroute tiebreakers configurations
                                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers>`
                                            
                                            .. attribute:: topology_independent_lfa
                                            
                                            	Topology Independet LFA configuration
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, self).__init__()

                                                self.yang_name = "per-prefix"
                                                self.yang_parent_name = "fast-reroute"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa), "tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers)}
                                                self._child_list_classes = {}

                                                self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                                self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                                self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces()
                                                self.candidate_interfaces.parent = self
                                                self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                                self._children_yang_names.add("candidate-interfaces")

                                                self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                                self.exclude_interfaces.parent = self
                                                self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                                self._children_yang_names.add("exclude-interfaces")

                                                self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa()
                                                self.remote_lfa.parent = self
                                                self._children_name_map["remote_lfa"] = "remote-lfa"
                                                self._children_yang_names.add("remote-lfa")

                                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers()
                                                self.tiebreakers.parent = self
                                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                                self._children_yang_names.add("tiebreakers")
                                                self._segment_path = lambda: "per-prefix"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                            class CandidateInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix candidate
                                                interface configuration
                                                
                                                .. attribute:: candidate_interface
                                                
                                                	Candidate backup interface
                                                	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                                    self.yang_name = "candidate-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                                    self.candidate_interface = YList(self)
                                                    self._segment_path = lambda: "candidate-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                                class CandidateInterface(Entity):
                                                    """
                                                    Candidate backup interface
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                                        self.yang_name = "candidate-interface"
                                                        self.yang_parent_name = "candidate-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                            class ExcludeInterfaces(Entity):
                                                """
                                                Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                                interface configuration
                                                
                                                .. attribute:: exclude_interface
                                                
                                                	Exclude an interface from becoming a backup or UCMP
                                                	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                                    self.yang_name = "exclude-interfaces"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                                    self.exclude_interface = YList(self)
                                                    self._segment_path = lambda: "exclude-interfaces"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                                class ExcludeInterface(Entity):
                                                    """
                                                    Exclude an interface from becoming a backup or
                                                    UCMP
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                                        self.yang_name = "exclude-interface"
                                                        self.yang_parent_name = "exclude-interfaces"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                                        self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                            class RemoteLfa(Entity):
                                                """
                                                Remote LFA configuration
                                                
                                                .. attribute:: maximum_cost
                                                
                                                	Maximum path cost to remote LFA
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel
                                                
                                                	Enable/Disable remote LFA computation
                                                	**type**\:   :py:class:`OspfFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFrrRlfaTunnel>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                                    self.yang_name = "remote-lfa"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                                    self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                                    self._segment_path = lambda: "remote-lfa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                                            class Tiebreakers(Entity):
                                                """
                                                Fast\-reroute tiebreakers configurations
                                                
                                                .. attribute:: tiebreaker
                                                
                                                	Fast\-reroute tiebreakers configuration
                                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                                    self.yang_name = "tiebreakers"
                                                    self.yang_parent_name = "per-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                                    self.tiebreaker = YList(self)
                                                    self._segment_path = lambda: "tiebreakers"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                                class Tiebreaker(Entity):
                                                    """
                                                    Fast\-reroute tiebreakers configuration
                                                    
                                                    .. attribute:: tiebreaker_type  <key>
                                                    
                                                    	Tiebreaker type
                                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakersIntf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakersIntf>`
                                                    
                                                    .. attribute:: tiebreaker_index
                                                    
                                                    	Index value for a tiebreaker, 0 to disable
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    	**mandatory**\: True
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-cfg'
                                                    _revision = '2017-07-14'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                                        self.yang_name = "tiebreaker"
                                                        self.yang_parent_name = "tiebreakers"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                                        self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                                    class Neighbors(Entity):
                                        """
                                        Neighbor router configuration information
                                        
                                        .. attribute:: neighbor
                                        
                                        	Router configuration information for a particular neighbor
                                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, self).__init__()

                                            self.yang_name = "neighbors"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor)}

                                            self.neighbor = YList(self)
                                            self._segment_path = lambda: "neighbors"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors, [], name, value)


                                        class Neighbor(Entity):
                                            """
                                            Router configuration information for a
                                            particular neighbor
                                            
                                            .. attribute:: neighbor_address  <key>
                                            
                                            	Neighbor IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: cost
                                            
                                            	OSPF cost for point\-to\-multipoint neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 1..65535
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: database_filter
                                            
                                            	Database filter\: Filter OSPF LSA during synchronization and flooding for point\-to\-multipoint
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: poll_interval
                                            
                                            	OSPF dead router poll\-interval in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 40
                                            
                                            .. attribute:: priority
                                            
                                            	OSPF priority of non\-broadcast neighbor
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, self).__init__()

                                                self.yang_name = "neighbor"
                                                self.yang_parent_name = "neighbors"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                                self.cost = YLeaf(YType.uint32, "cost")

                                                self.database_filter = YLeaf(YType.boolean, "database-filter")

                                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                                self.priority = YLeaf(YType.uint32, "priority")
                                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Neighbors.Neighbor, ['neighbor_address', 'cost', 'database_filter', 'poll_interval', 'priority'], name, value)


                                    class PrefixSid(Entity):
                                        """
                                        Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, self).__init__()

                                            self.yang_name = "prefix-sid"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")
                                            self._segment_path = lambda: "prefix-sid"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSid, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                    class PrefixSidStrict(Entity):
                                        """
                                        Strict Prefix SID
                                        
                                        .. attribute:: explicit_null
                                        
                                        	Force Penultimate Hop To Send Explicit\-Null Label
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: n_flag_clear
                                        
                                        	Not a node SID
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: sid_value
                                        
                                        	SID value
                                        	**type**\:  int
                                        
                                        	**range:** 0..1048575
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: type
                                        
                                        	OSPF SID Type
                                        	**type**\:   :py:class:`OspfSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSid>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, self).__init__()

                                            self.yang_name = "prefix-sid-strict"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.explicit_null = YLeaf(YType.boolean, "explicit-null")

                                            self.n_flag_clear = YLeaf(YType.boolean, "n-flag-clear")

                                            self.sid_value = YLeaf(YType.uint32, "sid-value")

                                            self.type = YLeaf(YType.enumeration, "type")
                                            self._segment_path = lambda: "prefix-sid-strict"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.PrefixSidStrict, ['explicit_null', 'n_flag_clear', 'sid_value', 'type'], name, value)


                                    class Security(Entity):
                                        """
                                        Container class for security related
                                        configuration parameters
                                        
                                        .. attribute:: ttl
                                        
                                        	Enabling turns on TTL security
                                        	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security, self).__init__()

                                            self.yang_name = "security"
                                            self.yang_parent_name = "name-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl)}
                                            self._child_list_classes = {}

                                            self.ttl = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl()
                                            self.ttl.parent = self
                                            self._children_name_map["ttl"] = "ttl"
                                            self._children_yang_names.add("ttl")
                                            self._segment_path = lambda: "security"


                                        class Ttl(Entity):
                                            """
                                            Enabling turns on TTL security
                                            
                                            .. attribute:: enable
                                            
                                            	Enable TTL security
                                            	**type**\:  bool
                                            
                                            .. attribute:: hop_count
                                            
                                            	Hop count
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, self).__init__()

                                                self.yang_name = "ttl"
                                                self.yang_parent_name = "security"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.hop_count = YLeaf(YType.uint32, "hop-count")
                                                self._segment_path = lambda: "ttl"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.NameScopes.NameScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                            class Nssa(Entity):
                                """
                                Specify area as a NSSA area
                                
                                .. attribute:: default_info_originate
                                
                                	Originate Type 7 default into NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: metric_type
                                
                                	OSPF External metric type
                                	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                
                                	**default value**\: type2
                                
                                .. attribute:: no_redistribution
                                
                                	No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: no_summary
                                
                                	Do not send summary LSA into NSSA
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: nssa_def_metric
                                
                                	OSPF default metric
                                	**type**\:  int
                                
                                	**range:** 1..16777214
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa, self).__init__()

                                    self.yang_name = "nssa"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.default_info_originate = YLeaf(YType.boolean, "default-info-originate")

                                    self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                    self.no_redistribution = YLeaf(YType.boolean, "no-redistribution")

                                    self.no_summary = YLeaf(YType.boolean, "no-summary")

                                    self.nssa_def_metric = YLeaf(YType.uint32, "nssa-def-metric")
                                    self._segment_path = lambda: "nssa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.Nssa, ['default_info_originate', 'metric_type', 'no_redistribution', 'no_summary', 'nssa_def_metric'], name, value)


                            class ShamLinkScopes(Entity):
                                """
                                Sham Link scope configurations
                                
                                .. attribute:: sham_link_scope
                                
                                	Sham Link configuration
                                	**type**\: list of    :py:class:`ShamLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes, self).__init__()

                                    self.yang_name = "sham-link-scopes"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sham-link-scope" : ("sham_link_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope)}

                                    self.sham_link_scope = YList(self)
                                    self._segment_path = lambda: "sham-link-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes, [], name, value)


                                class ShamLinkScope(Entity):
                                    """
                                    Sham Link configuration
                                    
                                    .. attribute:: source_address  <key>
                                    
                                    	Address of the local sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: destination_address  <key>
                                    
                                    	Address of the remote sham\-link endpoint
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication>`
                                    
                                    .. attribute:: cost
                                    
                                    	Interface cost
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: source
                                    
                                    	Address of the local sham\-link endpoint. Enter an IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, self).__init__()

                                        self.yang_name = "sham-link-scope"
                                        self.yang_parent_name = "sham-link-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal)}
                                        self._child_list_classes = {}

                                        self.source_address = YLeaf(YType.str, "source-address")

                                        self.destination_address = YLeaf(YType.str, "destination-address")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.source = YLeaf(YType.str, "source")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")
                                        self._segment_path = lambda: "sham-link-scope" + "[source-address='" + self.source_address.get() + "']" + "[destination-address='" + self.destination_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope, ['source_address', 'destination_address', 'cost', 'hello_interval', 'retransmit_interval', 'running', 'source', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "sham-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "sham-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.ShamLinkScopes.ShamLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                            class VirtualLinkScopes(Entity):
                                """
                                Virtual Link scope configurations
                                
                                .. attribute:: virtual_link_scope
                                
                                	Virtual Link configuration
                                	**type**\: list of    :py:class:`VirtualLinkScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, self).__init__()

                                    self.yang_name = "virtual-link-scopes"
                                    self.yang_parent_name = "area-area-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"virtual-link-scope" : ("virtual_link_scope", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope)}

                                    self.virtual_link_scope = YList(self)
                                    self._segment_path = lambda: "virtual-link-scopes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes, [], name, value)


                                class VirtualLinkScope(Entity):
                                    """
                                    Virtual Link configuration
                                    
                                    .. attribute:: address  <key>
                                    
                                    	Router ID of virtual link neighbor
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: authentication
                                    
                                    	Authentication
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication>`
                                    
                                    .. attribute:: dead_interval_minimal
                                    
                                    	Interval after which a neighbor is declared dead
                                    	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Interval between HELLO packets in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: retransmit_interval
                                    
                                    	Time in seconds between retransmitting lost link state advertisements
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 5
                                    
                                    .. attribute:: running
                                    
                                    	Enable routing on an IP network
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: transmit_delay
                                    
                                    	Number of seconds to delay transmission of LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**units**\: second
                                    
                                    	**default value**\: 1
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, self).__init__()

                                        self.yang_name = "virtual-link-scope"
                                        self.yang_parent_name = "virtual-link-scopes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal)}
                                        self._child_list_classes = {}

                                        self.address = YLeaf(YType.str, "address")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                                        self.running = YLeaf(YType.empty, "running")

                                        self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                                        self.authentication = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication()
                                        self.authentication.parent = self
                                        self._children_name_map["authentication"] = "authentication"
                                        self._children_yang_names.add("authentication")

                                        self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal()
                                        self.dead_interval_minimal.parent = self
                                        self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                                        self._children_yang_names.add("dead-interval-minimal")
                                        self._segment_path = lambda: "virtual-link-scope" + "[address='" + self.address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope, ['address', 'hello_interval', 'retransmit_interval', 'running', 'transmit_delay'], name, value)


                                    class Authentication(Entity):
                                        """
                                        Authentication
                                        
                                        .. attribute:: key
                                        
                                        	Authentication key configuration
                                        	**type**\:  str
                                        
                                        	**pattern:** (!.+)\|([^!].+)
                                        
                                        .. attribute:: message_digest_keies
                                        
                                        	Message digest authentication password (key) configurations, first 16 chars used
                                        	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies>`
                                        
                                        .. attribute:: type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, self).__init__()

                                            self.yang_name = "authentication"
                                            self.yang_parent_name = "virtual-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type)}
                                            self._child_list_classes = {}

                                            self.key = YLeaf(YType.str, "key")

                                            self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies()
                                            self.message_digest_keies.parent = self
                                            self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                            self._children_yang_names.add("message-digest-keies")

                                            self.type = Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type()
                                            self.type.parent = self
                                            self._children_name_map["type"] = "type"
                                            self._children_yang_names.add("type")
                                            self._segment_path = lambda: "authentication"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication, ['key'], name, value)


                                        class MessageDigestKeies(Entity):
                                            """
                                            Message digest authentication password (key)
                                            configurations, first 16 chars used
                                            
                                            .. attribute:: message_digest_key
                                            
                                            	Message digest authentication password (key) configuration
                                            	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, self).__init__()

                                                self.yang_name = "message-digest-keies"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                                self.message_digest_key = YList(self)
                                                self._segment_path = lambda: "message-digest-keies"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies, [], name, value)


                                            class MessageDigestKey(Entity):
                                                """
                                                Message digest authentication password (key)
                                                configuration
                                                
                                                .. attribute:: key_id  <key>
                                                
                                                	Key ID
                                                	**type**\:  int
                                                
                                                	**range:** 1..255
                                                
                                                .. attribute:: password
                                                
                                                	Password
                                                	**type**\:  str
                                                
                                                	**pattern:** (!.+)\|([^!].+)
                                                
                                                	**mandatory**\: True
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-cfg'
                                                _revision = '2017-07-14'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                                    self.yang_name = "message-digest-key"
                                                    self.yang_parent_name = "message-digest-keies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.key_id = YLeaf(YType.uint32, "key-id")

                                                    self.password = YLeaf(YType.str, "password")
                                                    self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                                        class Type(Entity):
                                            """
                                            Authentication type
                                            
                                            .. attribute:: authen_type
                                            
                                            	Authentication type code 
                                            	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                            
                                            .. attribute:: keychain_authen_type
                                            
                                            	Keychain authentication type
                                            	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                            
                                            .. attribute:: keychain_name
                                            
                                            	Keychain name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-cfg'
                                            _revision = '2017-07-14'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, self).__init__()

                                                self.yang_name = "type"
                                                self.yang_parent_name = "authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                                self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                                self.keychain_name = YLeaf(YType.str, "keychain-name")
                                                self._segment_path = lambda: "type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                                    class DeadIntervalMinimal(Entity):
                                        """
                                        Interval after which a neighbor is declared dead
                                        
                                        .. attribute:: interval
                                        
                                        	Interval size in seconds after which a neighbor is declared dead
                                        	**type**\:  int
                                        
                                        	**range:** 1..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: multiplier
                                        
                                        	Number of Hellos in one second
                                        	**type**\:  int
                                        
                                        	**range:** 3..20
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, self).__init__()

                                            self.yang_name = "dead-interval-minimal"
                                            self.yang_parent_name = "virtual-link-scope"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interval = YLeaf(YType.uint32, "interval")

                                            self.multiplier = YLeaf(YType.uint32, "multiplier")
                                            self._segment_path = lambda: "dead-interval-minimal"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaAddresses.AreaAreaId.VirtualLinkScopes.VirtualLinkScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                    class AutoCost(Entity):
                        """
                        Controls automatic cost based on bandwidth
                        
                        .. attribute:: bandwidth
                        
                        	The reference bandwidth in terms of Mbits per second
                        	**type**\:  int
                        
                        	**range:** 1..4294967
                        
                        	**units**\: Mbit/s
                        
                        	**default value**\: 100
                        
                        .. attribute:: disable
                        
                        	Disabling auto costing
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AutoCost, self).__init__()

                            self.yang_name = "auto-cost"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                            self.disable = YLeaf(YType.boolean, "disable")
                            self._segment_path = lambda: "auto-cost"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AutoCost, ['bandwidth', 'disable'], name, value)


                    class DefaultInformation(Entity):
                        """
                        Control distribution of default information
                        
                        .. attribute:: always_advertise
                        
                        	Always advertise default route
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: metric
                        
                        	OSPF metric
                        	**type**\:  int
                        
                        	**range:** 1..16777214
                        
                        	**default value**\: 1
                        
                        .. attribute:: metric_type
                        
                        	OSPF External metric type
                        	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                        
                        	**default value**\: type2
                        
                        .. attribute:: route_policy_name
                        
                        	Routing policy name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation, self).__init__()

                            self.yang_name = "default-information"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.always_advertise = YLeaf(YType.boolean, "always-advertise")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                            self._segment_path = lambda: "default-information"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.DefaultInformation, ['always_advertise', 'metric', 'metric_type', 'route_policy_name'], name, value)


                    class Distance(Entity):
                        """
                        Administrative distance configuration
                        
                        .. attribute:: admin_distance
                        
                        	Define an administrative distance
                        	**type**\:  int
                        
                        	**range:** 1..255
                        
                        	**default value**\: 110
                        
                        .. attribute:: ip_distances
                        
                        	IP specific administrative distance configuration
                        	**type**\:   :py:class:`IpDistances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances>`
                        
                        .. attribute:: ospf_distance
                        
                        	OSPF distance configuration
                        	**type**\:   :py:class:`OspfDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ip-distances" : ("ip_distances", Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances), "ospf-distance" : ("ospf_distance", Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance)}
                            self._child_list_classes = {}

                            self.admin_distance = YLeaf(YType.uint32, "admin-distance")

                            self.ip_distances = Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances()
                            self.ip_distances.parent = self
                            self._children_name_map["ip_distances"] = "ip-distances"
                            self._children_yang_names.add("ip-distances")

                            self.ospf_distance = Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance()
                            self.ospf_distance.parent = self
                            self._children_name_map["ospf_distance"] = "ospf-distance"
                            self._children_yang_names.add("ospf-distance")
                            self._segment_path = lambda: "distance"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Distance, ['admin_distance'], name, value)


                        class IpDistances(Entity):
                            """
                            IP specific administrative distance
                            configuration
                            
                            .. attribute:: ip_distance
                            
                            	Administrative distance configuration for a particular IP address
                            	**type**\: list of    :py:class:`IpDistance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances, self).__init__()

                                self.yang_name = "ip-distances"
                                self.yang_parent_name = "distance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ip-distance" : ("ip_distance", Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance)}

                                self.ip_distance = YList(self)
                                self._segment_path = lambda: "ip-distances"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances, [], name, value)


                            class IpDistance(Entity):
                                """
                                Administrative distance configuration for a
                                particular IP address
                                
                                .. attribute:: address  <key>
                                
                                	IP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: wildcard  <key>
                                
                                	IP wild card bits \-\- inverted mask
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: access_list_name
                                
                                	Access Control List name
                                	**type**\:  str
                                
                                .. attribute:: distance
                                
                                	Administrative distance
                                	**type**\:  int
                                
                                	**range:** 1..255
                                
                                	**default value**\: 110
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance, self).__init__()

                                    self.yang_name = "ip-distance"
                                    self.yang_parent_name = "ip-distances"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address = YLeaf(YType.str, "address")

                                    self.wildcard = YLeaf(YType.str, "wildcard")

                                    self.access_list_name = YLeaf(YType.str, "access-list-name")

                                    self.distance = YLeaf(YType.uint32, "distance")
                                    self._segment_path = lambda: "ip-distance" + "[address='" + self.address.get() + "']" + "[wildcard='" + self.wildcard.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Distance.IpDistances.IpDistance, ['address', 'wildcard', 'access_list_name', 'distance'], name, value)


                        class OspfDistance(Entity):
                            """
                            OSPF distance configuration
                            
                            .. attribute:: external_routes
                            
                            	Distance for external type 5 and type 7 routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            .. attribute:: inter_area
                            
                            	Distance for inter\-area routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            .. attribute:: intra_area
                            
                            	Distance for intra\-area routes
                            	**type**\:  int
                            
                            	**range:** 1..255
                            
                            	**default value**\: 110
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance, self).__init__()

                                self.yang_name = "ospf-distance"
                                self.yang_parent_name = "distance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_routes = YLeaf(YType.uint32, "external-routes")

                                self.inter_area = YLeaf(YType.uint32, "inter-area")

                                self.intra_area = YLeaf(YType.uint32, "intra-area")
                                self._segment_path = lambda: "ospf-distance"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Distance.OspfDistance, ['external_routes', 'inter_area', 'intra_area'], name, value)


                    class DomainId(Entity):
                        """
                        OSPF Domain ID
                        
                        .. attribute:: primary_domain_id
                        
                        	OSPF Primary domain ID
                        	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId>`
                        
                        .. attribute:: secondary_domain_ids
                        
                        	Secondary domain ID Table
                        	**type**\:   :py:class:`SecondaryDomainIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.DomainId, self).__init__()

                            self.yang_name = "domain-id"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"primary-domain-id" : ("primary_domain_id", Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId), "secondary-domain-ids" : ("secondary_domain_ids", Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds)}
                            self._child_list_classes = {}

                            self.primary_domain_id = Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId()
                            self.primary_domain_id.parent = self
                            self._children_name_map["primary_domain_id"] = "primary-domain-id"
                            self._children_yang_names.add("primary-domain-id")

                            self.secondary_domain_ids = Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds()
                            self.secondary_domain_ids.parent = self
                            self._children_name_map["secondary_domain_ids"] = "secondary-domain-ids"
                            self._children_yang_names.add("secondary-domain-ids")
                            self._segment_path = lambda: "domain-id"


                        class PrimaryDomainId(Entity):
                            """
                            OSPF Primary domain ID
                            
                            .. attribute:: domain_id_name
                            
                            	Primary domain ID value
                            	**type**\:  str
                            
                            .. attribute:: domain_id_type
                            
                            	Primary domain ID type
                            	**type**\:   :py:class:`OspfDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDomainId>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId, self).__init__()

                                self.yang_name = "primary-domain-id"
                                self.yang_parent_name = "domain-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.domain_id_name = YLeaf(YType.str, "domain-id-name")

                                self.domain_id_type = YLeaf(YType.enumeration, "domain-id-type")
                                self._segment_path = lambda: "primary-domain-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.DomainId.PrimaryDomainId, ['domain_id_name', 'domain_id_type'], name, value)


                        class SecondaryDomainIds(Entity):
                            """
                            Secondary domain ID Table
                            
                            .. attribute:: secondary_domain_id
                            
                            	OSPF Secondary domain ID
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds, self).__init__()

                                self.yang_name = "secondary-domain-ids"
                                self.yang_parent_name = "domain-id"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"secondary-domain-id" : ("secondary_domain_id", Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId)}

                                self.secondary_domain_id = YList(self)
                                self._segment_path = lambda: "secondary-domain-ids"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds, [], name, value)


                            class SecondaryDomainId(Entity):
                                """
                                OSPF Secondary domain ID
                                
                                .. attribute:: domain_id_type  <key>
                                
                                	Secondary domain ID type
                                	**type**\:   :py:class:`OspfDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDomainId>`
                                
                                .. attribute:: domain_id_name  <key>
                                
                                	Secondary domain ID value
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId, self).__init__()

                                    self.yang_name = "secondary-domain-id"
                                    self.yang_parent_name = "secondary-domain-ids"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.domain_id_type = YLeaf(YType.enumeration, "domain-id-type")

                                    self.domain_id_name = YLeaf(YType.str, "domain-id-name")
                                    self._segment_path = lambda: "secondary-domain-id" + "[domain-id-type='" + self.domain_id_type.get() + "']" + "[domain-id-name='" + self.domain_id_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.DomainId.SecondaryDomainIds.SecondaryDomainId, ['domain_id_type', 'domain_id_name'], name, value)


                    class FastReroute(Entity):
                        """
                        Fast\-reroute instance scoped parameters
                        
                        .. attribute:: per_link
                        
                        	Fast\-reroute per\-link global configuration
                        	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink>`
                        
                        .. attribute:: per_prefix
                        
                        	Fast\-reroute per\-prefix global configuration
                        	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix)}
                            self._child_list_classes = {}

                            self.per_link = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink()
                            self.per_link.parent = self
                            self._children_name_map["per_link"] = "per-link"
                            self._children_yang_names.add("per-link")

                            self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix()
                            self.per_prefix.parent = self
                            self._children_name_map["per_prefix"] = "per-prefix"
                            self._children_yang_names.add("per-prefix")
                            self._segment_path = lambda: "fast-reroute"


                        class PerLink(Entity):
                            """
                            Fast\-reroute per\-link global configuration
                            
                            .. attribute:: priority
                            
                            	Fast\-reroute per\-link/per\-prefix priority\-limit command
                            	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink, self).__init__()

                                self.yang_name = "per-link"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.priority = YLeaf(YType.enumeration, "priority")
                                self._segment_path = lambda: "per-link"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerLink, ['priority'], name, value)


                        class PerPrefix(Entity):
                            """
                            Fast\-reroute per\-prefix global configuration
                            
                            .. attribute:: load_sharing_disable
                            
                            	Disable load sharing between multiple backups
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: priority
                            
                            	Fast\-reroute per\-link/per\-prefix priority\-limit command
                            	**type**\:   :py:class:`OspfFastReroutePriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastReroutePriority>`
                            
                            .. attribute:: tiebreakers
                            
                            	Fast\-reroute tiebreakers configurations
                            	**type**\:   :py:class:`Tiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix, self).__init__()

                                self.yang_name = "per-prefix"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"tiebreakers" : ("tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers)}
                                self._child_list_classes = {}

                                self.load_sharing_disable = YLeaf(YType.empty, "load-sharing-disable")

                                self.priority = YLeaf(YType.enumeration, "priority")

                                self.tiebreakers = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers()
                                self.tiebreakers.parent = self
                                self._children_name_map["tiebreakers"] = "tiebreakers"
                                self._children_yang_names.add("tiebreakers")
                                self._segment_path = lambda: "per-prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix, ['load_sharing_disable', 'priority'], name, value)


                            class Tiebreakers(Entity):
                                """
                                Fast\-reroute tiebreakers configurations
                                
                                .. attribute:: tiebreaker
                                
                                	Fast\-reroute tiebreakers configuration
                                	**type**\: list of    :py:class:`Tiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers, self).__init__()

                                    self.yang_name = "tiebreakers"
                                    self.yang_parent_name = "per-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"tiebreaker" : ("tiebreaker", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker)}

                                    self.tiebreaker = YList(self)
                                    self._segment_path = lambda: "tiebreakers"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers, [], name, value)


                                class Tiebreaker(Entity):
                                    """
                                    Fast\-reroute tiebreakers configuration
                                    
                                    .. attribute:: tiebreaker_type  <key>
                                    
                                    	Tiebreaker type
                                    	**type**\:   :py:class:`OspfFastRerouteTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfFastRerouteTiebreakers>`
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Index value for a tiebreaker, 0 to disable
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, self).__init__()

                                        self.yang_name = "tiebreaker"
                                        self.yang_parent_name = "tiebreakers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")

                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")
                                        self._segment_path = lambda: "tiebreaker" + "[tiebreaker-type='" + self.tiebreaker_type.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.PerPrefix.Tiebreakers.Tiebreaker, ['tiebreaker_type', 'tiebreaker_index'], name, value)


                    class MaxLsa(Entity):
                        """
                        Set max\-lsa configuration
                        
                        .. attribute:: max_lsa_ignore_count
                        
                        	Set count on how many times adjacencies can be suppressed
                        	**type**\:  int
                        
                        	**range:** 1..4294967294
                        
                        .. attribute:: max_lsa_ignore_time
                        
                        	Set time during which all adjacencies are suppressed
                        	**type**\:  int
                        
                        	**range:** 1..35791394
                        
                        .. attribute:: max_lsa_limit
                        
                        	Set maximum number of non self\-generated LSAs
                        	**type**\:  int
                        
                        	**range:** 1..4294967294
                        
                        	**mandatory**\: True
                        
                        .. attribute:: max_lsa_reset_time
                        
                        	Set number of minutes after which ignore\-count is reset to zero
                        	**type**\:  int
                        
                        	**range:** 2..71582788
                        
                        	**units**\: minute
                        
                        .. attribute:: max_lsa_threshold
                        
                        	Set max\-lsa threshold for generating a warning message
                        	**type**\:  int
                        
                        	**range:** 1..100
                        
                        .. attribute:: max_lsa_warning_only
                        
                        	Only give warning message when limit is exceeded
                        	**type**\:  bool
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxLsa, self).__init__()

                            self.yang_name = "max-lsa"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                            self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                            self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                            self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                            self.max_lsa_threshold = YLeaf(YType.uint32, "max-lsa-threshold")

                            self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")
                            self._segment_path = lambda: "max-lsa"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxLsa, ['max_lsa_ignore_count', 'max_lsa_ignore_time', 'max_lsa_limit', 'max_lsa_reset_time', 'max_lsa_threshold', 'max_lsa_warning_only'], name, value)


                    class MaxMetric(Entity):
                        """
                        Set maximum metric configuration
                        
                        .. attribute:: max_metric_always
                        
                        	Set maximum metric always configuration
                        	**type**\:   :py:class:`MaxMetricAlways <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways>`
                        
                        .. attribute:: max_metric_no_abr_off
                        
                        	Block ABR\-disable mode entry while in max\-metric mode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: max_metric_on_proc_migration
                        
                        	Set maximum metric on\-proc\-migration configuration
                        	**type**\:   :py:class:`MaxMetricOnProcMigration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration>`
                        
                        .. attribute:: max_metric_on_proc_restart
                        
                        	Set maximum metric on\-proc\-restart configuration
                        	**type**\:   :py:class:`MaxMetricOnProcRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart>`
                        
                        .. attribute:: max_metric_on_startup
                        
                        	Set maximum metric on\-startup configuration
                        	**type**\:   :py:class:`MaxMetricOnStartup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup>`
                        
                        .. attribute:: max_metric_on_switchover
                        
                        	Set maximum metric on\-switchover configuration
                        	**type**\:   :py:class:`MaxMetricOnSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric, self).__init__()

                            self.yang_name = "max-metric"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"max-metric-always" : ("max_metric_always", Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways), "max-metric-on-proc-migration" : ("max_metric_on_proc_migration", Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration), "max-metric-on-proc-restart" : ("max_metric_on_proc_restart", Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart), "max-metric-on-startup" : ("max_metric_on_startup", Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup), "max-metric-on-switchover" : ("max_metric_on_switchover", Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover)}
                            self._child_list_classes = {}

                            self.max_metric_no_abr_off = YLeaf(YType.empty, "max-metric-no-abr-off")

                            self.max_metric_always = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways()
                            self.max_metric_always.parent = self
                            self._children_name_map["max_metric_always"] = "max-metric-always"
                            self._children_yang_names.add("max-metric-always")

                            self.max_metric_on_proc_migration = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration()
                            self.max_metric_on_proc_migration.parent = self
                            self._children_name_map["max_metric_on_proc_migration"] = "max-metric-on-proc-migration"
                            self._children_yang_names.add("max-metric-on-proc-migration")

                            self.max_metric_on_proc_restart = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart()
                            self.max_metric_on_proc_restart.parent = self
                            self._children_name_map["max_metric_on_proc_restart"] = "max-metric-on-proc-restart"
                            self._children_yang_names.add("max-metric-on-proc-restart")

                            self.max_metric_on_startup = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup()
                            self.max_metric_on_startup.parent = self
                            self._children_name_map["max_metric_on_startup"] = "max-metric-on-startup"
                            self._children_yang_names.add("max-metric-on-startup")

                            self.max_metric_on_switchover = Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover()
                            self.max_metric_on_switchover.parent = self
                            self._children_name_map["max_metric_on_switchover"] = "max-metric-on-switchover"
                            self._children_yang_names.add("max-metric-on-switchover")
                            self._segment_path = lambda: "max-metric"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric, ['max_metric_no_abr_off'], name, value)


                        class MaxMetricAlways(Entity):
                            """
                            Set maximum metric always configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways, self).__init__()

                                self.yang_name = "max-metric-always"
                                self.yang_parent_name = "max-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")
                                self._segment_path = lambda: "max-metric-always"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricAlways, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'summary_lsa', 'summary_lsa_maximum_metric'], name, value)


                        class MaxMetricOnProcMigration(Entity):
                            """
                            Set maximum metric on\-proc\-migration
                            configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration, self).__init__()

                                self.yang_name = "max-metric-on-proc-migration"
                                self.yang_parent_name = "max-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                                self._segment_path = lambda: "max-metric-on-proc-migration"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcMigration, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                        class MaxMetricOnProcRestart(Entity):
                            """
                            Set maximum metric on\-proc\-restart
                            configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart, self).__init__()

                                self.yang_name = "max-metric-on-proc-restart"
                                self.yang_parent_name = "max-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                                self._segment_path = lambda: "max-metric-on-proc-restart"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnProcRestart, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                        class MaxMetricOnStartup(Entity):
                            """
                            Set maximum metric on\-startup configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup, self).__init__()

                                self.yang_name = "max-metric-on-startup"
                                self.yang_parent_name = "max-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                                self._segment_path = lambda: "max-metric-on-startup"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnStartup, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                        class MaxMetricOnSwitchover(Entity):
                            """
                            Set maximum metric on\-switchover configuration
                            
                            .. attribute:: external_lsa
                            
                            	Override external\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: external_lsa_maximum_metric
                            
                            	Overriding metric in external\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: include_stub
                            
                            	Set maximum metric for stub links in router\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: startup_max
                            
                            	Time in seconds to originate router\-LSA with max\-metric
                            	**type**\:  int
                            
                            	**range:** 5..86400
                            
                            	**units**\: second
                            
                            .. attribute:: summary_lsa
                            
                            	Override summary\-lsa metric with max\-metric value
                            	**type**\:  bool
                            
                            .. attribute:: summary_lsa_maximum_metric
                            
                            	Overriding metric in summary\-LSAs (default 16711680)
                            	**type**\:  int
                            
                            	**range:** 1..16777215
                            
                            .. attribute:: wait_for_bgp
                            
                            	Let BGP decide when to originate router\-LSA with normal metric
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover, self).__init__()

                                self.yang_name = "max-metric-on-switchover"
                                self.yang_parent_name = "max-metric"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_lsa = YLeaf(YType.boolean, "external-lsa")

                                self.external_lsa_maximum_metric = YLeaf(YType.uint32, "external-lsa-maximum-metric")

                                self.include_stub = YLeaf(YType.boolean, "include-stub")

                                self.startup_max = YLeaf(YType.uint32, "startup-max")

                                self.summary_lsa = YLeaf(YType.boolean, "summary-lsa")

                                self.summary_lsa_maximum_metric = YLeaf(YType.uint32, "summary-lsa-maximum-metric")

                                self.wait_for_bgp = YLeaf(YType.boolean, "wait-for-bgp")
                                self._segment_path = lambda: "max-metric-on-switchover"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaxMetric.MaxMetricOnSwitchover, ['external_lsa', 'external_lsa_maximum_metric', 'include_stub', 'startup_max', 'summary_lsa', 'summary_lsa_maximum_metric', 'wait_for_bgp'], name, value)


                    class MaximumRedistributePrefix(Entity):
                        """
                        Maximum number of prefixes redistributed into
                        OSPF
                        
                        .. attribute:: number_of_prefixes
                        
                        	Maximum number of prefixes redistributed
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: threshold
                        
                        	Threshold value (%) at which to generate a warning msg
                        	**type**\:  int
                        
                        	**range:** 1..100
                        
                        .. attribute:: warning_only
                        
                        	Only give warning messsage when limit is exceeded
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix, self).__init__()

                            self.yang_name = "maximum-redistribute-prefix"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.number_of_prefixes = YLeaf(YType.uint32, "number-of-prefixes")

                            self.threshold = YLeaf(YType.uint32, "threshold")

                            self.warning_only = YLeaf(YType.boolean, "warning-only")
                            self._segment_path = lambda: "maximum-redistribute-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MaximumRedistributePrefix, ['number_of_prefixes', 'threshold', 'warning_only'], name, value)


                    class Microloop(Entity):
                        """
                        Microloop configuration
                        
                        .. attribute:: avoidance
                        
                        	Microloop avoidance configuration
                        	**type**\:   :py:class:`Avoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Microloop, self).__init__()

                            self.yang_name = "microloop"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"avoidance" : ("avoidance", Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance)}
                            self._child_list_classes = {}

                            self.avoidance = Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance()
                            self.avoidance.parent = self
                            self._children_name_map["avoidance"] = "avoidance"
                            self._children_yang_names.add("avoidance")
                            self._segment_path = lambda: "microloop"


                        class Avoidance(Entity):
                            """
                            Microloop avoidance configuration
                            
                            .. attribute:: enable
                            
                            	MicroLoop avoidance feature enable configuration
                            	**type**\:   :py:class:`OspfUloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfUloopAvoidance>`
                            
                            	**default value**\: all
                            
                            .. attribute:: rib_update_delay
                            
                            	Delay to introduce between SPF and RIB update in msecs
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 5000
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance, self).__init__()

                                self.yang_name = "avoidance"
                                self.yang_parent_name = "microloop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.enable = YLeaf(YType.enumeration, "enable")

                                self.rib_update_delay = YLeaf(YType.uint32, "rib-update-delay")
                                self._segment_path = lambda: "avoidance"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Microloop.Avoidance, ['enable', 'rib_update_delay'], name, value)


                    class Nsf(Entity):
                        """
                        Non Stop Forwarding configuration
                        
                        .. attribute:: cisco
                        
                        	Enable Cisco Non Stop Forwarding
                        	**type**\:   :py:class:`OspfCiscoNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfCiscoNsf>`
                        
                        .. attribute:: flush_delay_time
                        
                        	Maximum time allowed for external route learning (seconds)
                        	**type**\:  int
                        
                        	**range:** 1..3600
                        
                        	**units**\: second
                        
                        	**default value**\: 60
                        
                        .. attribute:: ietf
                        
                        	Enable IETF Non Stop Forwarding
                        	**type**\:   :py:class:`OspfIetfNsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsf>`
                        
                        .. attribute:: ietf_strict_lsa_checking
                        
                        	Enable Strict LSA checking of IETF NSF
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ietf_support_role
                        
                        	Disable helper support role for IETF Non Stop Forwarding
                        	**type**\:   :py:class:`OspfIetfNsfSupport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfIetfNsfSupport>`
                        
                        .. attribute:: interval
                        
                        	Minimum interval between Non Stop Forwarding restarts in seconds
                        	**type**\:  int
                        
                        	**range:** 90..3600
                        
                        	**units**\: second
                        
                        	**default value**\: 90
                        
                        .. attribute:: lifetime
                        
                        	Maximum route lifetime following restart in seconds
                        	**type**\:  int
                        
                        	**range:** 90..1800
                        
                        	**units**\: second
                        
                        	**default value**\: 90
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Nsf, self).__init__()

                            self.yang_name = "nsf"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.cisco = YLeaf(YType.enumeration, "cisco")

                            self.flush_delay_time = YLeaf(YType.uint32, "flush-delay-time")

                            self.ietf = YLeaf(YType.enumeration, "ietf")

                            self.ietf_strict_lsa_checking = YLeaf(YType.empty, "ietf-strict-lsa-checking")

                            self.ietf_support_role = YLeaf(YType.enumeration, "ietf-support-role")

                            self.interval = YLeaf(YType.uint32, "interval")

                            self.lifetime = YLeaf(YType.uint32, "lifetime")
                            self._segment_path = lambda: "nsf"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Nsf, ['cisco', 'flush_delay_time', 'ietf', 'ietf_strict_lsa_checking', 'ietf_support_role', 'interval', 'lifetime'], name, value)


                    class OutgoingRouteUpdates(Entity):
                        """
                        Filter outgoing routing updates
                        
                        .. attribute:: outgoing_route_update
                        
                        	Filter outgoing routing updates for a particular protocol
                        	**type**\: list of    :py:class:`OutgoingRouteUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates, self).__init__()

                            self.yang_name = "outgoing-route-updates"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"outgoing-route-update" : ("outgoing_route_update", Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate)}

                            self.outgoing_route_update = YList(self)
                            self._segment_path = lambda: "outgoing-route-updates"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates, [], name, value)


                        class OutgoingRouteUpdate(Entity):
                            """
                            Filter outgoing routing updates for a
                            particular protocol
                            
                            .. attribute:: protocol_name  <key>
                            
                            	Distribute list protocol type
                            	**type**\:   :py:class:`OspfDistListProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfDistListProtocol>`
                            
                            .. attribute:: access_list_name
                            
                            	Access Control List name
                            	**type**\:  str
                            
                            .. attribute:: as_xx
                            
                            	First half of BGP AS number in XX.YY format.  Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_yy
                            
                            	Second half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ospf_process_name
                            
                            	OSPF process name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate, self).__init__()

                                self.yang_name = "outgoing-route-update"
                                self.yang_parent_name = "outgoing-route-updates"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                self.as_yy = YLeaf(YType.uint32, "as-yy")

                                self.ospf_process_name = YLeaf(YType.str, "ospf-process-name")
                                self._segment_path = lambda: "outgoing-route-update" + "[protocol-name='" + self.protocol_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.OutgoingRouteUpdates.OutgoingRouteUpdate, ['protocol_name', 'access_list_name', 'as_xx', 'as_yy', 'ospf_process_name'], name, value)


                    class ProcessScope(Entity):
                        """
                        Process scope configuration
                        
                        .. attribute:: authentication
                        
                        	Authentication
                        	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication>`
                        
                        .. attribute:: bfd
                        
                        	BFD configuration
                        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd>`
                        
                        .. attribute:: cost
                        
                        	Interface cost
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        .. attribute:: cost_fallback
                        
                        	Interface fallback cost
                        	**type**\:   :py:class:`CostFallback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback>`
                        
                        .. attribute:: database_filter
                        
                        	Filter OSPF LSA during synchronization and flooding
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: dead_interval_minimal
                        
                        	Interval after which a neighbor is declared dead
                        	**type**\:   :py:class:`DeadIntervalMinimal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal>`
                        
                        .. attribute:: demand_circuit
                        
                        	Enable/Disable OSPF demand circuit
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: distribute_list
                        
                        	Filter networks intalled to RIB (disable as ACL name means filtering is disabled)
                        	**type**\:   :py:class:`DistributeList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: external_out
                        
                        	Enable/Disable an OSPF area to advertise intra\-area prefixes out of this area as external
                        	**type**\:  bool
                        
                        .. attribute:: fast_reroute
                        
                        	Fast\-reroute configuration
                        	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute>`
                        
                        .. attribute:: flood_reduction
                        
                        	Enable/Disable OSPF flood reduction
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: hello_interval
                        
                        	Interval between HELLO packets in seconds
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        .. attribute:: ldp_auto_config
                        
                        	Enable MPLS LDP Auto Config
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ldp_sync
                        
                        	Enable/Disable MPLS LDP sync
                        	**type**\:  bool
                        
                        .. attribute:: ldp_sync_igp_shortcuts
                        
                        	Enable/Disable MPLS LDP sync for igp\-shortcuts
                        	**type**\:  bool
                        
                        .. attribute:: link_down_fast_detect
                        
                        	Enable/Disable registration for early interface down notifications
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: loopback_stub_network
                        
                        	Enable/Disable advertising loopback as a stub network
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: mtu_ignore
                        
                        	Enable/Disable ignoring of MTU in DBD packets
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: network_type
                        
                        	Type of attached network
                        	**type**\:   :py:class:`OspfNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfNetwork>`
                        
                        .. attribute:: packet_size
                        
                        	Customize size of OSPF packets upto MTU
                        	**type**\:  int
                        
                        	**range:** 576..10000
                        
                        .. attribute:: passive
                        
                        	When enabled, prevent sending HELLO packets over link
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: prefix_suppression_primary
                        
                        	Enable/Disable prefix suppression for primary addresses
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: prefix_suppression_secondary
                        
                        	Enable/Disable prefix suppression for secondary addresses
                        	**type**\:  bool
                        
                        	**default value**\: false
                        
                        .. attribute:: priority
                        
                        	Router priority for DR and BDR election
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**default value**\: 1
                        
                        .. attribute:: retransmit_interval
                        
                        	Time in seconds between retransmitting lost link state advertisements
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        	**default value**\: 5
                        
                        .. attribute:: security
                        
                        	Container class for security related configuration parameters
                        	**type**\:   :py:class:`Security <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security>`
                        
                        .. attribute:: segment_routing
                        
                        	segment\-routing configuration Applicable only in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRouting>`
                        
                        .. attribute:: segment_routing_forwarding
                        
                        	segment\-routing forwarding configuration Applicableonly in Default VRF
                        	**type**\:   :py:class:`OspfSegmentRoutingForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfSegmentRoutingForwarding>`
                        
                        .. attribute:: srgb
                        
                        	Segment Routing Global Block configuration
                        	**type**\:   :py:class:`Srgb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: summary_in
                        
                        	Enable/Disable an OSPF area to advertise external prefixes into this area as summary
                        	**type**\:  bool
                        
                        .. attribute:: transmit_delay
                        
                        	Number of seconds to delay transmission of LSAs
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**units**\: second
                        
                        	**default value**\: 1
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope, self).__init__()

                            self.yang_name = "process-scope"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"authentication" : ("authentication", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication), "bfd" : ("bfd", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd), "cost-fallback" : ("cost_fallback", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback), "dead-interval-minimal" : ("dead_interval_minimal", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal), "distribute-list" : ("distribute_list", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute), "security" : ("security", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security), "srgb" : ("srgb", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb)}
                            self._child_list_classes = {}

                            self.cost = YLeaf(YType.uint32, "cost")

                            self.database_filter = YLeaf(YType.boolean, "database-filter")

                            self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                            self.external_out = YLeaf(YType.boolean, "external-out")

                            self.flood_reduction = YLeaf(YType.boolean, "flood-reduction")

                            self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                            self.ldp_auto_config = YLeaf(YType.empty, "ldp-auto-config")

                            self.ldp_sync = YLeaf(YType.boolean, "ldp-sync")

                            self.ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "ldp-sync-igp-shortcuts")

                            self.link_down_fast_detect = YLeaf(YType.boolean, "link-down-fast-detect")

                            self.loopback_stub_network = YLeaf(YType.boolean, "loopback-stub-network")

                            self.mtu_ignore = YLeaf(YType.boolean, "mtu-ignore")

                            self.network_type = YLeaf(YType.enumeration, "network-type")

                            self.packet_size = YLeaf(YType.uint32, "packet-size")

                            self.passive = YLeaf(YType.boolean, "passive")

                            self.prefix_suppression_primary = YLeaf(YType.boolean, "prefix-suppression-primary")

                            self.prefix_suppression_secondary = YLeaf(YType.boolean, "prefix-suppression-secondary")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.retransmit_interval = YLeaf(YType.uint32, "retransmit-interval")

                            self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                            self.segment_routing_forwarding = YLeaf(YType.enumeration, "segment-routing-forwarding")

                            self.summary_in = YLeaf(YType.boolean, "summary-in")

                            self.transmit_delay = YLeaf(YType.uint32, "transmit-delay")

                            self.authentication = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication()
                            self.authentication.parent = self
                            self._children_name_map["authentication"] = "authentication"
                            self._children_yang_names.add("authentication")

                            self.bfd = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"
                            self._children_yang_names.add("bfd")

                            self.cost_fallback = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback()
                            self.cost_fallback.parent = self
                            self._children_name_map["cost_fallback"] = "cost-fallback"
                            self._children_yang_names.add("cost-fallback")

                            self.dead_interval_minimal = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal()
                            self.dead_interval_minimal.parent = self
                            self._children_name_map["dead_interval_minimal"] = "dead-interval-minimal"
                            self._children_yang_names.add("dead-interval-minimal")

                            self.distribute_list = None
                            self._children_name_map["distribute_list"] = "distribute-list"
                            self._children_yang_names.add("distribute-list")

                            self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute()
                            self.fast_reroute.parent = self
                            self._children_name_map["fast_reroute"] = "fast-reroute"
                            self._children_yang_names.add("fast-reroute")

                            self.security = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security()
                            self.security.parent = self
                            self._children_name_map["security"] = "security"
                            self._children_yang_names.add("security")

                            self.srgb = None
                            self._children_name_map["srgb"] = "srgb"
                            self._children_yang_names.add("srgb")
                            self._segment_path = lambda: "process-scope"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope, ['cost', 'database_filter', 'demand_circuit', 'external_out', 'flood_reduction', 'hello_interval', 'ldp_auto_config', 'ldp_sync', 'ldp_sync_igp_shortcuts', 'link_down_fast_detect', 'loopback_stub_network', 'mtu_ignore', 'network_type', 'packet_size', 'passive', 'prefix_suppression_primary', 'prefix_suppression_secondary', 'priority', 'retransmit_interval', 'segment_routing', 'segment_routing_forwarding', 'summary_in', 'transmit_delay'], name, value)


                        class Authentication(Entity):
                            """
                            Authentication
                            
                            .. attribute:: key
                            
                            	Authentication key configuration
                            	**type**\:  str
                            
                            	**pattern:** (!.+)\|([^!].+)
                            
                            .. attribute:: message_digest_keies
                            
                            	Message digest authentication password (key) configurations, first 16 chars used
                            	**type**\:   :py:class:`MessageDigestKeies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies>`
                            
                            .. attribute:: type
                            
                            	Authentication type
                            	**type**\:   :py:class:`Type <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication, self).__init__()

                                self.yang_name = "authentication"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"message-digest-keies" : ("message_digest_keies", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies), "type" : ("type", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type)}
                                self._child_list_classes = {}

                                self.key = YLeaf(YType.str, "key")

                                self.message_digest_keies = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies()
                                self.message_digest_keies.parent = self
                                self._children_name_map["message_digest_keies"] = "message-digest-keies"
                                self._children_yang_names.add("message-digest-keies")

                                self.type = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type()
                                self.type.parent = self
                                self._children_name_map["type"] = "type"
                                self._children_yang_names.add("type")
                                self._segment_path = lambda: "authentication"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication, ['key'], name, value)


                            class MessageDigestKeies(Entity):
                                """
                                Message digest authentication password (key)
                                configurations, first 16 chars used
                                
                                .. attribute:: message_digest_key
                                
                                	Message digest authentication password (key) configuration
                                	**type**\: list of    :py:class:`MessageDigestKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies, self).__init__()

                                    self.yang_name = "message-digest-keies"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"message-digest-key" : ("message_digest_key", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey)}

                                    self.message_digest_key = YList(self)
                                    self._segment_path = lambda: "message-digest-keies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies, [], name, value)


                                class MessageDigestKey(Entity):
                                    """
                                    Message digest authentication password (key)
                                    configuration
                                    
                                    .. attribute:: key_id  <key>
                                    
                                    	Key ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    .. attribute:: password
                                    
                                    	Password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, self).__init__()

                                        self.yang_name = "message-digest-key"
                                        self.yang_parent_name = "message-digest-keies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.key_id = YLeaf(YType.uint32, "key-id")

                                        self.password = YLeaf(YType.str, "password")
                                        self._segment_path = lambda: "message-digest-key" + "[key-id='" + self.key_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.MessageDigestKeies.MessageDigestKey, ['key_id', 'password'], name, value)


                            class Type(Entity):
                                """
                                Authentication type
                                
                                .. attribute:: authen_type
                                
                                	Authentication type code 
                                	**type**\:   :py:class:`OspfAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfAuthentication>`
                                
                                .. attribute:: keychain_authen_type
                                
                                	Keychain authentication type
                                	**type**\:   :py:class:`OspfKeychainAuth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfKeychainAuth>`
                                
                                .. attribute:: keychain_name
                                
                                	Keychain name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type, self).__init__()

                                    self.yang_name = "type"
                                    self.yang_parent_name = "authentication"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.authen_type = YLeaf(YType.enumeration, "authen-type")

                                    self.keychain_authen_type = YLeaf(YType.enumeration, "keychain-authen-type")

                                    self.keychain_name = YLeaf(YType.str, "keychain-name")
                                    self._segment_path = lambda: "type"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Authentication.Type, ['authen_type', 'keychain_authen_type', 'keychain_name'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration
                            
                            .. attribute:: detection_multiplier
                            
                            	Detection multiplier for BFD sessions created by OSPF
                            	**type**\:  int
                            
                            	**range:** 2..50
                            
                            .. attribute:: fast_detect_mode
                            
                            	 use of Bidirectional Forwarding Detection
                            	**type**\:   :py:class:`BfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.BfdEnableMode>`
                            
                            .. attribute:: interval
                            
                            	Hello interval for BFD sessions created by OSPF
                            	**type**\:  int
                            
                            	**range:** 3..30000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                self.fast_detect_mode = YLeaf(YType.enumeration, "fast-detect-mode")

                                self.interval = YLeaf(YType.uint32, "interval")
                                self._segment_path = lambda: "bfd"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Bfd, ['detection_multiplier', 'fast_detect_mode', 'interval'], name, value)


                        class CostFallback(Entity):
                            """
                            Interface fallback cost
                            
                            .. attribute:: cost
                            
                            	Fallback cost of link
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: threshold
                            
                            	Bandwidth threshold
                            	**type**\:  int
                            
                            	**range:** 1..4294967
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback, self).__init__()

                                self.yang_name = "cost-fallback"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.cost = YLeaf(YType.uint32, "cost")

                                self.threshold = YLeaf(YType.uint32, "threshold")
                                self._segment_path = lambda: "cost-fallback"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.CostFallback, ['cost', 'threshold'], name, value)


                        class DeadIntervalMinimal(Entity):
                            """
                            Interval after which a neighbor is declared dead
                            
                            .. attribute:: interval
                            
                            	Interval size in seconds after which a neighbor is declared dead
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**units**\: second
                            
                            .. attribute:: multiplier
                            
                            	Number of Hellos in one second
                            	**type**\:  int
                            
                            	**range:** 3..20
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal, self).__init__()

                                self.yang_name = "dead-interval-minimal"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.interval = YLeaf(YType.uint32, "interval")

                                self.multiplier = YLeaf(YType.uint32, "multiplier")
                                self._segment_path = lambda: "dead-interval-minimal"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DeadIntervalMinimal, ['interval', 'multiplier'], name, value)


                        class DistributeList(Entity):
                            """
                            Filter networks intalled to RIB (disable as ACL
                            name means filtering is disabled)
                            
                            .. attribute:: access_list_name
                            
                            	Access Control List name
                            	**type**\:  str
                            
                            .. attribute:: route_policy_name
                            
                            	Route Policy name
                            	**type**\:  str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList, self).__init__()

                                self.yang_name = "distribute-list"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.access_list_name = YLeaf(YType.str, "access-list-name")

                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                self._segment_path = lambda: "distribute-list"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.DistributeList, ['access_list_name', 'route_policy_name'], name, value)


                        class FastReroute(Entity):
                            """
                            Fast\-reroute configuration
                            
                            .. attribute:: fast_reroute_enable
                            
                            	Enable/Disable Fast\-reroute per\-link or per\-prefix
                            	**type**\:   :py:class:`OspfProcFastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFastReroute>`
                            
                            .. attribute:: per_link
                            
                            	Fast\-reroute per\-link configuration
                            	**type**\:   :py:class:`PerLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink>`
                            
                            .. attribute:: per_prefix
                            
                            	Fast\-reroute per\-prefix configuration
                            	**type**\:   :py:class:`PerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"per-link" : ("per_link", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink), "per-prefix" : ("per_prefix", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix)}
                                self._child_list_classes = {}

                                self.fast_reroute_enable = YLeaf(YType.enumeration, "fast-reroute-enable")

                                self.per_link = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink()
                                self.per_link.parent = self
                                self._children_name_map["per_link"] = "per-link"
                                self._children_yang_names.add("per-link")

                                self.per_prefix = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix()
                                self.per_prefix.parent = self
                                self._children_name_map["per_prefix"] = "per-prefix"
                                self._children_yang_names.add("per-prefix")
                                self._segment_path = lambda: "fast-reroute"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute, ['fast_reroute_enable'], name, value)


                            class PerLink(Entity):
                                """
                                Fast\-reroute per\-link configuration
                                
                                .. attribute:: candidate_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces>`
                                
                                .. attribute:: exclude_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces>`
                                
                                .. attribute:: fast_reroute_use_candidate_only
                                
                                	Use only interfaces on the candidate list as a backup path
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink, self).__init__()

                                    self.yang_name = "per-link"
                                    self.yang_parent_name = "fast-reroute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces)}
                                    self._child_list_classes = {}

                                    self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces()
                                    self.candidate_interfaces.parent = self
                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                    self._children_yang_names.add("candidate-interfaces")

                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                    self._children_yang_names.add("exclude-interfaces")
                                    self._segment_path = lambda: "per-link"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink, ['fast_reroute_use_candidate_only'], name, value)


                                class CandidateInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix candidate
                                    interface configuration
                                    
                                    .. attribute:: candidate_interface
                                    
                                    	Candidate backup interface
                                    	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, self).__init__()

                                        self.yang_name = "candidate-interfaces"
                                        self.yang_parent_name = "per-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface)}

                                        self.candidate_interface = YList(self)
                                        self._segment_path = lambda: "candidate-interfaces"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces, [], name, value)


                                    class CandidateInterface(Entity):
                                        """
                                        Candidate backup interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, self).__init__()

                                            self.yang_name = "candidate-interface"
                                            self.yang_parent_name = "candidate-interfaces"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                class ExcludeInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                    interface configuration
                                    
                                    .. attribute:: exclude_interface
                                    
                                    	Exclude an interface from becoming a backup or UCMP
                                    	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, self).__init__()

                                        self.yang_name = "exclude-interfaces"
                                        self.yang_parent_name = "per-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface)}

                                        self.exclude_interface = YList(self)
                                        self._segment_path = lambda: "exclude-interfaces"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces, [], name, value)


                                    class ExcludeInterface(Entity):
                                        """
                                        Exclude an interface from becoming a backup or
                                        UCMP
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                            self.yang_name = "exclude-interface"
                                            self.yang_parent_name = "exclude-interfaces"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerLink.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                            class PerPrefix(Entity):
                                """
                                Fast\-reroute per\-prefix configuration
                                
                                .. attribute:: candidate_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix candidate interface configuration
                                	**type**\:   :py:class:`CandidateInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces>`
                                
                                .. attribute:: exclude_interfaces
                                
                                	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                                	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces>`
                                
                                .. attribute:: fast_reroute_use_candidate_only
                                
                                	Use only interfaces on the candidate list as a backup path
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: remote_lfa
                                
                                	Remote LFA configuration
                                	**type**\:   :py:class:`RemoteLfa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa>`
                                
                                .. attribute:: topology_independent_lfa
                                
                                	Topology Independet LFA configuration
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix, self).__init__()

                                    self.yang_name = "per-prefix"
                                    self.yang_parent_name = "fast-reroute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"candidate-interfaces" : ("candidate_interfaces", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces), "remote-lfa" : ("remote_lfa", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa)}
                                    self._child_list_classes = {}

                                    self.fast_reroute_use_candidate_only = YLeaf(YType.boolean, "fast-reroute-use-candidate-only")

                                    self.topology_independent_lfa = YLeaf(YType.boolean, "topology-independent-lfa")

                                    self.candidate_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces()
                                    self.candidate_interfaces.parent = self
                                    self._children_name_map["candidate_interfaces"] = "candidate-interfaces"
                                    self._children_yang_names.add("candidate-interfaces")

                                    self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces()
                                    self.exclude_interfaces.parent = self
                                    self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                                    self._children_yang_names.add("exclude-interfaces")

                                    self.remote_lfa = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa()
                                    self.remote_lfa.parent = self
                                    self._children_name_map["remote_lfa"] = "remote-lfa"
                                    self._children_yang_names.add("remote-lfa")
                                    self._segment_path = lambda: "per-prefix"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix, ['fast_reroute_use_candidate_only', 'topology_independent_lfa'], name, value)


                                class CandidateInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix candidate
                                    interface configuration
                                    
                                    .. attribute:: candidate_interface
                                    
                                    	Candidate backup interface
                                    	**type**\: list of    :py:class:`CandidateInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, self).__init__()

                                        self.yang_name = "candidate-interfaces"
                                        self.yang_parent_name = "per-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"candidate-interface" : ("candidate_interface", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface)}

                                        self.candidate_interface = YList(self)
                                        self._segment_path = lambda: "candidate-interfaces"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces, [], name, value)


                                    class CandidateInterface(Entity):
                                        """
                                        Candidate backup interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, self).__init__()

                                            self.yang_name = "candidate-interface"
                                            self.yang_parent_name = "candidate-interfaces"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "candidate-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.CandidateInterfaces.CandidateInterface, ['interface_name'], name, value)


                                class ExcludeInterfaces(Entity):
                                    """
                                    Fast\-reroute per\-link/per\-prefix or UCMP exclude
                                    interface configuration
                                    
                                    .. attribute:: exclude_interface
                                    
                                    	Exclude an interface from becoming a backup or UCMP
                                    	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, self).__init__()

                                        self.yang_name = "exclude-interfaces"
                                        self.yang_parent_name = "per-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface)}

                                        self.exclude_interface = YList(self)
                                        self._segment_path = lambda: "exclude-interfaces"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces, [], name, value)


                                    class ExcludeInterface(Entity):
                                        """
                                        Exclude an interface from becoming a backup or
                                        UCMP
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-cfg'
                                        _revision = '2017-07-14'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                            self.yang_name = "exclude-interface"
                                            self.yang_parent_name = "exclude-interfaces"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")
                                            self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)


                                class RemoteLfa(Entity):
                                    """
                                    Remote LFA configuration
                                    
                                    .. attribute:: maximum_cost
                                    
                                    	Maximum path cost to remote LFA
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    .. attribute:: tunnel
                                    
                                    	Enable/Disable remote LFA computation
                                    	**type**\:   :py:class:`OspfProcFrrRlfaTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfProcFrrRlfaTunnel>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, self).__init__()

                                        self.yang_name = "remote-lfa"
                                        self.yang_parent_name = "per-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.maximum_cost = YLeaf(YType.uint32, "maximum-cost")

                                        self.tunnel = YLeaf(YType.enumeration, "tunnel")
                                        self._segment_path = lambda: "remote-lfa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.FastReroute.PerPrefix.RemoteLfa, ['maximum_cost', 'tunnel'], name, value)


                        class Security(Entity):
                            """
                            Container class for security related
                            configuration parameters
                            
                            .. attribute:: ttl
                            
                            	Enabling turns on TTL security
                            	**type**\:   :py:class:`Ttl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security, self).__init__()

                                self.yang_name = "security"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ttl" : ("ttl", Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl)}
                                self._child_list_classes = {}

                                self.ttl = Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl()
                                self.ttl.parent = self
                                self._children_name_map["ttl"] = "ttl"
                                self._children_yang_names.add("ttl")
                                self._segment_path = lambda: "security"


                            class Ttl(Entity):
                                """
                                Enabling turns on TTL security
                                
                                .. attribute:: enable
                                
                                	Enable TTL security
                                	**type**\:  bool
                                
                                .. attribute:: hop_count
                                
                                	Hop count
                                	**type**\:  int
                                
                                	**range:** 1..254
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl, self).__init__()

                                    self.yang_name = "ttl"
                                    self.yang_parent_name = "security"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.enable = YLeaf(YType.boolean, "enable")

                                    self.hop_count = YLeaf(YType.uint32, "hop-count")
                                    self._segment_path = lambda: "ttl"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Security.Ttl, ['enable', 'hop_count'], name, value)


                        class Srgb(Entity):
                            """
                            Segment Routing Global Block configuration
                            
                            .. attribute:: lower_bound
                            
                            	The lower bound of the SRGB
                            	**type**\:  int
                            
                            	**range:** 16000..1048575
                            
                            	**mandatory**\: True
                            
                            .. attribute:: upper_bound
                            
                            	The upper bound of the SRGB
                            	**type**\:  int
                            
                            	**range:** 16000..1048575
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb, self).__init__()

                                self.yang_name = "srgb"
                                self.yang_parent_name = "process-scope"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.lower_bound = YLeaf(YType.uint32, "lower-bound")

                                self.upper_bound = YLeaf(YType.uint32, "upper-bound")
                                self._segment_path = lambda: "srgb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessScope.Srgb, ['lower_bound', 'upper_bound'], name, value)


                    class Queue(Entity):
                        """
                        Adjust OSPF input queue sizes and processing
                        quantums
                        
                        .. attribute:: dispatch_incoming
                        
                        	Maximum number of continuous incoming packet\-related events processed
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 300
                        
                        .. attribute:: dispatch_rate_limited
                        
                        	Maximum number of continuous rate\-limited LSAs processed
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 150
                        
                        .. attribute:: dispatch_rate_limited_flush
                        
                        	Maximum number of continuous rate\-limited LSAs processed for FLUSH
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 150
                        
                        .. attribute:: dispatch_spf_lsa_limit
                        
                        	Maximum number of continuous summary or external LSAs processed
                        	**type**\:  int
                        
                        	**range:** 30..3000
                        
                        	**default value**\: 150
                        
                        .. attribute:: limit_high
                        
                        	Hello events are dropped when incoming event queue exceeds this
                        	**type**\:  int
                        
                        	**range:** 1000..30000
                        
                        	**default value**\: 9500
                        
                        .. attribute:: limit_low
                        
                        	DBDs/Updates are dropped when incoming event queue exceeds this
                        	**type**\:  int
                        
                        	**range:** 1000..30000
                        
                        	**default value**\: 8000
                        
                        .. attribute:: limit_medium
                        
                        	LSA ACKs are dropped when incoming event queue exceeds this
                        	**type**\:  int
                        
                        	**range:** 1000..30000
                        
                        	**default value**\: 9000
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Queue, self).__init__()

                            self.yang_name = "queue"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.dispatch_incoming = YLeaf(YType.uint32, "dispatch-incoming")

                            self.dispatch_rate_limited = YLeaf(YType.uint32, "dispatch-rate-limited")

                            self.dispatch_rate_limited_flush = YLeaf(YType.uint32, "dispatch-rate-limited-flush")

                            self.dispatch_spf_lsa_limit = YLeaf(YType.uint32, "dispatch-spf-lsa-limit")

                            self.limit_high = YLeaf(YType.uint32, "limit-high")

                            self.limit_low = YLeaf(YType.uint32, "limit-low")

                            self.limit_medium = YLeaf(YType.uint32, "limit-medium")
                            self._segment_path = lambda: "queue"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Queue, ['dispatch_incoming', 'dispatch_rate_limited', 'dispatch_rate_limited_flush', 'dispatch_spf_lsa_limit', 'limit_high', 'limit_low', 'limit_medium'], name, value)


                    class Redistribution(Entity):
                        """
                        Redistribute configurations
                        
                        .. attribute:: redistributes
                        
                        	Redistribute information from another routing protocol
                        	**type**\:   :py:class:`Redistributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution, self).__init__()

                            self.yang_name = "redistribution"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"redistributes" : ("redistributes", Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes)}
                            self._child_list_classes = {}

                            self.redistributes = Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes()
                            self.redistributes.parent = self
                            self._children_name_map["redistributes"] = "redistributes"
                            self._children_yang_names.add("redistributes")
                            self._segment_path = lambda: "redistribution"


                        class Redistributes(Entity):
                            """
                            Redistribute information from another routing
                            protocol
                            
                            .. attribute:: redistribute
                            
                            	Redistribute information from another routing protocol
                            	**type**\: list of    :py:class:`Redistribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes, self).__init__()

                                self.yang_name = "redistributes"
                                self.yang_parent_name = "redistribution"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"redistribute" : ("redistribute", Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute)}

                                self.redistribute = YList(self)
                                self._segment_path = lambda: "redistributes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes, [], name, value)


                            class Redistribute(Entity):
                                """
                                Redistribute information from another routing
                                protocol
                                
                                .. attribute:: protocol_name  <key>
                                
                                	Distribute list protocol type
                                	**type**\:   :py:class:`OspfRedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistProtocol>`
                                
                                .. attribute:: application_or_isis_or_ospf
                                
                                	application or isis or ospf
                                	**type**\: list of    :py:class:`ApplicationOrIsisOrOspf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf>`
                                
                                .. attribute:: bgp
                                
                                	bgp
                                	**type**\: list of    :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp>`
                                
                                .. attribute:: connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip
                                
                                	connected or static or dagr or subscriber or mobile or rip
                                	**type**\:   :py:class:`ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp
                                
                                	eigrp
                                	**type**\: list of    :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute, self).__init__()

                                    self.yang_name = "redistribute"
                                    self.yang_parent_name = "redistributes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip" : ("connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip", Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip)}
                                    self._child_list_classes = {"application-or-isis-or-ospf" : ("application_or_isis_or_ospf", Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf), "bgp" : ("bgp", Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp), "eigrp" : ("eigrp", Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp)}

                                    self.protocol_name = YLeaf(YType.enumeration, "protocol-name")

                                    self.connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip = None
                                    self._children_name_map["connected_or_static_or_dagr_or_subscriber_or_mobile_or_rip"] = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                    self._children_yang_names.add("connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip")

                                    self.application_or_isis_or_ospf = YList(self)
                                    self.bgp = YList(self)
                                    self.eigrp = YList(self)
                                    self._segment_path = lambda: "redistribute" + "[protocol-name='" + self.protocol_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute, ['protocol_name'], name, value)


                                class ApplicationOrIsisOrOspf(Entity):
                                    """
                                    application or isis or ospf
                                    
                                    .. attribute:: instance_name  <key>
                                    
                                    	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, self).__init__()

                                        self.yang_name = "application-or-isis-or-ospf"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.instance_name = YLeaf(YType.str, "instance-name")

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.uint32, "tag")
                                        self._segment_path = lambda: "application-or-isis-or-ospf" + "[instance-name='" + self.instance_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ApplicationOrIsisOrOspf, ['instance_name', 'bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                                class Bgp(Entity):
                                    """
                                    bgp
                                    
                                    .. attribute:: instance_name  <key>
                                    
                                    	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: as_yy  <key>
                                    
                                    	Second half of BGP AS number in XX.YY format . Mandatory if Protocol is BGP or EIGRP and must not be specified otherwise. Must be a non\-zero value if first half is zero
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp, self).__init__()

                                        self.yang_name = "bgp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.instance_name = YLeaf(YType.str, "instance-name")

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.uint32, "tag")
                                        self._segment_path = lambda: "bgp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Bgp, ['instance_name', 'as_xx', 'as_yy', 'bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                                class ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip(Entity):
                                    """
                                    connected or static or dagr or subscriber or
                                    mobile or rip
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, self).__init__()

                                        self.yang_name = "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.uint32, "tag")
                                        self._segment_path = lambda: "connected-or-static-or-dagr-or-subscriber-or-mobile-or-rip"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.ConnectedOrStaticOrDagrOrSubscriberOrMobileOrRip, ['bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                                class Eigrp(Entity):
                                    """
                                    eigrp
                                    
                                    .. attribute:: instance_name  <key>
                                    
                                    	OSPF or ISIS process name or protocol name\: bgp, eigrp, connected
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	First half of BGP AS number in XX.YY format. Mandatory if Protocol is BGP and must not be specified otherwise. Must be a non\-zero value if second half is zero
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: bgp_preserve_default_info
                                    
                                    	Preserve Metric and Metric Type of BGP Default Route
                                    	**type**\:  bool
                                    
                                    .. attribute:: bgp_preserve_med
                                    
                                    	Preserve MED of BGP routes
                                    	**type**\:  bool
                                    
                                    .. attribute:: classful
                                    
                                    	Disallow subnetting
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: default_redistributed_route_metric
                                    
                                    	Default metric for routes being redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 1..16777214
                                    
                                    .. attribute:: eigrp_route_type
                                    
                                    	EIGRP route type
                                    	**type**\:   :py:class:`OspfEigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfEigrpRoute>`
                                    
                                    .. attribute:: isis_levels
                                    
                                    	Levels of ISIS routes
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: metric_type
                                    
                                    	Set OSPF External metric type
                                    	**type**\:   :py:class:`OspfLinkStateMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfLinkStateMetric>`
                                    
                                    .. attribute:: ospf_external
                                    
                                    	OSPF external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_internal
                                    
                                    	OSPF\_Internal route type
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_nssa_level
                                    
                                    	OSPF NSSA external route types
                                    	**type**\:   :py:class:`OspfRouteLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRouteLevel>`
                                    
                                    .. attribute:: ospf_redist_lsa_type
                                    
                                    	LSA type for redistributed routes
                                    	**type**\:   :py:class:`OspfRedistLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.OspfRedistLsa>`
                                    
                                    	**default value**\: external
                                    
                                    .. attribute:: ospfnssa_only
                                    
                                    	Only redistribute to NSSA areas
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Routing policy name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag
                                    
                                    	Set tag for routes redistributed into OSPF
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-cfg'
                                    _revision = '2017-07-14'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp, self).__init__()

                                        self.yang_name = "eigrp"
                                        self.yang_parent_name = "redistribute"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.instance_name = YLeaf(YType.str, "instance-name")

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.bgp_preserve_default_info = YLeaf(YType.boolean, "bgp-preserve-default-info")

                                        self.bgp_preserve_med = YLeaf(YType.boolean, "bgp-preserve-med")

                                        self.classful = YLeaf(YType.boolean, "classful")

                                        self.default_redistributed_route_metric = YLeaf(YType.uint32, "default-redistributed-route-metric")

                                        self.eigrp_route_type = YLeaf(YType.enumeration, "eigrp-route-type")

                                        self.isis_levels = YLeaf(YType.enumeration, "isis-levels")

                                        self.metric_type = YLeaf(YType.enumeration, "metric-type")

                                        self.ospf_external = YLeaf(YType.enumeration, "ospf-external")

                                        self.ospf_internal = YLeaf(YType.boolean, "ospf-internal")

                                        self.ospf_nssa_level = YLeaf(YType.enumeration, "ospf-nssa-level")

                                        self.ospf_redist_lsa_type = YLeaf(YType.enumeration, "ospf-redist-lsa-type")

                                        self.ospfnssa_only = YLeaf(YType.boolean, "ospfnssa-only")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.tag = YLeaf(YType.uint32, "tag")
                                        self._segment_path = lambda: "eigrp" + "[instance-name='" + self.instance_name.get() + "']" + "[as-xx='" + self.as_xx.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Redistribution.Redistributes.Redistribute.Eigrp, ['instance_name', 'as_xx', 'bgp_preserve_default_info', 'bgp_preserve_med', 'classful', 'default_redistributed_route_metric', 'eigrp_route_type', 'isis_levels', 'metric_type', 'ospf_external', 'ospf_internal', 'ospf_nssa_level', 'ospf_redist_lsa_type', 'ospfnssa_only', 'route_policy_name', 'tag'], name, value)


                    class SummaryPrefixes(Entity):
                        """
                        Configure IP prefix summary
                        
                        .. attribute:: netmask
                        
                        	keys\: netmask
                        	**type**\: list of    :py:class:`Netmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask>`
                        
                        .. attribute:: prefix
                        
                        	keys\: prefix
                        	**type**\: list of    :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix>`
                        
                        .. attribute:: prefix_and_netmask
                        
                        	keys\: prefix, netmask
                        	**type**\: list of    :py:class:`PrefixAndNetmask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask>`
                        
                        .. attribute:: summary_prefix_data
                        
                        	Data container
                        	**type**\:   :py:class:`SummaryPrefixData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__init__()

                            self.yang_name = "summary-prefixes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"summary-prefix-data" : ("summary_prefix_data", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData)}
                            self._child_list_classes = {"netmask" : ("netmask", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask), "prefix" : ("prefix", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix), "prefix-and-netmask" : ("prefix_and_netmask", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask)}

                            self.summary_prefix_data = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData()
                            self.summary_prefix_data.parent = self
                            self._children_name_map["summary_prefix_data"] = "summary-prefix-data"
                            self._children_yang_names.add("summary-prefix-data")

                            self.netmask = YList(self)
                            self.prefix = YList(self)
                            self.prefix_and_netmask = YList(self)
                            self._segment_path = lambda: "summary-prefixes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, [], name, value)


                        class Netmask(Entity):
                            """
                            keys\: netmask
                            
                            .. attribute:: netmask  <key>
                            
                            	Summary netmask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask, self).__init__()

                                self.yang_name = "netmask"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.netmask = YLeaf(YType.str, "netmask")

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.uint32, "tag")
                                self._segment_path = lambda: "netmask" + "[netmask='" + self.netmask.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Netmask, ['netmask', 'not_advertise', 'tag'], name, value)


                        class Prefix(Entity):
                            """
                            keys\: prefix
                            
                            .. attribute:: prefix  <key>
                            
                            	IP summary prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix, self).__init__()

                                self.yang_name = "prefix"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.uint32, "tag")
                                self._segment_path = lambda: "prefix" + "[prefix='" + self.prefix.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.Prefix, ['prefix', 'not_advertise', 'tag'], name, value)


                        class PrefixAndNetmask(Entity):
                            """
                            keys\: prefix, netmask
                            
                            .. attribute:: prefix  <key>
                            
                            	IP summary prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: netmask  <key>
                            
                            	Summary netmask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask, self).__init__()

                                self.yang_name = "prefix-and-netmask"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.netmask = YLeaf(YType.str, "netmask")

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.uint32, "tag")
                                self._segment_path = lambda: "prefix-and-netmask" + "[prefix='" + self.prefix.get() + "']" + "[netmask='" + self.netmask.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.PrefixAndNetmask, ['prefix', 'netmask', 'not_advertise', 'tag'], name, value)


                        class SummaryPrefixData(Entity):
                            """
                            Data container.
                            
                            .. attribute:: not_advertise
                            
                            	Do not advertise when translating OSPF type\-7 LSA
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: tag
                            
                            	32\-bit tag value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData, self).__init__()

                                self.yang_name = "summary-prefix-data"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.not_advertise = YLeaf(YType.boolean, "not-advertise")

                                self.tag = YLeaf(YType.uint32, "tag")
                                self._segment_path = lambda: "summary-prefix-data"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefixData, ['not_advertise', 'tag'], name, value)


                    class Timers(Entity):
                        """
                        Adjust routing timers
                        
                        .. attribute:: fast_reroute_timer
                        
                        	Number of ms between end of SPF and start of IPFRR computation
                        	**type**\:  int
                        
                        	**range:** 50..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 500
                        
                        .. attribute:: lsa_generation_timer
                        
                        	OSPF LSA timers (in milliseconds)
                        	**type**\:   :py:class:`LsaGenerationTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer>`
                        
                        .. attribute:: lsa_group_pacing
                        
                        	LSA group pacing timer (Seconds between group of LSAs being refreshed or maxaged)
                        	**type**\:  int
                        
                        	**range:** 10..1800
                        
                        	**units**\: second
                        
                        	**default value**\: 240
                        
                        .. attribute:: lsa_min_arrival
                        
                        	MinLSArrival timer (minimum interval in milliseconds between accepting the same LSA)
                        	**type**\:  int
                        
                        	**range:** 0..600000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 100
                        
                        .. attribute:: lsa_pacing_flood
                        
                        	Seconds between group of LSAs being refreshed or maxaged
                        	**type**\:  int
                        
                        	**range:** 5..100
                        
                        	**units**\: second
                        
                        .. attribute:: lsa_refresh
                        
                        	How often self\-originated LSAs should be refreshed
                        	**type**\:  int
                        
                        	**range:** 1800..2700
                        
                        	**units**\: second
                        
                        	**default value**\: 1800
                        
                        .. attribute:: spf_timer
                        
                        	OSPF SPF timers (in milliseconds)
                        	**type**\:   :py:class:`SpfTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"lsa-generation-timer" : ("lsa_generation_timer", Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer), "spf-timer" : ("spf_timer", Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer)}
                            self._child_list_classes = {}

                            self.fast_reroute_timer = YLeaf(YType.uint32, "fast-reroute-timer")

                            self.lsa_group_pacing = YLeaf(YType.uint32, "lsa-group-pacing")

                            self.lsa_min_arrival = YLeaf(YType.uint32, "lsa-min-arrival")

                            self.lsa_pacing_flood = YLeaf(YType.uint32, "lsa-pacing-flood")

                            self.lsa_refresh = YLeaf(YType.uint32, "lsa-refresh")

                            self.lsa_generation_timer = Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer()
                            self.lsa_generation_timer.parent = self
                            self._children_name_map["lsa_generation_timer"] = "lsa-generation-timer"
                            self._children_yang_names.add("lsa-generation-timer")

                            self.spf_timer = Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer()
                            self.spf_timer.parent = self
                            self._children_name_map["spf_timer"] = "spf-timer"
                            self._children_yang_names.add("spf-timer")
                            self._segment_path = lambda: "timers"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Timers, ['fast_reroute_timer', 'lsa_group_pacing', 'lsa_min_arrival', 'lsa_pacing_flood', 'lsa_refresh'], name, value)


                        class LsaGenerationTimer(Entity):
                            """
                            OSPF LSA timers (in milliseconds)
                            
                            .. attribute:: backoff_increment
                            
                            	Number of milliseconds delay between successive LSA builds
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 200
                            
                            .. attribute:: initial_delay
                            
                            	Number of milliseconds before generating first LSA
                            	**type**\:  int
                            
                            	**range:** 0..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 50
                            
                            .. attribute:: max_delay
                            
                            	Max number of milliseconds between consecutive LSA builds 
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 200
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer, self).__init__()

                                self.yang_name = "lsa-generation-timer"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                                self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                                self.max_delay = YLeaf(YType.uint32, "max-delay")
                                self._segment_path = lambda: "lsa-generation-timer"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Timers.LsaGenerationTimer, ['backoff_increment', 'initial_delay', 'max_delay'], name, value)


                        class SpfTimer(Entity):
                            """
                            OSPF SPF timers (in milliseconds)
                            
                            .. attribute:: backoff_increment
                            
                            	Number of milliseconds delay between successive SPF runs
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 10000
                            
                            .. attribute:: initial_delay
                            
                            	Number of milliseconds before first SPF run
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 5000
                            
                            .. attribute:: max_delay
                            
                            	Max number of milliseconds between consecutive SPF calculations
                            	**type**\:  int
                            
                            	**range:** 1..600000
                            
                            	**units**\: millisecond
                            
                            	**default value**\: 10000
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer, self).__init__()

                                self.yang_name = "spf-timer"
                                self.yang_parent_name = "timers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.backoff_increment = YLeaf(YType.uint32, "backoff-increment")

                                self.initial_delay = YLeaf(YType.uint32, "initial-delay")

                                self.max_delay = YLeaf(YType.uint32, "max-delay")
                                self._segment_path = lambda: "spf-timer"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Timers.SpfTimer, ['backoff_increment', 'initial_delay', 'max_delay'], name, value)


                    class Ucmp(Entity):
                        """
                        Unequal Cost Multi\-ptah configuration
                        
                        .. attribute:: delay_interval
                        
                        	Delay in msecs between primary SPF and UCMP computation
                        	**type**\:  int
                        
                        	**range:** 1..5000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 100
                        
                        .. attribute:: enable
                        
                        	UCMP feature enable configuration
                        	**type**\:   :py:class:`Enable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable>`
                        
                        .. attribute:: exclude_interfaces
                        
                        	Fast\-reroute per\-link/per\-prefix or UCMP exclude interface configuration
                        	**type**\:   :py:class:`ExcludeInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-cfg'
                        _revision = '2017-07-14'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp, self).__init__()

                            self.yang_name = "ucmp"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"enable" : ("enable", Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable), "exclude-interfaces" : ("exclude_interfaces", Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces)}
                            self._child_list_classes = {}

                            self.delay_interval = YLeaf(YType.uint32, "delay-interval")

                            self.enable = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable()
                            self.enable.parent = self
                            self._children_name_map["enable"] = "enable"
                            self._children_yang_names.add("enable")

                            self.exclude_interfaces = Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces()
                            self.exclude_interfaces.parent = self
                            self._children_name_map["exclude_interfaces"] = "exclude-interfaces"
                            self._children_yang_names.add("exclude-interfaces")
                            self._segment_path = lambda: "ucmp"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Ucmp, ['delay_interval'], name, value)


                        class Enable(Entity):
                            """
                            UCMP feature enable configuration
                            
                            .. attribute:: prefix_list_name
                            
                            	Name of the Prefix List
                            	**type**\:  str
                            
                            .. attribute:: variance
                            
                            	Value of variance
                            	**type**\:  int
                            
                            	**range:** 101..10000
                            
                            	**default value**\: 200
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable, self).__init__()

                                self.yang_name = "enable"
                                self.yang_parent_name = "ucmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                                self.variance = YLeaf(YType.uint32, "variance")
                                self._segment_path = lambda: "enable"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.Enable, ['prefix_list_name', 'variance'], name, value)


                        class ExcludeInterfaces(Entity):
                            """
                            Fast\-reroute per\-link/per\-prefix or UCMP exclude
                            interface configuration
                            
                            .. attribute:: exclude_interface
                            
                            	Exclude an interface from becoming a backup or UCMP
                            	**type**\: list of    :py:class:`ExcludeInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_cfg.Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-cfg'
                            _revision = '2017-07-14'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces, self).__init__()

                                self.yang_name = "exclude-interfaces"
                                self.yang_parent_name = "ucmp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"exclude-interface" : ("exclude_interface", Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface)}

                                self.exclude_interface = YList(self)
                                self._segment_path = lambda: "exclude-interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces, [], name, value)


                            class ExcludeInterface(Entity):
                                """
                                Exclude an interface from becoming a backup or
                                UCMP
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-ospf-cfg'
                                _revision = '2017-07-14'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface, self).__init__()

                                    self.yang_name = "exclude-interface"
                                    self.yang_parent_name = "exclude-interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                    self._segment_path = lambda: "exclude-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Ucmp.ExcludeInterfaces.ExcludeInterface, ['interface_name'], name, value)

    def clone_ptr(self):
        self._top_entity = Ospf()
        return self._top_entity

