""" Cisco_IOS_XR_ipv4_ospf_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-ospf package operational data.

This module contains definitions
for the following management objects\:
  ospf\: OSPF operational data

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class Authentication(Enum):
    """
    Authentication

    Authentication

    .. data:: mgmt_ospf_auth_none = 0

    	No Authentication

    .. data:: mgmt_ospf_auth_ct = 1

    	Clear Text

    .. data:: mgmt_ospf_auth_md = 2

    	MD5

    .. data:: mgmt_ospf_auth_kc = 3

    	Keychain

    """

    mgmt_ospf_auth_none = Enum.YLeaf(0, "mgmt-ospf-auth-none")

    mgmt_ospf_auth_ct = Enum.YLeaf(1, "mgmt-ospf-auth-ct")

    mgmt_ospf_auth_md = Enum.YLeaf(2, "mgmt-ospf-auth-md")

    mgmt_ospf_auth_kc = Enum.YLeaf(3, "mgmt-ospf-auth-kc")


class DrBdrState(Enum):
    """
    DrBdrState

    Dr bdr state

    .. data:: mgmt_dbdr_none = 0

    	None

    .. data:: mgmt_dbdr_dr = 1

    	Designated Router

    .. data:: mgmt_dbdr_bdr = 2

    	Backup Designated Router

    .. data:: mgmt_dbdr_dr_other = 3

    	Designated Router Other

    """

    mgmt_dbdr_none = Enum.YLeaf(0, "mgmt-dbdr-none")

    mgmt_dbdr_dr = Enum.YLeaf(1, "mgmt-dbdr-dr")

    mgmt_dbdr_bdr = Enum.YLeaf(2, "mgmt-dbdr-bdr")

    mgmt_dbdr_dr_other = Enum.YLeaf(3, "mgmt-dbdr-dr-other")


class ExMetric(Enum):
    """
    ExMetric

    Ex metric

    .. data:: mgmt_ex_metric_type_none = 0

    	No metric type

    .. data:: mgmt_ex_metric_type_1 = 1

    	Type 1 External

    .. data:: mgmt_ex_metric_type_2 = 2

    	Type 2 External

    """

    mgmt_ex_metric_type_none = Enum.YLeaf(0, "mgmt-ex-metric-type-none")

    mgmt_ex_metric_type_1 = Enum.YLeaf(1, "mgmt-ex-metric-type-1")

    mgmt_ex_metric_type_2 = Enum.YLeaf(2, "mgmt-ex-metric-type-2")


class GsState(Enum):
    """
    GsState

    Gs state

    .. data:: mgmt_gs_init = 0

    	Process in initialization 

    .. data:: mgmt_gs_normal = 1

    	Graceful Shutdown not running

    .. data:: mgmt_gs_delay = 2

    	Delaying  before Graceful Shutdown

    .. data:: mgmt_gs_flush = 3

    	Flushing self originated LSAs

    .. data:: mgmt_gs_hello = 4

    	Sending empty hellos

    .. data:: mgmt_gs_quiet = 5

    	Shutdown mode.

    """

    mgmt_gs_init = Enum.YLeaf(0, "mgmt-gs-init")

    mgmt_gs_normal = Enum.YLeaf(1, "mgmt-gs-normal")

    mgmt_gs_delay = Enum.YLeaf(2, "mgmt-gs-delay")

    mgmt_gs_flush = Enum.YLeaf(3, "mgmt-gs-flush")

    mgmt_gs_hello = Enum.YLeaf(4, "mgmt-gs-hello")

    mgmt_gs_quiet = Enum.YLeaf(5, "mgmt-gs-quiet")


class IgpteLibBwModel(Enum):
    """
    IgpteLibBwModel

    Bandwidth model

    .. data:: rdm = 0

    	Russian Dolls Model

    .. data:: mam = 1

    	Maximum Allocation Model

    .. data:: not_set = 2

    	No model set

    """

    rdm = Enum.YLeaf(0, "rdm")

    mam = Enum.YLeaf(1, "mam")

    not_set = Enum.YLeaf(2, "not-set")


class Interface(Enum):
    """
    Interface

    Interface

    .. data:: mgmt_if_broadcast = 1

    	Broadcast

    .. data:: mgmt_if_nonbroadcast = 2

    	Non broadcast multi access

    .. data:: mgmt_if_point_to_point = 3

    	Point to Point

    .. data:: mgmt_if_point_to_m_point = 4

    	Point to multipoint

    .. data:: mgmt_if_p2mp_non_bcast = 5

    	Non broadcast point to multipoint

    .. data:: mgmt_if_virtual_link = 6

    	Virtual link

    .. data:: mgmt_if_sham_link = 7

    	Sham link

    .. data:: mgmt_if_loop_back = 8

    	Loopback

    """

    mgmt_if_broadcast = Enum.YLeaf(1, "mgmt-if-broadcast")

    mgmt_if_nonbroadcast = Enum.YLeaf(2, "mgmt-if-nonbroadcast")

    mgmt_if_point_to_point = Enum.YLeaf(3, "mgmt-if-point-to-point")

    mgmt_if_point_to_m_point = Enum.YLeaf(4, "mgmt-if-point-to-m-point")

    mgmt_if_p2mp_non_bcast = Enum.YLeaf(5, "mgmt-if-p2mp-non-bcast")

    mgmt_if_virtual_link = Enum.YLeaf(6, "mgmt-if-virtual-link")

    mgmt_if_sham_link = Enum.YLeaf(7, "mgmt-if-sham-link")

    mgmt_if_loop_back = Enum.YLeaf(8, "mgmt-if-loop-back")


class InterfaceState(Enum):
    """
    InterfaceState

    Interface state

    .. data:: mgmt_ifs_unknown = 0

    	Interface state unknown

    .. data:: mgmt_ifs_admin_down = 1

    	Interface is administratively down

    .. data:: mgmt_ifs_down = 2

    	Interface is down

    .. data:: mgmt_ifs_up = 3

    	Interface is up

    .. data:: mgmt_ifs_shutdown = 4

    	Interface is administratively down

    """

    mgmt_ifs_unknown = Enum.YLeaf(0, "mgmt-ifs-unknown")

    mgmt_ifs_admin_down = Enum.YLeaf(1, "mgmt-ifs-admin-down")

    mgmt_ifs_down = Enum.YLeaf(2, "mgmt-ifs-down")

    mgmt_ifs_up = Enum.YLeaf(3, "mgmt-ifs-up")

    mgmt_ifs_shutdown = Enum.YLeaf(4, "mgmt-ifs-shutdown")


class Ipfrr(Enum):
    """
    Ipfrr

    FRR Types

    .. data:: none = 0

    	Disabled

    .. data:: per_link = 1

    	Per link

    .. data:: per_prefix = 2

    	Per prefix

    """

    none = Enum.YLeaf(0, "none")

    per_link = Enum.YLeaf(1, "per-link")

    per_prefix = Enum.YLeaf(2, "per-prefix")


class IpfrrTbrkr(Enum):
    """
    IpfrrTbrkr

    FRR Tiebreakers

    .. data:: downstream = 0

    	Downsteram

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: backup_metric = 2

    	Backup metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondary path

    .. data:: srlg_disjoint = 6

    	SRLG disjoint

    .. data:: tunnel = 7

    	Tunnel

    .. data:: post_convergence = 8

    	Post Convergence

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    backup_metric = Enum.YLeaf(2, "backup-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")

    tunnel = Enum.YLeaf(7, "tunnel")

    post_convergence = Enum.YLeaf(8, "post-convergence")


class LinkSubnet(Enum):
    """
    LinkSubnet

    Link subnet

    .. data:: mgmt_igp_subnet_type_none = 0

    	None

    .. data:: mgmt_igp_subnet_type_p2p = 1

    	Point to Point

    .. data:: mgmt_igp_subnet_type_broadcast = 2

    	Broadcast

    .. data:: mgmt_igp_subnet_type_nbma = 3

    	Non Broadcast Multi Access

    .. data:: mgmt_igp_subnet_type_p2mp = 4

    	Point to multipoint

    .. data:: mgmt_igp_subnet_type_loop_back = 5

    	Loopback

    .. data:: mgmt_igp_subnet_type_max = 6

    	Unsupported

    """

    mgmt_igp_subnet_type_none = Enum.YLeaf(0, "mgmt-igp-subnet-type-none")

    mgmt_igp_subnet_type_p2p = Enum.YLeaf(1, "mgmt-igp-subnet-type-p2p")

    mgmt_igp_subnet_type_broadcast = Enum.YLeaf(2, "mgmt-igp-subnet-type-broadcast")

    mgmt_igp_subnet_type_nbma = Enum.YLeaf(3, "mgmt-igp-subnet-type-nbma")

    mgmt_igp_subnet_type_p2mp = Enum.YLeaf(4, "mgmt-igp-subnet-type-p2mp")

    mgmt_igp_subnet_type_loop_back = Enum.YLeaf(5, "mgmt-igp-subnet-type-loop-back")

    mgmt_igp_subnet_type_max = Enum.YLeaf(6, "mgmt-igp-subnet-type-max")


class Lsa(Enum):
    """
    Lsa

    Lsa

    .. data:: mgmt_lsa_type_rtr = 1

    	Router LSA

    .. data:: mgmt_lsa_type_net = 2

    	Network LSA

    .. data:: mgmt_lsa_type_sum_net = 3

    	Summary LSA

    .. data:: mgmt_lsa_type_sum_asb = 4

    	Summary-ASBR LSA

    .. data:: mgmt_lsa_type_ext = 5

    	AS external LSA

    .. data:: mgmt_lsa_type_mospf = 6

    	MOSPF LSA

    .. data:: mgmt_lsa_type_7_ase = 7

    	Type-7 External LSA

    .. data:: mgmt_lsa_type_8_ignore = 8

    	Invalid type

    .. data:: mgmt_lsa_type_opq_link = 9

    	Opaque link LSA

    .. data:: mgmt_lsa_type_opq_area = 10

    	Opaque Area LSA

    .. data:: mgmt_lsa_type_opq_as = 11

    	Opaque AS LSA

    """

    mgmt_lsa_type_rtr = Enum.YLeaf(1, "mgmt-lsa-type-rtr")

    mgmt_lsa_type_net = Enum.YLeaf(2, "mgmt-lsa-type-net")

    mgmt_lsa_type_sum_net = Enum.YLeaf(3, "mgmt-lsa-type-sum-net")

    mgmt_lsa_type_sum_asb = Enum.YLeaf(4, "mgmt-lsa-type-sum-asb")

    mgmt_lsa_type_ext = Enum.YLeaf(5, "mgmt-lsa-type-ext")

    mgmt_lsa_type_mospf = Enum.YLeaf(6, "mgmt-lsa-type-mospf")

    mgmt_lsa_type_7_ase = Enum.YLeaf(7, "mgmt-lsa-type-7-ase")

    mgmt_lsa_type_8_ignore = Enum.YLeaf(8, "mgmt-lsa-type-8-ignore")

    mgmt_lsa_type_opq_link = Enum.YLeaf(9, "mgmt-lsa-type-opq-link")

    mgmt_lsa_type_opq_area = Enum.YLeaf(10, "mgmt-lsa-type-opq-area")

    mgmt_lsa_type_opq_as = Enum.YLeaf(11, "mgmt-lsa-type-opq-as")


class MaxMetricSetReason(Enum):
    """
    MaxMetricSetReason

    Max metric set reason

    .. data:: mgmt_max_metric_on_proc_migration = 0

    	proc migration

    .. data:: mgmt_max_metric_on_proc_restart = 1

    	proc restart

    .. data:: mgmt_max_metric_on_switchover = 2

    	switch over

    .. data:: mgmt_max_metric_on_startup = 3

    	start up

    .. data:: mgmt_max_metric_always = 4

    	always

    .. data:: mgmt_max_metric_reason_none = 5

    	none

    """

    mgmt_max_metric_on_proc_migration = Enum.YLeaf(0, "mgmt-max-metric-on-proc-migration")

    mgmt_max_metric_on_proc_restart = Enum.YLeaf(1, "mgmt-max-metric-on-proc-restart")

    mgmt_max_metric_on_switchover = Enum.YLeaf(2, "mgmt-max-metric-on-switchover")

    mgmt_max_metric_on_startup = Enum.YLeaf(3, "mgmt-max-metric-on-startup")

    mgmt_max_metric_always = Enum.YLeaf(4, "mgmt-max-metric-always")

    mgmt_max_metric_reason_none = Enum.YLeaf(5, "mgmt-max-metric-reason-none")


class MaxMetricUnsetReason(Enum):
    """
    MaxMetricUnsetReason

    Max metric unset reason

    .. data:: mgmt_max_metric_unset_none = 0

    	none

    .. data:: mgmt_max_metric_unset_bgp = 1

    	BGP converged

    .. data:: mgmt_max_metric_unset_timer = 2

    	timer expired

    .. data:: mgmt_max_metric_unset_cfg = 3

    	unconfigured

    .. data:: mgmt_max_metric_unset_process_cleared = 4

    	process cleared

    .. data:: mgmt_max_metric_unset_over_write = 5

    	set for other reason

    """

    mgmt_max_metric_unset_none = Enum.YLeaf(0, "mgmt-max-metric-unset-none")

    mgmt_max_metric_unset_bgp = Enum.YLeaf(1, "mgmt-max-metric-unset-bgp")

    mgmt_max_metric_unset_timer = Enum.YLeaf(2, "mgmt-max-metric-unset-timer")

    mgmt_max_metric_unset_cfg = Enum.YLeaf(3, "mgmt-max-metric-unset-cfg")

    mgmt_max_metric_unset_process_cleared = Enum.YLeaf(4, "mgmt-max-metric-unset-process-cleared")

    mgmt_max_metric_unset_over_write = Enum.YLeaf(5, "mgmt-max-metric-unset-over-write")


class MplsTeOptTlv(Enum):
    """
    MplsTeOptTlv

    Mpls te opt tlv

    .. data:: mpls_te_opt_tlv_type_none = 0

    	None

    .. data:: mpls_te_opt_tlv_type_srlg = 1

    	SRLGs

    .. data:: mpls_te_opt_tlv_type_bc = 2

    	Bandwidth Constraints

    .. data:: mpls_te_opt_tlv_type_ixcd = 3

    	Intarface Switching Capability Descriptor

    .. data:: mpls_te_opt_tlv_type_uni_delay = 4

    	Unidirectional Link Delay

    """

    mpls_te_opt_tlv_type_none = Enum.YLeaf(0, "mpls-te-opt-tlv-type-none")

    mpls_te_opt_tlv_type_srlg = Enum.YLeaf(1, "mpls-te-opt-tlv-type-srlg")

    mpls_te_opt_tlv_type_bc = Enum.YLeaf(2, "mpls-te-opt-tlv-type-bc")

    mpls_te_opt_tlv_type_ixcd = Enum.YLeaf(3, "mpls-te-opt-tlv-type-ixcd")

    mpls_te_opt_tlv_type_uni_delay = Enum.YLeaf(4, "mpls-te-opt-tlv-type-uni-delay")


class NeighborState(Enum):
    """
    NeighborState

    Neighbor state

    .. data:: mgmt_nbr_down = 0

    	Down

    .. data:: mgmt_nbr_attempt = 1

    	Attempt

    .. data:: mgmt_nbr_init = 2

    	Init

    .. data:: mgmt_nbr_2way = 3

    	2 Way

    .. data:: mgmt_nbr_ex_start = 4

    	Exstart

    .. data:: mgmt_nbr_ex_change = 5

    	Exchange

    .. data:: mgmt_nbr_load_ing = 6

    	Loading

    .. data:: mgmt_nbr_full = 7

    	Full

    .. data:: mgmt_nbr_sc_virtual = 8

    	SCvirtual

    """

    mgmt_nbr_down = Enum.YLeaf(0, "mgmt-nbr-down")

    mgmt_nbr_attempt = Enum.YLeaf(1, "mgmt-nbr-attempt")

    mgmt_nbr_init = Enum.YLeaf(2, "mgmt-nbr-init")

    mgmt_nbr_2way = Enum.YLeaf(3, "mgmt-nbr-2way")

    mgmt_nbr_ex_start = Enum.YLeaf(4, "mgmt-nbr-ex-start")

    mgmt_nbr_ex_change = Enum.YLeaf(5, "mgmt-nbr-ex-change")

    mgmt_nbr_load_ing = Enum.YLeaf(6, "mgmt-nbr-load-ing")

    mgmt_nbr_full = Enum.YLeaf(7, "mgmt-nbr-full")

    mgmt_nbr_sc_virtual = Enum.YLeaf(8, "mgmt-nbr-sc-virtual")


class NsfRtr(Enum):
    """
    NsfRtr

    Nsf rtr

    .. data:: mgmt_nsf_rtr_none = 0

    	None

    .. data:: mgmt_nsf_rtr_requester = 1

    	Requester

    .. data:: mgmt_nsf_rtr_receiver = 2

    	Receiver

    """

    mgmt_nsf_rtr_none = Enum.YLeaf(0, "mgmt-nsf-rtr-none")

    mgmt_nsf_rtr_requester = Enum.YLeaf(1, "mgmt-nsf-rtr-requester")

    mgmt_nsf_rtr_receiver = Enum.YLeaf(2, "mgmt-nsf-rtr-receiver")


class OspfBr(Enum):
    """
    OspfBr

    Ospf br

    .. data:: mgmt_d_type_abr_asbr = 0

    	Both Area Border Router and AS Border Router

    .. data:: mgmt_d_type_asbr = 1

    	AS Border Router

    .. data:: mgmt_d_type_abr = 2

    	Area Border Router

    """

    mgmt_d_type_abr_asbr = Enum.YLeaf(0, "mgmt-d-type-abr-asbr")

    mgmt_d_type_asbr = Enum.YLeaf(1, "mgmt-d-type-asbr")

    mgmt_d_type_abr = Enum.YLeaf(2, "mgmt-d-type-abr")


class OspfGrReason(Enum):
    """
    OspfGrReason

    Ospf gr reason

    .. data:: mgmt_gr_reason_unknown = 0

    	Unknown

    .. data:: mgmt_gr_reason_sw_restart = 1

    	Software restart

    .. data:: mgmt_gr_reason_sw_upgrade = 2

    	Software reload/upgrade

    .. data:: mgmt_gr_reason_switchover = 3

    	Switch to redundant control processor

    """

    mgmt_gr_reason_unknown = Enum.YLeaf(0, "mgmt-gr-reason-unknown")

    mgmt_gr_reason_sw_restart = Enum.YLeaf(1, "mgmt-gr-reason-sw-restart")

    mgmt_gr_reason_sw_upgrade = Enum.YLeaf(2, "mgmt-gr-reason-sw-upgrade")

    mgmt_gr_reason_switchover = Enum.YLeaf(3, "mgmt-gr-reason-switchover")


class OspfInterfaceState(Enum):
    """
    OspfInterfaceState

    Ospf interface state

    .. data:: mgmt_ospf_ifs_down = 0

    	Down

    .. data:: mgmt_ospf_ifs_loop_back = 1

    	Loopback

    .. data:: mgmt_ospf_ifs_waiting = 2

    	Waiting

    .. data:: mgmt_ospf_ifs_point_to_m_point = 3

    	Point to multipoint

    .. data:: mgmt_ospf_ifs_point_to_point = 4

    	Point to point

    .. data:: mgmt_ospf_ifs_dr = 5

    	DesignatedRouter

    .. data:: mgmt_ospf_ifs_backup = 6

    	Backup Designated Router

    .. data:: mgmt_ospf_ifs_other = 7

    	Designated Router Other

    """

    mgmt_ospf_ifs_down = Enum.YLeaf(0, "mgmt-ospf-ifs-down")

    mgmt_ospf_ifs_loop_back = Enum.YLeaf(1, "mgmt-ospf-ifs-loop-back")

    mgmt_ospf_ifs_waiting = Enum.YLeaf(2, "mgmt-ospf-ifs-waiting")

    mgmt_ospf_ifs_point_to_m_point = Enum.YLeaf(3, "mgmt-ospf-ifs-point-to-m-point")

    mgmt_ospf_ifs_point_to_point = Enum.YLeaf(4, "mgmt-ospf-ifs-point-to-point")

    mgmt_ospf_ifs_dr = Enum.YLeaf(5, "mgmt-ospf-ifs-dr")

    mgmt_ospf_ifs_backup = Enum.YLeaf(6, "mgmt-ospf-ifs-backup")

    mgmt_ospf_ifs_other = Enum.YLeaf(7, "mgmt-ospf-ifs-other")


class OspfInternalLsaTypes(Enum):
    """
    OspfInternalLsaTypes

    OSPF LSA format types

    .. data:: mgmt_rtr_type = 1

    	Router LSA

    .. data:: mgmt_ntwk_type = 2

    	Network LSA

    .. data:: mgmt_sum_type = 3

    	Summary and ASBR summary LSA

    .. data:: mgmt_ext_type = 4

    	Type 5 and NSSA external LSA

    .. data:: mgmt_opq_type = 5

    	Generic AS/Area Opaque LSA

    .. data:: mgmt_opq_link_type = 6

    	Generic Link Opaque LSA

    .. data:: mgmt_opq_rrr_type = 7

    	Opaque Area type 1 LSA

    .. data:: mgmt_opq_gr_type = 8

    	Opaque link type 1 LSA

    .. data:: mgmt_opq_ri_type = 9

    	Opaque Router Information LSA

    .. data:: mgmt_opq_epl_type = 10

    	Opaque Area type 128

    .. data:: mgmt_opq_ell_type = 11

    	Opaque Area type 8

    """

    mgmt_rtr_type = Enum.YLeaf(1, "mgmt-rtr-type")

    mgmt_ntwk_type = Enum.YLeaf(2, "mgmt-ntwk-type")

    mgmt_sum_type = Enum.YLeaf(3, "mgmt-sum-type")

    mgmt_ext_type = Enum.YLeaf(4, "mgmt-ext-type")

    mgmt_opq_type = Enum.YLeaf(5, "mgmt-opq-type")

    mgmt_opq_link_type = Enum.YLeaf(6, "mgmt-opq-link-type")

    mgmt_opq_rrr_type = Enum.YLeaf(7, "mgmt-opq-rrr-type")

    mgmt_opq_gr_type = Enum.YLeaf(8, "mgmt-opq-gr-type")

    mgmt_opq_ri_type = Enum.YLeaf(9, "mgmt-opq-ri-type")

    mgmt_opq_epl_type = Enum.YLeaf(10, "mgmt-opq-epl-type")

    mgmt_opq_ell_type = Enum.YLeaf(11, "mgmt-opq-ell-type")


class OspfLinkTypes(Enum):
    """
    OspfLinkTypes

    Type of router LSA links

    .. data:: mgmt_rtr_link = 1

    	Link to a Router

    .. data:: mgmt_trans_link = 2

    	Link to a transit network

    .. data:: mgmt_stub_net = 3

    	Link to Stub network

    .. data:: mgmt_vitural_link = 4

    	Link to Virtual Link

    """

    mgmt_rtr_link = Enum.YLeaf(1, "mgmt-rtr-link")

    mgmt_trans_link = Enum.YLeaf(2, "mgmt-trans-link")

    mgmt_stub_net = Enum.YLeaf(3, "mgmt-stub-net")

    mgmt_vitural_link = Enum.YLeaf(4, "mgmt-vitural-link")


class OspfLs(Enum):
    """
    OspfLs

    Ospf ls

    .. data:: router = 1

    	Router LSA

    .. data:: network = 2

    	Network LSA

    .. data:: summary = 3

    	Summary LSA

    .. data:: asbr_summary = 4

    	ASBR-Summary LSA

    .. data:: external = 5

    	External LSA

    .. data:: nssa_external = 7

    	NSSA External LSA

    .. data:: opaque_link = 9

    	Opaque LSALink Scope

    .. data:: opaque_area = 10

    	Opaque LSA Area Scope

    .. data:: opaque_as = 11

    	Opaque LSA AS Scope

    """

    router = Enum.YLeaf(1, "router")

    network = Enum.YLeaf(2, "network")

    summary = Enum.YLeaf(3, "summary")

    asbr_summary = Enum.YLeaf(4, "asbr-summary")

    external = Enum.YLeaf(5, "external")

    nssa_external = Enum.YLeaf(7, "nssa-external")

    opaque_link = Enum.YLeaf(9, "opaque-link")

    opaque_area = Enum.YLeaf(10, "opaque-area")

    opaque_as = Enum.YLeaf(11, "opaque-as")


class OspfLsaOpqRiScope(Enum):
    """
    OspfLsaOpqRiScope

    OSPF Router Information LSA scope types

    .. data:: mgmt_lsa_opq_ri_scope_link = 9

    	Link-local Router Information LSA

    .. data:: mgmt_lsa_opq_ri_scope_area = 10

    	Area-scope Router Information LSA

    .. data:: mgmt_lsa_opq_ri_scope_as = 11

    	AS-scope Router Information LSA

    """

    mgmt_lsa_opq_ri_scope_link = Enum.YLeaf(9, "mgmt-lsa-opq-ri-scope-link")

    mgmt_lsa_opq_ri_scope_area = Enum.YLeaf(10, "mgmt-lsa-opq-ri-scope-area")

    mgmt_lsa_opq_ri_scope_as = Enum.YLeaf(11, "mgmt-lsa-opq-ri-scope-as")


class OspfMaxMetricAbrOffReasons(Enum):
    """
    OspfMaxMetricAbrOffReasons

    Ospf max metric abr off reasons

    .. data:: ospf_max_metric_abr_off_reason_none = 0

    	No reason

    .. data:: ospf_max_metric_abr_off_reason_no_nbr = 1

    	No neighbors seen yet

    .. data:: ospf_max_metric_abr_off_reason_new_nbr = 2

    	New neighbor seen recently

    .. data:: ospf_max_metric_abr_off_reason_nbr_full = 4

    	Adjacency FULL seen recently

    .. data:: ospf_max_metric_abr_off_reason_flush_p_end = 8

    	LSA flushes pending

    """

    ospf_max_metric_abr_off_reason_none = Enum.YLeaf(0, "ospf-max-metric-abr-off-reason-none")

    ospf_max_metric_abr_off_reason_no_nbr = Enum.YLeaf(1, "ospf-max-metric-abr-off-reason-no-nbr")

    ospf_max_metric_abr_off_reason_new_nbr = Enum.YLeaf(2, "ospf-max-metric-abr-off-reason-new-nbr")

    ospf_max_metric_abr_off_reason_nbr_full = Enum.YLeaf(4, "ospf-max-metric-abr-off-reason-nbr-full")

    ospf_max_metric_abr_off_reason_flush_p_end = Enum.YLeaf(8, "ospf-max-metric-abr-off-reason-flush-p-end")


class OspfRoute(Enum):
    """
    OspfRoute

    Ospf route

    .. data:: mgmt_r_type_none = 0

    	No route type

    .. data:: mgmt_r_type_other = 1

    	Not set

    .. data:: mgmt_r_type_intra = 2

    	Intra-area route

    .. data:: mgmt_r_type_inter = 4

    	Inter-area route

    .. data:: mgmt_r_type_extern1 = 8

    	Type 1 External route

    .. data:: mgmt_r_type_extern2 = 16

    	Type 2 External route

    .. data:: mgmt_r_type_isis_sum = 32

    	IS-IS summary route

    .. data:: mgmt_r_type_isis_l1 = 64

    	IS-IS level 1 route

    .. data:: mgmt_r_type_isis_l2 = 128

    	IS-IS level 2 route

    .. data:: mgmt_r_type_isis_l1_ia = 256

    	IS-IS level 1 inter-area route

    .. data:: mgmt_r_type_bgp_int = 512

    	iBGP route

    .. data:: mgmt_r_type_bgp_ext = 1024

    	eBGP route

    .. data:: mgmt_r_type_bgp_loc = 2048

    	BGP local route

    .. data:: mgmt_r_type_nssa1 = 4096

    	Type 1 NSSA route

    .. data:: mgmt_r_type_nssa2 = 8192

    	Type 2 NSSA route

    .. data:: mgmt_r_type_i_grp2_int = 16384

    	EIGRP internal route

    .. data:: mgmt_r_type_i_grp2_ext = 32768

    	EIGRP external route

    """

    mgmt_r_type_none = Enum.YLeaf(0, "mgmt-r-type-none")

    mgmt_r_type_other = Enum.YLeaf(1, "mgmt-r-type-other")

    mgmt_r_type_intra = Enum.YLeaf(2, "mgmt-r-type-intra")

    mgmt_r_type_inter = Enum.YLeaf(4, "mgmt-r-type-inter")

    mgmt_r_type_extern1 = Enum.YLeaf(8, "mgmt-r-type-extern1")

    mgmt_r_type_extern2 = Enum.YLeaf(16, "mgmt-r-type-extern2")

    mgmt_r_type_isis_sum = Enum.YLeaf(32, "mgmt-r-type-isis-sum")

    mgmt_r_type_isis_l1 = Enum.YLeaf(64, "mgmt-r-type-isis-l1")

    mgmt_r_type_isis_l2 = Enum.YLeaf(128, "mgmt-r-type-isis-l2")

    mgmt_r_type_isis_l1_ia = Enum.YLeaf(256, "mgmt-r-type-isis-l1-ia")

    mgmt_r_type_bgp_int = Enum.YLeaf(512, "mgmt-r-type-bgp-int")

    mgmt_r_type_bgp_ext = Enum.YLeaf(1024, "mgmt-r-type-bgp-ext")

    mgmt_r_type_bgp_loc = Enum.YLeaf(2048, "mgmt-r-type-bgp-loc")

    mgmt_r_type_nssa1 = Enum.YLeaf(4096, "mgmt-r-type-nssa1")

    mgmt_r_type_nssa2 = Enum.YLeaf(8192, "mgmt-r-type-nssa2")

    mgmt_r_type_i_grp2_int = Enum.YLeaf(16384, "mgmt-r-type-i-grp2-int")

    mgmt_r_type_i_grp2_ext = Enum.YLeaf(32768, "mgmt-r-type-i-grp2-ext")


class OspfShOpqRiPceAddrTypes(Enum):
    """
    OspfShOpqRiPceAddrTypes

    OSPF PCE Address Type

    .. data:: mgmt_ospf_opq_pce_addr_type_invalid = 0

    	Invalid PCE Address

    .. data:: mgmt_ospf_opq_pce_addr_type_ipv4 = 1

    	IPv4 PCE Address

    .. data:: mgmt_ospf_opq_pce_addr_type_ipv6 = 2

    	IPv6 PCE Address

    """

    mgmt_ospf_opq_pce_addr_type_invalid = Enum.YLeaf(0, "mgmt-ospf-opq-pce-addr-type-invalid")

    mgmt_ospf_opq_pce_addr_type_ipv4 = Enum.YLeaf(1, "mgmt-ospf-opq-pce-addr-type-ipv4")

    mgmt_ospf_opq_pce_addr_type_ipv6 = Enum.YLeaf(2, "mgmt-ospf-opq-pce-addr-type-ipv6")


class OspfShOpqRiTlvTypes(Enum):
    """
    OspfShOpqRiTlvTypes

    OSPF Router Information TLV types

    .. data:: mgmt_ospf_opq_ri_tlv_type_unknown = 0

    	Unknown

    .. data:: mgmt_ospf_opq_ri_tlv_type_rtrcap = 1

    	Router Capabilities

    .. data:: mgmt_ospf_opq_ri_tlv_type_pce_discovery = 2

    	PCE Discovery

    .. data:: mgmt_ospf_opq_ri_tlv_type_sr_algo = 3

    	Segment Routing Algorithm

    .. data:: mgmt_ospf_opq_ri_tlv_type_sr_range = 4

    	Segment Routing SID Range

    .. data:: mgmt_ospf_opq_ri_tlv_type_node_msd = 5

    	Node MSD (Max SID Depth)

    """

    mgmt_ospf_opq_ri_tlv_type_unknown = Enum.YLeaf(0, "mgmt-ospf-opq-ri-tlv-type-unknown")

    mgmt_ospf_opq_ri_tlv_type_rtrcap = Enum.YLeaf(1, "mgmt-ospf-opq-ri-tlv-type-rtrcap")

    mgmt_ospf_opq_ri_tlv_type_pce_discovery = Enum.YLeaf(2, "mgmt-ospf-opq-ri-tlv-type-pce-discovery")

    mgmt_ospf_opq_ri_tlv_type_sr_algo = Enum.YLeaf(3, "mgmt-ospf-opq-ri-tlv-type-sr-algo")

    mgmt_ospf_opq_ri_tlv_type_sr_range = Enum.YLeaf(4, "mgmt-ospf-opq-ri-tlv-type-sr-range")

    mgmt_ospf_opq_ri_tlv_type_node_msd = Enum.YLeaf(5, "mgmt-ospf-opq-ri-tlv-type-node-msd")


class OspfSrgbStatus(Enum):
    """
    OspfSrgbStatus

    Ospf srgb status

    .. data:: not_allocated = 0

    	Not allocated

    .. data:: pending = 1

    	Allocation pending

    .. data:: allocated = 2

    	Allocated

    """

    not_allocated = Enum.YLeaf(0, "not-allocated")

    pending = Enum.YLeaf(1, "pending")

    allocated = Enum.YLeaf(2, "allocated")


class RedistProtocol(Enum):
    """
    RedistProtocol

    Redist protocol

    .. data:: mgmt_rib_protocol_all = 0

    	Unknown

    .. data:: mgmt_rib_protocol_connected = 1

    	Connected

    .. data:: mgmt_rib_protocol_local = 2

    	Local

    .. data:: mgmt_rib_protocol_static = 3

    	Static

    .. data:: mgmt_rib_protocol_bgp = 4

    	BGP

    .. data:: mgmt_rib_protocol_rip = 5

    	RIP

    .. data:: mgmt_rib_protocol_isis = 6

    	ISIS

    .. data:: mgmt_rib_protocol_ospf = 7

    	OSPF

    .. data:: mgmt_rib_protocol_eigrp = 8

    	EIGRP

    .. data:: mgmt_rib_protocol_dagr = 9

    	DAGR

    .. data:: mgmt_rib_protocol_subscriber = 10

    	Subscriber

    .. data:: mgmt_rib_protocol_application = 11

    	Application

    .. data:: mgmt_rib_protocol_mobile = 12

    	Mobile

    """

    mgmt_rib_protocol_all = Enum.YLeaf(0, "mgmt-rib-protocol-all")

    mgmt_rib_protocol_connected = Enum.YLeaf(1, "mgmt-rib-protocol-connected")

    mgmt_rib_protocol_local = Enum.YLeaf(2, "mgmt-rib-protocol-local")

    mgmt_rib_protocol_static = Enum.YLeaf(3, "mgmt-rib-protocol-static")

    mgmt_rib_protocol_bgp = Enum.YLeaf(4, "mgmt-rib-protocol-bgp")

    mgmt_rib_protocol_rip = Enum.YLeaf(5, "mgmt-rib-protocol-rip")

    mgmt_rib_protocol_isis = Enum.YLeaf(6, "mgmt-rib-protocol-isis")

    mgmt_rib_protocol_ospf = Enum.YLeaf(7, "mgmt-rib-protocol-ospf")

    mgmt_rib_protocol_eigrp = Enum.YLeaf(8, "mgmt-rib-protocol-eigrp")

    mgmt_rib_protocol_dagr = Enum.YLeaf(9, "mgmt-rib-protocol-dagr")

    mgmt_rib_protocol_subscriber = Enum.YLeaf(10, "mgmt-rib-protocol-subscriber")

    mgmt_rib_protocol_application = Enum.YLeaf(11, "mgmt-rib-protocol-application")

    mgmt_rib_protocol_mobile = Enum.YLeaf(12, "mgmt-rib-protocol-mobile")


class SrUloopEvent(Enum):
    """
    SrUloopEvent

    Sr uloop event

    .. data:: none = 0

    	No SR uloop event

    .. data:: link_down = 1

    	SR Uloop Event Link Down

    .. data:: link_up = 2

    	SR Uloop Event Link Up

    """

    none = Enum.YLeaf(0, "none")

    link_down = Enum.YLeaf(1, "link-down")

    link_up = Enum.YLeaf(2, "link-up")


class SrmsMiAfEB(Enum):
    """
    SrmsMiAfEB

    Srms mi af e b

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")


class SrmsMiFlagEB(Enum):
    """
    SrmsMiFlagEB

    Srms mi flag e b

    .. data:: false = 0

    	False

    .. data:: true = 1

    	True

    """

    false = Enum.YLeaf(0, "false")

    true = Enum.YLeaf(1, "true")


class SrmsMiSrcEB(Enum):
    """
    SrmsMiSrcEB

    Srms mi src e b

    .. data:: none = 0

    	None

    .. data:: local = 1

    	Local

    .. data:: remote = 2

    	Remote

    """

    none = Enum.YLeaf(0, "none")

    local = Enum.YLeaf(1, "local")

    remote = Enum.YLeaf(2, "remote")


class Stlv(Enum):
    """
    Stlv

    OSPF Opaque\-area Type 1 sub TLV types

    .. data:: mgmt_rrr_link_type = 1

    	Link Type

    .. data:: mgmt_rrr_link_id = 2

    	Link ID

    .. data:: mgmt_rrr_link_local_if_addr = 3

    	Local interface IP address

    .. data:: mgmt_rrr_link_remote_if_addr = 4

    	Remote interface IP address

    .. data:: mgmt_rrr_link_metric = 5

    	Traffic Engineering metric

    .. data:: mgmt_rrr_link_max_bw = 6

    	Maximum Link Bandwidth

    .. data:: mgmt_rrr_link_max_reservable_bw = 7

    	Maximum Reservable bandwidth

    .. data:: mgmt_rrr_link_unreserved_bw = 8

    	Unreserved Bandwidth

    .. data:: mgmt_rrr_link_re_source_class = 9

    	Administrative group

    .. data:: mgmt_rrr_link_in_out_if_id = 11

    	Link Local/Remote Identifiers

    .. data:: mgmt_rrr_link_if_switching_cap_desc = 15

    	Interface Switching Capability Descriptor

    .. data:: mgmt_ospf_rrr_link_srlg = 16

    	Shared Risk Link Group

    .. data:: mgmt_rrr_link_bw_constraints_sub = 17

    	Bandwidth constraints

    .. data:: mgmt_ospf_rrr_link_uni_delay = 27

    	Unidirectional link delay

    .. data:: mgmt_ospf_rrr_link_max_reservable_bw_sub = 32768

    	Maximum reservable sub-pool bandwidth

    .. data:: mgmt_ospf_rrr_link_unreserved_bw_sub = 32769

    	Unreserved sub-pool bandwidth

    .. data:: mgmt_rrr_link_igp_metric = 32770

    	IGP Link Metric

    .. data:: mgmt_ospf_rrr_link_ext_admin_sub = 32771

    	Extended admin

    """

    mgmt_rrr_link_type = Enum.YLeaf(1, "mgmt-rrr-link-type")

    mgmt_rrr_link_id = Enum.YLeaf(2, "mgmt-rrr-link-id")

    mgmt_rrr_link_local_if_addr = Enum.YLeaf(3, "mgmt-rrr-link-local-if-addr")

    mgmt_rrr_link_remote_if_addr = Enum.YLeaf(4, "mgmt-rrr-link-remote-if-addr")

    mgmt_rrr_link_metric = Enum.YLeaf(5, "mgmt-rrr-link-metric")

    mgmt_rrr_link_max_bw = Enum.YLeaf(6, "mgmt-rrr-link-max-bw")

    mgmt_rrr_link_max_reservable_bw = Enum.YLeaf(7, "mgmt-rrr-link-max-reservable-bw")

    mgmt_rrr_link_unreserved_bw = Enum.YLeaf(8, "mgmt-rrr-link-unreserved-bw")

    mgmt_rrr_link_re_source_class = Enum.YLeaf(9, "mgmt-rrr-link-re-source-class")

    mgmt_rrr_link_in_out_if_id = Enum.YLeaf(11, "mgmt-rrr-link-in-out-if-id")

    mgmt_rrr_link_if_switching_cap_desc = Enum.YLeaf(15, "mgmt-rrr-link-if-switching-cap-desc")

    mgmt_ospf_rrr_link_srlg = Enum.YLeaf(16, "mgmt-ospf-rrr-link-srlg")

    mgmt_rrr_link_bw_constraints_sub = Enum.YLeaf(17, "mgmt-rrr-link-bw-constraints-sub")

    mgmt_ospf_rrr_link_uni_delay = Enum.YLeaf(27, "mgmt-ospf-rrr-link-uni-delay")

    mgmt_ospf_rrr_link_max_reservable_bw_sub = Enum.YLeaf(32768, "mgmt-ospf-rrr-link-max-reservable-bw-sub")

    mgmt_ospf_rrr_link_unreserved_bw_sub = Enum.YLeaf(32769, "mgmt-ospf-rrr-link-unreserved-bw-sub")

    mgmt_rrr_link_igp_metric = Enum.YLeaf(32770, "mgmt-rrr-link-igp-metric")

    mgmt_ospf_rrr_link_ext_admin_sub = Enum.YLeaf(32771, "mgmt-ospf-rrr-link-ext-admin-sub")


class Timer(Enum):
    """
    Timer

    The LSA timer running can be refresh, checksum or

    maxage

    .. data:: mgmt_db_stop = 0

    	Timer stopped

    .. data:: mgmt_db_refresh = 1

    	Refresh

    .. data:: mgmt_db_checksum = 2

    	Checksum

    .. data:: mgmt_db_max_age = 3

    	Maxage

    """

    mgmt_db_stop = Enum.YLeaf(0, "mgmt-db-stop")

    mgmt_db_refresh = Enum.YLeaf(1, "mgmt-db-refresh")

    mgmt_db_checksum = Enum.YLeaf(2, "mgmt-db-checksum")

    mgmt_db_max_age = Enum.YLeaf(3, "mgmt-db-max-age")


class TimerTable(Enum):
    """
    TimerTable

    The throttled LSA can be in second, buffer or

    minute timer table

    .. data:: mgmt_db_no_table = 0

    	Not in time table

    .. data:: mgmt_db_sec_table = 1

    	In second table

    .. data:: mgmt_db_buffer_table = 2

    	In buffer table

    .. data:: mgmt_db_min_table = 3

    	In minute table

    """

    mgmt_db_no_table = Enum.YLeaf(0, "mgmt-db-no-table")

    mgmt_db_sec_table = Enum.YLeaf(1, "mgmt-db-sec-table")

    mgmt_db_buffer_table = Enum.YLeaf(2, "mgmt-db-buffer-table")

    mgmt_db_min_table = Enum.YLeaf(3, "mgmt-db-min-table")


class UloopAvoidance(Enum):
    """
    UloopAvoidance

    Uloop avoidance

    .. data:: none = 0

    	No uloop avoidance

    .. data:: protected_prefixes = 1

    	Apply Local uloop avoidance only for protected

    	prefixes

    .. data:: all_prefixes = 2

    	Apply Local uloop avoidance for all prefixes

    .. data:: segment_routing_uloop = 3

    	Apply segment routing uloop avoidance

    """

    none = Enum.YLeaf(0, "none")

    protected_prefixes = Enum.YLeaf(1, "protected-prefixes")

    all_prefixes = Enum.YLeaf(2, "all-prefixes")

    segment_routing_uloop = Enum.YLeaf(3, "segment-routing-uloop")



class Ospf(Entity):
    """
    OSPF operational data
    
    .. attribute:: processes
    
    	Table for each process
    	**type**\:   :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes>`
    
    

    """

    _prefix = 'ipv4-ospf-oper'
    _revision = '2017-05-01'

    def __init__(self):
        super(Ospf, self).__init__()
        self._top_entity = None

        self.yang_name = "ospf"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-ospf-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"processes" : ("processes", Ospf.Processes)}
        self._child_list_classes = {}

        self.processes = Ospf.Processes()
        self.processes.parent = self
        self._children_name_map["processes"] = "processes"
        self._children_yang_names.add("processes")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-ospf-oper:ospf"


    class Processes(Entity):
        """
        Table for each process
        
        .. attribute:: process
        
        	Operational data for a particular OSPF process
        	**type**\: list of    :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process>`
        
        

        """

        _prefix = 'ipv4-ospf-oper'
        _revision = '2017-05-01'

        def __init__(self):
            super(Ospf.Processes, self).__init__()

            self.yang_name = "processes"
            self.yang_parent_name = "ospf"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"process" : ("process", Ospf.Processes.Process)}

            self.process = YList(self)
            self._segment_path = lambda: "processes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-ospf-oper:ospf/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Ospf.Processes, [], name, value)


        class Process(Entity):
            """
            Operational data for a particular OSPF process
            
            .. attribute:: process_name  <key>
            
            	OSPF process
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: default_vrf
            
            	Operational data for the default VRF (instance) in the OSPF process
            	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf>`
            
            .. attribute:: srms
            
            	Segment Routing Mapping Server operational data
            	**type**\:   :py:class:`Srms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms>`
            
            .. attribute:: vrfs
            
            	Table for each VRF
            	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs>`
            
            

            """

            _prefix = 'ipv4-ospf-oper'
            _revision = '2017-05-01'

            def __init__(self):
                super(Ospf.Processes.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "processes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"default-vrf" : ("default_vrf", Ospf.Processes.Process.DefaultVrf), "srms" : ("srms", Ospf.Processes.Process.Srms), "vrfs" : ("vrfs", Ospf.Processes.Process.Vrfs)}
                self._child_list_classes = {}

                self.process_name = YLeaf(YType.str, "process-name")

                self.default_vrf = Ospf.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._children_yang_names.add("default-vrf")

                self.srms = Ospf.Processes.Process.Srms()
                self.srms.parent = self
                self._children_name_map["srms"] = "srms"
                self._children_yang_names.add("srms")

                self.vrfs = Ospf.Processes.Process.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"
                self._children_yang_names.add("vrfs")
                self._segment_path = lambda: "process" + "[process-name='" + self.process_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-ospf-oper:ospf/processes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Ospf.Processes.Process, ['process_name'], name, value)


            class DefaultVrf(Entity):
                """
                Operational data for the default VRF
                (instance) in the OSPF process
                
                .. attribute:: adjacency_information
                
                	Container for OSPF Interfaces
                	**type**\:   :py:class:`AdjacencyInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation>`
                
                .. attribute:: area_statistics
                
                	Container for Statistics
                	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics>`
                
                .. attribute:: areas
                
                	Area table
                	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas>`
                
                .. attribute:: border_routers
                
                	Border router table
                	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.BorderRouters>`
                
                .. attribute:: database
                
                	OSPF Link State Database
                	**type**\:   :py:class:`Database <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database>`
                
                .. attribute:: fast_reroute
                
                	Container for FastReroute
                	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute>`
                
                .. attribute:: flood_list_table
                
                	Flood list table
                	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable>`
                
                .. attribute:: interface_information
                
                	Container for OSPF Interfaces/links
                	**type**\:   :py:class:`InterfaceInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation>`
                
                .. attribute:: mpls_te
                
                	Container for MPLS TE
                	**type**\:   :py:class:`MplsTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe>`
                
                .. attribute:: ospf_summary
                
                	Fast\-reroute topology information
                	**type**\:   :py:class:`OspfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.OspfSummary>`
                
                .. attribute:: process_information
                
                	Container for OSPF Process information
                	**type**\:   :py:class:`ProcessInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation>`
                
                .. attribute:: route_information
                
                	Container for OSPF routing tables
                	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation>`
                
                .. attribute:: statistics
                
                	Container for Statistics
                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics>`
                
                .. attribute:: summary_prefixes
                
                	Summary prefix table
                	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                

                """

                _prefix = 'ipv4-ospf-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(Ospf.Processes.Process.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"adjacency-information" : ("adjacency_information", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation), "area-statistics" : ("area_statistics", Ospf.Processes.Process.DefaultVrf.AreaStatistics), "areas" : ("areas", Ospf.Processes.Process.DefaultVrf.Areas), "border-routers" : ("border_routers", Ospf.Processes.Process.DefaultVrf.BorderRouters), "database" : ("database", Ospf.Processes.Process.DefaultVrf.Database), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.DefaultVrf.FastReroute), "flood-list-table" : ("flood_list_table", Ospf.Processes.Process.DefaultVrf.FloodListTable), "interface-information" : ("interface_information", Ospf.Processes.Process.DefaultVrf.InterfaceInformation), "mpls-te" : ("mpls_te", Ospf.Processes.Process.DefaultVrf.MplsTe), "ospf-summary" : ("ospf_summary", Ospf.Processes.Process.DefaultVrf.OspfSummary), "process-information" : ("process_information", Ospf.Processes.Process.DefaultVrf.ProcessInformation), "route-information" : ("route_information", Ospf.Processes.Process.DefaultVrf.RouteInformation), "statistics" : ("statistics", Ospf.Processes.Process.DefaultVrf.Statistics), "summary-prefixes" : ("summary_prefixes", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes)}
                    self._child_list_classes = {}

                    self.adjacency_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation()
                    self.adjacency_information.parent = self
                    self._children_name_map["adjacency_information"] = "adjacency-information"
                    self._children_yang_names.add("adjacency-information")

                    self.area_statistics = Ospf.Processes.Process.DefaultVrf.AreaStatistics()
                    self.area_statistics.parent = self
                    self._children_name_map["area_statistics"] = "area-statistics"
                    self._children_yang_names.add("area-statistics")

                    self.areas = Ospf.Processes.Process.DefaultVrf.Areas()
                    self.areas.parent = self
                    self._children_name_map["areas"] = "areas"
                    self._children_yang_names.add("areas")

                    self.border_routers = Ospf.Processes.Process.DefaultVrf.BorderRouters()
                    self.border_routers.parent = self
                    self._children_name_map["border_routers"] = "border-routers"
                    self._children_yang_names.add("border-routers")

                    self.database = Ospf.Processes.Process.DefaultVrf.Database()
                    self.database.parent = self
                    self._children_name_map["database"] = "database"
                    self._children_yang_names.add("database")

                    self.fast_reroute = Ospf.Processes.Process.DefaultVrf.FastReroute()
                    self.fast_reroute.parent = self
                    self._children_name_map["fast_reroute"] = "fast-reroute"
                    self._children_yang_names.add("fast-reroute")

                    self.flood_list_table = Ospf.Processes.Process.DefaultVrf.FloodListTable()
                    self.flood_list_table.parent = self
                    self._children_name_map["flood_list_table"] = "flood-list-table"
                    self._children_yang_names.add("flood-list-table")

                    self.interface_information = Ospf.Processes.Process.DefaultVrf.InterfaceInformation()
                    self.interface_information.parent = self
                    self._children_name_map["interface_information"] = "interface-information"
                    self._children_yang_names.add("interface-information")

                    self.mpls_te = Ospf.Processes.Process.DefaultVrf.MplsTe()
                    self.mpls_te.parent = self
                    self._children_name_map["mpls_te"] = "mpls-te"
                    self._children_yang_names.add("mpls-te")

                    self.ospf_summary = Ospf.Processes.Process.DefaultVrf.OspfSummary()
                    self.ospf_summary.parent = self
                    self._children_name_map["ospf_summary"] = "ospf-summary"
                    self._children_yang_names.add("ospf-summary")

                    self.process_information = Ospf.Processes.Process.DefaultVrf.ProcessInformation()
                    self.process_information.parent = self
                    self._children_name_map["process_information"] = "process-information"
                    self._children_yang_names.add("process-information")

                    self.route_information = Ospf.Processes.Process.DefaultVrf.RouteInformation()
                    self.route_information.parent = self
                    self._children_name_map["route_information"] = "route-information"
                    self._children_yang_names.add("route-information")

                    self.statistics = Ospf.Processes.Process.DefaultVrf.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"
                    self._children_yang_names.add("statistics")

                    self.summary_prefixes = Ospf.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self._children_name_map["summary_prefixes"] = "summary-prefixes"
                    self._children_yang_names.add("summary-prefixes")
                    self._segment_path = lambda: "default-vrf"


                class AdjacencyInformation(Entity):
                    """
                    Container for OSPF Interfaces
                    
                    .. attribute:: neighbor_details
                    
                    	Neighbor detail table
                    	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails>`
                    
                    .. attribute:: neighbors
                    
                    	Neighbor table
                    	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors>`
                    
                    .. attribute:: requests
                    
                    	Request List table
                    	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests>`
                    
                    .. attribute:: retransmissions
                    
                    	Retransmission list table
                    	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation, self).__init__()

                        self.yang_name = "adjacency-information"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"neighbor-details" : ("neighbor_details", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails), "neighbors" : ("neighbors", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors), "requests" : ("requests", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests), "retransmissions" : ("retransmissions", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions)}
                        self._child_list_classes = {}

                        self.neighbor_details = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails()
                        self.neighbor_details.parent = self
                        self._children_name_map["neighbor_details"] = "neighbor-details"
                        self._children_yang_names.add("neighbor-details")

                        self.neighbors = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"
                        self._children_yang_names.add("neighbors")

                        self.requests = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests()
                        self.requests.parent = self
                        self._children_name_map["requests"] = "requests"
                        self._children_yang_names.add("requests")

                        self.retransmissions = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions()
                        self.retransmissions.parent = self
                        self._children_name_map["retransmissions"] = "retransmissions"
                        self._children_yang_names.add("retransmissions")
                        self._segment_path = lambda: "adjacency-information"


                    class NeighborDetails(Entity):
                        """
                        Neighbor detail table
                        
                        .. attribute:: neighbor_detail
                        
                        	A single neighbor's detail information
                        	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails, self).__init__()

                            self.yang_name = "neighbor-details"
                            self.yang_parent_name = "adjacency-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail)}

                            self.neighbor_detail = YList(self)
                            self._segment_path = lambda: "neighbor-details"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails, [], name, value)


                        class NeighborDetail(Entity):
                            """
                            A single neighbor's detail information
                            
                            .. attribute:: adjacency_sid_label
                            
                            	SR Adjacency SID Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_sid_protected
                            
                            	SR Adjacency SID Protected
                            	**type**\:  bool
                            
                            .. attribute:: adjacency_sid_unprotected_label
                            
                            	SR Adjacency SID Unprotected Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                            
                            .. attribute:: last_oob_time
                            
                            	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: lfa_interface
                            
                            	LFA Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: lfa_neighbor_id
                            
                            	LFA Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lfa_neighbor_revision
                            
                            	LFA Neighbor Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfa_next_hop
                            
                            	LFA Next Hop
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_ack_list_count
                            
                            	Ack List Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_ack_list_high_watermark
                            
                            	Ack List High Watermark
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_area_id
                            
                            	Area ID string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_information
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_filter
                            
                            	If true, filter outgoing LSAs
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Interface ID of neighbor recived via LLS
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_lls_option
                            
                            	This is a bitmask of Link Local signalling options received from the neighbor
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmaks of neighbor's option field received
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_retransmission_information
                            
                            	Retransmission information with this neighbor
                            	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                            
                            .. attribute:: neighbor_summary
                            
                            	Neighbor summary information
                            	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary>`
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nsf_router_state
                            
                            	For cisco NSF, the router is either Requester or Receiver
                            	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                            
                            .. attribute:: oob_resynchronization
                            
                            	Out\-Of\-Bound resynchronization in progress
                            	**type**\:  bool
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state_change_count
                            
                            	Number of state changes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor-details"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation), "neighbor-retransmission-information" : ("neighbor_retransmission_information", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation), "neighbor-summary" : ("neighbor_summary", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary)}
                                self._child_list_classes = {}

                                self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                self.neighbor_interface_id = YLeaf(YType.uint16, "neighbor-interface-id")

                                self.neighbor_lls_option = YLeaf(YType.uint32, "neighbor-lls-option")

                                self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                self.pending_events = YLeaf(YType.uint16, "pending-events")

                                self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                self.neighbor_bfd_information.parent = self
                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                self._children_yang_names.add("neighbor-bfd-information")

                                self.neighbor_retransmission_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                self.neighbor_retransmission_information.parent = self
                                self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                self._children_yang_names.add("neighbor-retransmission-information")

                                self.neighbor_summary = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary()
                                self.neighbor_summary.parent = self
                                self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                self._children_yang_names.add("neighbor-summary")
                                self._segment_path = lambda: "neighbor-detail"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail, ['adjacency_sid_label', 'adjacency_sid_protected', 'adjacency_sid_unprotected_label', 'interface_name', 'interface_type', 'last_oob_time', 'lfa_interface', 'lfa_neighbor_id', 'lfa_neighbor_revision', 'lfa_next_hop', 'neighbor_ack_list_count', 'neighbor_ack_list_high_watermark', 'neighbor_address', 'neighbor_area_id', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_filter', 'neighbor_interface_id', 'neighbor_lls_option', 'neighbor_option', 'next_poll_interval', 'nsf_router_state', 'oob_resynchronization', 'pending_events', 'poll_interval', 'state_change_count'], name, value)


                            class NeighborBfdInformation(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                    self.yang_name = "neighbor-bfd-information"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                    self._segment_path = lambda: "neighbor-bfd-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                            class NeighborRetransmissionInformation(Entity):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: area_first_flood_information
                                
                                	First flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_information_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flooding_index
                                
                                	Area scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_information
                                
                                	Next flood item for area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_information_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_information
                                
                                	First flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_information_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_information
                                
                                	Next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_information_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dbd_retransmission_count
                                
                                	Number of DBD retransmissions during last exchange
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dbd_retransmission_total_count
                                
                                	Total number of DBD retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmission_count
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_of_retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                    self.yang_name = "neighbor-retransmission-information"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                    self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                    self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                    self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                    self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                    self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                    self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                    self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                    self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                    self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                    self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                    self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                    self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                    self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                    self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                    self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                    self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                    self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                    self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                    self._segment_path = lambda: "neighbor-retransmission-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                            class NeighborSummary(Entity):
                                """
                                Neighbor summary information
                                
                                .. attribute:: dr_bdr_state
                                
                                	Designated Router state
                                	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_name
                                
                                	Interface via which the neighbor is seen
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_madj_interface
                                
                                	Interface is MADJ
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                    self.yang_name = "neighbor-summary"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation)}
                                    self._child_list_classes = {}

                                    self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                    self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")
                                    self._segment_path = lambda: "neighbor-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, ['dr_bdr_state', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                    class Neighbors(Entity):
                        """
                        Neighbor table
                        
                        .. attribute:: neighbor
                        
                        	Neighbor information
                        	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors, self).__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "adjacency-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor)}

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors, [], name, value)


                        class Neighbor(Entity):
                            """
                            Neighbor information
                            
                            .. attribute:: dr_bdr_state
                            
                            	Designated Router state
                            	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_bfd_information
                            
                            	Neighbor BFD information
                            	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation>`
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_id
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_interface_name
                            
                            	Interface via which the neighbor is seen
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: neighbor_madj_interface
                            
                            	Interface is MADJ
                            	**type**\:  bool
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation)}
                                self._child_list_classes = {}

                                self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation()
                                self.neighbor_bfd_information.parent = self
                                self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                self._children_yang_names.add("neighbor-bfd-information")
                                self._segment_path = lambda: "neighbor"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor, ['dr_bdr_state', 'interface_name', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                            class NeighborBfdInformation(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                    self.yang_name = "neighbor-bfd-information"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                    self._segment_path = lambda: "neighbor-bfd-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                    class Requests(Entity):
                        """
                        Request List table
                        
                        .. attribute:: request
                        
                        	Request list for a particular adjacency
                        	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests, self).__init__()

                            self.yang_name = "requests"
                            self.yang_parent_name = "adjacency-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request)}

                            self.request = YList(self)
                            self._segment_path = lambda: "requests"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests, [], name, value)


                        class Request(Entity):
                            """
                            Request list for a particular adjacency
                            
                            .. attribute:: interface_name
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request
                            
                            	List of request list entries
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request>`
                            
                            .. attribute:: request_interface_name
                            
                            	Request list interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: request_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request_neighbor_id
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "requests"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                self.request = YList(self)
                                self._segment_path = lambda: "request"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request, ['interface_name', 'neighbor_address', 'request_interface_name', 'request_neighbor_address', 'request_neighbor_id'], name, value)


                            class Request(Entity):
                                """
                                List of request list entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                    self._segment_path = lambda: "request"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Requests.Request.Request, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class Retransmissions(Entity):
                        """
                        Retransmission list table
                        
                        .. attribute:: retransmission
                        
                        	Retransmission list for a particular adjacency
                        	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions, self).__init__()

                            self.yang_name = "retransmissions"
                            self.yang_parent_name = "adjacency-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"retransmission" : ("retransmission", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission)}

                            self.retransmission = YList(self)
                            self._segment_path = lambda: "retransmissions"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions, [], name, value)


                        class Retransmission(Entity):
                            """
                            Retransmission list for a particular adjacency
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_area_db
                            
                            	List of Area scope entries
                            	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb>`
                            
                            .. attribute:: retransmission_asdb
                            
                            	List of AS Scope entries
                            	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb>`
                            
                            .. attribute:: retransmission_count
                            
                            	Retransmission queue length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_interface_name
                            
                            	Retransmission list interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: retransmission_neighbor_id
                            
                            	Neighbor ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_neighbor_ip_address
                            
                            	Neighbor IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_timer
                            
                            	Amount of time remaining on retransmission timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission, self).__init__()

                                self.yang_name = "retransmission"
                                self.yang_parent_name = "retransmissions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                self.retransmission_area_db = YList(self)
                                self.retransmission_asdb = YList(self)
                                self._segment_path = lambda: "retransmission"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission, ['interface_name', 'neighbor_address', 'retransmission_count', 'retransmission_interface_name', 'retransmission_neighbor_id', 'retransmission_neighbor_ip_address', 'retransmission_timer'], name, value)


                            class RetransmissionAreaDb(Entity):
                                """
                                List of Area scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                    self.yang_name = "retransmission-area-db"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                    self._segment_path = lambda: "retransmission-area-db"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class RetransmissionAsdb(Entity):
                                """
                                List of AS Scope entries
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                    self.yang_name = "retransmission-asdb"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                    self._segment_path = lambda: "retransmission-asdb"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                class AreaStatistics(Entity):
                    """
                    Container for Statistics
                    
                    .. attribute:: interface_stats_entries
                    
                    	Statistics innformation Interface table
                    	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.AreaStatistics, self).__init__()

                        self.yang_name = "area-statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"interface-stats-entries" : ("interface_stats_entries", Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries)}
                        self._child_list_classes = {}

                        self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries()
                        self.interface_stats_entries.parent = self
                        self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                        self._children_yang_names.add("interface-stats-entries")
                        self._segment_path = lambda: "area-statistics"


                    class InterfaceStatsEntries(Entity):
                        """
                        Statistics innformation Interface table
                        
                        .. attribute:: interface_stats_entry
                        
                        	Statistics information for a specific interface
                        	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries, self).__init__()

                            self.yang_name = "interface-stats-entries"
                            self.yang_parent_name = "area-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"interface-stats-entry" : ("interface_stats_entry", Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry)}

                            self.interface_stats_entry = YList(self)
                            self._segment_path = lambda: "interface-stats-entries"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries, [], name, value)


                        class InterfaceStatsEntry(Entity):
                            """
                            Statistics information for a specific interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: handle
                            
                            	interface handle type
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: if_entry
                            
                            	interface entry
                            	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                            
                            .. attribute:: if_name_str
                            
                            	interface name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                self.yang_name = "interface-stats-entry"
                                self.yang_parent_name = "interface-stats-entries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"if-entry" : ("if_entry", Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.handle = YLeaf(YType.str, "handle")

                                self.if_name_str = YLeaf(YType.str, "if-name-str")

                                self.if_entry = YList(self)
                                self._segment_path = lambda: "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, ['interface_name', 'handle', 'if_name_str'], name, value)


                            class IfEntry(Entity):
                                """
                                interface entry
                                
                                .. attribute:: area_id
                                
                                	OSPF area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_id_str
                                
                                	OSPF aread id string
                                	**type**\:  str
                                
                                .. attribute:: if_stat
                                
                                	OSPF interface statistics
                                	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                
                                .. attribute:: madj_intf
                                
                                	OSPF madj interface
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                    self.yang_name = "if-entry"
                                    self.yang_parent_name = "interface-stats-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"if-stat" : ("if_stat", Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat)}

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.area_id_str = YLeaf(YType.str, "area-id-str")

                                    self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                    self.if_stat = YList(self)
                                    self._segment_path = lambda: "if-entry"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, ['area_id', 'area_id_str', 'madj_intf'], name, value)


                                class IfStat(Entity):
                                    """
                                    OSPF interface statistics
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                        self.yang_name = "if-stat"
                                        self.yang_parent_name = "if-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "if-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, ['entry'], name, value)


                class Areas(Entity):
                    """
                    Area table
                    
                    .. attribute:: area
                    
                    	Container for per area data
                    	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Areas, self).__init__()

                        self.yang_name = "areas"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"area" : ("area", Ospf.Processes.Process.DefaultVrf.Areas.Area)}

                        self.area = YList(self)
                        self._segment_path = lambda: "areas"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas, [], name, value)


                    class Area(Entity):
                        """
                        Container for per area data
                        
                        .. attribute:: area_id  <key>
                        
                        	Area ID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: area_statistics
                        
                        	Container for Statistics
                        	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics>`
                        
                        .. attribute:: flood_list_area_table
                        
                        	Area specific flood list table
                        	**type**\:   :py:class:`FloodListAreaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable>`
                        
                        .. attribute:: interface_briefs
                        
                        	OSPF Interface Brief Table
                        	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs>`
                        
                        .. attribute:: interfaces
                        
                        	OSPF Interface Table
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces>`
                        
                        .. attribute:: neighbor_details
                        
                        	Neighbor detail table
                        	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails>`
                        
                        .. attribute:: neighbors
                        
                        	Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors>`
                        
                        .. attribute:: requests
                        
                        	Request List table
                        	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests>`
                        
                        .. attribute:: retransmissions
                        
                        	Retransmission list table
                        	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area, self).__init__()

                            self.yang_name = "area"
                            self.yang_parent_name = "areas"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"area-statistics" : ("area_statistics", Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics), "flood-list-area-table" : ("flood_list_area_table", Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable), "interface-briefs" : ("interface_briefs", Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs), "interfaces" : ("interfaces", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces), "neighbor-details" : ("neighbor_details", Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails), "neighbors" : ("neighbors", Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors), "requests" : ("requests", Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests), "retransmissions" : ("retransmissions", Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions)}
                            self._child_list_classes = {}

                            self.area_id = YLeaf(YType.int32, "area-id")

                            self.area_statistics = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics()
                            self.area_statistics.parent = self
                            self._children_name_map["area_statistics"] = "area-statistics"
                            self._children_yang_names.add("area-statistics")

                            self.flood_list_area_table = Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable()
                            self.flood_list_area_table.parent = self
                            self._children_name_map["flood_list_area_table"] = "flood-list-area-table"
                            self._children_yang_names.add("flood-list-area-table")

                            self.interface_briefs = Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs()
                            self.interface_briefs.parent = self
                            self._children_name_map["interface_briefs"] = "interface-briefs"
                            self._children_yang_names.add("interface-briefs")

                            self.interfaces = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")

                            self.neighbor_details = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails()
                            self.neighbor_details.parent = self
                            self._children_name_map["neighbor_details"] = "neighbor-details"
                            self._children_yang_names.add("neighbor-details")

                            self.neighbors = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.requests = Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests()
                            self.requests.parent = self
                            self._children_name_map["requests"] = "requests"
                            self._children_yang_names.add("requests")

                            self.retransmissions = Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions()
                            self.retransmissions.parent = self
                            self._children_name_map["retransmissions"] = "retransmissions"
                            self._children_yang_names.add("retransmissions")
                            self._segment_path = lambda: "area" + "[area-id='" + self.area_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area, ['area_id'], name, value)


                        class AreaStatistics(Entity):
                            """
                            Container for Statistics
                            
                            .. attribute:: interface_stats_entries
                            
                            	Statistics innformation Interface table
                            	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics, self).__init__()

                                self.yang_name = "area-statistics"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"interface-stats-entries" : ("interface_stats_entries", Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries)}
                                self._child_list_classes = {}

                                self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries()
                                self.interface_stats_entries.parent = self
                                self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                self._children_yang_names.add("interface-stats-entries")
                                self._segment_path = lambda: "area-statistics"


                            class InterfaceStatsEntries(Entity):
                                """
                                Statistics innformation Interface table
                                
                                .. attribute:: interface_stats_entry
                                
                                	Statistics information for a specific interface
                                	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__init__()

                                    self.yang_name = "interface-stats-entries"
                                    self.yang_parent_name = "area-statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface-stats-entry" : ("interface_stats_entry", Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry)}

                                    self.interface_stats_entry = YList(self)
                                    self._segment_path = lambda: "interface-stats-entries"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, [], name, value)


                                class InterfaceStatsEntry(Entity):
                                    """
                                    Statistics information for a specific interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: handle
                                    
                                    	interface handle type
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: if_entry
                                    
                                    	interface entry
                                    	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                    
                                    .. attribute:: if_name_str
                                    
                                    	interface name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                        self.yang_name = "interface-stats-entry"
                                        self.yang_parent_name = "interface-stats-entries"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"if-entry" : ("if_entry", Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.handle = YLeaf(YType.str, "handle")

                                        self.if_name_str = YLeaf(YType.str, "if-name-str")

                                        self.if_entry = YList(self)
                                        self._segment_path = lambda: "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, ['interface_name', 'handle', 'if_name_str'], name, value)


                                    class IfEntry(Entity):
                                        """
                                        interface entry
                                        
                                        .. attribute:: area_id
                                        
                                        	OSPF area id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_id_str
                                        
                                        	OSPF aread id string
                                        	**type**\:  str
                                        
                                        .. attribute:: if_stat
                                        
                                        	OSPF interface statistics
                                        	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                        
                                        .. attribute:: madj_intf
                                        
                                        	OSPF madj interface
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                            self.yang_name = "if-entry"
                                            self.yang_parent_name = "interface-stats-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"if-stat" : ("if_stat", Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat)}

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.area_id_str = YLeaf(YType.str, "area-id-str")

                                            self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                            self.if_stat = YList(self)
                                            self._segment_path = lambda: "if-entry"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, ['area_id', 'area_id_str', 'madj_intf'], name, value)


                                        class IfStat(Entity):
                                            """
                                            OSPF interface statistics
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                                self.yang_name = "if-stat"
                                                self.yang_parent_name = "if-entry"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "if-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, ['entry'], name, value)


                        class FloodListAreaTable(Entity):
                            """
                            Area specific flood list table
                            
                            .. attribute:: flood
                            
                            	Flooding information for a specific interface
                            	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable, self).__init__()

                                self.yang_name = "flood-list-area-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"flood" : ("flood", Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood)}

                                self.flood = YList(self)
                                self._segment_path = lambda: "flood-list-area-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable, [], name, value)


                            class Flood(Entity):
                                """
                                Flooding information for a specific interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: area_flood
                                
                                	Area scope floodlist
                                	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood>`
                                
                                .. attribute:: as_flood
                                
                                	AS scope floodlist
                                	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood>`
                                
                                .. attribute:: flood_interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: flood_lsa_count
                                
                                	Number of LSAs currently being flooded
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flood_pacing_timer
                                
                                	Time until next LS update due (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood, self).__init__()

                                    self.yang_name = "flood"
                                    self.yang_parent_name = "flood-list-area-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-flood" : ("area_flood", Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                                    self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                                    self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                                    self.area_flood = YList(self)
                                    self.as_flood = YList(self)
                                    self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood, ['interface_name', 'flood_interface_name', 'flood_lsa_count', 'flood_pacing_timer'], name, value)


                                class AreaFlood(Entity):
                                    """
                                    Area scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__init__()

                                        self.yang_name = "area-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "area-flood"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class AsFlood(Entity):
                                    """
                                    AS scope floodlist
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__init__()

                                        self.yang_name = "as-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "as-flood"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class InterfaceBriefs(Entity):
                            """
                            OSPF Interface Brief Table
                            
                            .. attribute:: interface_brief
                            
                            	OSPF interface brief information
                            	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs, self).__init__()

                                self.yang_name = "interface-briefs"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface-brief" : ("interface_brief", Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief)}

                                self.interface_brief = YList(self)
                                self._segment_path = lambda: "interface-briefs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs, [], name, value)


                            class InterfaceBrief(Entity):
                                """
                                OSPF interface brief information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Interface in fast detect hold down state
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Total number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__init__()

                                    self.yang_name = "interface-brief"
                                    self.yang_parent_name = "interface-briefs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.interface_madj = YList(self)
                                    self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adj_neighbor_count', 'interface_area', 'interface_fast_detect_hold_down', 'interface_link_cost', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_neighbor_count', 'interfaceis_madj', 'ospf_interface_state'], name, value)


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface-brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                        self._segment_path = lambda: "interface-madj"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                        class Interfaces(Entity):
                            """
                            OSPF Interface Table
                            
                            .. attribute:: interface
                            
                            	OSPF interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface" : ("interface", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface)}

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                OSPF interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: active_interface
                                
                                	Active interface details
                                	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface>`
                                
                                .. attribute:: backup_designated_router
                                
                                	If true, backup designated router
                                	**type**\:  bool
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cfg_cost_fallback
                                
                                	If true, cost fallback is configured
                                	**type**\:  bool
                                
                                .. attribute:: configured_demand_circuit
                                
                                	If true, configured as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync_igp_shortcuts
                                
                                	If true, sync igp shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: cost_fallback_active
                                
                                	If true, cost fallback is active
                                	**type**\:  bool
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: designated_router
                                
                                	If true, designated router
                                	**type**\:  bool
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: fast_detect_hold_down_time
                                
                                	Hold\-down time in ms for fast\-detect event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_detect_hold_down_time_remaining
                                
                                	Remaining hold down time in ms
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_reroute_topology_independent_lfa
                                
                                	Topology Independent LFA
                                	**type**\:  bool
                                
                                .. attribute:: fast_reroute_type
                                
                                	IP Fast Reroute Type
                                	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hello_interval_ms
                                
                                	Configured hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_bandwidth
                                
                                	Interface bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_bfd_information
                                
                                	BFD information
                                	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation>`
                                
                                .. attribute:: interface_bkp_labels
                                
                                	Max number of backup labels
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_dc_bitless_lsa_count
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Link in hold\-down state due to fast detect event
                                	**type**\:  bool
                                
                                .. attribute:: interface_forw
                                
                                	Forward reference interface
                                	**type**\:  bool
                                
                                .. attribute:: interface_last_nsf
                                
                                	Time since last NSF restart (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\:  bool
                                
                                .. attribute:: interface_line_state
                                
                                	If true, line protocol is up
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_lsa_filter
                                
                                	Filter is configured for out going LSAs
                                	**type**\:  bool
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor>`
                                
                                .. attribute:: interface_nsf
                                
                                	If true, NSF restart in progress on this interface
                                	**type**\:  bool
                                
                                .. attribute:: interface_nsf_enabled
                                
                                	If true, NSF is enabled
                                	**type**\:  bool
                                
                                .. attribute:: interface_pri_labels
                                
                                	Max number of primary labels
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_retransmission_interrval
                                
                                	Configured retransmit interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_sid
                                
                                	Interface SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_sid_n_flag_clear
                                
                                	SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_sid_php_off
                                
                                	SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_srte_labels
                                
                                	Max number of SRTE labels
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                                
                                .. attribute:: interface_strict_spf_sid
                                
                                	Interface Strict\-SPF SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_strict_spf_sid_n_flag_clear
                                
                                	Strict\-SPF SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_strict_spf_sid_php_off
                                
                                	Strict\-SPF SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_tunnel_flags
                                
                                	Interface tunnel flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_unnum
                                
                                	Unnumbered interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ip_mtu
                                
                                	IP MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ip_sec_addr
                                
                                	Secondary IP address list
                                	**type**\: list of    :py:class:`IpSecAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpSecAddr>`
                                
                                .. attribute:: ipfrr_tiebreakers
                                
                                	IPFRR\-Tiebreakers list
                                	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers>`
                                
                                .. attribute:: is_loopback_stub_network
                                
                                	If true, loopback interface is advertised as a stub network
                                	**type**\:  bool
                                
                                .. attribute:: maximum_packet_size
                                
                                	Maximum Packet Size
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hello_time_ms
                                
                                	Time until next Hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: passive_interface
                                
                                	If true, passive interface
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_primary_addresses
                                
                                	Prefix Suppression for primary addresses
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_secondary_addresses
                                
                                	Prefix Suppression for secondary addresses
                                	**type**\:  bool
                                
                                .. attribute:: registered_for_link_down_fast_detection
                                
                                	Registered for Link Down Fast Detection
                                	**type**\:  bool
                                
                                .. attribute:: srlg
                                
                                	SRLG Values
                                	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg>`
                                
                                .. attribute:: transmission_delay
                                
                                	Interface Transmission delay
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL security enabled on the interface
                                	**type**\:  bool
                                
                                .. attribute:: ttl_security_hop_count
                                
                                	TTL security hop counts
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"active-interface" : ("active_interface", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface), "interface-bfd-information" : ("interface_bfd_information", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation)}
                                    self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj), "interface-neighbor" : ("interface_neighbor", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor), "ip-sec-addr" : ("ip_sec_addr", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpSecAddr), "ipfrr-tiebreakers" : ("ipfrr_tiebreakers", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers), "srlg" : ("srlg", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                    self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                    self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                    self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                    self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                    self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                    self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                    self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                    self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                    self.designated_router = YLeaf(YType.boolean, "designated-router")

                                    self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                    self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                    self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                    self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                    self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                    self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                    self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                    self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                    self.interface_bkp_labels = YLeaf(YType.uint8, "interface-bkp-labels")

                                    self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                    self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                    self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_forw = YLeaf(YType.boolean, "interface-forw")

                                    self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                    self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                    self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                    self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                    self.interface_pri_labels = YLeaf(YType.uint8, "interface-pri-labels")

                                    self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                    self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                    self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                    self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                    self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                    self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                    self.interface_srte_labels = YLeaf(YType.uint8, "interface-srte-labels")

                                    self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                    self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                    self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                    self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                    self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                    self.interface_unnum = YLeaf(YType.str, "interface-unnum")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                    self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                    self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                    self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                    self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                    self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                    self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                    self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                    self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                    self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                    self.active_interface = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self._children_name_map["active_interface"] = "active-interface"
                                    self._children_yang_names.add("active-interface")

                                    self.interface_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation()
                                    self.interface_bfd_information.parent = self
                                    self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                    self._children_yang_names.add("interface-bfd-information")

                                    self.interface_madj = YList(self)
                                    self.interface_neighbor = YList(self)
                                    self.ip_sec_addr = YList(self)
                                    self.ipfrr_tiebreakers = YList(self)
                                    self.srlg = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface, ['interface_name', 'backup_designated_router', 'backup_designated_router_address', 'backup_designated_router_id', 'cfg_cost_fallback', 'configured_demand_circuit', 'configured_ldp_sync', 'configured_ldp_sync_igp_shortcuts', 'cost_fallback_active', 'dead_interval', 'designated_router', 'designated_router_address', 'designated_router_id', 'fast_detect_hold_down_time', 'fast_detect_hold_down_time_remaining', 'fast_reroute_topology_independent_lfa', 'fast_reroute_type', 'hello_interval', 'hello_interval_ms', 'interface_ack_list_count', 'interface_ack_list_high_watermark', 'interface_address', 'interface_area', 'interface_bandwidth', 'interface_bkp_labels', 'interface_cost_fallback', 'interface_dc_bitless_lsa_count', 'interface_demand_circuit', 'interface_fast_detect_hold_down', 'interface_forw', 'interface_last_nsf', 'interface_ldp_sync', 'interface_line_state', 'interface_link_cost', 'interface_lsa_filter', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_nsf', 'interface_nsf_enabled', 'interface_pri_labels', 'interface_priority', 'interface_retransmission_interrval', 'interface_router_id', 'interface_sid', 'interface_sid_n_flag_clear', 'interface_sid_php_off', 'interface_srte_labels', 'interface_state', 'interface_strict_spf_sid', 'interface_strict_spf_sid_n_flag_clear', 'interface_strict_spf_sid_php_off', 'interface_tunnel_flags', 'interface_unnum', 'interfaceis_madj', 'ip_mtu', 'is_loopback_stub_network', 'maximum_packet_size', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'next_hello_time_ms', 'ospf_interface_state', 'passive_interface', 'prefix_suppress_primary_addresses', 'prefix_suppress_secondary_addresses', 'registered_for_link_down_fast_detection', 'transmission_delay', 'ttl_security_enabled', 'ttl_security_hop_count', 'wait_interval'], name, value)


                                class ActiveInterface(Entity):
                                    """
                                    Active interface details
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                    
                                    .. attribute:: interface_flood_length
                                    
                                    	Flood queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Total number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: keychain_id
                                    
                                    	Keychain ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: md_keys
                                    
                                    	List of old MD keys
                                    	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys>`
                                    
                                    .. attribute:: old_md5_key_neighbor_count
                                    
                                    	Number of neighbors using the old key (if rollover in progress)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: suppress_hello_count
                                    
                                    	Number of neighbors for which hellos are suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: youngest_md_key
                                    
                                    	If true, MD key is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: youngest_md_key_id
                                    
                                    	Youngest MD key ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__init__()

                                        self.yang_name = "active-interface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"md-keys" : ("md_keys", Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys)}

                                        self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                        self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                        self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                        self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                        self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                        self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                        self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                        self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                        self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                        self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                        self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                        self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                        self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                        self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                        self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                        self.wait_time = YLeaf(YType.uint32, "wait-time")

                                        self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                        self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                        self.md_keys = YList(self)
                                        self._segment_path = lambda: "active-interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface, ['flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_authentication_type', 'interface_flood_length', 'interface_flood_pacing_timer', 'interface_neighbor_count', 'keychain_id', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'old_md5_key_neighbor_count', 'suppress_hello_count', 'wait_time', 'youngest_md_key', 'youngest_md_key_id'], name, value)


                                    class MdKeys(Entity):
                                        """
                                        List of old MD keys
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                            self.yang_name = "md-keys"
                                            self.yang_parent_name = "active-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint16, "entry")
                                            self._segment_path = lambda: "md-keys"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, ['entry'], name, value)


                                class InterfaceBfdInformation(Entity):
                                    """
                                    BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	BFD detection multiplier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	BFD interval (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                        self.yang_name = "interface-bfd-information"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.interval = YLeaf(YType.uint32, "interval")
                                        self._segment_path = lambda: "interface-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, ['bfd_intf_enable_mode', 'detection_multiplier', 'interval'], name, value)


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                        self._segment_path = lambda: "interface-madj"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                                class InterfaceNeighbor(Entity):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bdr
                                    
                                    	If true, Backup designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_dr
                                    
                                    	If true, Designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress_hello
                                    
                                    	If true, hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                        self.yang_name = "interface-neighbor"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                        self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                        self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                        self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                        self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")
                                        self._segment_path = lambda: "interface-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'neighbor_bdr', 'neighbor_dr', 'suppress_hello'], name, value)


                                class IpSecAddr(Entity):
                                    """
                                    Secondary IP address list
                                    
                                    .. attribute:: secondary_addr
                                    
                                    	Secondary Address Type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary_prefix
                                    
                                    	Secondary Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpSecAddr, self).__init__()

                                        self.yang_name = "ip-sec-addr"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.secondary_addr = YLeaf(YType.str, "secondary-addr")

                                        self.secondary_prefix = YLeaf(YType.uint32, "secondary-prefix")
                                        self._segment_path = lambda: "ip-sec-addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpSecAddr, ['secondary_addr', 'secondary_prefix'], name, value)


                                class IpfrrTiebreakers(Entity):
                                    """
                                    IPFRR\-Tiebreakers list
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Tiebreaker Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tiebreaker_type
                                    
                                    	Tiebreaker Type
                                    	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                        self.yang_name = "ipfrr-tiebreakers"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")
                                        self._segment_path = lambda: "ipfrr-tiebreakers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, ['tiebreaker_index', 'tiebreaker_type'], name, value)


                                class Srlg(Entity):
                                    """
                                    SRLG Values
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg, self).__init__()

                                        self.yang_name = "srlg"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "srlg"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Interfaces.Interface.Srlg, ['entry'], name, value)


                        class NeighborDetails(Entity):
                            """
                            Neighbor detail table
                            
                            .. attribute:: neighbor_detail
                            
                            	A single neighbor's detail information
                            	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails, self).__init__()

                                self.yang_name = "neighbor-details"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail)}

                                self.neighbor_detail = YList(self)
                                self._segment_path = lambda: "neighbor-details"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails, [], name, value)


                            class NeighborDetail(Entity):
                                """
                                A single neighbor's detail information
                                
                                .. attribute:: adjacency_sid_label
                                
                                	SR Adjacency SID Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adjacency_sid_protected
                                
                                	SR Adjacency SID Protected
                                	**type**\:  bool
                                
                                .. attribute:: adjacency_sid_unprotected_label
                                
                                	SR Adjacency SID Unprotected Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: last_oob_time
                                
                                	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: lfa_interface
                                
                                	LFA Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: lfa_neighbor_id
                                
                                	LFA Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lfa_neighbor_revision
                                
                                	LFA Neighbor Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfa_next_hop
                                
                                	LFA Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_area_id
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_filter
                                
                                	If true, filter outgoing LSAs
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Interface ID of neighbor recived via LLS
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_lls_option
                                
                                	This is a bitmask of Link Local signalling options received from the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmaks of neighbor's option field received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_retransmission_information
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                                
                                .. attribute:: neighbor_summary
                                
                                	Neighbor summary information
                                	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsf_router_state
                                
                                	For cisco NSF, the router is either Requester or Receiver
                                	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                                
                                .. attribute:: oob_resynchronization
                                
                                	Out\-Of\-Bound resynchronization in progress
                                	**type**\:  bool
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_change_count
                                
                                	Number of state changes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-details"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation), "neighbor-retransmission-information" : ("neighbor_retransmission_information", Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation), "neighbor-summary" : ("neighbor_summary", Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary)}
                                    self._child_list_classes = {}

                                    self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                    self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                    self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                    self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                    self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                    self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                    self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                    self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                    self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                    self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                    self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                    self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                    self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                    self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                    self.neighbor_interface_id = YLeaf(YType.uint16, "neighbor-interface-id")

                                    self.neighbor_lls_option = YLeaf(YType.uint32, "neighbor-lls-option")

                                    self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                    self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                    self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                    self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                    self.pending_events = YLeaf(YType.uint16, "pending-events")

                                    self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                    self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                    self.neighbor_retransmission_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                    self.neighbor_retransmission_information.parent = self
                                    self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                    self._children_yang_names.add("neighbor-retransmission-information")

                                    self.neighbor_summary = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary()
                                    self.neighbor_summary.parent = self
                                    self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                    self._children_yang_names.add("neighbor-summary")
                                    self._segment_path = lambda: "neighbor-detail"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail, ['adjacency_sid_label', 'adjacency_sid_protected', 'adjacency_sid_unprotected_label', 'interface_name', 'interface_type', 'last_oob_time', 'lfa_interface', 'lfa_neighbor_id', 'lfa_neighbor_revision', 'lfa_next_hop', 'neighbor_ack_list_count', 'neighbor_ack_list_high_watermark', 'neighbor_address', 'neighbor_area_id', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_filter', 'neighbor_interface_id', 'neighbor_lls_option', 'neighbor_option', 'next_poll_interval', 'nsf_router_state', 'oob_resynchronization', 'pending_events', 'poll_interval', 'state_change_count'], name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                class NeighborRetransmissionInformation(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood_information
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_information_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flooding_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_count
                                    
                                    	Number of DBD retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_total_count
                                    
                                    	Total number of DBD retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                        self.yang_name = "neighbor-retransmission-information"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                        self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                        self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                        self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                        self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                        self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                        self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                        self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                        self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                        self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                        self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                        self._segment_path = lambda: "neighbor-retransmission-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                                class NeighborSummary(Entity):
                                    """
                                    Neighbor summary information
                                    
                                    .. attribute:: dr_bdr_state
                                    
                                    	Designated Router state
                                    	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_name
                                    
                                    	Interface via which the neighbor is seen
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: neighbor_madj_interface
                                    
                                    	Interface is MADJ
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                        self.yang_name = "neighbor-summary"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation)}
                                        self._child_list_classes = {}

                                        self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                        self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                        self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")
                                        self._segment_path = lambda: "neighbor-summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, ['dr_bdr_state', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                            self._segment_path = lambda: "neighbor-bfd-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                        class Neighbors(Entity):
                            """
                            Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	Neighbor information
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor)}

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                Neighbor information
                                
                                .. attribute:: dr_bdr_state
                                
                                	Designated Router state
                                	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_name
                                
                                	Interface via which the neighbor is seen
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_madj_interface
                                
                                	Interface is MADJ
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation)}
                                    self._child_list_classes = {}

                                    self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                    self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")
                                    self._segment_path = lambda: "neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor, ['dr_bdr_state', 'interface_name', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                        class Requests(Entity):
                            """
                            Request List table
                            
                            .. attribute:: request
                            
                            	Request list for a particular adjacency
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests, self).__init__()

                                self.yang_name = "requests"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request)}

                                self.request = YList(self)
                                self._segment_path = lambda: "requests"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests, [], name, value)


                            class Request(Entity):
                                """
                                Request list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request>`
                                
                                .. attribute:: request_interface_name
                                
                                	Request list interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "requests"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                    self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                    self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                    self.request = YList(self)
                                    self._segment_path = lambda: "request"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request, ['interface_name', 'neighbor_address', 'request_interface_name', 'request_neighbor_address', 'request_neighbor_id'], name, value)


                                class Request(Entity):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "request"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Requests.Request.Request, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class Retransmissions(Entity):
                            """
                            Retransmission list table
                            
                            .. attribute:: retransmission
                            
                            	Retransmission list for a particular adjacency
                            	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions, self).__init__()

                                self.yang_name = "retransmissions"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"retransmission" : ("retransmission", Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission)}

                                self.retransmission = YList(self)
                                self._segment_path = lambda: "retransmissions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions, [], name, value)


                            class Retransmission(Entity):
                                """
                                Retransmission list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of Area scope entries
                                	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS Scope entries
                                	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb>`
                                
                                .. attribute:: retransmission_count
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_interface_name
                                
                                	Retransmission list interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: retransmission_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_neighbor_ip_address
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission, self).__init__()

                                    self.yang_name = "retransmission"
                                    self.yang_parent_name = "retransmissions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                    self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                    self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                    self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                    self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                    self.retransmission_area_db = YList(self)
                                    self.retransmission_asdb = YList(self)
                                    self._segment_path = lambda: "retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission, ['interface_name', 'neighbor_address', 'retransmission_count', 'retransmission_interface_name', 'retransmission_neighbor_id', 'retransmission_neighbor_ip_address', 'retransmission_timer'], name, value)


                                class RetransmissionAreaDb(Entity):
                                    """
                                    List of Area scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                        self.yang_name = "retransmission-area-db"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmission-area-db"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class RetransmissionAsdb(Entity):
                                    """
                                    List of AS Scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                        self.yang_name = "retransmission-asdb"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmission-asdb"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                class BorderRouters(Entity):
                    """
                    Border router table
                    
                    .. attribute:: border_router
                    
                    	Information for a particular border router
                    	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.BorderRouters, self).__init__()

                        self.yang_name = "border-routers"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"border-router" : ("border_router", Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter)}

                        self.border_router = YList(self)
                        self._segment_path = lambda: "border-routers"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.BorderRouters, [], name, value)


                    class BorderRouter(Entity):
                        """
                        Information for a particular border router
                        
                        .. attribute:: border_router_id  <key>
                        
                        	Router address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_id_xr
                        
                        	Router ID of Border Router
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_path
                        
                        	List of Border Router paths
                        	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, self).__init__()

                            self.yang_name = "border-router"
                            self.yang_parent_name = "border-routers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"border-router-path" : ("border_router_path", Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath)}

                            self.border_router_id = YLeaf(YType.str, "border-router-id")

                            self.border_router_id_xr = YLeaf(YType.str, "border-router-id-xr")

                            self.border_router_path = YList(self)
                            self._segment_path = lambda: "border-router" + "[border-router-id='" + self.border_router_id.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, ['border_router_id', 'border_router_id_xr'], name, value)


                        class BorderRouterPath(Entity):
                            """
                            List of Border Router paths
                            
                            .. attribute:: border_router_area_id
                            
                            	Area string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: border_router_next_hop
                            
                            	Next hop address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_next_hop_interface_name
                            
                            	Next hop Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: border_router_route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: border_router_route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            .. attribute:: border_router_type
                            
                            	Border router type
                            	**type**\:   :py:class:`OspfBr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfBr>`
                            
                            .. attribute:: spf_version
                            
                            	SPF run instance count
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                self.yang_name = "border-router-path"
                                self.yang_parent_name = "border-router"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.border_router_area_id = YLeaf(YType.str, "border-router-area-id")

                                self.border_router_next_hop = YLeaf(YType.str, "border-router-next-hop")

                                self.border_router_next_hop_interface_name = YLeaf(YType.str, "border-router-next-hop-interface-name")

                                self.border_router_route_metric = YLeaf(YType.uint32, "border-router-route-metric")

                                self.border_router_route_type = YLeaf(YType.enumeration, "border-router-route-type")

                                self.border_router_type = YLeaf(YType.enumeration, "border-router-type")

                                self.spf_version = YLeaf(YType.uint64, "spf-version")
                                self._segment_path = lambda: "border-router-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, ['border_router_area_id', 'border_router_next_hop', 'border_router_next_hop_interface_name', 'border_router_route_metric', 'border_router_route_type', 'border_router_type', 'spf_version'], name, value)


                class Database(Entity):
                    """
                    OSPF Link State Database
                    
                    .. attribute:: database_areas
                    
                    	Per\-Area view of Link state database
                    	**type**\:   :py:class:`DatabaseAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas>`
                    
                    .. attribute:: database_summaries
                    
                    	Link State database summary table
                    	**type**\:   :py:class:`DatabaseSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries>`
                    
                    .. attribute:: database_summary_as
                    
                    	Link State Database summary for the AS
                    	**type**\:   :py:class:`DatabaseSummaryAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs>`
                    
                    .. attribute:: lsa_summaries
                    
                    	Link state advertisement summary table
                    	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries>`
                    
                    .. attribute:: lsas
                    
                    	Link State Database Table
                    	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Database, self).__init__()

                        self.yang_name = "database"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"database-areas" : ("database_areas", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas), "database-summaries" : ("database_summaries", Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries), "database-summary-as" : ("database_summary_as", Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs), "lsa-summaries" : ("lsa_summaries", Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries), "lsas" : ("lsas", Ospf.Processes.Process.DefaultVrf.Database.Lsas)}
                        self._child_list_classes = {}

                        self.database_areas = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas()
                        self.database_areas.parent = self
                        self._children_name_map["database_areas"] = "database-areas"
                        self._children_yang_names.add("database-areas")

                        self.database_summaries = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries()
                        self.database_summaries.parent = self
                        self._children_name_map["database_summaries"] = "database-summaries"
                        self._children_yang_names.add("database-summaries")

                        self.database_summary_as = Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs()
                        self.database_summary_as.parent = self
                        self._children_name_map["database_summary_as"] = "database-summary-as"
                        self._children_yang_names.add("database-summary-as")

                        self.lsa_summaries = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries()
                        self.lsa_summaries.parent = self
                        self._children_name_map["lsa_summaries"] = "lsa-summaries"
                        self._children_yang_names.add("lsa-summaries")

                        self.lsas = Ospf.Processes.Process.DefaultVrf.Database.Lsas()
                        self.lsas.parent = self
                        self._children_name_map["lsas"] = "lsas"
                        self._children_yang_names.add("lsas")
                        self._segment_path = lambda: "database"


                    class DatabaseAreas(Entity):
                        """
                        Per\-Area view of Link state database
                        
                        .. attribute:: database_area
                        
                        	Per\-Area Link State Database data
                        	**type**\: list of    :py:class:`DatabaseArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas, self).__init__()

                            self.yang_name = "database-areas"
                            self.yang_parent_name = "database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"database-area" : ("database_area", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea)}

                            self.database_area = YList(self)
                            self._segment_path = lambda: "database-areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas, [], name, value)


                        class DatabaseArea(Entity):
                            """
                            Per\-Area Link State Database data
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_summaries
                            
                            	Link state advertisement summary table
                            	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries>`
                            
                            .. attribute:: lsas
                            
                            	Link State Database Table
                            	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea, self).__init__()

                                self.yang_name = "database-area"
                                self.yang_parent_name = "database-areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"lsa-summaries" : ("lsa_summaries", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries), "lsas" : ("lsas", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas)}
                                self._child_list_classes = {}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.lsa_summaries = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries()
                                self.lsa_summaries.parent = self
                                self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                self._children_yang_names.add("lsa-summaries")

                                self.lsas = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas()
                                self.lsas.parent = self
                                self._children_name_map["lsas"] = "lsas"
                                self._children_yang_names.add("lsas")
                                self._segment_path = lambda: "database-area" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea, ['area_id'], name, value)


                            class LsaSummaries(Entity):
                                """
                                Link state advertisement summary table
                                
                                .. attribute:: lsa_summary
                                
                                	LSA summary information
                                	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__init__()

                                    self.yang_name = "lsa-summaries"
                                    self.yang_parent_name = "database-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"lsa-summary" : ("lsa_summary", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary)}

                                    self.lsa_summary = YList(self)
                                    self._segment_path = lambda: "lsa-summaries"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, [], name, value)


                                class LsaSummary(Entity):
                                    """
                                    LSA summary information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: link_count
                                    
                                    	Number of links
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ls_type
                                    
                                    	Link state type
                                    	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	LSA header information
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__init__()

                                        self.yang_name = "lsa-summary"
                                        self.yang_parent_name = "lsa-summaries"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-header" : ("lsa_header", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader)}
                                        self._child_list_classes = {}

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.area_id = YLeaf(YType.int32, "area-id")

                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.link_count = YLeaf(YType.uint16, "link-count")

                                        self.ls_id = YLeaf(YType.str, "ls-id")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")
                                        self._segment_path = lambda: "lsa-summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, ['advertising_router', 'area_id', 'external_tag', 'interface_name', 'link_count', 'ls_id', 'ls_type'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        LSA header information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dn_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsid
                                        
                                        	LS ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: nsf
                                        
                                        	If true,  LSA received from neighbor during NSF
                                        	**type**\:  bool
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsid = YLeaf(YType.str, "lsid")

                                            self.nsf = YLeaf(YType.boolean, "nsf")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                            class Lsas(Entity):
                                """
                                Link State Database Table
                                
                                .. attribute:: lsa
                                
                                	Link State Advertisement information
                                	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__init__()

                                    self.yang_name = "lsas"
                                    self.yang_parent_name = "database-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"lsa" : ("lsa", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa)}

                                    self.lsa = YList(self)
                                    self._segment_path = lambda: "lsas"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas, [], name, value)


                                class Lsa(Entity):
                                    """
                                    Link State Advertisement information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ls_type
                                    
                                    	Link state type
                                    	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                    
                                    .. attribute:: lsa_detail_data
                                    
                                    	Detailed LSA Information
                                    	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData>`
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information
                                    	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader>`
                                    
                                    .. attribute:: lsa_internal_data
                                    
                                    	Information pertaining to a specific LSA type
                                    	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "lsas"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-detail-data" : ("lsa_detail_data", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData), "lsa-header" : ("lsa_header", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader), "lsa-internal-data" : ("lsa_internal_data", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData)}
                                        self._child_list_classes = {}

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.area_id = YLeaf(YType.int32, "area-id")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.ls_id = YLeaf(YType.str, "ls-id")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_detail_data = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData()
                                        self.lsa_detail_data.parent = self
                                        self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                        self._children_yang_names.add("lsa-detail-data")

                                        self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"
                                        self._children_yang_names.add("lsa-header")

                                        self.lsa_internal_data = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData()
                                        self.lsa_internal_data.parent = self
                                        self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                        self._children_yang_names.add("lsa-internal-data")
                                        self._segment_path = lambda: "lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                    class LsaDetailData(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\:  bool
                                        
                                        .. attribute:: ase_origin
                                        
                                        	External Origin
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: demand_circuit
                                        
                                        	If true, capable of demand circuit as indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        .. attribute:: dn_bit
                                        
                                        	if true, DN bit set on the summary LSA indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        .. attribute:: in_sync
                                        
                                        	Not In Sync With Active
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: length
                                        
                                        	Length of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\:  bool
                                        
                                        .. attribute:: lsa_last_updated_time
                                        
                                        	Time LSA was last updated
                                        	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                        
                                        .. attribute:: lsa_prefix_priority
                                        
                                        	Current LSA prefix priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: lsa_rate_limit_due_time
                                        
                                        	Due time for rate\-limit timer (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_throttle_timer
                                        
                                        	LSA throttle timer table information
                                        	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                        
                                        .. attribute:: lsadb_base_clock
                                        
                                        	Clock stamp since boot
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: lsadb_base_time_stamp
                                        
                                        	Current time stamp
                                        	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                        
                                        .. attribute:: new_lsa_prefix_priority
                                        
                                        	New LSA prefix priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: not_delete
                                        
                                        	Reason why LSA is not deleted
                                        	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete>`
                                        
                                        .. attribute:: nssa_translation
                                        
                                        	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        .. attribute:: routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: sum_origin
                                        
                                        	Summary Origin
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tos_capable
                                        
                                        	If true, type of service capable indicated by LSA's option field
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__init__()

                                            self.yang_name = "lsa-detail-data"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-last-updated-time" : ("lsa_last_updated_time", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime), "lsa-throttle-timer" : ("lsa_throttle_timer", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer), "lsadb-base-time-stamp" : ("lsadb_base_time_stamp", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp), "not-delete" : ("not_delete", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete)}
                                            self._child_list_classes = {}

                                            self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                            self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                            self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                            self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                            self.in_sync = YLeaf(YType.uint8, "in-sync")

                                            self.length = YLeaf(YType.uint16, "length")

                                            self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                            self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                            self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                            self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                            self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                            self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                            self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                            self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                            self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                            self.lsa_last_updated_time = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                            self.lsa_last_updated_time.parent = self
                                            self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                            self._children_yang_names.add("lsa-last-updated-time")

                                            self.lsa_throttle_timer = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                            self.lsa_throttle_timer.parent = self
                                            self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                            self._children_yang_names.add("lsa-throttle-timer")

                                            self.lsadb_base_time_stamp = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                            self.lsadb_base_time_stamp.parent = self
                                            self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                            self._children_yang_names.add("lsadb-base-time-stamp")

                                            self.not_delete = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete()
                                            self.not_delete.parent = self
                                            self._children_name_map["not_delete"] = "not-delete"
                                            self._children_yang_names.add("not-delete")
                                            self._segment_path = lambda: "lsa-detail-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, ['advertising_router_reachable', 'ase_origin', 'demand_circuit', 'dn_bit', 'in_sync', 'length', 'lsa_flood_required_post_fail_over', 'lsa_prefix_priority', 'lsa_rate_limit_due_time', 'lsadb_base_clock', 'new_lsa_prefix_priority', 'nssa_translation', 'routing_bit', 'sum_origin', 'tos_capable'], name, value)


                                        class LsaLastUpdatedTime(Entity):
                                            """
                                            Time LSA was last updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                                self.yang_name = "lsa-last-updated-time"
                                                self.yang_parent_name = "lsa-detail-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "lsa-last-updated-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, ['nanosecond', 'second'], name, value)


                                        class LsaThrottleTimer(Entity):
                                            """
                                            LSA throttle timer table information
                                            
                                            .. attribute:: last_inst_minute_table_index
                                            
                                            	Last Minute table index processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: last_inst_second_table_index
                                            
                                            	Last Second table index processed
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timer_location
                                            
                                            	Timer table
                                            	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                            
                                            .. attribute:: timer_type
                                            
                                            	Timer type
                                            	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                                self.yang_name = "lsa-throttle-timer"
                                                self.yang_parent_name = "lsa-detail-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                                self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                                self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                                self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                                self.timer_type = YLeaf(YType.enumeration, "timer-type")
                                                self._segment_path = lambda: "lsa-throttle-timer"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, ['last_inst_minute_table_index', 'last_inst_second_table_index', 'minute_table_index', 'second_table_index', 'timer_location', 'timer_type'], name, value)


                                        class LsadbBaseTimeStamp(Entity):
                                            """
                                            Current time stamp
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                                self.yang_name = "lsadb-base-time-stamp"
                                                self.yang_parent_name = "lsa-detail-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "lsadb-base-time-stamp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, ['nanosecond', 'second'], name, value)


                                        class NotDelete(Entity):
                                            """
                                            Reason why LSA is not deleted
                                            
                                            .. attribute:: acknowledgement
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\:  bool
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_age
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\:  bool
                                            
                                            .. attribute:: no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\:  bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\:  bool
                                            
                                            .. attribute:: partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\:  bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\:  bool
                                            
                                            .. attribute:: routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                            	**type**\:  bool
                                            
                                            .. attribute:: sum_orig_pending
                                            
                                            	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                                self.yang_name = "not-delete"
                                                self.yang_parent_name = "lsa-detail-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                                self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                                self.free_time = YLeaf(YType.uint32, "free-time")

                                                self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                                self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                                self.no_delete = YLeaf(YType.boolean, "no-delete")

                                                self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                                self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                                self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                self.routing_table = YLeaf(YType.boolean, "routing-table")

                                                self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")
                                                self._segment_path = lambda: "not-delete"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, ['acknowledgement', 'flood_pending', 'free_time', 'maximum_age', 'neighbor_exchange', 'no_delete', 'nsr_ack_pending', 'nsr_flood_required', 'partial_spf', 'rate_limit', 'routing_table', 'sum_orig_pending'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dn_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsid
                                        
                                        	LS ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: nsf
                                        
                                        	If true,  LSA received from neighbor during NSF
                                        	**type**\:  bool
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.checksum = YLeaf(YType.uint16, "checksum")

                                            self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                            self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                            self.lsid = YLeaf(YType.str, "lsid")

                                            self.nsf = YLeaf(YType.boolean, "nsf")

                                            self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                            self._segment_path = lambda: "lsa-header"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                                    class LsaInternalData(Entity):
                                        """
                                        Information pertaining to a specific LSA type
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                        
                                        .. attribute:: internal_lsa_type
                                        
                                        	InternalLSAType
                                        	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                        
                                        .. attribute:: opaque_el_lsa_type
                                        
                                        	Extended Link LSA type
                                        	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                        
                                        .. attribute:: opaque_ep_lsa_type
                                        
                                        	Extende Prefix LSA type
                                        	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                        
                                        .. attribute:: opaque_grace_lsa
                                        
                                        	Opaque\-link, opaque type 3 Grace LSA
                                        	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                        
                                        .. attribute:: opaque_link_lsa_type
                                        
                                        	Opaque\-Link LSA
                                        	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                        
                                        .. attribute:: opaque_mpls_te_lsa_type
                                        
                                        	Opaque\-Area, opaque type 1 LSA
                                        	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                        
                                        .. attribute:: opaque_router_info_lsa_type
                                        
                                        	Opaque Router Information LSA
                                        	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                        
                                        .. attribute:: summary_lsa_type
                                        
                                        	Summary LSA
                                        	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__init__()

                                            self.yang_name = "lsa-internal-data"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType), "network-lsa-type" : ("network_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType), "opaque-el-lsa-type" : ("opaque_el_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType), "opaque-ep-lsa-type" : ("opaque_ep_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType), "opaque-grace-lsa" : ("opaque_grace_lsa", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa), "opaque-link-lsa-type" : ("opaque_link_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType), "opaque-mpls-te-lsa-type" : ("opaque_mpls_te_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType), "opaque-router-info-lsa-type" : ("opaque_router_info_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType), "router-lsa-type" : ("router_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType), "summary-lsa-type" : ("summary_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType)}
                                            self._child_list_classes = {}

                                            self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                            self.external_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                            self._children_yang_names.add("external-lsa-type")

                                            self.network_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                            self._children_yang_names.add("network-lsa-type")

                                            self.opaque_el_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                            self.opaque_el_lsa_type.parent = self
                                            self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                            self._children_yang_names.add("opaque-el-lsa-type")

                                            self.opaque_ep_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                            self.opaque_ep_lsa_type.parent = self
                                            self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                            self._children_yang_names.add("opaque-ep-lsa-type")

                                            self.opaque_grace_lsa = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                            self.opaque_grace_lsa.parent = self
                                            self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                            self._children_yang_names.add("opaque-grace-lsa")

                                            self.opaque_link_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                            self.opaque_link_lsa_type.parent = self
                                            self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                            self._children_yang_names.add("opaque-link-lsa-type")

                                            self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                            self.opaque_mpls_te_lsa_type.parent = self
                                            self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                            self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                            self.opaque_router_info_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                            self.opaque_router_info_lsa_type.parent = self
                                            self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                            self._children_yang_names.add("opaque-router-info-lsa-type")

                                            self.router_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                            self._children_yang_names.add("router-lsa-type")

                                            self.summary_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                            self.summary_lsa_type.parent = self
                                            self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                            self._children_yang_names.add("summary-lsa-type")
                                            self._segment_path = lambda: "lsa-internal-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, ['internal_lsa_type'], name, value)


                                        class ExternalLsaType(Entity):
                                            """
                                            External LSA
                                            
                                            .. attribute:: external_prefix_length
                                            
                                            	Prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: external_tos_metric
                                            
                                            	Type of service information
                                            	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                            
                                            .. attribute:: internal_external_lsa
                                            
                                            	If true, internal max\-metric LSA
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                                self.yang_name = "external-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"external-tos-metric" : ("external_tos_metric", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric)}

                                                self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                                self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                                self.external_tos_metric = YList(self)
                                                self._segment_path = lambda: "external-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, ['external_prefix_length', 'internal_external_lsa'], name, value)


                                            class ExternalTosMetric(Entity):
                                                """
                                                Type of service information
                                                
                                                .. attribute:: external_metric
                                                
                                                	Cost of this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: external_metric_type
                                                
                                                	External LSA metric type
                                                	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: external_tos
                                                
                                                	Type of Service
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                                    self.yang_name = "external-tos-metric"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.external_metric = YLeaf(YType.uint32, "external-metric")

                                                    self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                    self.external_tos = YLeaf(YType.uint32, "external-tos")

                                                    self.forwarding_address = YLeaf(YType.str, "forwarding-address")
                                                    self._segment_path = lambda: "external-tos-metric"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, ['external_metric', 'external_metric_type', 'external_tag', 'external_tos', 'forwarding_address'], name, value)


                                        class NetworkLsaType(Entity):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                            
                                            .. attribute:: network_prefix_length
                                            
                                            	Network prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                                self.yang_name = "network-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"neighbor-router" : ("neighbor_router", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter)}

                                                self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                                self.neighbor_router = YList(self)
                                                self._segment_path = lambda: "network-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, ['network_prefix_length'], name, value)


                                            class NeighborRouter(Entity):
                                                """
                                                Neighbor router list
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                                    self.yang_name = "neighbor-router"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.str, "entry")
                                                    self._segment_path = lambda: "neighbor-router"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, ['entry'], name, value)


                                        class OpaqueElLsaType(Entity):
                                            """
                                            Extended Link LSA type
                                            
                                            .. attribute:: tlv
                                            
                                            	List of TLVs
                                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                                self.yang_name = "opaque-el-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv)}

                                                self.tlv = YList(self)
                                                self._segment_path = lambda: "opaque-el-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, [], name, value)


                                            class Tlv(Entity):
                                                """
                                                List of TLVs
                                                
                                                .. attribute:: mpls_dste_link
                                                
                                                	MPLS DS\-TE supported
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_router_id
                                                
                                                	MPLS\-TE Router ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: te_link_sub_tlv
                                                
                                                	List of Sub\-TLVs
                                                	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                                
                                                .. attribute:: tlv_data
                                                
                                                	TLV direct data
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tlv_length
                                                
                                                	Length of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tlv_type
                                                
                                                	Type of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                                    self.yang_name = "tlv"
                                                    self.yang_parent_name = "opaque-el-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv)}

                                                    self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                    self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                    self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                    self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                    self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                    self.te_link_sub_tlv = YList(self)
                                                    self._segment_path = lambda: "tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                                class TeLinkSubTlv(Entity):
                                                    """
                                                    List of Sub\-TLVs
                                                    
                                                    .. attribute:: sub_tlv_length
                                                    
                                                    	Length of sub TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sub_tlv_type
                                                    
                                                    	Type of sub TLV
                                                    	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                    
                                                    .. attribute:: sub_tlv_value
                                                    
                                                    	Value of sub TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                        self.yang_name = "te-link-sub-tlv"
                                                        self.yang_parent_name = "tlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                        self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                        self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                        self._segment_path = lambda: "te-link-sub-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                        class OpaqueEpLsaType(Entity):
                                            """
                                            Extende Prefix LSA type
                                            
                                            .. attribute:: tlv
                                            
                                            	List of TLVs
                                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                                self.yang_name = "opaque-ep-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv)}

                                                self.tlv = YList(self)
                                                self._segment_path = lambda: "opaque-ep-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, [], name, value)


                                            class Tlv(Entity):
                                                """
                                                List of TLVs
                                                
                                                .. attribute:: mpls_dste_link
                                                
                                                	MPLS DS\-TE supported
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_router_id
                                                
                                                	MPLS\-TE Router ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: te_link_sub_tlv
                                                
                                                	List of Sub\-TLVs
                                                	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                                
                                                .. attribute:: tlv_data
                                                
                                                	TLV direct data
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tlv_length
                                                
                                                	Length of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tlv_type
                                                
                                                	Type of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                                    self.yang_name = "tlv"
                                                    self.yang_parent_name = "opaque-ep-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv)}

                                                    self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                    self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                    self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                    self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                    self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                    self.te_link_sub_tlv = YList(self)
                                                    self._segment_path = lambda: "tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                                class TeLinkSubTlv(Entity):
                                                    """
                                                    List of Sub\-TLVs
                                                    
                                                    .. attribute:: sub_tlv_length
                                                    
                                                    	Length of sub TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sub_tlv_type
                                                    
                                                    	Type of sub TLV
                                                    	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                    
                                                    .. attribute:: sub_tlv_value
                                                    
                                                    	Value of sub TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                        self.yang_name = "te-link-sub-tlv"
                                                        self.yang_parent_name = "tlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                        self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                        self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                        self._segment_path = lambda: "te-link-sub-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                        class OpaqueGraceLsa(Entity):
                                            """
                                            Opaque\-link, opaque type 3 Grace LSA
                                            
                                            .. attribute:: grace_period
                                            
                                            	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                            
                                            .. attribute:: ip_address
                                            
                                            	IP interface address on the subnet associated with the grace LSA
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                                self.yang_name = "opaque-grace-lsa"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                self.ip_address = YLeaf(YType.str, "ip-address")
                                                self._segment_path = lambda: "opaque-grace-lsa"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, ['grace_period', 'grace_reason', 'ip_address'], name, value)


                                        class OpaqueLinkLsaType(Entity):
                                            """
                                            Opaque\-Link LSA
                                            
                                            .. attribute:: opaque_interface_name
                                            
                                            	Interface on which the Opaque link LSA is received
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                                self.yang_name = "opaque-link-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")
                                                self._segment_path = lambda: "opaque-link-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, ['opaque_interface_name'], name, value)


                                        class OpaqueMplsTeLsaType(Entity):
                                            """
                                            Opaque\-Area, opaque type 1 LSA
                                            
                                            .. attribute:: tlv
                                            
                                            	List of TLVs
                                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                                self.yang_name = "opaque-mpls-te-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv)}

                                                self.tlv = YList(self)
                                                self._segment_path = lambda: "opaque-mpls-te-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, [], name, value)


                                            class Tlv(Entity):
                                                """
                                                List of TLVs
                                                
                                                .. attribute:: mpls_dste_link
                                                
                                                	MPLS DS\-TE supported
                                                	**type**\:  bool
                                                
                                                .. attribute:: mpls_router_id
                                                
                                                	MPLS\-TE Router ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: te_link_sub_tlv
                                                
                                                	List of Sub\-TLVs
                                                	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                                
                                                .. attribute:: tlv_data
                                                
                                                	TLV direct data
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: tlv_length
                                                
                                                	Length of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tlv_type
                                                
                                                	Type of top\-level TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                                    self.yang_name = "tlv"
                                                    self.yang_parent_name = "opaque-mpls-te-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv)}

                                                    self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                    self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                    self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                    self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                    self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                    self.te_link_sub_tlv = YList(self)
                                                    self._segment_path = lambda: "tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                                class TeLinkSubTlv(Entity):
                                                    """
                                                    List of Sub\-TLVs
                                                    
                                                    .. attribute:: sub_tlv_length
                                                    
                                                    	Length of sub TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sub_tlv_type
                                                    
                                                    	Type of sub TLV
                                                    	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                    
                                                    .. attribute:: sub_tlv_value
                                                    
                                                    	Value of sub TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                        self.yang_name = "te-link-sub-tlv"
                                                        self.yang_parent_name = "tlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                        self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                        self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                        self._segment_path = lambda: "te-link-sub-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                        class OpaqueRouterInfoLsaType(Entity):
                                            """
                                            Opaque Router Information LSA
                                            
                                            .. attribute:: opaque_ri_interface_name
                                            
                                            	Interface on which this Link\-Local Opaque link LSA is received
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: opaque_rilsa_scope
                                            
                                            	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                            	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                            
                                            .. attribute:: opaque_ritlv
                                            
                                            	Router Information TLV
                                            	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                                self.yang_name = "opaque-router-info-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"opaque-ritlv" : ("opaque_ritlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv)}

                                                self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                                self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                                self.opaque_ritlv = YList(self)
                                                self._segment_path = lambda: "opaque-router-info-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, ['opaque_ri_interface_name', 'opaque_rilsa_scope'], name, value)


                                            class OpaqueRitlv(Entity):
                                                """
                                                Router Information TLV
                                                
                                                .. attribute:: node_msdtlv
                                                
                                                	Node MSD TLV
                                                	**type**\:   :py:class:`NodeMsdtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv>`
                                                
                                                .. attribute:: pcedtlv
                                                
                                                	PCE Discovery TLV
                                                	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                                
                                                .. attribute:: ritlv_internal_type
                                                
                                                	RITLVInternalType
                                                	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                                
                                                .. attribute:: rtr_cap_tlv
                                                
                                                	Rtr Cap TLV
                                                	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                                
                                                .. attribute:: sr_algo_tlv
                                                
                                                	SR Algorithm TLV
                                                	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                                
                                                .. attribute:: sr_range_tlv
                                                
                                                	SR Range TLV
                                                	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                                
                                                .. attribute:: unknown_tlv
                                                
                                                	Unknown Rtr Info TLV
                                                	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                                    self.yang_name = "opaque-ritlv"
                                                    self.yang_parent_name = "opaque-router-info-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"node-msdtlv" : ("node_msdtlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv), "pcedtlv" : ("pcedtlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv), "rtr-cap-tlv" : ("rtr_cap_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv), "sr-algo-tlv" : ("sr_algo_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv), "sr-range-tlv" : ("sr_range_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv), "unknown-tlv" : ("unknown_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv)}
                                                    self._child_list_classes = {}

                                                    self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                                    self.node_msdtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv()
                                                    self.node_msdtlv.parent = self
                                                    self._children_name_map["node_msdtlv"] = "node-msdtlv"
                                                    self._children_yang_names.add("node-msdtlv")

                                                    self.pcedtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                    self.pcedtlv.parent = self
                                                    self._children_name_map["pcedtlv"] = "pcedtlv"
                                                    self._children_yang_names.add("pcedtlv")

                                                    self.rtr_cap_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                    self.rtr_cap_tlv.parent = self
                                                    self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                    self._children_yang_names.add("rtr-cap-tlv")

                                                    self.sr_algo_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                    self.sr_algo_tlv.parent = self
                                                    self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                    self._children_yang_names.add("sr-algo-tlv")

                                                    self.sr_range_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                    self.sr_range_tlv.parent = self
                                                    self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                    self._children_yang_names.add("sr-range-tlv")

                                                    self.unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                    self.unknown_tlv.parent = self
                                                    self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                    self._children_yang_names.add("unknown-tlv")
                                                    self._segment_path = lambda: "opaque-ritlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, ['ritlv_internal_type'], name, value)


                                                class NodeMsdtlv(Entity):
                                                    """
                                                    Node MSD TLV
                                                    
                                                    .. attribute:: node_msd_sub_types
                                                    
                                                    	Node MSD Subtypes
                                                    	**type**\:   :py:class:`NodeMsdSubTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes>`
                                                    
                                                    .. attribute:: node_msdtlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, self).__init__()

                                                        self.yang_name = "node-msdtlv"
                                                        self.yang_parent_name = "opaque-ritlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"node-msd-sub-types" : ("node_msd_sub_types", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes)}
                                                        self._child_list_classes = {}

                                                        self.node_msdtlv_length = YLeaf(YType.uint16, "node-msdtlv-length")

                                                        self.node_msd_sub_types = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes()
                                                        self.node_msd_sub_types.parent = self
                                                        self._children_name_map["node_msd_sub_types"] = "node-msd-sub-types"
                                                        self._children_yang_names.add("node-msd-sub-types")
                                                        self._segment_path = lambda: "node-msdtlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, ['node_msdtlv_length'], name, value)


                                                    class NodeMsdSubTypes(Entity):
                                                        """
                                                        Node MSD Subtypes
                                                        
                                                        .. attribute:: msd_sub_type
                                                        
                                                        	MSD SubType
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: msd_value
                                                        
                                                        	MSD Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, self).__init__()

                                                            self.yang_name = "node-msd-sub-types"
                                                            self.yang_parent_name = "node-msdtlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.msd_sub_type = YLeaf(YType.uint8, "msd-sub-type")

                                                            self.msd_value = YLeaf(YType.uint8, "msd-value")
                                                            self._segment_path = lambda: "node-msd-sub-types"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, ['msd_sub_type', 'msd_value'], name, value)


                                                class Pcedtlv(Entity):
                                                    """
                                                    PCE Discovery TLV
                                                    
                                                    .. attribute:: pced_addr
                                                    
                                                    	PCE Address
                                                    	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                                    
                                                    .. attribute:: pced_scope
                                                    
                                                    	PCE Scope Information
                                                    	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                                    
                                                    .. attribute:: pcedtlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                        self.yang_name = "pcedtlv"
                                                        self.yang_parent_name = "opaque-ritlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"pced-addr" : ("pced_addr", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr), "pced-scope" : ("pced_scope", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope)}
                                                        self._child_list_classes = {}

                                                        self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                        self.pced_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                        self.pced_addr.parent = self
                                                        self._children_name_map["pced_addr"] = "pced-addr"
                                                        self._children_yang_names.add("pced-addr")

                                                        self.pced_scope = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                        self.pced_scope.parent = self
                                                        self._children_name_map["pced_scope"] = "pced-scope"
                                                        self._children_yang_names.add("pced-scope")
                                                        self._segment_path = lambda: "pcedtlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, ['pcedtlv_length'], name, value)


                                                    class PcedAddr(Entity):
                                                        """
                                                        PCE Address
                                                        
                                                        .. attribute:: ipv4pce_addr
                                                        
                                                        	IPv4 PCE Address
                                                        	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                        
                                                        .. attribute:: ipv6pce_addr
                                                        
                                                        	IPv6 PCE Address
                                                        	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                        
                                                        .. attribute:: pce_addr_type
                                                        
                                                        	PCEAddrType
                                                        	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                        
                                                        .. attribute:: pce_addr_unknown_tlv
                                                        
                                                        	Unknown PCE Addr TLV
                                                        	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                            self.yang_name = "pced-addr"
                                                            self.yang_parent_name = "pcedtlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ipv4pce-addr" : ("ipv4pce_addr", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr), "ipv6pce-addr" : ("ipv6pce_addr", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr), "pce-addr-unknown-tlv" : ("pce_addr_unknown_tlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv)}
                                                            self._child_list_classes = {}

                                                            self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                            self.ipv4pce_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                            self.ipv4pce_addr.parent = self
                                                            self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                            self._children_yang_names.add("ipv4pce-addr")

                                                            self.ipv6pce_addr = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                            self.ipv6pce_addr.parent = self
                                                            self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                            self._children_yang_names.add("ipv6pce-addr")

                                                            self.pce_addr_unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                            self.pce_addr_unknown_tlv.parent = self
                                                            self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                            self._children_yang_names.add("pce-addr-unknown-tlv")
                                                            self._segment_path = lambda: "pced-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, ['pce_addr_type'], name, value)


                                                        class Ipv4PceAddr(Entity):
                                                            """
                                                            IPv4 PCE Address
                                                            
                                                            .. attribute:: pceipv4_addr
                                                            
                                                            	PCE IPv4 Address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                                self.yang_name = "ipv4pce-addr"
                                                                self.yang_parent_name = "pced-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")
                                                                self._segment_path = lambda: "ipv4pce-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, ['pceipv4_addr'], name, value)


                                                        class Ipv6PceAddr(Entity):
                                                            """
                                                            IPv6 PCE Address
                                                            
                                                            .. attribute:: pceipv6_addr
                                                            
                                                            	PCE IPv6 Address
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                                self.yang_name = "ipv6pce-addr"
                                                                self.yang_parent_name = "pced-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")
                                                                self._segment_path = lambda: "ipv6pce-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, ['pceipv6_addr'], name, value)


                                                        class PceAddrUnknownTlv(Entity):
                                                            """
                                                            Unknown PCE Addr TLV
                                                            
                                                            .. attribute:: ri_gen_tlv_length
                                                            
                                                            	Length of TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ri_gen_tlv_type
                                                            
                                                            	Type of TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: ri_genvalue
                                                            
                                                            	Data in TLV
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                                self.yang_name = "pce-addr-unknown-tlv"
                                                                self.yang_parent_name = "pced-addr"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                                self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                                self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                                self._segment_path = lambda: "pce-addr-unknown-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                                    class PcedScope(Entity):
                                                        """
                                                        PCE Scope Information
                                                        
                                                        .. attribute:: all_scope_info_bits
                                                        
                                                        	PCE Scope Information
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: lbit
                                                        
                                                        	L Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pref_l
                                                        
                                                        	Pref L
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pref_r
                                                        
                                                        	Pref R
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pref_s
                                                        
                                                        	Pref S
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: pref_y
                                                        
                                                        	Pref Y
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: rbit
                                                        
                                                        	R Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rd_bit
                                                        
                                                        	Rd Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sbit
                                                        
                                                        	S Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: sd_bit
                                                        
                                                        	Sd Bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: ybit
                                                        
                                                        	Y Bit
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                            self.yang_name = "pced-scope"
                                                            self.yang_parent_name = "pcedtlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                            self.lbit = YLeaf(YType.boolean, "lbit")

                                                            self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                            self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                            self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                            self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                            self.rbit = YLeaf(YType.boolean, "rbit")

                                                            self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                            self.sbit = YLeaf(YType.boolean, "sbit")

                                                            self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                            self.ybit = YLeaf(YType.boolean, "ybit")
                                                            self._segment_path = lambda: "pced-scope"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, ['all_scope_info_bits', 'lbit', 'pref_l', 'pref_r', 'pref_s', 'pref_y', 'rbit', 'rd_bit', 'sbit', 'sd_bit', 'ybit'], name, value)


                                                class RtrCapTlv(Entity):
                                                    """
                                                    Rtr Cap TLV
                                                    
                                                    .. attribute:: rtr_cap_additional_info
                                                    
                                                    	Additional Information in TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: rtr_cap_all_bits
                                                    
                                                    	All capability bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rtr_cap_area_te
                                                    
                                                    	Traffic Engineering capability of area
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_graceful_restart
                                                    
                                                    	Graceful Restart Capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_graceful_restart_helper
                                                    
                                                    	Graceful Restart Helper Capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_p2plan
                                                    
                                                    	P2P LAN Capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_stub_rtr
                                                    
                                                    	Stub Router capability
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_te_exp
                                                    
                                                    	TE Experimental bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rtr_cap_tlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                        self.yang_name = "rtr-cap-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                        self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                        self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                        self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                        self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                        self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                        self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                        self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                        self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")
                                                        self._segment_path = lambda: "rtr-cap-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, ['rtr_cap_additional_info', 'rtr_cap_all_bits', 'rtr_cap_area_te', 'rtr_cap_graceful_restart', 'rtr_cap_graceful_restart_helper', 'rtr_cap_p2plan', 'rtr_cap_stub_rtr', 'rtr_cap_te_exp', 'rtr_cap_tlv_length'], name, value)


                                                class SrAlgoTlv(Entity):
                                                    """
                                                    SR Algorithm TLV
                                                    
                                                    .. attribute:: sr_algo_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sr_algo_value
                                                    
                                                    	SR Algorithms
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                        self.yang_name = "sr-algo-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                        self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")
                                                        self._segment_path = lambda: "sr-algo-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, ['sr_algo_length', 'sr_algo_value'], name, value)


                                                class SrRangeTlv(Entity):
                                                    """
                                                    SR Range TLV
                                                    
                                                    .. attribute:: sidtlv
                                                    
                                                    	SID sub\-TLV
                                                    	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                                    
                                                    .. attribute:: sr_range_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sr_range_size
                                                    
                                                    	SR Range Size
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                        self.yang_name = "sr-range-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"sidtlv" : ("sidtlv", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv)}
                                                        self._child_list_classes = {}

                                                        self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                        self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                        self.sidtlv = Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                        self.sidtlv.parent = self
                                                        self._children_name_map["sidtlv"] = "sidtlv"
                                                        self._children_yang_names.add("sidtlv")
                                                        self._segment_path = lambda: "sr-range-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, ['sr_range_length', 'sr_range_size'], name, value)


                                                    class Sidtlv(Entity):
                                                        """
                                                        SID sub\-TLV
                                                        
                                                        .. attribute:: sr_sid_length
                                                        
                                                        	Length of sub\-TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sr_sid_value
                                                        
                                                        	SID Value
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                            self.yang_name = "sidtlv"
                                                            self.yang_parent_name = "sr-range-tlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                            self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")
                                                            self._segment_path = lambda: "sidtlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, ['sr_sid_length', 'sr_sid_value'], name, value)


                                                class UnknownTlv(Entity):
                                                    """
                                                    Unknown Rtr Info TLV
                                                    
                                                    .. attribute:: ri_gen_tlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_gen_tlv_type
                                                    
                                                    	Type of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_genvalue
                                                    
                                                    	Data in TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                        self.yang_name = "unknown-tlv"
                                                        self.yang_parent_name = "opaque-ritlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                        self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                        self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                        self._segment_path = lambda: "unknown-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                        class RouterLsaType(Entity):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: internal_link
                                            
                                            	List of links for internal LSA
                                            	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                            
                                            .. attribute:: internal_lsa
                                            
                                            	If true, internal LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                            
                                            .. attribute:: router_abr
                                            
                                            	If True, router is an Area Border Router
                                            	**type**\:  bool
                                            
                                            .. attribute:: router_asbr
                                            
                                            	If True, router is an Autonomous system Border Router
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                                self.yang_name = "router-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"internal-link" : ("internal_link", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink), "link" : ("link", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link)}

                                                self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                                self.router_abr = YLeaf(YType.boolean, "router-abr")

                                                self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                                self.internal_link = YList(self)
                                                self.link = YList(self)
                                                self._segment_path = lambda: "router-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, ['internal_lsa', 'router_abr', 'router_asbr'], name, value)


                                            class InternalLink(Entity):
                                                """
                                                List of links for internal LSA
                                                
                                                .. attribute:: link_data
                                                
                                                	Link Data
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_id
                                                
                                                	Link ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_metric
                                                
                                                	Cost for using this link
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_tos
                                                
                                                	List of type of service metrics
                                                	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                                    self.yang_name = "internal-link"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos)}

                                                    self.link_data = YLeaf(YType.str, "link-data")

                                                    self.link_id = YLeaf(YType.str, "link-id")

                                                    self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                    self.link_type = YLeaf(YType.enumeration, "link-type")

                                                    self.link_tos = YList(self)
                                                    self._segment_path = lambda: "internal-link"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                                class LinkTos(Entity):
                                                    """
                                                    List of type of service metrics
                                                    
                                                    .. attribute:: router_tos
                                                    
                                                    	Type of Service
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tos_cost
                                                    
                                                    	Type of service specific metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                        self.yang_name = "link-tos"
                                                        self.yang_parent_name = "internal-link"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                        self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                        self._segment_path = lambda: "link-tos"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                            class Link(Entity):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_data
                                                
                                                	Link Data
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_id
                                                
                                                	Link ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: link_metric
                                                
                                                	Cost for using this link
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_tos
                                                
                                                	List of type of service metrics
                                                	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                                    self.yang_name = "link"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos)}

                                                    self.link_data = YLeaf(YType.str, "link-data")

                                                    self.link_id = YLeaf(YType.str, "link-id")

                                                    self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                    self.link_type = YLeaf(YType.enumeration, "link-type")

                                                    self.link_tos = YList(self)
                                                    self._segment_path = lambda: "link"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                                class LinkTos(Entity):
                                                    """
                                                    List of type of service metrics
                                                    
                                                    .. attribute:: router_tos
                                                    
                                                    	Type of Service
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tos_cost
                                                    
                                                    	Type of service specific metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                        self.yang_name = "link-tos"
                                                        self.yang_parent_name = "link"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                        self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                        self._segment_path = lambda: "link-tos"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                        class SummaryLsaType(Entity):
                                            """
                                            Summary LSA
                                            
                                            .. attribute:: internal_sum_lsa
                                            
                                            	If true, internal max\-metric LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: summary_lsa_metric
                                            
                                            	Metric
                                            	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                            
                                            .. attribute:: summary_prefix_length
                                            
                                            	Summary LSA prefix length
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                                self.yang_name = "summary-lsa-type"
                                                self.yang_parent_name = "lsa-internal-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"summary-lsa-metric" : ("summary_lsa_metric", Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric)}

                                                self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                                self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                                self.summary_lsa_metric = YList(self)
                                                self._segment_path = lambda: "summary-lsa-type"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, ['internal_sum_lsa', 'summary_prefix_length'], name, value)


                                            class SummaryLsaMetric(Entity):
                                                """
                                                Metric
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                                    self.yang_name = "summary-lsa-metric"
                                                    self.yang_parent_name = "summary-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "summary-lsa-metric"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, ['entry'], name, value)


                    class DatabaseSummaries(Entity):
                        """
                        Link State database summary table
                        
                        .. attribute:: database_summary
                        
                        	Link State Database summary for a particular area
                        	**type**\: list of    :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries, self).__init__()

                            self.yang_name = "database-summaries"
                            self.yang_parent_name = "database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"database-summary" : ("database_summary", Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary)}

                            self.database_summary = YList(self)
                            self._segment_path = lambda: "database-summaries"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries, [], name, value)


                        class DatabaseSummary(Entity):
                            """
                            Link State Database summary for a particular
                            area
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_lsa_counter
                            
                            	Summary counters for Area scope LSAs
                            	**type**\: list of    :py:class:`AreaLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter>`
                            
                            .. attribute:: dbase_sum_area_id_string
                            
                            	Area id
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary, self).__init__()

                                self.yang_name = "database-summary"
                                self.yang_parent_name = "database-summaries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-lsa-counter" : ("area_lsa_counter", Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter)}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.dbase_sum_area_id_string = YLeaf(YType.str, "dbase-sum-area-id-string")

                                self.area_lsa_counter = YList(self)
                                self._segment_path = lambda: "database-summary" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary, ['area_id', 'dbase_sum_area_id_string'], name, value)


                            class AreaLsaCounter(Entity):
                                """
                                Summary counters for Area scope LSAs
                                
                                .. attribute:: lsa_count
                                
                                	Number of LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_delete_count
                                
                                	Number of deleted LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_maxage_count
                                
                                	Number of MaxAged LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_self_count
                                
                                	Number of self\-generated LSAs
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_type
                                
                                	Type of LSAs
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__init__()

                                    self.yang_name = "area-lsa-counter"
                                    self.yang_parent_name = "database-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                    self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                    self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                    self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                    self.lsa_type = YLeaf(YType.enumeration, "lsa-type")
                                    self._segment_path = lambda: "area-lsa-counter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, ['lsa_count', 'lsa_delete_count', 'lsa_maxage_count', 'lsa_self_count', 'lsa_type'], name, value)


                    class DatabaseSummaryAs(Entity):
                        """
                        Link State Database summary for the AS
                        
                        .. attribute:: as_lsa_counter
                        
                        	Summary counter for AS scope LSAs
                        	**type**\: list of    :py:class:`AsLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs, self).__init__()

                            self.yang_name = "database-summary-as"
                            self.yang_parent_name = "database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"as-lsa-counter" : ("as_lsa_counter", Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter)}

                            self.as_lsa_counter = YList(self)
                            self._segment_path = lambda: "database-summary-as"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs, [], name, value)


                        class AsLsaCounter(Entity):
                            """
                            Summary counter for AS scope LSAs
                            
                            .. attribute:: lsa_count
                            
                            	Number of LSAs of this type
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_delete_count
                            
                            	Number of deleted LSAs of this type
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_maxage_count
                            
                            	Number of MaxAged LSAs of this type
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_self_count
                            
                            	Number of self\-generated LSAs
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsa_type
                            
                            	Type of LSAs
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__init__()

                                self.yang_name = "as-lsa-counter"
                                self.yang_parent_name = "database-summary-as"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                self.lsa_type = YLeaf(YType.enumeration, "lsa-type")
                                self._segment_path = lambda: "as-lsa-counter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.DatabaseSummaryAs.AsLsaCounter, ['lsa_count', 'lsa_delete_count', 'lsa_maxage_count', 'lsa_self_count', 'lsa_type'], name, value)


                    class LsaSummaries(Entity):
                        """
                        Link state advertisement summary table
                        
                        .. attribute:: lsa_summary
                        
                        	LSA summary information
                        	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries, self).__init__()

                            self.yang_name = "lsa-summaries"
                            self.yang_parent_name = "database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"lsa-summary" : ("lsa_summary", Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary)}

                            self.lsa_summary = YList(self)
                            self._segment_path = lambda: "lsa-summaries"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries, [], name, value)


                        class LsaSummary(Entity):
                            """
                            LSA summary information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: external_tag
                            
                            	Route Tag
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: link_count
                            
                            	Number of links
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_type
                            
                            	Link state type
                            	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                            
                            .. attribute:: lsa_header
                            
                            	LSA header information
                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary, self).__init__()

                                self.yang_name = "lsa-summary"
                                self.yang_parent_name = "lsa-summaries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"lsa-header" : ("lsa_header", Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader)}
                                self._child_list_classes = {}

                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.link_count = YLeaf(YType.uint16, "link-count")

                                self.ls_id = YLeaf(YType.str, "ls-id")

                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader()
                                self.lsa_header.parent = self
                                self._children_name_map["lsa_header"] = "lsa-header"
                                self._children_yang_names.add("lsa-header")
                                self._segment_path = lambda: "lsa-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary, ['advertising_router', 'area_id', 'external_tag', 'interface_name', 'link_count', 'ls_id', 'ls_type'], name, value)


                            class LsaHeader(Entity):
                                """
                                LSA header information
                                
                                .. attribute:: advertising_router
                                
                                	Router ID of Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: checksum
                                
                                	Checksum value
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dn_age_lsa
                                
                                	If true, Do Not Age this LSA
                                	**type**\:  bool
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: lsa_age
                                
                                	LSA's Age (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: lsid
                                
                                	LS ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nsf
                                
                                	If true,  LSA received from neighbor during NSF
                                	**type**\:  bool
                                
                                .. attribute:: sequence_number
                                
                                	Current Sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                    self.yang_name = "lsa-header"
                                    self.yang_parent_name = "lsa-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                    self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                    self.lsid = YLeaf(YType.str, "lsid")

                                    self.nsf = YLeaf(YType.boolean, "nsf")

                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                    self._segment_path = lambda: "lsa-header"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.LsaSummaries.LsaSummary.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                    class Lsas(Entity):
                        """
                        Link State Database Table
                        
                        .. attribute:: lsa
                        
                        	Link State Advertisement information
                        	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas, self).__init__()

                            self.yang_name = "lsas"
                            self.yang_parent_name = "database"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"lsa" : ("lsa", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa)}

                            self.lsa = YList(self)
                            self._segment_path = lambda: "lsas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas, [], name, value)


                        class Lsa(Entity):
                            """
                            Link State Advertisement information
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_type
                            
                            	Link state type
                            	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                            
                            .. attribute:: lsa_detail_data
                            
                            	Detailed LSA Information
                            	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData>`
                            
                            .. attribute:: lsa_header
                            
                            	Header information
                            	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader>`
                            
                            .. attribute:: lsa_internal_data
                            
                            	Information pertaining to a specific LSA type
                            	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "lsas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"lsa-detail-data" : ("lsa_detail_data", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData), "lsa-header" : ("lsa_header", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader), "lsa-internal-data" : ("lsa_internal_data", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData)}
                                self._child_list_classes = {}

                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.ls_id = YLeaf(YType.str, "ls-id")

                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                self.lsa_detail_data = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData()
                                self.lsa_detail_data.parent = self
                                self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                self._children_yang_names.add("lsa-detail-data")

                                self.lsa_header = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader()
                                self.lsa_header.parent = self
                                self._children_name_map["lsa_header"] = "lsa-header"
                                self._children_yang_names.add("lsa-header")

                                self.lsa_internal_data = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData()
                                self.lsa_internal_data.parent = self
                                self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                self._children_yang_names.add("lsa-internal-data")
                                self._segment_path = lambda: "lsa"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                            class LsaDetailData(Entity):
                                """
                                Detailed LSA Information
                                
                                .. attribute:: advertising_router_reachable
                                
                                	If true, Advertising Router is reachable
                                	**type**\:  bool
                                
                                .. attribute:: ase_origin
                                
                                	External Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: demand_circuit
                                
                                	If true, capable of demand circuit as indicated by LSA's option field
                                	**type**\:  bool
                                
                                .. attribute:: dn_bit
                                
                                	if true, DN bit set on the summary LSA indicated by LSA's option field
                                	**type**\:  bool
                                
                                .. attribute:: in_sync
                                
                                	Not In Sync With Active
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: length
                                
                                	Length of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsa_flood_required_post_fail_over
                                
                                	LSA flood required after FO
                                	**type**\:  bool
                                
                                .. attribute:: lsa_last_updated_time
                                
                                	Time LSA was last updated
                                	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                
                                .. attribute:: lsa_prefix_priority
                                
                                	Current LSA prefix priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: lsa_rate_limit_due_time
                                
                                	Due time for rate\-limit timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_throttle_timer
                                
                                	LSA throttle timer table information
                                	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                
                                .. attribute:: lsadb_base_clock
                                
                                	Clock stamp since boot
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: lsadb_base_time_stamp
                                
                                	Current time stamp
                                	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                
                                .. attribute:: new_lsa_prefix_priority
                                
                                	New LSA prefix priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: not_delete
                                
                                	Reason why LSA is not deleted
                                	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete>`
                                
                                .. attribute:: nssa_translation
                                
                                	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                	**type**\:  bool
                                
                                .. attribute:: routing_bit
                                
                                	If true, Routing Bit set on the LSA
                                	**type**\:  bool
                                
                                .. attribute:: sum_origin
                                
                                	Summary Origin
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: tos_capable
                                
                                	If true, type of service capable indicated by LSA's option field
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData, self).__init__()

                                    self.yang_name = "lsa-detail-data"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-last-updated-time" : ("lsa_last_updated_time", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime), "lsa-throttle-timer" : ("lsa_throttle_timer", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer), "lsadb-base-time-stamp" : ("lsadb_base_time_stamp", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp), "not-delete" : ("not_delete", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete)}
                                    self._child_list_classes = {}

                                    self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                    self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                    self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                    self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                    self.in_sync = YLeaf(YType.uint8, "in-sync")

                                    self.length = YLeaf(YType.uint16, "length")

                                    self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                    self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                    self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                    self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                    self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                    self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                    self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                    self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                    self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                    self.lsa_last_updated_time = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                    self.lsa_last_updated_time.parent = self
                                    self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                    self._children_yang_names.add("lsa-last-updated-time")

                                    self.lsa_throttle_timer = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                    self.lsa_throttle_timer.parent = self
                                    self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                    self._children_yang_names.add("lsa-throttle-timer")

                                    self.lsadb_base_time_stamp = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                    self.lsadb_base_time_stamp.parent = self
                                    self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                    self._children_yang_names.add("lsadb-base-time-stamp")

                                    self.not_delete = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete()
                                    self.not_delete.parent = self
                                    self._children_name_map["not_delete"] = "not-delete"
                                    self._children_yang_names.add("not-delete")
                                    self._segment_path = lambda: "lsa-detail-data"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData, ['advertising_router_reachable', 'ase_origin', 'demand_circuit', 'dn_bit', 'in_sync', 'length', 'lsa_flood_required_post_fail_over', 'lsa_prefix_priority', 'lsa_rate_limit_due_time', 'lsadb_base_clock', 'new_lsa_prefix_priority', 'nssa_translation', 'routing_bit', 'sum_origin', 'tos_capable'], name, value)


                                class LsaLastUpdatedTime(Entity):
                                    """
                                    Time LSA was last updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                        self.yang_name = "lsa-last-updated-time"
                                        self.yang_parent_name = "lsa-detail-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "lsa-last-updated-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, ['nanosecond', 'second'], name, value)


                                class LsaThrottleTimer(Entity):
                                    """
                                    LSA throttle timer table information
                                    
                                    .. attribute:: last_inst_minute_table_index
                                    
                                    	Last Minute table index processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: last_inst_second_table_index
                                    
                                    	Last Second table index processed
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: minute_table_index
                                    
                                    	Minute table index
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: second_table_index
                                    
                                    	Second table index
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: timer_location
                                    
                                    	Timer table
                                    	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                    
                                    .. attribute:: timer_type
                                    
                                    	Timer type
                                    	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                        self.yang_name = "lsa-throttle-timer"
                                        self.yang_parent_name = "lsa-detail-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                        self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                        self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                        self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                        self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                        self.timer_type = YLeaf(YType.enumeration, "timer-type")
                                        self._segment_path = lambda: "lsa-throttle-timer"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, ['last_inst_minute_table_index', 'last_inst_second_table_index', 'minute_table_index', 'second_table_index', 'timer_location', 'timer_type'], name, value)


                                class LsadbBaseTimeStamp(Entity):
                                    """
                                    Current time stamp
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                        self.yang_name = "lsadb-base-time-stamp"
                                        self.yang_parent_name = "lsa-detail-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "lsadb-base-time-stamp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, ['nanosecond', 'second'], name, value)


                                class NotDelete(Entity):
                                    """
                                    Reason why LSA is not deleted
                                    
                                    .. attribute:: acknowledgement
                                    
                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_pending
                                    
                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                    	**type**\:  bool
                                    
                                    .. attribute:: free_time
                                    
                                    	The amount of time since the last check was made to free this LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_age
                                    
                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_exchange
                                    
                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                    	**type**\:  bool
                                    
                                    .. attribute:: no_delete
                                    
                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_ack_pending
                                    
                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                    	**type**\:  bool
                                    
                                    .. attribute:: nsr_flood_required
                                    
                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                    	**type**\:  bool
                                    
                                    .. attribute:: partial_spf
                                    
                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                    	**type**\:  bool
                                    
                                    .. attribute:: rate_limit
                                    
                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                    	**type**\:  bool
                                    
                                    .. attribute:: routing_table
                                    
                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                    	**type**\:  bool
                                    
                                    .. attribute:: sum_orig_pending
                                    
                                    	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                        self.yang_name = "not-delete"
                                        self.yang_parent_name = "lsa-detail-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                        self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                        self.free_time = YLeaf(YType.uint32, "free-time")

                                        self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                        self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                        self.no_delete = YLeaf(YType.boolean, "no-delete")

                                        self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                        self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                        self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                        self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                        self.routing_table = YLeaf(YType.boolean, "routing-table")

                                        self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")
                                        self._segment_path = lambda: "not-delete"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, ['acknowledgement', 'flood_pending', 'free_time', 'maximum_age', 'neighbor_exchange', 'no_delete', 'nsr_ack_pending', 'nsr_flood_required', 'partial_spf', 'rate_limit', 'routing_table', 'sum_orig_pending'], name, value)


                            class LsaHeader(Entity):
                                """
                                Header information
                                
                                .. attribute:: advertising_router
                                
                                	Router ID of Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: checksum
                                
                                	Checksum value
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dn_age_lsa
                                
                                	If true, Do Not Age this LSA
                                	**type**\:  bool
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: lsa_age
                                
                                	LSA's Age (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: lsid
                                
                                	LS ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nsf
                                
                                	If true,  LSA received from neighbor during NSF
                                	**type**\:  bool
                                
                                .. attribute:: sequence_number
                                
                                	Current Sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader, self).__init__()

                                    self.yang_name = "lsa-header"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.checksum = YLeaf(YType.uint16, "checksum")

                                    self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                    self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                    self.lsid = YLeaf(YType.str, "lsid")

                                    self.nsf = YLeaf(YType.boolean, "nsf")

                                    self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                    self._segment_path = lambda: "lsa-header"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                            class LsaInternalData(Entity):
                                """
                                Information pertaining to a specific LSA type
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                
                                .. attribute:: internal_lsa_type
                                
                                	InternalLSAType
                                	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                
                                .. attribute:: opaque_el_lsa_type
                                
                                	Extended Link LSA type
                                	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                
                                .. attribute:: opaque_ep_lsa_type
                                
                                	Extende Prefix LSA type
                                	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                
                                .. attribute:: opaque_grace_lsa
                                
                                	Opaque\-link, opaque type 3 Grace LSA
                                	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                
                                .. attribute:: opaque_link_lsa_type
                                
                                	Opaque\-Link LSA
                                	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                
                                .. attribute:: opaque_mpls_te_lsa_type
                                
                                	Opaque\-Area, opaque type 1 LSA
                                	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                
                                .. attribute:: opaque_router_info_lsa_type
                                
                                	Opaque Router Information LSA
                                	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                
                                .. attribute:: summary_lsa_type
                                
                                	Summary LSA
                                	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData, self).__init__()

                                    self.yang_name = "lsa-internal-data"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType), "network-lsa-type" : ("network_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType), "opaque-el-lsa-type" : ("opaque_el_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType), "opaque-ep-lsa-type" : ("opaque_ep_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType), "opaque-grace-lsa" : ("opaque_grace_lsa", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa), "opaque-link-lsa-type" : ("opaque_link_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType), "opaque-mpls-te-lsa-type" : ("opaque_mpls_te_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType), "opaque-router-info-lsa-type" : ("opaque_router_info_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType), "router-lsa-type" : ("router_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType), "summary-lsa-type" : ("summary_lsa_type", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType)}
                                    self._child_list_classes = {}

                                    self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                    self.external_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                    self._children_yang_names.add("external-lsa-type")

                                    self.network_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                    self._children_yang_names.add("network-lsa-type")

                                    self.opaque_el_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                    self.opaque_el_lsa_type.parent = self
                                    self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                    self._children_yang_names.add("opaque-el-lsa-type")

                                    self.opaque_ep_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                    self.opaque_ep_lsa_type.parent = self
                                    self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                    self._children_yang_names.add("opaque-ep-lsa-type")

                                    self.opaque_grace_lsa = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                    self.opaque_grace_lsa.parent = self
                                    self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                    self._children_yang_names.add("opaque-grace-lsa")

                                    self.opaque_link_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                    self.opaque_link_lsa_type.parent = self
                                    self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                    self._children_yang_names.add("opaque-link-lsa-type")

                                    self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                    self.opaque_mpls_te_lsa_type.parent = self
                                    self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                    self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                    self.opaque_router_info_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                    self.opaque_router_info_lsa_type.parent = self
                                    self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                    self._children_yang_names.add("opaque-router-info-lsa-type")

                                    self.router_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                    self._children_yang_names.add("router-lsa-type")

                                    self.summary_lsa_type = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                    self.summary_lsa_type.parent = self
                                    self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                    self._children_yang_names.add("summary-lsa-type")
                                    self._segment_path = lambda: "lsa-internal-data"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData, ['internal_lsa_type'], name, value)


                                class ExternalLsaType(Entity):
                                    """
                                    External LSA
                                    
                                    .. attribute:: external_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_tos_metric
                                    
                                    	Type of service information
                                    	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                    
                                    .. attribute:: internal_external_lsa
                                    
                                    	If true, internal max\-metric LSA
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                        self.yang_name = "external-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"external-tos-metric" : ("external_tos_metric", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric)}

                                        self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                        self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                        self.external_tos_metric = YList(self)
                                        self._segment_path = lambda: "external-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, ['external_prefix_length', 'internal_external_lsa'], name, value)


                                    class ExternalTosMetric(Entity):
                                        """
                                        Type of service information
                                        
                                        .. attribute:: external_metric
                                        
                                        	Cost of this route
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_metric_type
                                        
                                        	External LSA metric type
                                        	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_tos
                                        
                                        	Type of Service
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                            self.yang_name = "external-tos-metric"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.external_metric = YLeaf(YType.uint32, "external-metric")

                                            self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.external_tos = YLeaf(YType.uint32, "external-tos")

                                            self.forwarding_address = YLeaf(YType.str, "forwarding-address")
                                            self._segment_path = lambda: "external-tos-metric"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, ['external_metric', 'external_metric_type', 'external_tag', 'external_tos', 'forwarding_address'], name, value)


                                class NetworkLsaType(Entity):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                    
                                    .. attribute:: network_prefix_length
                                    
                                    	Network prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                        self.yang_name = "network-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor-router" : ("neighbor_router", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter)}

                                        self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                        self.neighbor_router = YList(self)
                                        self._segment_path = lambda: "network-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, ['network_prefix_length'], name, value)


                                    class NeighborRouter(Entity):
                                        """
                                        Neighbor router list
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                            self.yang_name = "neighbor-router"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.str, "entry")
                                            self._segment_path = lambda: "neighbor-router"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, ['entry'], name, value)


                                class OpaqueElLsaType(Entity):
                                    """
                                    Extended Link LSA type
                                    
                                    .. attribute:: tlv
                                    
                                    	List of TLVs
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                        self.yang_name = "opaque-el-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv)}

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "opaque-el-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, [], name, value)


                                    class Tlv(Entity):
                                        """
                                        List of TLVs
                                        
                                        .. attribute:: mpls_dste_link
                                        
                                        	MPLS DS\-TE supported
                                        	**type**\:  bool
                                        
                                        .. attribute:: mpls_router_id
                                        
                                        	MPLS\-TE Router ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_link_sub_tlv
                                        
                                        	List of Sub\-TLVs
                                        	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                        
                                        .. attribute:: tlv_data
                                        
                                        	TLV direct data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tlv_length
                                        
                                        	Length of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tlv_type
                                        
                                        	Type of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "opaque-el-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv)}

                                            self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                            self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                            self.tlv_data = YLeaf(YType.str, "tlv-data")

                                            self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                            self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                            self.te_link_sub_tlv = YList(self)
                                            self._segment_path = lambda: "tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                        class TeLinkSubTlv(Entity):
                                            """
                                            List of Sub\-TLVs
                                            
                                            .. attribute:: sub_tlv_length
                                            
                                            	Length of sub TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sub_tlv_type
                                            
                                            	Type of sub TLV
                                            	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                            
                                            .. attribute:: sub_tlv_value
                                            
                                            	Value of sub TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                self.yang_name = "te-link-sub-tlv"
                                                self.yang_parent_name = "tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                self._segment_path = lambda: "te-link-sub-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                class OpaqueEpLsaType(Entity):
                                    """
                                    Extende Prefix LSA type
                                    
                                    .. attribute:: tlv
                                    
                                    	List of TLVs
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                        self.yang_name = "opaque-ep-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv)}

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "opaque-ep-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, [], name, value)


                                    class Tlv(Entity):
                                        """
                                        List of TLVs
                                        
                                        .. attribute:: mpls_dste_link
                                        
                                        	MPLS DS\-TE supported
                                        	**type**\:  bool
                                        
                                        .. attribute:: mpls_router_id
                                        
                                        	MPLS\-TE Router ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_link_sub_tlv
                                        
                                        	List of Sub\-TLVs
                                        	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                        
                                        .. attribute:: tlv_data
                                        
                                        	TLV direct data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tlv_length
                                        
                                        	Length of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tlv_type
                                        
                                        	Type of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "opaque-ep-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv)}

                                            self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                            self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                            self.tlv_data = YLeaf(YType.str, "tlv-data")

                                            self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                            self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                            self.te_link_sub_tlv = YList(self)
                                            self._segment_path = lambda: "tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                        class TeLinkSubTlv(Entity):
                                            """
                                            List of Sub\-TLVs
                                            
                                            .. attribute:: sub_tlv_length
                                            
                                            	Length of sub TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sub_tlv_type
                                            
                                            	Type of sub TLV
                                            	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                            
                                            .. attribute:: sub_tlv_value
                                            
                                            	Value of sub TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                self.yang_name = "te-link-sub-tlv"
                                                self.yang_parent_name = "tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                self._segment_path = lambda: "te-link-sub-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                class OpaqueGraceLsa(Entity):
                                    """
                                    Opaque\-link, opaque type 3 Grace LSA
                                    
                                    .. attribute:: grace_period
                                    
                                    	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                    
                                    .. attribute:: ip_address
                                    
                                    	IP interface address on the subnet associated with the grace LSA
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                        self.yang_name = "opaque-grace-lsa"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.grace_period = YLeaf(YType.uint32, "grace-period")

                                        self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                        self.ip_address = YLeaf(YType.str, "ip-address")
                                        self._segment_path = lambda: "opaque-grace-lsa"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, ['grace_period', 'grace_reason', 'ip_address'], name, value)


                                class OpaqueLinkLsaType(Entity):
                                    """
                                    Opaque\-Link LSA
                                    
                                    .. attribute:: opaque_interface_name
                                    
                                    	Interface on which the Opaque link LSA is received
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                        self.yang_name = "opaque-link-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")
                                        self._segment_path = lambda: "opaque-link-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, ['opaque_interface_name'], name, value)


                                class OpaqueMplsTeLsaType(Entity):
                                    """
                                    Opaque\-Area, opaque type 1 LSA
                                    
                                    .. attribute:: tlv
                                    
                                    	List of TLVs
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                        self.yang_name = "opaque-mpls-te-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv)}

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "opaque-mpls-te-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, [], name, value)


                                    class Tlv(Entity):
                                        """
                                        List of TLVs
                                        
                                        .. attribute:: mpls_dste_link
                                        
                                        	MPLS DS\-TE supported
                                        	**type**\:  bool
                                        
                                        .. attribute:: mpls_router_id
                                        
                                        	MPLS\-TE Router ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_link_sub_tlv
                                        
                                        	List of Sub\-TLVs
                                        	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                        
                                        .. attribute:: tlv_data
                                        
                                        	TLV direct data
                                        	**type**\:  str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        .. attribute:: tlv_length
                                        
                                        	Length of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: tlv_type
                                        
                                        	Type of top\-level TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "opaque-mpls-te-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv)}

                                            self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                            self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                            self.tlv_data = YLeaf(YType.str, "tlv-data")

                                            self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                            self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                            self.te_link_sub_tlv = YList(self)
                                            self._segment_path = lambda: "tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                        class TeLinkSubTlv(Entity):
                                            """
                                            List of Sub\-TLVs
                                            
                                            .. attribute:: sub_tlv_length
                                            
                                            	Length of sub TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sub_tlv_type
                                            
                                            	Type of sub TLV
                                            	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                            
                                            .. attribute:: sub_tlv_value
                                            
                                            	Value of sub TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                self.yang_name = "te-link-sub-tlv"
                                                self.yang_parent_name = "tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                self._segment_path = lambda: "te-link-sub-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                class OpaqueRouterInfoLsaType(Entity):
                                    """
                                    Opaque Router Information LSA
                                    
                                    .. attribute:: opaque_ri_interface_name
                                    
                                    	Interface on which this Link\-Local Opaque link LSA is received
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: opaque_rilsa_scope
                                    
                                    	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                    	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                    
                                    .. attribute:: opaque_ritlv
                                    
                                    	Router Information TLV
                                    	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                        self.yang_name = "opaque-router-info-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"opaque-ritlv" : ("opaque_ritlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv)}

                                        self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                        self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                        self.opaque_ritlv = YList(self)
                                        self._segment_path = lambda: "opaque-router-info-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, ['opaque_ri_interface_name', 'opaque_rilsa_scope'], name, value)


                                    class OpaqueRitlv(Entity):
                                        """
                                        Router Information TLV
                                        
                                        .. attribute:: node_msdtlv
                                        
                                        	Node MSD TLV
                                        	**type**\:   :py:class:`NodeMsdtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv>`
                                        
                                        .. attribute:: pcedtlv
                                        
                                        	PCE Discovery TLV
                                        	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                        
                                        .. attribute:: ritlv_internal_type
                                        
                                        	RITLVInternalType
                                        	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                        
                                        .. attribute:: rtr_cap_tlv
                                        
                                        	Rtr Cap TLV
                                        	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                        
                                        .. attribute:: sr_algo_tlv
                                        
                                        	SR Algorithm TLV
                                        	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                        
                                        .. attribute:: sr_range_tlv
                                        
                                        	SR Range TLV
                                        	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                        
                                        .. attribute:: unknown_tlv
                                        
                                        	Unknown Rtr Info TLV
                                        	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                            self.yang_name = "opaque-ritlv"
                                            self.yang_parent_name = "opaque-router-info-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"node-msdtlv" : ("node_msdtlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv), "pcedtlv" : ("pcedtlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv), "rtr-cap-tlv" : ("rtr_cap_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv), "sr-algo-tlv" : ("sr_algo_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv), "sr-range-tlv" : ("sr_range_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv), "unknown-tlv" : ("unknown_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv)}
                                            self._child_list_classes = {}

                                            self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                            self.node_msdtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv()
                                            self.node_msdtlv.parent = self
                                            self._children_name_map["node_msdtlv"] = "node-msdtlv"
                                            self._children_yang_names.add("node-msdtlv")

                                            self.pcedtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                            self.pcedtlv.parent = self
                                            self._children_name_map["pcedtlv"] = "pcedtlv"
                                            self._children_yang_names.add("pcedtlv")

                                            self.rtr_cap_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                            self.rtr_cap_tlv.parent = self
                                            self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                            self._children_yang_names.add("rtr-cap-tlv")

                                            self.sr_algo_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                            self.sr_algo_tlv.parent = self
                                            self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                            self._children_yang_names.add("sr-algo-tlv")

                                            self.sr_range_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                            self.sr_range_tlv.parent = self
                                            self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                            self._children_yang_names.add("sr-range-tlv")

                                            self.unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                            self.unknown_tlv.parent = self
                                            self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                            self._children_yang_names.add("unknown-tlv")
                                            self._segment_path = lambda: "opaque-ritlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, ['ritlv_internal_type'], name, value)


                                        class NodeMsdtlv(Entity):
                                            """
                                            Node MSD TLV
                                            
                                            .. attribute:: node_msd_sub_types
                                            
                                            	Node MSD Subtypes
                                            	**type**\:   :py:class:`NodeMsdSubTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes>`
                                            
                                            .. attribute:: node_msdtlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, self).__init__()

                                                self.yang_name = "node-msdtlv"
                                                self.yang_parent_name = "opaque-ritlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"node-msd-sub-types" : ("node_msd_sub_types", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes)}
                                                self._child_list_classes = {}

                                                self.node_msdtlv_length = YLeaf(YType.uint16, "node-msdtlv-length")

                                                self.node_msd_sub_types = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes()
                                                self.node_msd_sub_types.parent = self
                                                self._children_name_map["node_msd_sub_types"] = "node-msd-sub-types"
                                                self._children_yang_names.add("node-msd-sub-types")
                                                self._segment_path = lambda: "node-msdtlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, ['node_msdtlv_length'], name, value)


                                            class NodeMsdSubTypes(Entity):
                                                """
                                                Node MSD Subtypes
                                                
                                                .. attribute:: msd_sub_type
                                                
                                                	MSD SubType
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: msd_value
                                                
                                                	MSD Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, self).__init__()

                                                    self.yang_name = "node-msd-sub-types"
                                                    self.yang_parent_name = "node-msdtlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.msd_sub_type = YLeaf(YType.uint8, "msd-sub-type")

                                                    self.msd_value = YLeaf(YType.uint8, "msd-value")
                                                    self._segment_path = lambda: "node-msd-sub-types"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, ['msd_sub_type', 'msd_value'], name, value)


                                        class Pcedtlv(Entity):
                                            """
                                            PCE Discovery TLV
                                            
                                            .. attribute:: pced_addr
                                            
                                            	PCE Address
                                            	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                            
                                            .. attribute:: pced_scope
                                            
                                            	PCE Scope Information
                                            	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                            
                                            .. attribute:: pcedtlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                self.yang_name = "pcedtlv"
                                                self.yang_parent_name = "opaque-ritlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"pced-addr" : ("pced_addr", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr), "pced-scope" : ("pced_scope", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope)}
                                                self._child_list_classes = {}

                                                self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                self.pced_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                self.pced_addr.parent = self
                                                self._children_name_map["pced_addr"] = "pced-addr"
                                                self._children_yang_names.add("pced-addr")

                                                self.pced_scope = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                self.pced_scope.parent = self
                                                self._children_name_map["pced_scope"] = "pced-scope"
                                                self._children_yang_names.add("pced-scope")
                                                self._segment_path = lambda: "pcedtlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, ['pcedtlv_length'], name, value)


                                            class PcedAddr(Entity):
                                                """
                                                PCE Address
                                                
                                                .. attribute:: ipv4pce_addr
                                                
                                                	IPv4 PCE Address
                                                	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                
                                                .. attribute:: ipv6pce_addr
                                                
                                                	IPv6 PCE Address
                                                	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                
                                                .. attribute:: pce_addr_type
                                                
                                                	PCEAddrType
                                                	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                
                                                .. attribute:: pce_addr_unknown_tlv
                                                
                                                	Unknown PCE Addr TLV
                                                	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                    self.yang_name = "pced-addr"
                                                    self.yang_parent_name = "pcedtlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ipv4pce-addr" : ("ipv4pce_addr", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr), "ipv6pce-addr" : ("ipv6pce_addr", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr), "pce-addr-unknown-tlv" : ("pce_addr_unknown_tlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv)}
                                                    self._child_list_classes = {}

                                                    self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                    self.ipv4pce_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                    self.ipv4pce_addr.parent = self
                                                    self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                    self._children_yang_names.add("ipv4pce-addr")

                                                    self.ipv6pce_addr = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                    self.ipv6pce_addr.parent = self
                                                    self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                    self._children_yang_names.add("ipv6pce-addr")

                                                    self.pce_addr_unknown_tlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                    self.pce_addr_unknown_tlv.parent = self
                                                    self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                    self._children_yang_names.add("pce-addr-unknown-tlv")
                                                    self._segment_path = lambda: "pced-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, ['pce_addr_type'], name, value)


                                                class Ipv4PceAddr(Entity):
                                                    """
                                                    IPv4 PCE Address
                                                    
                                                    .. attribute:: pceipv4_addr
                                                    
                                                    	PCE IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                        self.yang_name = "ipv4pce-addr"
                                                        self.yang_parent_name = "pced-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")
                                                        self._segment_path = lambda: "ipv4pce-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, ['pceipv4_addr'], name, value)


                                                class Ipv6PceAddr(Entity):
                                                    """
                                                    IPv6 PCE Address
                                                    
                                                    .. attribute:: pceipv6_addr
                                                    
                                                    	PCE IPv6 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                        self.yang_name = "ipv6pce-addr"
                                                        self.yang_parent_name = "pced-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")
                                                        self._segment_path = lambda: "ipv6pce-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, ['pceipv6_addr'], name, value)


                                                class PceAddrUnknownTlv(Entity):
                                                    """
                                                    Unknown PCE Addr TLV
                                                    
                                                    .. attribute:: ri_gen_tlv_length
                                                    
                                                    	Length of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_gen_tlv_type
                                                    
                                                    	Type of TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ri_genvalue
                                                    
                                                    	Data in TLV
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                        self.yang_name = "pce-addr-unknown-tlv"
                                                        self.yang_parent_name = "pced-addr"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                        self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                        self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                        self._segment_path = lambda: "pce-addr-unknown-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                            class PcedScope(Entity):
                                                """
                                                PCE Scope Information
                                                
                                                .. attribute:: all_scope_info_bits
                                                
                                                	PCE Scope Information
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lbit
                                                
                                                	L Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: pref_l
                                                
                                                	Pref L
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pref_r
                                                
                                                	Pref R
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pref_s
                                                
                                                	Pref S
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pref_y
                                                
                                                	Pref Y
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rbit
                                                
                                                	R Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: rd_bit
                                                
                                                	Rd Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: sbit
                                                
                                                	S Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: sd_bit
                                                
                                                	Sd Bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: ybit
                                                
                                                	Y Bit
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                    self.yang_name = "pced-scope"
                                                    self.yang_parent_name = "pcedtlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                    self.lbit = YLeaf(YType.boolean, "lbit")

                                                    self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                    self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                    self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                    self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                    self.rbit = YLeaf(YType.boolean, "rbit")

                                                    self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                    self.sbit = YLeaf(YType.boolean, "sbit")

                                                    self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                    self.ybit = YLeaf(YType.boolean, "ybit")
                                                    self._segment_path = lambda: "pced-scope"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, ['all_scope_info_bits', 'lbit', 'pref_l', 'pref_r', 'pref_s', 'pref_y', 'rbit', 'rd_bit', 'sbit', 'sd_bit', 'ybit'], name, value)


                                        class RtrCapTlv(Entity):
                                            """
                                            Rtr Cap TLV
                                            
                                            .. attribute:: rtr_cap_additional_info
                                            
                                            	Additional Information in TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: rtr_cap_all_bits
                                            
                                            	All capability bits
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rtr_cap_area_te
                                            
                                            	Traffic Engineering capability of area
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_graceful_restart
                                            
                                            	Graceful Restart Capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_graceful_restart_helper
                                            
                                            	Graceful Restart Helper Capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_p2plan
                                            
                                            	P2P LAN Capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_stub_rtr
                                            
                                            	Stub Router capability
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_te_exp
                                            
                                            	TE Experimental bit
                                            	**type**\:  bool
                                            
                                            .. attribute:: rtr_cap_tlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                self.yang_name = "rtr-cap-tlv"
                                                self.yang_parent_name = "opaque-ritlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")
                                                self._segment_path = lambda: "rtr-cap-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, ['rtr_cap_additional_info', 'rtr_cap_all_bits', 'rtr_cap_area_te', 'rtr_cap_graceful_restart', 'rtr_cap_graceful_restart_helper', 'rtr_cap_p2plan', 'rtr_cap_stub_rtr', 'rtr_cap_te_exp', 'rtr_cap_tlv_length'], name, value)


                                        class SrAlgoTlv(Entity):
                                            """
                                            SR Algorithm TLV
                                            
                                            .. attribute:: sr_algo_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_algo_value
                                            
                                            	SR Algorithms
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                self.yang_name = "sr-algo-tlv"
                                                self.yang_parent_name = "opaque-ritlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")
                                                self._segment_path = lambda: "sr-algo-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, ['sr_algo_length', 'sr_algo_value'], name, value)


                                        class SrRangeTlv(Entity):
                                            """
                                            SR Range TLV
                                            
                                            .. attribute:: sidtlv
                                            
                                            	SID sub\-TLV
                                            	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                            
                                            .. attribute:: sr_range_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: sr_range_size
                                            
                                            	SR Range Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                self.yang_name = "sr-range-tlv"
                                                self.yang_parent_name = "opaque-ritlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"sidtlv" : ("sidtlv", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv)}
                                                self._child_list_classes = {}

                                                self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                self.sidtlv = Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                self.sidtlv.parent = self
                                                self._children_name_map["sidtlv"] = "sidtlv"
                                                self._children_yang_names.add("sidtlv")
                                                self._segment_path = lambda: "sr-range-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, ['sr_range_length', 'sr_range_size'], name, value)


                                            class Sidtlv(Entity):
                                                """
                                                SID sub\-TLV
                                                
                                                .. attribute:: sr_sid_length
                                                
                                                	Length of sub\-TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sr_sid_value
                                                
                                                	SID Value
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                    self.yang_name = "sidtlv"
                                                    self.yang_parent_name = "sr-range-tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                    self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")
                                                    self._segment_path = lambda: "sidtlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, ['sr_sid_length', 'sr_sid_value'], name, value)


                                        class UnknownTlv(Entity):
                                            """
                                            Unknown Rtr Info TLV
                                            
                                            .. attribute:: ri_gen_tlv_length
                                            
                                            	Length of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ri_gen_tlv_type
                                            
                                            	Type of TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ri_genvalue
                                            
                                            	Data in TLV
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                self.yang_name = "unknown-tlv"
                                                self.yang_parent_name = "opaque-ritlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                self._segment_path = lambda: "unknown-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                class RouterLsaType(Entity):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: internal_link
                                    
                                    	List of links for internal LSA
                                    	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                    
                                    .. attribute:: internal_lsa
                                    
                                    	If true, internal LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                    
                                    .. attribute:: router_abr
                                    
                                    	If True, router is an Area Border Router
                                    	**type**\:  bool
                                    
                                    .. attribute:: router_asbr
                                    
                                    	If True, router is an Autonomous system Border Router
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                        self.yang_name = "router-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"internal-link" : ("internal_link", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink), "link" : ("link", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link)}

                                        self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                        self.router_abr = YLeaf(YType.boolean, "router-abr")

                                        self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                        self.internal_link = YList(self)
                                        self.link = YList(self)
                                        self._segment_path = lambda: "router-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, ['internal_lsa', 'router_abr', 'router_asbr'], name, value)


                                    class InternalLink(Entity):
                                        """
                                        List of links for internal LSA
                                        
                                        .. attribute:: link_data
                                        
                                        	Link Data
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_id
                                        
                                        	Link ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_metric
                                        
                                        	Cost for using this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_tos
                                        
                                        	List of type of service metrics
                                        	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                            self.yang_name = "internal-link"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos)}

                                            self.link_data = YLeaf(YType.str, "link-data")

                                            self.link_id = YLeaf(YType.str, "link-id")

                                            self.link_metric = YLeaf(YType.uint16, "link-metric")

                                            self.link_type = YLeaf(YType.enumeration, "link-type")

                                            self.link_tos = YList(self)
                                            self._segment_path = lambda: "internal-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                        class LinkTos(Entity):
                                            """
                                            List of type of service metrics
                                            
                                            .. attribute:: router_tos
                                            
                                            	Type of Service
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service specific metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                self.yang_name = "link-tos"
                                                self.yang_parent_name = "internal-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                self._segment_path = lambda: "link-tos"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                    class Link(Entity):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_data
                                        
                                        	Link Data
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_id
                                        
                                        	Link ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_metric
                                        
                                        	Cost for using this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_tos
                                        
                                        	List of type of service metrics
                                        	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                            self.yang_name = "link"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos)}

                                            self.link_data = YLeaf(YType.str, "link-data")

                                            self.link_id = YLeaf(YType.str, "link-id")

                                            self.link_metric = YLeaf(YType.uint16, "link-metric")

                                            self.link_type = YLeaf(YType.enumeration, "link-type")

                                            self.link_tos = YList(self)
                                            self._segment_path = lambda: "link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                        class LinkTos(Entity):
                                            """
                                            List of type of service metrics
                                            
                                            .. attribute:: router_tos
                                            
                                            	Type of Service
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service specific metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                self.yang_name = "link-tos"
                                                self.yang_parent_name = "link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                self._segment_path = lambda: "link-tos"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                class SummaryLsaType(Entity):
                                    """
                                    Summary LSA
                                    
                                    .. attribute:: internal_sum_lsa
                                    
                                    	If true, internal max\-metric LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: summary_lsa_metric
                                    
                                    	Metric
                                    	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                    
                                    .. attribute:: summary_prefix_length
                                    
                                    	Summary LSA prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                        self.yang_name = "summary-lsa-type"
                                        self.yang_parent_name = "lsa-internal-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"summary-lsa-metric" : ("summary_lsa_metric", Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric)}

                                        self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                        self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                        self.summary_lsa_metric = YList(self)
                                        self._segment_path = lambda: "summary-lsa-type"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, ['internal_sum_lsa', 'summary_prefix_length'], name, value)


                                    class SummaryLsaMetric(Entity):
                                        """
                                        Metric
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                            self.yang_name = "summary-lsa-metric"
                                            self.yang_parent_name = "summary-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "summary-lsa-metric"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, ['entry'], name, value)


                class FastReroute(Entity):
                    """
                    Container for FastReroute
                    
                    .. attribute:: topologies
                    
                    	Fast\-reroute topology information table
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.FastReroute, self).__init__()

                        self.yang_name = "fast-reroute"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"topologies" : ("topologies", Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies)}
                        self._child_list_classes = {}

                        self.topologies = Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")
                        self._segment_path = lambda: "fast-reroute"


                    class Topologies(Entity):
                        """
                        Fast\-reroute topology information table
                        
                        .. attribute:: topology
                        
                        	Fast\-reroute topology information
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "fast-reroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"topology" : ("topology", Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology)}

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Fast\-reroute topology information
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: ipfrr_area_revision
                            
                            	IPFRR Topology Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipfrr_router_id
                            
                            	OSPF Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipfrr_topo
                            
                            	IPFRR Topology entries
                            	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo>`
                            
                            .. attribute:: ipfrr_topo_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ipfrr-topo" : ("ipfrr_topo", Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo)}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.ipfrr_area_revision = YLeaf(YType.uint32, "ipfrr-area-revision")

                                self.ipfrr_router_id = YLeaf(YType.str, "ipfrr-router-id")

                                self.ipfrr_topo_area_id = YLeaf(YType.str, "ipfrr-topo-area-id")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.ipfrr_topo = YList(self)
                                self._segment_path = lambda: "topology"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology, ['area_id', 'ipfrr_area_revision', 'ipfrr_router_id', 'ipfrr_topo_area_id', 'router_id'], name, value)


                            class IpfrrTopo(Entity):
                                """
                                IPFRR Topology entries
                                
                                .. attribute:: distance
                                
                                	IPFRR Topology Distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: distance_reverse
                                
                                	IPFRR Topology Reverse Distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dr
                                
                                	IPFRR Topology DR entry
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_sourced
                                
                                	IPFRR Topology Neighbor Sourced
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	IPFRR Topology Node ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: poison
                                
                                	IPFRR Topology rSPT poison
                                	**type**\:  bool
                                
                                .. attribute:: revision
                                
                                	IPFRR Topology Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type4
                                
                                	IPFRR Topoogy Type\-4 entry
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__init__()

                                    self.yang_name = "ipfrr-topo"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.distance = YLeaf(YType.uint32, "distance")

                                    self.distance_reverse = YLeaf(YType.uint32, "distance-reverse")

                                    self.dr = YLeaf(YType.boolean, "dr")

                                    self.neighbor_sourced = YLeaf(YType.boolean, "neighbor-sourced")

                                    self.node_id = YLeaf(YType.str, "node-id")

                                    self.poison = YLeaf(YType.boolean, "poison")

                                    self.revision = YLeaf(YType.uint32, "revision")

                                    self.type4 = YLeaf(YType.boolean, "type4")
                                    self._segment_path = lambda: "ipfrr-topo"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FastReroute.Topologies.Topology.IpfrrTopo, ['distance', 'distance_reverse', 'dr', 'neighbor_sourced', 'node_id', 'poison', 'revision', 'type4'], name, value)


                class FloodListTable(Entity):
                    """
                    Flood list table
                    
                    .. attribute:: flood
                    
                    	Flooding information for a specific interface
                    	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.FloodListTable, self).__init__()

                        self.yang_name = "flood-list-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"flood" : ("flood", Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood)}

                        self.flood = YList(self)
                        self._segment_path = lambda: "flood-list-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FloodListTable, [], name, value)


                    class Flood(Entity):
                        """
                        Flooding information for a specific interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: area_flood
                        
                        	Area scope floodlist
                        	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood>`
                        
                        .. attribute:: as_flood
                        
                        	AS scope floodlist
                        	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood>`
                        
                        .. attribute:: flood_interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: flood_lsa_count
                        
                        	Number of LSAs currently being flooded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flood_pacing_timer
                        
                        	Time until next LS update due (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood, self).__init__()

                            self.yang_name = "flood"
                            self.yang_parent_name = "flood-list-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area-flood" : ("area_flood", Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                            self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                            self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                            self.area_flood = YList(self)
                            self.as_flood = YList(self)
                            self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood, ['interface_name', 'flood_interface_name', 'flood_lsa_count', 'flood_pacing_timer'], name, value)


                        class AreaFlood(Entity):
                            """
                            Area scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the Advertising Router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_ls_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (s)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_checksum
                            
                            	Checksum of the LSA
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA Type
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood, self).__init__()

                                self.yang_name = "area-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                self._segment_path = lambda: "area-flood"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AreaFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class AsFlood(Entity):
                            """
                            AS scope floodlist
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the Advertising Router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_ls_id
                            
                            	LSA ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (s)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_checksum
                            
                            	Checksum of the LSA
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA Type
                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood, self).__init__()

                                self.yang_name = "as-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                self._segment_path = lambda: "as-flood"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.FloodListTable.Flood.AsFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                class InterfaceInformation(Entity):
                    """
                    Container for OSPF Interfaces/links
                    
                    .. attribute:: interface_briefs
                    
                    	OSPF Interface Brief Table
                    	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs>`
                    
                    .. attribute:: interfaces
                    
                    	OSPF Interface Table
                    	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces>`
                    
                    .. attribute:: virtual_links
                    
                    	Virtual Link table
                    	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation, self).__init__()

                        self.yang_name = "interface-information"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"interface-briefs" : ("interface_briefs", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs), "interfaces" : ("interfaces", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces), "virtual-links" : ("virtual_links", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks)}
                        self._child_list_classes = {}

                        self.interface_briefs = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs()
                        self.interface_briefs.parent = self
                        self._children_name_map["interface_briefs"] = "interface-briefs"
                        self._children_yang_names.add("interface-briefs")

                        self.interfaces = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                        self._children_yang_names.add("interfaces")

                        self.virtual_links = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks()
                        self.virtual_links.parent = self
                        self._children_name_map["virtual_links"] = "virtual-links"
                        self._children_yang_names.add("virtual-links")
                        self._segment_path = lambda: "interface-information"


                    class InterfaceBriefs(Entity):
                        """
                        OSPF Interface Brief Table
                        
                        .. attribute:: interface_brief
                        
                        	OSPF interface brief information
                        	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs, self).__init__()

                            self.yang_name = "interface-briefs"
                            self.yang_parent_name = "interface-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"interface-brief" : ("interface_brief", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief)}

                            self.interface_brief = YList(self)
                            self._segment_path = lambda: "interface-briefs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs, [], name, value)


                        class InterfaceBrief(Entity):
                            """
                            OSPF interface brief information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: interface_address
                            
                            	Interface IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_adj_neighbor_count
                            
                            	Total number of Adjacent Neighbors
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_area
                            
                            	Area ID string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: interface_fast_detect_hold_down
                            
                            	Interface in fast detect hold down state
                            	**type**\:  bool
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_madj
                            
                            	Information for multi\-area on the interface
                            	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                            
                            .. attribute:: interface_madj_count
                            
                            	Total number of multi\-area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_mask
                            
                            	Interface IP Mask
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: interface_neighbor_count
                            
                            	Total number of Neighbors
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interfaceis_madj
                            
                            	If true, interface is multi\-area
                            	**type**\:  bool
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__init__()

                                self.yang_name = "interface-brief"
                                self.yang_parent_name = "interface-briefs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                self.interface_area = YLeaf(YType.str, "interface-area")

                                self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                self.interface_madj = YList(self)
                                self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adj_neighbor_count', 'interface_area', 'interface_fast_detect_hold_down', 'interface_link_cost', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_neighbor_count', 'interfaceis_madj', 'ospf_interface_state'], name, value)


                            class InterfaceMadj(Entity):
                                """
                                Information for multi\-area on the interface
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: madj_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                    self.yang_name = "interface-madj"
                                    self.yang_parent_name = "interface-brief"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                    self._segment_path = lambda: "interface-madj"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                    class Interfaces(Entity):
                        """
                        OSPF Interface Table
                        
                        .. attribute:: interface
                        
                        	OSPF interface information
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces, self).__init__()

                            self.yang_name = "interfaces"
                            self.yang_parent_name = "interface-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"interface" : ("interface", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface)}

                            self.interface = YList(self)
                            self._segment_path = lambda: "interfaces"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces, [], name, value)


                        class Interface(Entity):
                            """
                            OSPF interface information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: active_interface
                            
                            	Active interface details
                            	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface>`
                            
                            .. attribute:: backup_designated_router
                            
                            	If true, backup designated router
                            	**type**\:  bool
                            
                            .. attribute:: backup_designated_router_address
                            
                            	Backup designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: backup_designated_router_id
                            
                            	Backup designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cfg_cost_fallback
                            
                            	If true, cost fallback is configured
                            	**type**\:  bool
                            
                            .. attribute:: configured_demand_circuit
                            
                            	If true, configured as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: configured_ldp_sync
                            
                            	If true, configured as LDP sync
                            	**type**\:  bool
                            
                            .. attribute:: configured_ldp_sync_igp_shortcuts
                            
                            	If true, sync igp shortcuts
                            	**type**\:  bool
                            
                            .. attribute:: cost_fallback_active
                            
                            	If true, cost fallback is active
                            	**type**\:  bool
                            
                            .. attribute:: dead_interval
                            
                            	Configured dead interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: designated_router
                            
                            	If true, designated router
                            	**type**\:  bool
                            
                            .. attribute:: designated_router_address
                            
                            	Designated router interface address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: designated_router_id
                            
                            	Designated router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: fast_detect_hold_down_time
                            
                            	Hold\-down time in ms for fast\-detect event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fast_detect_hold_down_time_remaining
                            
                            	Remaining hold down time in ms
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fast_reroute_topology_independent_lfa
                            
                            	Topology Independent LFA
                            	**type**\:  bool
                            
                            .. attribute:: fast_reroute_type
                            
                            	IP Fast Reroute Type
                            	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                            
                            .. attribute:: hello_interval
                            
                            	Configured hello interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: hello_interval_ms
                            
                            	Configured hello interval (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ack_list_count
                            
                            	Ack List Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ack_list_high_watermark
                            
                            	Ack List High Watermark
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_address
                            
                            	Interface IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_area
                            
                            	Area ID string in decimal or dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: interface_bandwidth
                            
                            	Interface bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_bfd_information
                            
                            	BFD information
                            	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation>`
                            
                            .. attribute:: interface_bkp_labels
                            
                            	Max number of backup labels
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_cost_fallback
                            
                            	Interface fallback cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_dc_bitless_lsa_count
                            
                            	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_demand_circuit
                            
                            	If true, interface running as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: interface_fast_detect_hold_down
                            
                            	Link in hold\-down state due to fast detect event
                            	**type**\:  bool
                            
                            .. attribute:: interface_forw
                            
                            	Forward reference interface
                            	**type**\:  bool
                            
                            .. attribute:: interface_last_nsf
                            
                            	Time since last NSF restart (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_ldp_sync
                            
                            	If true, interface LDP sync is achieved
                            	**type**\:  bool
                            
                            .. attribute:: interface_line_state
                            
                            	If true, line protocol is up
                            	**type**\:  bool
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_lsa_filter
                            
                            	Filter is configured for out going LSAs
                            	**type**\:  bool
                            
                            .. attribute:: interface_madj
                            
                            	Information for multi\-area on the interface
                            	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj>`
                            
                            .. attribute:: interface_madj_count
                            
                            	Total number of multi\-area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_mask
                            
                            	Interface IP Mask
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: interface_neighbor
                            
                            	Information for neighbors on the interface
                            	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor>`
                            
                            .. attribute:: interface_nsf
                            
                            	If true, NSF restart in progress on this interface
                            	**type**\:  bool
                            
                            .. attribute:: interface_nsf_enabled
                            
                            	If true, NSF is enabled
                            	**type**\:  bool
                            
                            .. attribute:: interface_pri_labels
                            
                            	Max number of primary labels
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_priority
                            
                            	Interface priority
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_retransmission_interrval
                            
                            	Configured retransmit interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_router_id
                            
                            	Interface Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_sid
                            
                            	Interface SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_sid_n_flag_clear
                            
                            	SID N\-Flag Clear
                            	**type**\:  bool
                            
                            .. attribute:: interface_sid_php_off
                            
                            	SID PHP Off
                            	**type**\:  bool
                            
                            .. attribute:: interface_srte_labels
                            
                            	Max number of SRTE labels
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_state
                            
                            	Interface state
                            	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                            
                            .. attribute:: interface_strict_spf_sid
                            
                            	Interface Strict\-SPF SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_strict_spf_sid_n_flag_clear
                            
                            	Strict\-SPF SID N\-Flag Clear
                            	**type**\:  bool
                            
                            .. attribute:: interface_strict_spf_sid_php_off
                            
                            	Strict\-SPF SID PHP Off
                            	**type**\:  bool
                            
                            .. attribute:: interface_tunnel_flags
                            
                            	Interface tunnel flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_unnum
                            
                            	Unnumbered interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: interfaceis_madj
                            
                            	If true, interface is multi\-area
                            	**type**\:  bool
                            
                            .. attribute:: ip_mtu
                            
                            	IP MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ip_sec_addr
                            
                            	Secondary IP address list
                            	**type**\: list of    :py:class:`IpSecAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpSecAddr>`
                            
                            .. attribute:: ipfrr_tiebreakers
                            
                            	IPFRR\-Tiebreakers list
                            	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers>`
                            
                            .. attribute:: is_loopback_stub_network
                            
                            	If true, loopback interface is advertised as a stub network
                            	**type**\:  bool
                            
                            .. attribute:: maximum_packet_size
                            
                            	Maximum Packet Size
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: network_lsa_flush_timer
                            
                            	The amount of time in seconds before flush timer for old network LSA expires
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                            
                            .. attribute:: next_hello_time
                            
                            	Time until next Hello (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hello_time_ms
                            
                            	Time until next Hello (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                            
                            .. attribute:: passive_interface
                            
                            	If true, passive interface
                            	**type**\:  bool
                            
                            .. attribute:: prefix_suppress_primary_addresses
                            
                            	Prefix Suppression for primary addresses
                            	**type**\:  bool
                            
                            .. attribute:: prefix_suppress_secondary_addresses
                            
                            	Prefix Suppression for secondary addresses
                            	**type**\:  bool
                            
                            .. attribute:: registered_for_link_down_fast_detection
                            
                            	Registered for Link Down Fast Detection
                            	**type**\:  bool
                            
                            .. attribute:: srlg
                            
                            	SRLG Values
                            	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg>`
                            
                            .. attribute:: transmission_delay
                            
                            	Interface Transmission delay
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ttl_security_enabled
                            
                            	TTL security enabled on the interface
                            	**type**\:  bool
                            
                            .. attribute:: ttl_security_hop_count
                            
                            	TTL security hop counts
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wait_interval
                            
                            	Configured wait interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"active-interface" : ("active_interface", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface), "interface-bfd-information" : ("interface_bfd_information", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation)}
                                self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj), "interface-neighbor" : ("interface_neighbor", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor), "ip-sec-addr" : ("ip_sec_addr", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpSecAddr), "ipfrr-tiebreakers" : ("ipfrr_tiebreakers", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers), "srlg" : ("srlg", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                self.designated_router = YLeaf(YType.boolean, "designated-router")

                                self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                self.interface_address = YLeaf(YType.str, "interface-address")

                                self.interface_area = YLeaf(YType.str, "interface-area")

                                self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                self.interface_bkp_labels = YLeaf(YType.uint8, "interface-bkp-labels")

                                self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                self.interface_forw = YLeaf(YType.boolean, "interface-forw")

                                self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                self.interface_pri_labels = YLeaf(YType.uint8, "interface-pri-labels")

                                self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                self.interface_srte_labels = YLeaf(YType.uint8, "interface-srte-labels")

                                self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                self.interface_unnum = YLeaf(YType.str, "interface-unnum")

                                self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                self.network_type = YLeaf(YType.enumeration, "network-type")

                                self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                self.active_interface = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface()
                                self.active_interface.parent = self
                                self._children_name_map["active_interface"] = "active-interface"
                                self._children_yang_names.add("active-interface")

                                self.interface_bfd_information = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation()
                                self.interface_bfd_information.parent = self
                                self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                self._children_yang_names.add("interface-bfd-information")

                                self.interface_madj = YList(self)
                                self.interface_neighbor = YList(self)
                                self.ip_sec_addr = YList(self)
                                self.ipfrr_tiebreakers = YList(self)
                                self.srlg = YList(self)
                                self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface, ['interface_name', 'backup_designated_router', 'backup_designated_router_address', 'backup_designated_router_id', 'cfg_cost_fallback', 'configured_demand_circuit', 'configured_ldp_sync', 'configured_ldp_sync_igp_shortcuts', 'cost_fallback_active', 'dead_interval', 'designated_router', 'designated_router_address', 'designated_router_id', 'fast_detect_hold_down_time', 'fast_detect_hold_down_time_remaining', 'fast_reroute_topology_independent_lfa', 'fast_reroute_type', 'hello_interval', 'hello_interval_ms', 'interface_ack_list_count', 'interface_ack_list_high_watermark', 'interface_address', 'interface_area', 'interface_bandwidth', 'interface_bkp_labels', 'interface_cost_fallback', 'interface_dc_bitless_lsa_count', 'interface_demand_circuit', 'interface_fast_detect_hold_down', 'interface_forw', 'interface_last_nsf', 'interface_ldp_sync', 'interface_line_state', 'interface_link_cost', 'interface_lsa_filter', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_nsf', 'interface_nsf_enabled', 'interface_pri_labels', 'interface_priority', 'interface_retransmission_interrval', 'interface_router_id', 'interface_sid', 'interface_sid_n_flag_clear', 'interface_sid_php_off', 'interface_srte_labels', 'interface_state', 'interface_strict_spf_sid', 'interface_strict_spf_sid_n_flag_clear', 'interface_strict_spf_sid_php_off', 'interface_tunnel_flags', 'interface_unnum', 'interfaceis_madj', 'ip_mtu', 'is_loopback_stub_network', 'maximum_packet_size', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'next_hello_time_ms', 'ospf_interface_state', 'passive_interface', 'prefix_suppress_primary_addresses', 'prefix_suppress_secondary_addresses', 'registered_for_link_down_fast_detection', 'transmission_delay', 'ttl_security_enabled', 'ttl_security_hop_count', 'wait_interval'], name, value)


                            class ActiveInterface(Entity):
                                """
                                Active interface details
                                
                                .. attribute:: flood_scan_length
                                
                                	Last flood scan length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_flood_index
                                
                                	Area scope LSAs flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood
                                
                                	Next LSA to flood (Area scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood_index
                                
                                	Index of next LSA to flood (Area scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_flood_index
                                
                                	AS scope LSAs flood index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood
                                
                                	Next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood_index
                                
                                	Index of next LSA to flood (AS scope)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: interface_flood_length
                                
                                	Flood queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_flood_pacing_timer
                                
                                	Time until next flood pacing timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Total number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: keychain_id
                                
                                	Keychain ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: last_flood_time
                                
                                	Last flood scan time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_length
                                
                                	Maximum flood length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_time
                                
                                	Maximum flood time (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: md_keys
                                
                                	List of old MD keys
                                	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys>`
                                
                                .. attribute:: old_md5_key_neighbor_count
                                
                                	Number of neighbors using the old key (if rollover in progress)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: suppress_hello_count
                                
                                	Number of neighbors for which hellos are suppressed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: wait_time
                                
                                	Wait time for DR/BDR selection (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: youngest_md_key
                                
                                	If true, MD key is configured
                                	**type**\:  bool
                                
                                .. attribute:: youngest_md_key_id
                                
                                	Youngest MD key ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__init__()

                                    self.yang_name = "active-interface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"md-keys" : ("md_keys", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys)}

                                    self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                    self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                    self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                    self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                    self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                    self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                    self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                    self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                    self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                    self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                    self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                    self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                    self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                    self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                    self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                    self.wait_time = YLeaf(YType.uint32, "wait-time")

                                    self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                    self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                    self.md_keys = YList(self)
                                    self._segment_path = lambda: "active-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, ['flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_authentication_type', 'interface_flood_length', 'interface_flood_pacing_timer', 'interface_neighbor_count', 'keychain_id', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'old_md5_key_neighbor_count', 'suppress_hello_count', 'wait_time', 'youngest_md_key', 'youngest_md_key_id'], name, value)


                                class MdKeys(Entity):
                                    """
                                    List of old MD keys
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                        self.yang_name = "md-keys"
                                        self.yang_parent_name = "active-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint16, "entry")
                                        self._segment_path = lambda: "md-keys"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, ['entry'], name, value)


                            class InterfaceBfdInformation(Entity):
                                """
                                BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: detection_multiplier
                                
                                	BFD detection multiplier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interval
                                
                                	BFD interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                    self.yang_name = "interface-bfd-information"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.interval = YLeaf(YType.uint32, "interval")
                                    self._segment_path = lambda: "interface-bfd-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, ['bfd_intf_enable_mode', 'detection_multiplier', 'interval'], name, value)


                            class InterfaceMadj(Entity):
                                """
                                Information for multi\-area on the interface
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: madj_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__init__()

                                    self.yang_name = "interface-madj"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                    self._segment_path = lambda: "interface-madj"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                            class InterfaceNeighbor(Entity):
                                """
                                Information for neighbors on the interface
                                
                                .. attribute:: interface_neighbor_cost
                                
                                	Cost of link to neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbor_id
                                
                                	Neighbor Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bdr
                                
                                	If true, Backup designated router
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_dr
                                
                                	If true, Designated router
                                	**type**\:  bool
                                
                                .. attribute:: suppress_hello
                                
                                	If true, hellos suppressed
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                    self.yang_name = "interface-neighbor"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                    self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                    self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                    self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                    self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")
                                    self._segment_path = lambda: "interface-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'neighbor_bdr', 'neighbor_dr', 'suppress_hello'], name, value)


                            class IpSecAddr(Entity):
                                """
                                Secondary IP address list
                                
                                .. attribute:: secondary_addr
                                
                                	Secondary Address Type
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: secondary_prefix
                                
                                	Secondary Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpSecAddr, self).__init__()

                                    self.yang_name = "ip-sec-addr"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.secondary_addr = YLeaf(YType.str, "secondary-addr")

                                    self.secondary_prefix = YLeaf(YType.uint32, "secondary-prefix")
                                    self._segment_path = lambda: "ip-sec-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpSecAddr, ['secondary_addr', 'secondary_prefix'], name, value)


                            class IpfrrTiebreakers(Entity):
                                """
                                IPFRR\-Tiebreakers list
                                
                                .. attribute:: tiebreaker_index
                                
                                	Tiebreaker Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tiebreaker_type
                                
                                	Tiebreaker Type
                                	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                    self.yang_name = "ipfrr-tiebreakers"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                    self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")
                                    self._segment_path = lambda: "ipfrr-tiebreakers"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, ['tiebreaker_index', 'tiebreaker_type'], name, value)


                            class Srlg(Entity):
                                """
                                SRLG Values
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__init__()

                                    self.yang_name = "srlg"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint32, "entry")
                                    self._segment_path = lambda: "srlg"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.Interfaces.Interface.Srlg, ['entry'], name, value)


                    class VirtualLinks(Entity):
                        """
                        Virtual Link table
                        
                        .. attribute:: virtual_link
                        
                        	Information for one Virtual link
                        	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks, self).__init__()

                            self.yang_name = "virtual-links"
                            self.yang_parent_name = "interface-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"virtual-link" : ("virtual_link", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink)}

                            self.virtual_link = YList(self)
                            self._segment_path = lambda: "virtual-links"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks, [], name, value)


                        class VirtualLink(Entity):
                            """
                            Information for one Virtual link
                            
                            .. attribute:: virtual_link_name  <key>
                            
                            	Virtual link
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: transit_area
                            
                            	Transit area id
                            	**type**\:  str
                            
                            .. attribute:: virtaul_link_retransmission_interval
                            
                            	Retransmission interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_authentication_type
                            
                            	Authentication type
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                            
                            .. attribute:: virtual_link_cost
                            
                            	Cost of the virtual link
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virtual_link_dc_bitless_lsa
                            
                            	Number of LSA's with demand circuit bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_dead_interval
                            
                            	Dead interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_demand_circuit
                            
                            	If true, the link runs as demand circuit
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_hello_interval
                            
                            	Hello interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_hello_interval_ms
                            
                            	Hello interval (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_interface_name
                            
                            	Interface on which this virtual link is formed
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: virtual_link_keychain_id
                            
                            	Virtual Link Keychain ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: virtual_link_last_nsf
                            
                            	Time in seconds since last NSF
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: virtual_link_md_key
                            
                            	List of old MD keys (if any)
                            	**type**\: list of    :py:class:`VirtualLinkMdKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey>`
                            
                            .. attribute:: virtual_link_name_xr
                            
                            	Virtual link name
                            	**type**\:  str
                            
                            .. attribute:: virtual_link_neighbor
                            
                            	Neighbor information
                            	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor>`
                            
                            .. attribute:: virtual_link_neighbor_id
                            
                            	Neighbor on other end of this virtual link
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: virtual_link_next_hello
                            
                            	Time until next hello (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_next_hello_ms
                            
                            	Time until next hello (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_nsf
                            
                            	If true, NSF restart in progress on the virtual link
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_nsf_enabled
                            
                            	If true, NSF enabled
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_old_md_key_count
                            
                            	Number of neighbors still using the old key (rollover in progress)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_passive
                            
                            	If true, interface is passive
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_state
                            
                            	OSPF interface state for the virtual link
                            	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                            
                            .. attribute:: virtual_link_wait_interval
                            
                            	Wait interval (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: virtual_link_youngest_md_key
                            
                            	If true, MD key configured
                            	**type**\:  bool
                            
                            .. attribute:: virtual_link_youngest_md_key_id
                            
                            	Youngest MD key ID
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: virual_link_transmission_delay
                            
                            	Transmission delay in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__init__()

                                self.yang_name = "virtual-link"
                                self.yang_parent_name = "virtual-links"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"virtual-link-neighbor" : ("virtual_link_neighbor", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor)}
                                self._child_list_classes = {"virtual-link-md-key" : ("virtual_link_md_key", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey)}

                                self.virtual_link_name = YLeaf(YType.str, "virtual-link-name")

                                self.transit_area = YLeaf(YType.str, "transit-area")

                                self.virtaul_link_retransmission_interval = YLeaf(YType.uint32, "virtaul-link-retransmission-interval")

                                self.virtual_link_authentication_type = YLeaf(YType.enumeration, "virtual-link-authentication-type")

                                self.virtual_link_cost = YLeaf(YType.uint16, "virtual-link-cost")

                                self.virtual_link_dc_bitless_lsa = YLeaf(YType.uint32, "virtual-link-dc-bitless-lsa")

                                self.virtual_link_dead_interval = YLeaf(YType.uint32, "virtual-link-dead-interval")

                                self.virtual_link_demand_circuit = YLeaf(YType.boolean, "virtual-link-demand-circuit")

                                self.virtual_link_hello_interval = YLeaf(YType.uint32, "virtual-link-hello-interval")

                                self.virtual_link_hello_interval_ms = YLeaf(YType.uint32, "virtual-link-hello-interval-ms")

                                self.virtual_link_interface_name = YLeaf(YType.str, "virtual-link-interface-name")

                                self.virtual_link_keychain_id = YLeaf(YType.uint64, "virtual-link-keychain-id")

                                self.virtual_link_last_nsf = YLeaf(YType.uint32, "virtual-link-last-nsf")

                                self.virtual_link_name_xr = YLeaf(YType.str, "virtual-link-name-xr")

                                self.virtual_link_neighbor_id = YLeaf(YType.str, "virtual-link-neighbor-id")

                                self.virtual_link_next_hello = YLeaf(YType.uint32, "virtual-link-next-hello")

                                self.virtual_link_next_hello_ms = YLeaf(YType.uint32, "virtual-link-next-hello-ms")

                                self.virtual_link_nsf = YLeaf(YType.boolean, "virtual-link-nsf")

                                self.virtual_link_nsf_enabled = YLeaf(YType.boolean, "virtual-link-nsf-enabled")

                                self.virtual_link_old_md_key_count = YLeaf(YType.uint32, "virtual-link-old-md-key-count")

                                self.virtual_link_passive = YLeaf(YType.boolean, "virtual-link-passive")

                                self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                self.virtual_link_wait_interval = YLeaf(YType.uint32, "virtual-link-wait-interval")

                                self.virtual_link_youngest_md_key = YLeaf(YType.boolean, "virtual-link-youngest-md-key")

                                self.virtual_link_youngest_md_key_id = YLeaf(YType.uint16, "virtual-link-youngest-md-key-id")

                                self.virual_link_transmission_delay = YLeaf(YType.uint16, "virual-link-transmission-delay")

                                self.virtual_link_neighbor = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor()
                                self.virtual_link_neighbor.parent = self
                                self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                                self._children_yang_names.add("virtual-link-neighbor")

                                self.virtual_link_md_key = YList(self)
                                self._segment_path = lambda: "virtual-link" + "[virtual-link-name='" + self.virtual_link_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink, ['virtual_link_name', 'transit_area', 'virtaul_link_retransmission_interval', 'virtual_link_authentication_type', 'virtual_link_cost', 'virtual_link_dc_bitless_lsa', 'virtual_link_dead_interval', 'virtual_link_demand_circuit', 'virtual_link_hello_interval', 'virtual_link_hello_interval_ms', 'virtual_link_interface_name', 'virtual_link_keychain_id', 'virtual_link_last_nsf', 'virtual_link_name_xr', 'virtual_link_neighbor_id', 'virtual_link_next_hello', 'virtual_link_next_hello_ms', 'virtual_link_nsf', 'virtual_link_nsf_enabled', 'virtual_link_old_md_key_count', 'virtual_link_passive', 'virtual_link_state', 'virtual_link_wait_interval', 'virtual_link_youngest_md_key', 'virtual_link_youngest_md_key_id', 'virual_link_transmission_delay'], name, value)


                            class VirtualLinkMdKey(Entity):
                                """
                                List of old MD keys (if any)
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__init__()

                                    self.yang_name = "virtual-link-md-key"
                                    self.yang_parent_name = "virtual-link"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint16, "entry")
                                    self._segment_path = lambda: "virtual-link-md-key"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, ['entry'], name, value)


                            class VirtualLinkNeighbor(Entity):
                                """
                                Neighbor information
                                
                                .. attribute:: virtual_link_retransmissoin
                                
                                	Neighbor retransmission info
                                	**type**\:   :py:class:`VirtualLinkRetransmissoin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin>`
                                
                                .. attribute:: virtual_link_state
                                
                                	Adjacency state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: virtual_link_suppress_hello
                                
                                	If true Hellos suppressed
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__init__()

                                    self.yang_name = "virtual-link-neighbor"
                                    self.yang_parent_name = "virtual-link"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"virtual-link-retransmissoin" : ("virtual_link_retransmissoin", Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin)}
                                    self._child_list_classes = {}

                                    self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                    self.virtual_link_suppress_hello = YLeaf(YType.boolean, "virtual-link-suppress-hello")

                                    self.virtual_link_retransmissoin = Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin()
                                    self.virtual_link_retransmissoin.parent = self
                                    self._children_name_map["virtual_link_retransmissoin"] = "virtual-link-retransmissoin"
                                    self._children_yang_names.add("virtual-link-retransmissoin")
                                    self._segment_path = lambda: "virtual-link-neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, ['virtual_link_state', 'virtual_link_suppress_hello'], name, value)


                                class VirtualLinkRetransmissoin(Entity):
                                    """
                                    Neighbor retransmission info
                                    
                                    .. attribute:: area_first_flood_information
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_information_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flooding_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_count
                                    
                                    	Number of DBD retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_total_count
                                    
                                    	Total number of DBD retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__init__()

                                        self.yang_name = "virtual-link-retransmissoin"
                                        self.yang_parent_name = "virtual-link-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                        self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                        self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                        self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                        self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                        self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                        self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                        self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                        self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                        self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                        self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                        self._segment_path = lambda: "virtual-link-retransmissoin"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                class MplsTe(Entity):
                    """
                    Container for MPLS TE
                    
                    .. attribute:: mpls_te_fragments
                    
                    	MPLS TE Fragment information table
                    	**type**\:   :py:class:`MplsTeFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments>`
                    
                    .. attribute:: mpls_te_links
                    
                    	MPLS TE link information table
                    	**type**\:   :py:class:`MplsTeLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.MplsTe, self).__init__()

                        self.yang_name = "mpls-te"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"mpls-te-fragments" : ("mpls_te_fragments", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments), "mpls-te-links" : ("mpls_te_links", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks)}
                        self._child_list_classes = {}

                        self.mpls_te_fragments = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments()
                        self.mpls_te_fragments.parent = self
                        self._children_name_map["mpls_te_fragments"] = "mpls-te-fragments"
                        self._children_yang_names.add("mpls-te-fragments")

                        self.mpls_te_links = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks()
                        self.mpls_te_links.parent = self
                        self._children_name_map["mpls_te_links"] = "mpls-te-links"
                        self._children_yang_names.add("mpls-te-links")
                        self._segment_path = lambda: "mpls-te"


                    class MplsTeFragments(Entity):
                        """
                        MPLS TE Fragment information table
                        
                        .. attribute:: mpls_te_fragment
                        
                        	MPLS TE Fragment
                        	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments, self).__init__()

                            self.yang_name = "mpls-te-fragments"
                            self.yang_parent_name = "mpls-te"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"mpls-te-fragment" : ("mpls_te_fragment", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment)}

                            self.mpls_te_fragment = YList(self)
                            self._segment_path = lambda: "mpls-te-fragments"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments, [], name, value)


                        class MplsTeFragment(Entity):
                            """
                            MPLS TE Fragment
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mpls_te_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: mpls_te_area_instance
                            
                            	Area information instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_enabled
                            
                            	If true, MPLS\-TE enabled in area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_fragment
                            
                            	MPLS TE fragments in the area
                            	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment>`
                            
                            .. attribute:: mpls_te_initialized
                            
                            	If true, MPLS\-TE initialized in the area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_link
                            
                            	MPLS\-TE links in the area
                            	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink>`
                            
                            .. attribute:: mpls_te_next_fragment_id
                            
                            	Next MPLS\-TE fragment ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_router_address
                            
                            	MPLS\-TE router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mpls_te_router_id
                            
                            	OSPF MPLS\-TE router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: spacious_fragment
                            
                            	If true, fragment has space for next link
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__init__()

                                self.yang_name = "mpls-te-fragment"
                                self.yang_parent_name = "mpls-te-fragments"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"mpls-te-fragment" : ("mpls_te_fragment", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment), "mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink)}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                self.mpls_te_fragment = YList(self)
                                self.mpls_te_link = YList(self)
                                self._segment_path = lambda: "mpls-te-fragment" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment, ['area_id', 'mpls_te_area_id', 'mpls_te_area_instance', 'mpls_te_enabled', 'mpls_te_initialized', 'mpls_te_next_fragment_id', 'mpls_te_router_address', 'mpls_te_router_id', 'spacious_fragment'], name, value)


                            class MplsTeFragment(Entity):
                                """
                                MPLS TE fragments in the area
                                
                                .. attribute:: dste_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fragment_instance
                                
                                	Fragment instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_link
                                
                                	List of fragment links
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink>`
                                
                                .. attribute:: same_fragment_count
                                
                                	Number of fragment links which haven't changed since the last update
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__init__()

                                    self.yang_name = "mpls-te-fragment"
                                    self.yang_parent_name = "mpls-te-fragment"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink)}

                                    self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                    self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                    self.mpls_te_link = YList(self)
                                    self._segment_path = lambda: "mpls-te-fragment"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, ['dste_model_id', 'fragment_id', 'fragment_instance', 'same_fragment_count'], name, value)


                                class MplsTeLink(Entity):
                                    """
                                    List of fragment links
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-fragment"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                        self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv)}

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)
                                        self._segment_path = lambda: "mpls-te-link"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)
                                            self._segment_path = lambda: "extended-admin-group-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "ext-admin-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                            self._segment_path = lambda: "link-protocol-priority-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)
                                            self._segment_path = lambda: "link-sw-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)
                                            self._segment_path = lambda: "mplste-link-opt-tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                                self._child_list_classes = {}

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")
                                                self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)
                                                    self._segment_path = lambda: "bctlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                        self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                    self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)
                                                    self._segment_path = lambda: "ixcdtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                        self._child_list_classes = {}

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")
                                                        self._segment_path = lambda: "ixcd-switching-cap-type"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                            self.arr_bw_sub_tlv = YList(self)
                                                            self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                                self._child_list_classes = {}

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")
                                                                self._segment_path = lambda: "arr-bw-sub-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                    self._child_list_classes = {}

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                    self._segment_path = lambda: "bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                        self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)
                                                                        self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                                            self._segment_path = lambda: "unres-oduj-prio"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                        self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)
                                                                        self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "max-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "unres-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                            self._segment_path = lambda: "ixcdpsc-info"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.int64, "entry")
                                                        self._segment_path = lambda: "max-lspbw"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)
                                                    self._segment_path = lambda: "srlgtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "mplste-link-srlg-data"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                    self._segment_path = lambda: "unidtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                            class MplsTeLink(Entity):
                                """
                                MPLS\-TE links in the area
                                
                                .. attribute:: affinity
                                
                                	Affinity
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dste_allocation_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                
                                .. attribute:: dste_in_use
                                
                                	A DS\-TE Allocation Model in use
                                	**type**\:  bool
                                
                                .. attribute:: extended_admin_group_list
                                
                                	Extended Admin Group
                                	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID for this link
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: global_unreserve_bw_per_priority
                                
                                	Global pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                
                                .. attribute:: igp_metric
                                
                                	Link IGP metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: input_interface_id
                                
                                	Input interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_address
                                
                                	The local interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: link_protocol_priority_capability
                                
                                	Link protocol and protocol priority capability
                                	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                
                                .. attribute:: link_sw_capability
                                
                                	Link switching capability
                                	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                
                                .. attribute:: maximum_link_bw
                                
                                	Maximum link bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_reservable_bw
                                
                                	Maximum link global pool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_sub_reservable_bw
                                
                                	Maximum link subpool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: mpls_link_instance
                                
                                	Link instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_link_type
                                
                                	Type of link
                                	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                
                                .. attribute:: mplste_link_opt_tlv
                                
                                	List of Optional TLVs
                                	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                
                                .. attribute:: neighbor_ip_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_system_id
                                
                                	Neighbor system ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: new_link
                                
                                	If true, Link is new
                                	**type**\:  bool
                                
                                .. attribute:: number_of_optional_tl_vs
                                
                                	Number of Optional TLVs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: output_interface_id
                                
                                	Output interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: priority_count
                                
                                	Number of priorities
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: sub_pool_unreserve_bw_per_priority
                                
                                	Sub pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                
                                .. attribute:: te_metric
                                
                                	Link TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__init__()

                                    self.yang_name = "mpls-te-link"
                                    self.yang_parent_name = "mpls-te-fragment"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                    self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv)}

                                    self.affinity = YLeaf(YType.uint32, "affinity")

                                    self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                    self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                    self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                    self.link_address = YLeaf(YType.str, "link-address")

                                    self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                    self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                    self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                    self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                    self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                    self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                    self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                    self.new_link = YLeaf(YType.boolean, "new-link")

                                    self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                    self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                    self.priority_count = YLeaf(YType.int32, "priority-count")

                                    self.te_metric = YLeaf(YType.uint32, "te-metric")

                                    self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                    self.extended_admin_group_list.parent = self
                                    self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                    self._children_yang_names.add("extended-admin-group-list")

                                    self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                    self.global_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                    self._children_yang_names.add("global-unreserve-bw-per-priority")

                                    self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                    self.link_protocol_priority_capability.parent = self
                                    self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                    self._children_yang_names.add("link-protocol-priority-capability")

                                    self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                    self.link_sw_capability.parent = self
                                    self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                    self._children_yang_names.add("link-sw-capability")

                                    self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                    self.sub_pool_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                    self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                    self.mplste_link_opt_tlv = YList(self)
                                    self._segment_path = lambda: "mpls-te-link"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                class ExtendedAdminGroupList(Entity):
                                    """
                                    Extended Admin Group
                                    
                                    .. attribute:: ext_admin_data
                                    
                                    	Value of Extended Admin Group
                                    	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                    
                                    .. attribute:: extended_admin_size
                                    
                                    	Size of the extended admin group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                        self.yang_name = "extended-admin-group-list"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                        self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                        self.ext_admin_data = YList(self)
                                        self._segment_path = lambda: "extended-admin-group-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                    class ExtAdminData(Entity):
                                        """
                                        Value of Extended Admin Group
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                            self.yang_name = "ext-admin-data"
                                            self.yang_parent_name = "extended-admin-group-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "ext-admin-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                class GlobalUnreserveBwPerPriority(Entity):
                                    """
                                    Global pool unreserved bandwidth for each
                                    priority (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "global-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                        self.bw_per_priority = YList(self)
                                        self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "global-unreserve-bw-per-priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint64, "entry")
                                            self._segment_path = lambda: "bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                class LinkProtocolPriorityCapability(Entity):
                                    """
                                    Link protocol and protocol priority capability
                                    
                                    .. attribute:: link_protocol_capability
                                    
                                    	Link protocol capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_protocol_priority
                                    
                                    	Link protocol priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                        self.yang_name = "link-protocol-priority-capability"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                        self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                        self._segment_path = lambda: "link-protocol-priority-capability"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                class LinkSwCapability(Entity):
                                    """
                                    Link switching capability
                                    
                                    .. attribute:: link_encoding
                                    
                                    	Link Encoding
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_mtu
                                    
                                    	Link MTU size (bytes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: link_switching_capability
                                    
                                    	Link Switching Capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: maximum_lsp_bw_per_priority
                                    
                                    	Maximum LSP bandwidth for each priority  (bytes/s)
                                    	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                    
                                    .. attribute:: minimum_lsp_bw
                                    
                                    	Minimum LSP bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte/s
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                        self.yang_name = "link-sw-capability"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                        self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                        self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                        self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                        self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                        self.maximum_lsp_bw_per_priority = YList(self)
                                        self._segment_path = lambda: "link-sw-capability"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                    class MaximumLspBwPerPriority(Entity):
                                        """
                                        Maximum LSP bandwidth for each priority
                                        
                                        (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                            self.yang_name = "maximum-lsp-bw-per-priority"
                                            self.yang_parent_name = "link-sw-capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint64, "entry")
                                            self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                class MplsteLinkOptTlv(Entity):
                                    """
                                    List of Optional TLVs
                                    
                                    .. attribute:: mplste_link_opt_tlv_len
                                    
                                    	Length of Opt TLV
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mplste_link_opt_tlv_type
                                    
                                    	Type of Opt TLV
                                    	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                    
                                    .. attribute:: mplste_link_opt_tlv_value
                                    
                                    	Value of Opt TLV
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                        self.yang_name = "mplste-link-opt-tlv"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                        self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                        self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                        self.mplste_link_opt_tlv_value = YList(self)
                                        self._segment_path = lambda: "mplste-link-opt-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                    class MplsteLinkOptTlvValue(Entity):
                                        """
                                        Value of Opt TLV
                                        
                                        .. attribute:: bctlv_value
                                        
                                        	Value of Bandwidth Constraints TLV
                                        	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                        
                                        .. attribute:: ixcdtlv_value
                                        
                                        	Value of IXCD TLV
                                        	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                        
                                        .. attribute:: opaque_tlv_type
                                        
                                        	OpaqueTLVType
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: srlgtlv_value
                                        
                                        	Value of SRLG TLV
                                        	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                        
                                        .. attribute:: unidtlv_value
                                        
                                        	Value of Uni Delay TLV
                                        	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv-value"
                                            self.yang_parent_name = "mplste-link-opt-tlv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                            self._child_list_classes = {}

                                            self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                            self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                            self.bctlv_value.parent = self
                                            self._children_name_map["bctlv_value"] = "bctlv-value"
                                            self._children_yang_names.add("bctlv-value")

                                            self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                            self.ixcdtlv_value.parent = self
                                            self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                            self._children_yang_names.add("ixcdtlv-value")

                                            self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                            self.srlgtlv_value.parent = self
                                            self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                            self._children_yang_names.add("srlgtlv-value")

                                            self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                            self.unidtlv_value.parent = self
                                            self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                            self._children_yang_names.add("unidtlv-value")
                                            self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                        class BctlvValue(Entity):
                                            """
                                            Value of Bandwidth Constraints TLV
                                            
                                            .. attribute:: model_id
                                            
                                            	Allocation Model ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mplste_link_bc_bandwidth
                                            
                                            	Value of BC TLV
                                            	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                            
                                            .. attribute:: num_b_cs
                                            
                                            	Number of BC TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                self.yang_name = "bctlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                self.model_id = YLeaf(YType.uint8, "model-id")

                                                self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                self.mplste_link_bc_bandwidth = YList(self)
                                                self._segment_path = lambda: "bctlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                            class MplsteLinkBcBandwidth(Entity):
                                                """
                                                Value of BC TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                    self.yang_name = "mplste-link-bc-bandwidth"
                                                    self.yang_parent_name = "bctlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                        class IxcdtlvValue(Entity):
                                            """
                                            Value of IXCD TLV
                                            
                                            .. attribute:: fixed_scsi_count
                                            
                                            	Fixed SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flex_scsi_count
                                            
                                            	Flexible SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ixcd_switching_cap_type
                                            
                                            	Switching Cap type
                                            	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                            
                                            .. attribute:: max_lspbw
                                            
                                            	Max LSP bandwidth array
                                            	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                            
                                            .. attribute:: rile_len_code
                                            
                                            	Rile LenCode
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: switching_cap
                                            
                                            	SCap
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                self.yang_name = "ixcdtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                self.ixcd_switching_cap_type.parent = self
                                                self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                self._children_yang_names.add("ixcd-switching-cap-type")

                                                self.max_lspbw = YList(self)
                                                self._segment_path = lambda: "ixcdtlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                            class IxcdSwitchingCapType(Entity):
                                                """
                                                Switching Cap type
                                                
                                                .. attribute:: ixcdbw_sub_tlv
                                                
                                                	Sub TLVs
                                                	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                
                                                .. attribute:: ixcdpsc_info
                                                
                                                	IXCD PSC information
                                                	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                
                                                .. attribute:: switching_cap_type
                                                
                                                	SwitchingCapType
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                    self.yang_name = "ixcd-switching-cap-type"
                                                    self.yang_parent_name = "ixcdtlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                    self._child_list_classes = {}

                                                    self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                    self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                    self.ixcdbw_sub_tlv.parent = self
                                                    self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                    self._children_yang_names.add("ixcdbw-sub-tlv")

                                                    self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                    self.ixcdpsc_info.parent = self
                                                    self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                    self._children_yang_names.add("ixcdpsc-info")
                                                    self._segment_path = lambda: "ixcd-switching-cap-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                class IxcdbwSubTlv(Entity):
                                                    """
                                                    Sub TLVs
                                                    
                                                    .. attribute:: arr_bw_sub_tlv
                                                    
                                                    	Array of sub tlvs
                                                    	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                        self.yang_name = "ixcdbw-sub-tlv"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                        self.arr_bw_sub_tlv = YList(self)
                                                        self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                    class ArrBwSubTlv(Entity):
                                                        """
                                                        Array of sub tlvs
                                                        
                                                        .. attribute:: bw_sub_tlv_length
                                                        
                                                        	Length of BW Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_type
                                                        
                                                        	Type of Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_value
                                                        
                                                        	Value of BW Sub TLV
                                                        	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                            self.yang_name = "arr-bw-sub-tlv"
                                                            self.yang_parent_name = "ixcdbw-sub-tlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                            self._child_list_classes = {}

                                                            self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                            self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                            self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                            self.bw_sub_tlv_value.parent = self
                                                            self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                            self._children_yang_names.add("bw-sub-tlv-value")
                                                            self._segment_path = lambda: "arr-bw-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                        class BwSubTlvValue(Entity):
                                                            """
                                                            Value of BW Sub TLV
                                                            
                                                            .. attribute:: fixed_bw_sub_tlv_value
                                                            
                                                            	Value of Fixed Sub TLV
                                                            	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                            
                                                            .. attribute:: flex_bw_sub_tlv_value
                                                            
                                                            	Value of Flex Sub TLV
                                                            	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                            
                                                            .. attribute:: ixcdbw_sub_tlv_type
                                                            
                                                            	IXCDBWSubTLVType
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                self.yang_name = "bw-sub-tlv-value"
                                                                self.yang_parent_name = "arr-bw-sub-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                self._child_list_classes = {}

                                                                self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                self.fixed_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                self.flex_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                self._segment_path = lambda: "bw-sub-tlv-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                            class FixedBwSubTlvValue(Entity):
                                                                """
                                                                Value of Fixed Sub TLV
                                                                
                                                                .. attribute:: fixed_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                
                                                                .. attribute:: unres_oduj_prio
                                                                
                                                                	Array of Unres Oduj Prio
                                                                	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "fixed-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                    self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                    self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                    self.fixed_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-sub-tlv-value")

                                                                    self.unres_oduj_prio = YList(self)
                                                                    self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                class FixedSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-sub-tlv-value"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")
                                                                        self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                class UnresOdujPrio(Entity):
                                                                    """
                                                                    Array of Unres Oduj Prio
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                        self.yang_name = "unres-oduj-prio"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "unres-oduj-prio"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                            class FlexBwSubTlvValue(Entity):
                                                                """
                                                                Value of Flex Sub TLV
                                                                
                                                                .. attribute:: flex_sub_tlv_value_common
                                                                
                                                                	Flex Sub TLV Value
                                                                	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                
                                                                .. attribute:: max_lspbw
                                                                
                                                                	Max LSP BW Array
                                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                
                                                                .. attribute:: unres_lspbw
                                                                
                                                                	Array of Unres LSP BW
                                                                	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "flex-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                    self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                    self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                    self.flex_sub_tlv_value_common.parent = self
                                                                    self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                    self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                    self.max_lspbw = YList(self)
                                                                    self.unres_lspbw = YList(self)
                                                                    self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                class FlexSubTlvValueCommon(Entity):
                                                                    """
                                                                    Flex Sub TLV Value
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                        self.yang_name = "flex-sub-tlv-value-common"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")
                                                                        self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                class MaxLspbw(Entity):
                                                                    """
                                                                    Max LSP BW Array
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                        self.yang_name = "max-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                                        self._segment_path = lambda: "max-lspbw"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                class UnresLspbw(Entity):
                                                                    """
                                                                    Array of Unres LSP BW
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                        self.yang_name = "unres-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                                        self._segment_path = lambda: "unres-lspbw"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                class IxcdpscInfo(Entity):
                                                    """
                                                    IXCD PSC information
                                                    
                                                    .. attribute:: min_lsp_bandwidth
                                                    
                                                    	Min LSP bandwidth
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: psc_interface_mtu
                                                    
                                                    	 Interface MTU
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                        self.yang_name = "ixcdpsc-info"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                        self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                        self._segment_path = lambda: "ixcdpsc-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                            class MaxLspbw(Entity):
                                                """
                                                Max LSP bandwidth array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** \-9223372036854775808..9223372036854775807
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                    self.yang_name = "max-lspbw"
                                                    self.yang_parent_name = "ixcdtlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.int64, "entry")
                                                    self._segment_path = lambda: "max-lspbw"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                        class SrlgtlvValue(Entity):
                                            """
                                            Value of SRLG TLV
                                            
                                            .. attribute:: mplste_link_srlg_data
                                            
                                            	Value of SRLG TLV
                                            	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                            
                                            .. attribute:: num_srl_gs
                                            
                                            	Number of SRLG TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: srlg_len
                                            
                                            	Length of SRLG TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                self.yang_name = "srlgtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                self.mplste_link_srlg_data = YList(self)
                                                self._segment_path = lambda: "srlgtlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                            class MplsteLinkSrlgData(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                    self.yang_name = "mplste-link-srlg-data"
                                                    self.yang_parent_name = "srlgtlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "mplste-link-srlg-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                        class UnidtlvValue(Entity):
                                            """
                                            Value of Uni Delay TLV
                                            
                                            .. attribute:: uni_dir_delay
                                            
                                            	Uni Dir Delay
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                self.yang_name = "unidtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                self._segment_path = lambda: "unidtlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                class SubPoolUnreserveBwPerPriority(Entity):
                                    """
                                    Sub pool unreserved bandwidth for each priority
                                    (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                        self.bw_per_priority = YList(self)
                                        self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint64, "entry")
                                            self._segment_path = lambda: "bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                    class MplsTeLinks(Entity):
                        """
                        MPLS TE link information table
                        
                        .. attribute:: mpls_te_link
                        
                        	MPLS TE link information
                        	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks, self).__init__()

                            self.yang_name = "mpls-te-links"
                            self.yang_parent_name = "mpls-te"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink)}

                            self.mpls_te_link = YList(self)
                            self._segment_path = lambda: "mpls-te-links"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks, [], name, value)


                        class MplsTeLink(Entity):
                            """
                            MPLS TE link information
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: mpls_te_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: mpls_te_area_instance
                            
                            	Area information instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_enabled
                            
                            	If true, MPLS\-TE enabled in area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_fragment
                            
                            	MPLS TE fragments in the area
                            	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment>`
                            
                            .. attribute:: mpls_te_initialized
                            
                            	If true, MPLS\-TE initialized in the area
                            	**type**\:  bool
                            
                            .. attribute:: mpls_te_link
                            
                            	MPLS\-TE links in the area
                            	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink>`
                            
                            .. attribute:: mpls_te_next_fragment_id
                            
                            	Next MPLS\-TE fragment ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mpls_te_router_address
                            
                            	MPLS\-TE router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mpls_te_router_id
                            
                            	OSPF MPLS\-TE router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: spacious_fragment
                            
                            	If true, fragment has space for next link
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink, self).__init__()

                                self.yang_name = "mpls-te-link"
                                self.yang_parent_name = "mpls-te-links"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"mpls-te-fragment" : ("mpls_te_fragment", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment), "mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink)}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                self.mpls_te_fragment = YList(self)
                                self.mpls_te_link = YList(self)
                                self._segment_path = lambda: "mpls-te-link" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink, ['area_id', 'mpls_te_area_id', 'mpls_te_area_instance', 'mpls_te_enabled', 'mpls_te_initialized', 'mpls_te_next_fragment_id', 'mpls_te_router_address', 'mpls_te_router_id', 'spacious_fragment'], name, value)


                            class MplsTeFragment(Entity):
                                """
                                MPLS TE fragments in the area
                                
                                .. attribute:: dste_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fragment_instance
                                
                                	Fragment instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_link
                                
                                	List of fragment links
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink>`
                                
                                .. attribute:: same_fragment_count
                                
                                	Number of fragment links which haven't changed since the last update
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__init__()

                                    self.yang_name = "mpls-te-fragment"
                                    self.yang_parent_name = "mpls-te-link"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink)}

                                    self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                    self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                    self.mpls_te_link = YList(self)
                                    self._segment_path = lambda: "mpls-te-fragment"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, ['dste_model_id', 'fragment_id', 'fragment_instance', 'same_fragment_count'], name, value)


                                class MplsTeLink(Entity):
                                    """
                                    List of fragment links
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-fragment"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                        self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv)}

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)
                                        self._segment_path = lambda: "mpls-te-link"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)
                                            self._segment_path = lambda: "extended-admin-group-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "ext-admin-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                            self._segment_path = lambda: "link-protocol-priority-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)
                                            self._segment_path = lambda: "link-sw-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)
                                            self._segment_path = lambda: "mplste-link-opt-tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                                self._child_list_classes = {}

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")
                                                self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)
                                                    self._segment_path = lambda: "bctlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                        self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                    self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)
                                                    self._segment_path = lambda: "ixcdtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                        self._child_list_classes = {}

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")
                                                        self._segment_path = lambda: "ixcd-switching-cap-type"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                            self.arr_bw_sub_tlv = YList(self)
                                                            self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                                self._child_list_classes = {}

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")
                                                                self._segment_path = lambda: "arr-bw-sub-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                    self._child_list_classes = {}

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                    self._segment_path = lambda: "bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                        self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)
                                                                        self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                                            self._segment_path = lambda: "unres-oduj-prio"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                        self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)
                                                                        self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "max-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "unres-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                            self._segment_path = lambda: "ixcdpsc-info"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.int64, "entry")
                                                        self._segment_path = lambda: "max-lspbw"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)
                                                    self._segment_path = lambda: "srlgtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "mplste-link-srlg-data"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                    self._segment_path = lambda: "unidtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                            class MplsTeLink(Entity):
                                """
                                MPLS\-TE links in the area
                                
                                .. attribute:: affinity
                                
                                	Affinity
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dste_allocation_model_id
                                
                                	DS\-TE Allocation Model ID
                                	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                
                                .. attribute:: dste_in_use
                                
                                	A DS\-TE Allocation Model in use
                                	**type**\:  bool
                                
                                .. attribute:: extended_admin_group_list
                                
                                	Extended Admin Group
                                	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList>`
                                
                                .. attribute:: fragment_id
                                
                                	Fragment ID for this link
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: global_unreserve_bw_per_priority
                                
                                	Global pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                
                                .. attribute:: igp_metric
                                
                                	Link IGP metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: input_interface_id
                                
                                	Input interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_address
                                
                                	The local interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: link_protocol_priority_capability
                                
                                	Link protocol and protocol priority capability
                                	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability>`
                                
                                .. attribute:: link_sw_capability
                                
                                	Link switching capability
                                	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability>`
                                
                                .. attribute:: maximum_link_bw
                                
                                	Maximum link bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_reservable_bw
                                
                                	Maximum link global pool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: maximum_link_sub_reservable_bw
                                
                                	Maximum link subpool reservable bandwidth (bytes/s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: byte/s
                                
                                .. attribute:: mpls_link_instance
                                
                                	Link instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_link_type
                                
                                	Type of link
                                	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                
                                .. attribute:: mplste_link_opt_tlv
                                
                                	List of Optional TLVs
                                	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv>`
                                
                                .. attribute:: neighbor_ip_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_system_id
                                
                                	Neighbor system ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: new_link
                                
                                	If true, Link is new
                                	**type**\:  bool
                                
                                .. attribute:: number_of_optional_tl_vs
                                
                                	Number of Optional TLVs
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: output_interface_id
                                
                                	Output interface ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: priority_count
                                
                                	Number of priorities
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: sub_pool_unreserve_bw_per_priority
                                
                                	Sub pool unreserved bandwidth for each priority (bytes/s)
                                	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                
                                .. attribute:: te_metric
                                
                                	Link TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__init__()

                                    self.yang_name = "mpls-te-link"
                                    self.yang_parent_name = "mpls-te-link"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                    self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv)}

                                    self.affinity = YLeaf(YType.uint32, "affinity")

                                    self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                    self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                    self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                    self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                    self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                    self.link_address = YLeaf(YType.str, "link-address")

                                    self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                    self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                    self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                    self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                    self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                    self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                    self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                    self.new_link = YLeaf(YType.boolean, "new-link")

                                    self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                    self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                    self.priority_count = YLeaf(YType.int32, "priority-count")

                                    self.te_metric = YLeaf(YType.uint32, "te-metric")

                                    self.extended_admin_group_list = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList()
                                    self.extended_admin_group_list.parent = self
                                    self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                    self._children_yang_names.add("extended-admin-group-list")

                                    self.global_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority()
                                    self.global_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                    self._children_yang_names.add("global-unreserve-bw-per-priority")

                                    self.link_protocol_priority_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability()
                                    self.link_protocol_priority_capability.parent = self
                                    self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                    self._children_yang_names.add("link-protocol-priority-capability")

                                    self.link_sw_capability = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability()
                                    self.link_sw_capability.parent = self
                                    self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                    self._children_yang_names.add("link-sw-capability")

                                    self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                    self.sub_pool_unreserve_bw_per_priority.parent = self
                                    self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                    self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                    self.mplste_link_opt_tlv = YList(self)
                                    self._segment_path = lambda: "mpls-te-link"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                class ExtendedAdminGroupList(Entity):
                                    """
                                    Extended Admin Group
                                    
                                    .. attribute:: ext_admin_data
                                    
                                    	Value of Extended Admin Group
                                    	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                    
                                    .. attribute:: extended_admin_size
                                    
                                    	Size of the extended admin group
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                        self.yang_name = "extended-admin-group-list"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                        self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                        self.ext_admin_data = YList(self)
                                        self._segment_path = lambda: "extended-admin-group-list"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                    class ExtAdminData(Entity):
                                        """
                                        Value of Extended Admin Group
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                            self.yang_name = "ext-admin-data"
                                            self.yang_parent_name = "extended-admin-group-list"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "ext-admin-data"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                class GlobalUnreserveBwPerPriority(Entity):
                                    """
                                    Global pool unreserved bandwidth for each
                                    priority (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "global-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                        self.bw_per_priority = YList(self)
                                        self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "global-unreserve-bw-per-priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint64, "entry")
                                            self._segment_path = lambda: "bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                class LinkProtocolPriorityCapability(Entity):
                                    """
                                    Link protocol and protocol priority capability
                                    
                                    .. attribute:: link_protocol_capability
                                    
                                    	Link protocol capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_protocol_priority
                                    
                                    	Link protocol priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                        self.yang_name = "link-protocol-priority-capability"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                        self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                        self._segment_path = lambda: "link-protocol-priority-capability"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                class LinkSwCapability(Entity):
                                    """
                                    Link switching capability
                                    
                                    .. attribute:: link_encoding
                                    
                                    	Link Encoding
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link_mtu
                                    
                                    	Link MTU size (bytes)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: link_switching_capability
                                    
                                    	Link Switching Capability
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: maximum_lsp_bw_per_priority
                                    
                                    	Maximum LSP bandwidth for each priority  (bytes/s)
                                    	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                    
                                    .. attribute:: minimum_lsp_bw
                                    
                                    	Minimum LSP bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte/s
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__init__()

                                        self.yang_name = "link-sw-capability"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                        self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                        self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                        self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                        self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                        self.maximum_lsp_bw_per_priority = YList(self)
                                        self._segment_path = lambda: "link-sw-capability"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                    class MaximumLspBwPerPriority(Entity):
                                        """
                                        Maximum LSP bandwidth for each priority
                                        
                                        (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                            self.yang_name = "maximum-lsp-bw-per-priority"
                                            self.yang_parent_name = "link-sw-capability"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint64, "entry")
                                            self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                class MplsteLinkOptTlv(Entity):
                                    """
                                    List of Optional TLVs
                                    
                                    .. attribute:: mplste_link_opt_tlv_len
                                    
                                    	Length of Opt TLV
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: mplste_link_opt_tlv_type
                                    
                                    	Type of Opt TLV
                                    	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                    
                                    .. attribute:: mplste_link_opt_tlv_value
                                    
                                    	Value of Opt TLV
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                        self.yang_name = "mplste-link-opt-tlv"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                        self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                        self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                        self.mplste_link_opt_tlv_value = YList(self)
                                        self._segment_path = lambda: "mplste-link-opt-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                    class MplsteLinkOptTlvValue(Entity):
                                        """
                                        Value of Opt TLV
                                        
                                        .. attribute:: bctlv_value
                                        
                                        	Value of Bandwidth Constraints TLV
                                        	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                        
                                        .. attribute:: ixcdtlv_value
                                        
                                        	Value of IXCD TLV
                                        	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                        
                                        .. attribute:: opaque_tlv_type
                                        
                                        	OpaqueTLVType
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: srlgtlv_value
                                        
                                        	Value of SRLG TLV
                                        	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                        
                                        .. attribute:: unidtlv_value
                                        
                                        	Value of Uni Delay TLV
                                        	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv-value"
                                            self.yang_parent_name = "mplste-link-opt-tlv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                            self._child_list_classes = {}

                                            self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                            self.bctlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                            self.bctlv_value.parent = self
                                            self._children_name_map["bctlv_value"] = "bctlv-value"
                                            self._children_yang_names.add("bctlv-value")

                                            self.ixcdtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                            self.ixcdtlv_value.parent = self
                                            self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                            self._children_yang_names.add("ixcdtlv-value")

                                            self.srlgtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                            self.srlgtlv_value.parent = self
                                            self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                            self._children_yang_names.add("srlgtlv-value")

                                            self.unidtlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                            self.unidtlv_value.parent = self
                                            self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                            self._children_yang_names.add("unidtlv-value")
                                            self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                        class BctlvValue(Entity):
                                            """
                                            Value of Bandwidth Constraints TLV
                                            
                                            .. attribute:: model_id
                                            
                                            	Allocation Model ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: mplste_link_bc_bandwidth
                                            
                                            	Value of BC TLV
                                            	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                            
                                            .. attribute:: num_b_cs
                                            
                                            	Number of BC TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                self.yang_name = "bctlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                self.model_id = YLeaf(YType.uint8, "model-id")

                                                self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                self.mplste_link_bc_bandwidth = YList(self)
                                                self._segment_path = lambda: "bctlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                            class MplsteLinkBcBandwidth(Entity):
                                                """
                                                Value of BC TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                    self.yang_name = "mplste-link-bc-bandwidth"
                                                    self.yang_parent_name = "bctlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                        class IxcdtlvValue(Entity):
                                            """
                                            Value of IXCD TLV
                                            
                                            .. attribute:: fixed_scsi_count
                                            
                                            	Fixed SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flex_scsi_count
                                            
                                            	Flexible SCSI count
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: ixcd_switching_cap_type
                                            
                                            	Switching Cap type
                                            	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                            
                                            .. attribute:: max_lspbw
                                            
                                            	Max LSP bandwidth array
                                            	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                            
                                            .. attribute:: rile_len_code
                                            
                                            	Rile LenCode
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: switching_cap
                                            
                                            	SCap
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                self.yang_name = "ixcdtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                self.ixcd_switching_cap_type = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                self.ixcd_switching_cap_type.parent = self
                                                self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                self._children_yang_names.add("ixcd-switching-cap-type")

                                                self.max_lspbw = YList(self)
                                                self._segment_path = lambda: "ixcdtlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                            class IxcdSwitchingCapType(Entity):
                                                """
                                                Switching Cap type
                                                
                                                .. attribute:: ixcdbw_sub_tlv
                                                
                                                	Sub TLVs
                                                	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                
                                                .. attribute:: ixcdpsc_info
                                                
                                                	IXCD PSC information
                                                	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                
                                                .. attribute:: switching_cap_type
                                                
                                                	SwitchingCapType
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                    self.yang_name = "ixcd-switching-cap-type"
                                                    self.yang_parent_name = "ixcdtlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                    self._child_list_classes = {}

                                                    self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                    self.ixcdbw_sub_tlv = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                    self.ixcdbw_sub_tlv.parent = self
                                                    self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                    self._children_yang_names.add("ixcdbw-sub-tlv")

                                                    self.ixcdpsc_info = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                    self.ixcdpsc_info.parent = self
                                                    self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                    self._children_yang_names.add("ixcdpsc-info")
                                                    self._segment_path = lambda: "ixcd-switching-cap-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                class IxcdbwSubTlv(Entity):
                                                    """
                                                    Sub TLVs
                                                    
                                                    .. attribute:: arr_bw_sub_tlv
                                                    
                                                    	Array of sub tlvs
                                                    	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                        self.yang_name = "ixcdbw-sub-tlv"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                        self.arr_bw_sub_tlv = YList(self)
                                                        self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                    class ArrBwSubTlv(Entity):
                                                        """
                                                        Array of sub tlvs
                                                        
                                                        .. attribute:: bw_sub_tlv_length
                                                        
                                                        	Length of BW Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_type
                                                        
                                                        	Type of Sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: bw_sub_tlv_value
                                                        
                                                        	Value of BW Sub TLV
                                                        	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                            self.yang_name = "arr-bw-sub-tlv"
                                                            self.yang_parent_name = "ixcdbw-sub-tlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                            self._child_list_classes = {}

                                                            self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                            self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                            self.bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                            self.bw_sub_tlv_value.parent = self
                                                            self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                            self._children_yang_names.add("bw-sub-tlv-value")
                                                            self._segment_path = lambda: "arr-bw-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                        class BwSubTlvValue(Entity):
                                                            """
                                                            Value of BW Sub TLV
                                                            
                                                            .. attribute:: fixed_bw_sub_tlv_value
                                                            
                                                            	Value of Fixed Sub TLV
                                                            	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                            
                                                            .. attribute:: flex_bw_sub_tlv_value
                                                            
                                                            	Value of Flex Sub TLV
                                                            	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                            
                                                            .. attribute:: ixcdbw_sub_tlv_type
                                                            
                                                            	IXCDBWSubTLVType
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                self.yang_name = "bw-sub-tlv-value"
                                                                self.yang_parent_name = "arr-bw-sub-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                self._child_list_classes = {}

                                                                self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                self.fixed_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                self.flex_bw_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                self.flex_bw_sub_tlv_value.parent = self
                                                                self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                self._segment_path = lambda: "bw-sub-tlv-value"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                            class FixedBwSubTlvValue(Entity):
                                                                """
                                                                Value of Fixed Sub TLV
                                                                
                                                                .. attribute:: fixed_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                
                                                                .. attribute:: unres_oduj_prio
                                                                
                                                                	Array of Unres Oduj Prio
                                                                	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "fixed-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                    self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                    self.fixed_sub_tlv_value = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                    self.fixed_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-sub-tlv-value")

                                                                    self.unres_oduj_prio = YList(self)
                                                                    self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                class FixedSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-sub-tlv-value"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")
                                                                        self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                class UnresOdujPrio(Entity):
                                                                    """
                                                                    Array of Unres Oduj Prio
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                        self.yang_name = "unres-oduj-prio"
                                                                        self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "unres-oduj-prio"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                            class FlexBwSubTlvValue(Entity):
                                                                """
                                                                Value of Flex Sub TLV
                                                                
                                                                .. attribute:: flex_sub_tlv_value_common
                                                                
                                                                	Flex Sub TLV Value
                                                                	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                
                                                                .. attribute:: max_lspbw
                                                                
                                                                	Max LSP BW Array
                                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                
                                                                .. attribute:: unres_lspbw
                                                                
                                                                	Array of Unres LSP BW
                                                                	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                    self.yang_name = "flex-bw-sub-tlv-value"
                                                                    self.yang_parent_name = "bw-sub-tlv-value"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                    self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                    self.flex_sub_tlv_value_common = Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                    self.flex_sub_tlv_value_common.parent = self
                                                                    self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                    self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                    self.max_lspbw = YList(self)
                                                                    self.unres_lspbw = YList(self)
                                                                    self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                class FlexSubTlvValueCommon(Entity):
                                                                    """
                                                                    Flex Sub TLV Value
                                                                    
                                                                    .. attribute:: num_stages
                                                                    
                                                                    	Number of stages
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit0
                                                                    
                                                                    	Priority 0
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit1
                                                                    
                                                                    	Priority 1
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit2
                                                                    
                                                                    	Priority 2
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit3
                                                                    
                                                                    	Priority 3
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit4
                                                                    
                                                                    	Priority 4
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit5
                                                                    
                                                                    	Priority 5
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit6
                                                                    
                                                                    	Priority 6
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: priority_bit7
                                                                    
                                                                    	Priority 7
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: res
                                                                    
                                                                    	Res
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: sbit
                                                                    
                                                                    	S Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: signal_type
                                                                    
                                                                    	Signal Type
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: stage
                                                                    
                                                                    	Array of Stages
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                    
                                                                    .. attribute:: tbit
                                                                    
                                                                    	T Bit
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: tsg
                                                                    
                                                                    	TSG
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                        self.yang_name = "flex-sub-tlv-value-common"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                        self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                        self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                        self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                        self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                        self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                        self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                        self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                        self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                        self.res = YLeaf(YType.uint8, "res")

                                                                        self.sbit = YLeaf(YType.uint8, "sbit")

                                                                        self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                        self.stage = YLeaf(YType.str, "stage")

                                                                        self.tbit = YLeaf(YType.uint8, "tbit")

                                                                        self.tsg = YLeaf(YType.uint8, "tsg")
                                                                        self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                class MaxLspbw(Entity):
                                                                    """
                                                                    Max LSP BW Array
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                        self.yang_name = "max-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                                        self._segment_path = lambda: "max-lspbw"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                class UnresLspbw(Entity):
                                                                    """
                                                                    Array of Unres LSP BW
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..18446744073709551615
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                        self.yang_name = "unres-lspbw"
                                                                        self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                                        self._segment_path = lambda: "unres-lspbw"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                class IxcdpscInfo(Entity):
                                                    """
                                                    IXCD PSC information
                                                    
                                                    .. attribute:: min_lsp_bandwidth
                                                    
                                                    	Min LSP bandwidth
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: psc_interface_mtu
                                                    
                                                    	 Interface MTU
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                        self.yang_name = "ixcdpsc-info"
                                                        self.yang_parent_name = "ixcd-switching-cap-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                        self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                        self._segment_path = lambda: "ixcdpsc-info"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                            class MaxLspbw(Entity):
                                                """
                                                Max LSP bandwidth array
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** \-9223372036854775808..9223372036854775807
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                    self.yang_name = "max-lspbw"
                                                    self.yang_parent_name = "ixcdtlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.int64, "entry")
                                                    self._segment_path = lambda: "max-lspbw"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                        class SrlgtlvValue(Entity):
                                            """
                                            Value of SRLG TLV
                                            
                                            .. attribute:: mplste_link_srlg_data
                                            
                                            	Value of SRLG TLV
                                            	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                            
                                            .. attribute:: num_srl_gs
                                            
                                            	Number of SRLG TLVs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: srlg_len
                                            
                                            	Length of SRLG TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                self.yang_name = "srlgtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                self.mplste_link_srlg_data = YList(self)
                                                self._segment_path = lambda: "srlgtlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                            class MplsteLinkSrlgData(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                    self.yang_name = "mplste-link-srlg-data"
                                                    self.yang_parent_name = "srlgtlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "mplste-link-srlg-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                        class UnidtlvValue(Entity):
                                            """
                                            Value of Uni Delay TLV
                                            
                                            .. attribute:: uni_dir_delay
                                            
                                            	Uni Dir Delay
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                self.yang_name = "unidtlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                self._segment_path = lambda: "unidtlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                class SubPoolUnreserveBwPerPriority(Entity):
                                    """
                                    Sub pool unreserved bandwidth for each priority
                                    (bytes/s)
                                    
                                    .. attribute:: bw_per_priority
                                    
                                    	Unreserved bandwidth for each priority (bytes/s)
                                    	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                        self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                        self.bw_per_priority = YList(self)
                                        self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                    class BwPerPriority(Entity):
                                        """
                                        Unreserved bandwidth for each priority (bytes/s)
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                            self.yang_name = "bw-per-priority"
                                            self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint64, "entry")
                                            self._segment_path = lambda: "bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                class OspfSummary(Entity):
                    """
                    Fast\-reroute topology information
                    
                    .. attribute:: sa_lsa_cnt_type_7ase
                    
                    	sa lsa cnt type 7ase
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_8_ignore
                    
                    	sa lsa cnt type 8 ignore
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_ase
                    
                    	sa lsa cnt type ase
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_mospf
                    
                    	sa lsa cnt type mospf
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_net
                    
                    	sa lsa cnt type net
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_opq_area
                    
                    	sa lsa cnt type opq area
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_opq_as
                    
                    	sa lsa cnt type opq as
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_opq_link
                    
                    	sa lsa cnt type opq link
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_rtr
                    
                    	sa lsa cnt type rtr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_sum_asb
                    
                    	sa lsa cnt type sum asb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_lsa_cnt_type_sum_net
                    
                    	sa lsa cnt type sum net
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_areas
                    
                    	sa num areas
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_intf
                    
                    	sa num intf
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_intf_up
                    
                    	sa num intf up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_nbrs
                    
                    	sa num nbrs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_nbrs_up
                    
                    	sa num nbrs up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_slintf_up
                    
                    	sa num slintf up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sa_num_vintf_up
                    
                    	sa num vintf up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.OspfSummary, self).__init__()

                        self.yang_name = "ospf-summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.sa_lsa_cnt_type_7ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-7ase")

                        self.sa_lsa_cnt_type_8_ignore = YLeaf(YType.uint32, "sa-lsa-cnt-type-8-ignore")

                        self.sa_lsa_cnt_type_ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-ase")

                        self.sa_lsa_cnt_type_mospf = YLeaf(YType.uint32, "sa-lsa-cnt-type-mospf")

                        self.sa_lsa_cnt_type_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-net")

                        self.sa_lsa_cnt_type_opq_area = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-area")

                        self.sa_lsa_cnt_type_opq_as = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-as")

                        self.sa_lsa_cnt_type_opq_link = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-link")

                        self.sa_lsa_cnt_type_rtr = YLeaf(YType.uint32, "sa-lsa-cnt-type-rtr")

                        self.sa_lsa_cnt_type_sum_asb = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-asb")

                        self.sa_lsa_cnt_type_sum_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-net")

                        self.sa_num_areas = YLeaf(YType.uint32, "sa-num-areas")

                        self.sa_num_intf = YLeaf(YType.uint32, "sa-num-intf")

                        self.sa_num_intf_up = YLeaf(YType.uint32, "sa-num-intf-up")

                        self.sa_num_nbrs = YLeaf(YType.uint32, "sa-num-nbrs")

                        self.sa_num_nbrs_up = YLeaf(YType.uint32, "sa-num-nbrs-up")

                        self.sa_num_slintf_up = YLeaf(YType.uint32, "sa-num-slintf-up")

                        self.sa_num_vintf_up = YLeaf(YType.uint32, "sa-num-vintf-up")
                        self._segment_path = lambda: "ospf-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.OspfSummary, ['sa_lsa_cnt_type_7ase', 'sa_lsa_cnt_type_8_ignore', 'sa_lsa_cnt_type_ase', 'sa_lsa_cnt_type_mospf', 'sa_lsa_cnt_type_net', 'sa_lsa_cnt_type_opq_area', 'sa_lsa_cnt_type_opq_as', 'sa_lsa_cnt_type_opq_link', 'sa_lsa_cnt_type_rtr', 'sa_lsa_cnt_type_sum_asb', 'sa_lsa_cnt_type_sum_net', 'sa_num_areas', 'sa_num_intf', 'sa_num_intf_up', 'sa_num_nbrs', 'sa_num_nbrs_up', 'sa_num_slintf_up', 'sa_num_vintf_up'], name, value)


                class ProcessInformation(Entity):
                    """
                    Container for OSPF Process information
                    
                    .. attribute:: process_areas
                    
                    	Process Area table
                    	**type**\:   :py:class:`ProcessAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas>`
                    
                    .. attribute:: process_summary
                    
                    	Basic OSPF summary information
                    	**type**\:   :py:class:`ProcessSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary>`
                    
                    .. attribute:: protocol_areas
                    
                    	Protocol Area table
                    	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas>`
                    
                    .. attribute:: protocol_summary
                    
                    	Basic OSPF protocol information
                    	**type**\:   :py:class:`ProtocolSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary>`
                    
                    .. attribute:: redistributions
                    
                    	Redistribution information table
                    	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.ProcessInformation, self).__init__()

                        self.yang_name = "process-information"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"process-areas" : ("process_areas", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas), "process-summary" : ("process_summary", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary), "protocol-areas" : ("protocol_areas", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas), "protocol-summary" : ("protocol_summary", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary), "redistributions" : ("redistributions", Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions)}
                        self._child_list_classes = {}

                        self.process_areas = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas()
                        self.process_areas.parent = self
                        self._children_name_map["process_areas"] = "process-areas"
                        self._children_yang_names.add("process-areas")

                        self.process_summary = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary()
                        self.process_summary.parent = self
                        self._children_name_map["process_summary"] = "process-summary"
                        self._children_yang_names.add("process-summary")

                        self.protocol_areas = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas()
                        self.protocol_areas.parent = self
                        self._children_name_map["protocol_areas"] = "protocol-areas"
                        self._children_yang_names.add("protocol-areas")

                        self.protocol_summary = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary()
                        self.protocol_summary.parent = self
                        self._children_name_map["protocol_summary"] = "protocol-summary"
                        self._children_yang_names.add("protocol-summary")

                        self.redistributions = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions()
                        self.redistributions.parent = self
                        self._children_name_map["redistributions"] = "redistributions"
                        self._children_yang_names.add("redistributions")
                        self._segment_path = lambda: "process-information"


                    class ProcessAreas(Entity):
                        """
                        Process Area table
                        
                        .. attribute:: process_area
                        
                        	Detailed information for a particular area
                        	**type**\: list of    :py:class:`ProcessArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas, self).__init__()

                            self.yang_name = "process-areas"
                            self.yang_parent_name = "process-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"process-area" : ("process_area", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea)}

                            self.process_area = YList(self)
                            self._segment_path = lambda: "process-areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas, [], name, value)


                        class ProcessArea(Entity):
                            """
                            Detailed information for a particular area
                            
                            .. attribute:: address
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_adj_stag_num_nbr_forming
                            
                            	Num of nbrs currently forming
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_dc_bitless_lsa_count
                            
                            	Number of LSA with demand circuit bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_id
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_id_string
                            
                            	Area ID string
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: area_interface_count
                            
                            	Number of interfaces in the area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_lfa_interface_count
                            
                            	Number of LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lfa_revision
                            
                            	Area LFA revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lsa_checksum
                            
                            	Sum of all area LSAs checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lsa_count
                            
                            	Number of LSAs in the Area
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_nssa
                            
                            	If true, area is a NSSA
                            	**type**\:  bool
                            
                            .. attribute:: area_num_nbr_full
                            
                            	Num of full nbrs in area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: area_opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksums
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsa_count
                            
                            	Number of Opaque LSAs in the Area
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_per_prefix_lfa_interface_count
                            
                            	Number of Per Prefix LFA enabled interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_policy_in
                            
                            	If true, inbound policy is configured
                            	**type**\:  bool
                            
                            .. attribute:: area_policy_in_name
                            
                            	Inbound summary lsa filtering policy
                            	**type**\:  str
                            
                            .. attribute:: area_policy_out
                            
                            	If true, outbound policy is configured
                            	**type**\:  bool
                            
                            .. attribute:: area_policy_out_name
                            
                            	Outbound summary lsa filtering policy
                            	**type**\:  str
                            
                            .. attribute:: area_range
                            
                            	List of ranges to summarize
                            	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange>`
                            
                            .. attribute:: area_stub
                            
                            	If true, stub area
                            	**type**\:  bool
                            
                            .. attribute:: area_total_stub
                            
                            	If true, totally stubby area
                            	**type**\:  bool
                            
                            .. attribute:: authentication_type
                            
                            	Authentication type
                            	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                            
                            .. attribute:: backbone_area_active
                            
                            	If true, Backbone area is active
                            	**type**\:  bool
                            
                            .. attribute:: dna_lsa_count
                            
                            	Number of DoNotAge LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_out
                            
                            	If true, advertise intra\-area prefixes as external
                            	**type**\:  bool
                            
                            .. attribute:: flood_list_length
                            
                            	Number of LSAs which need to be flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: indication_lsa_count
                            
                            	Number of indication LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_default
                            
                            	If true, generate NSSA default route
                            	**type**\:  bool
                            
                            .. attribute:: nssa_no_redistribution
                            
                            	If true, No redistribution into this NSSA area
                            	**type**\:  bool
                            
                            .. attribute:: nssa_translate
                            
                            	If true, perform 7/5 translation
                            	**type**\:  bool
                            
                            .. attribute:: segment_routing
                            
                            	If true, Segment Routing enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_count
                            
                            	Number of SPF calculations run
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_microloop_avoidance_active
                            
                            	If true, Segment routing Uloop avoidance         is currently active in this area
                            	**type**\:  bool
                            
                            .. attribute:: sr_microloop_avoidance_event_type
                            
                            	Event for which SR uloop is triggered            Link Up/Link Down
                            	**type**\:   :py:class:`SrUloopEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrUloopEvent>`
                            
                            .. attribute:: sr_microloop_avoidance_far_end_id
                            
                            	Link State ID of the far end                     of the topology change
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: sr_microloop_avoidance_near_end_id
                            
                            	Link State ID of the near end                    of the topology change
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: sr_microloop_avoidance_pseudonode_id
                            
                            	Link State ID of the pseudo node,                if the change is on a broadcast link
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: sr_strict_spf_cap
                            
                            	If true, All routers in Area are SR Strict\-SPF Capable
                            	**type**\:  bool
                            
                            .. attribute:: sr_strict_spfsids_available
                            
                            	If true, All routers in Area have SR Strict\-SPF SIDs
                            	**type**\:  bool
                            
                            .. attribute:: stub_default_cost
                            
                            	Default cost for Stub or NSSA area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: summary_in
                            
                            	If true, advertise redistributedprefixes as summary
                            	**type**\:  bool
                            
                            .. attribute:: te_enabled
                            
                            	If true, MPLS\-TE enabled
                            	**type**\:  bool
                            
                            .. attribute:: te_topology_version
                            
                            	TE area topology version number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea, self).__init__()

                                self.yang_name = "process-area"
                                self.yang_parent_name = "process-areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-range" : ("area_range", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange)}

                                self.address = YLeaf(YType.str, "address")

                                self.area_adj_stag_num_nbr_forming = YLeaf(YType.uint16, "area-adj-stag-num-nbr-forming")

                                self.area_dc_bitless_lsa_count = YLeaf(YType.uint32, "area-dc-bitless-lsa-count")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.area_id_string = YLeaf(YType.str, "area-id-string")

                                self.area_interface_count = YLeaf(YType.uint16, "area-interface-count")

                                self.area_lfa_interface_count = YLeaf(YType.uint32, "area-lfa-interface-count")

                                self.area_lfa_revision = YLeaf(YType.uint32, "area-lfa-revision")

                                self.area_lsa_checksum = YLeaf(YType.uint32, "area-lsa-checksum")

                                self.area_lsa_count = YLeaf(YType.uint32, "area-lsa-count")

                                self.area_nssa = YLeaf(YType.boolean, "area-nssa")

                                self.area_num_nbr_full = YLeaf(YType.uint16, "area-num-nbr-full")

                                self.area_opaque_lsa_checksum = YLeaf(YType.uint32, "area-opaque-lsa-checksum")

                                self.area_opaque_lsa_count = YLeaf(YType.uint32, "area-opaque-lsa-count")

                                self.area_per_prefix_lfa_interface_count = YLeaf(YType.uint32, "area-per-prefix-lfa-interface-count")

                                self.area_policy_in = YLeaf(YType.boolean, "area-policy-in")

                                self.area_policy_in_name = YLeaf(YType.str, "area-policy-in-name")

                                self.area_policy_out = YLeaf(YType.boolean, "area-policy-out")

                                self.area_policy_out_name = YLeaf(YType.str, "area-policy-out-name")

                                self.area_stub = YLeaf(YType.boolean, "area-stub")

                                self.area_total_stub = YLeaf(YType.boolean, "area-total-stub")

                                self.authentication_type = YLeaf(YType.enumeration, "authentication-type")

                                self.backbone_area_active = YLeaf(YType.boolean, "backbone-area-active")

                                self.dna_lsa_count = YLeaf(YType.uint32, "dna-lsa-count")

                                self.external_out = YLeaf(YType.boolean, "external-out")

                                self.flood_list_length = YLeaf(YType.uint32, "flood-list-length")

                                self.indication_lsa_count = YLeaf(YType.uint32, "indication-lsa-count")

                                self.nssa_default = YLeaf(YType.boolean, "nssa-default")

                                self.nssa_no_redistribution = YLeaf(YType.boolean, "nssa-no-redistribution")

                                self.nssa_translate = YLeaf(YType.boolean, "nssa-translate")

                                self.segment_routing = YLeaf(YType.uint32, "segment-routing")

                                self.spf_count = YLeaf(YType.uint32, "spf-count")

                                self.sr_microloop_avoidance_active = YLeaf(YType.boolean, "sr-microloop-avoidance-active")

                                self.sr_microloop_avoidance_event_type = YLeaf(YType.enumeration, "sr-microloop-avoidance-event-type")

                                self.sr_microloop_avoidance_far_end_id = YLeaf(YType.str, "sr-microloop-avoidance-far-end-id")

                                self.sr_microloop_avoidance_near_end_id = YLeaf(YType.str, "sr-microloop-avoidance-near-end-id")

                                self.sr_microloop_avoidance_pseudonode_id = YLeaf(YType.str, "sr-microloop-avoidance-pseudonode-id")

                                self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                                self.sr_strict_spfsids_available = YLeaf(YType.boolean, "sr-strict-spfsids-available")

                                self.stub_default_cost = YLeaf(YType.uint16, "stub-default-cost")

                                self.summary_in = YLeaf(YType.boolean, "summary-in")

                                self.te_enabled = YLeaf(YType.boolean, "te-enabled")

                                self.te_topology_version = YLeaf(YType.uint32, "te-topology-version")

                                self.area_range = YList(self)
                                self._segment_path = lambda: "process-area"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea, ['address', 'area_adj_stag_num_nbr_forming', 'area_dc_bitless_lsa_count', 'area_id', 'area_id_string', 'area_interface_count', 'area_lfa_interface_count', 'area_lfa_revision', 'area_lsa_checksum', 'area_lsa_count', 'area_nssa', 'area_num_nbr_full', 'area_opaque_lsa_checksum', 'area_opaque_lsa_count', 'area_per_prefix_lfa_interface_count', 'area_policy_in', 'area_policy_in_name', 'area_policy_out', 'area_policy_out_name', 'area_stub', 'area_total_stub', 'authentication_type', 'backbone_area_active', 'dna_lsa_count', 'external_out', 'flood_list_length', 'indication_lsa_count', 'nssa_default', 'nssa_no_redistribution', 'nssa_translate', 'segment_routing', 'spf_count', 'sr_microloop_avoidance_active', 'sr_microloop_avoidance_event_type', 'sr_microloop_avoidance_far_end_id', 'sr_microloop_avoidance_near_end_id', 'sr_microloop_avoidance_pseudonode_id', 'sr_strict_spf_cap', 'sr_strict_spfsids_available', 'stub_default_cost', 'summary_in', 'te_enabled', 'te_topology_version'], name, value)


                            class AreaRange(Entity):
                                """
                                List of ranges to summarize
                                
                                .. attribute:: advertise_flag
                                
                                	Whether to advertise Summary LSAs for this range
                                	**type**\:  bool
                                
                                .. attribute:: cost
                                
                                	Cost
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: range_mask
                                
                                	Network mask
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range_prefix
                                
                                	IP prefix for summarization
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "process-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.advertise_flag = YLeaf(YType.boolean, "advertise-flag")

                                    self.cost = YLeaf(YType.uint32, "cost")

                                    self.range_mask = YLeaf(YType.str, "range-mask")

                                    self.range_prefix = YLeaf(YType.str, "range-prefix")
                                    self._segment_path = lambda: "area-range"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, ['advertise_flag', 'cost', 'range_mask', 'range_prefix'], name, value)


                    class ProcessSummary(Entity):
                        """
                        Basic OSPF summary information
                        
                        .. attribute:: adj_stag_init_num_nbr
                        
                        	Num of nbrs brought up initially per area
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: adj_stag_max_num_nbr
                        
                        	Max num of nbrs brought up simultaneously per OSPF instance
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: adj_stag_num_nbr_forming
                        
                        	Num of nbrs currently forming for OSPF instance
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: adj_stagger_enabled
                        
                        	If true, OSPF Adjacency Staggering is configured
                        	**type**\:  bool
                        
                        .. attribute:: area_border_router
                        
                        	If true, is an Area Border Router
                        	**type**\:  bool
                        
                        .. attribute:: area_count
                        
                        	Number of areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_border_router
                        
                        	If true, is an AS Border Router
                        	**type**\:  bool
                        
                        .. attribute:: as_dc_bitless_lsa_count
                        
                        	Number of External and AS Opaque LSAs with demand circut bit not set
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_dna_lsa_count
                        
                        	Number of External and AS Opaque LSAs with DoNotAge set 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_checksum
                        
                        	Sum of AS scope LSA checksum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_count
                        
                        	Number of AS scope LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_lsa_flood_list_length
                        
                        	Length of AS LSAs flood list
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: context_name
                        
                        	Context name
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: domain_id
                        
                        	Domain ID information
                        	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId>`
                        
                        .. attribute:: graceful_shutdown_retention_time
                        
                        	Amount of time routes are retained after graceful shutdown (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: graceful_shutdown_state
                        
                        	State of graceful shutdown
                        	**type**\:   :py:class:`GsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.GsState>`
                        
                        .. attribute:: if_flood_pacing_interval
                        
                        	Flood pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: if_retrans_pacing_interval
                        
                        	Retransmission pacing timer (ms)
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: igp_intact_on
                        
                        	If true, running in IGP\-Intact mode
                        	**type**\:  bool
                        
                        .. attribute:: last_nsf_time
                        
                        	 Length of time since the last NSF (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_hold_time
                        
                        	Second delay before generating next LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_maximum_time
                        
                        	Maximum delay before generating an LSA (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_refresh_interval
                        
                        	LSA refresh interval (sec)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_start_time
                        
                        	Inital LSA throttle delay (ms)
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: lsd_bound
                        
                        	True if bound to LSD
                        	**type**\:  bool
                        
                        .. attribute:: lsd_connected
                        
                        	True if connected to LSD
                        	**type**\:  bool
                        
                        .. attribute:: lsd_connection_revision
                        
                        	LSD Connection Revision
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsd_registered
                        
                        	True if registered with LSD
                        	**type**\:  bool
                        
                        .. attribute:: max_lsa_enabled
                        
                        	If true, max\-lsa protection enabled
                        	**type**\:  bool
                        
                        .. attribute:: max_lsa_ignore_count
                        
                        	How many times ignore state has been entered
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_ignore_limit
                        
                        	Max allowed number of entering ignore state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_ignore_time
                        
                        	Time ignoring new LSAs after max\-lsa reached
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_ignore_timer
                        
                        	Remaining time when ignore timer is running
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_limit
                        
                        	Maximum allowed number of non self\-generated LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_reset_time
                        
                        	Time after which LSA protection counter is reset
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_reset_timer
                        
                        	Remaining time when reset timer is running
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_treshold
                        
                        	max\-lsa protection warning threshold
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_lsa_warning_only
                        
                        	Warning only when max\-lsa reached
                        	**type**\:  bool
                        
                        .. attribute:: maximum_interfaces
                        
                        	Maximum number of interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_metric
                        
                        	Max\-metric list
                        	**type**\: list of    :py:class:`MaximumMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric>`
                        
                        .. attribute:: maximum_metric_abr_off_buffer_time
                        
                        	Buffer time in seconds since last neighbor activity, to remain in max\-metric ABR off state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: maximum_metric_abr_off_mode
                        
                        	If true, ABR duties temporarily disabled
                        	**type**\:  bool
                        
                        .. attribute:: maximum_metric_abr_off_reasons
                        
                        	Reasons for ABR duties being temporarily disabled
                        	**type**\:   :py:class:`OspfMaxMetricAbrOffReasons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfMaxMetricAbrOffReasons>`
                        
                        .. attribute:: maximum_metric_set_reason
                        
                        	Max\-metric set reason
                        	**type**\:   :py:class:`MaxMetricSetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricSetReason>`
                        
                        .. attribute:: maximum_metric_start
                        
                        	If true, originate Router LSA with maximum metric
                        	**type**\:  bool
                        
                        .. attribute:: maximum_metric_start_timer
                        
                        	Time remaining for hold down timer (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: microloop_avoidance_active
                        
                        	If true, Uloop is active
                        	**type**\:  bool
                        
                        .. attribute:: microloop_avoidance_delay
                        
                        	Microloop delay time after which actual          post convergence paths are given to RIB (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: microloop_avoidance_delay_expiry
                        
                        	Remaining time for uloop delay timer             to expire (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: microloop_avoidance_type
                        
                        	Microloop avoidance type configured
                        	**type**\:   :py:class:`UloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.UloopAvoidance>`
                        
                        .. attribute:: minimum_lsa_arrival_interval
                        
                        	Minimum time between accepting LSAs (ms) Rel 4.0 .1, deprecated by MinimumLSAArrivalIntervalU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: minimum_lsa_arrival_interval_u32
                        
                        	Minimum time between accepting LSAs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_lsa_interval
                        
                        	Minimum time between LSA regeneration (ms) Rel 4 .0.1, deprecated by MinimumLSAIntervalU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: minimum_lsa_interval_u32
                        
                        	Minimum time between LSA regeneration (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: non_self_lsa_count
                        
                        	Non self\-generated LSA count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: normal_area_count
                        
                        	Number of normal Areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nsf_enabled
                        
                        	If true, NSF enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsf_time
                        
                        	Total time to complete NSF (s)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	If true, NSR is enabled
                        	**type**\:  bool
                        
                        .. attribute:: nsr_switchover_on_restart
                        
                        	Trigger RP Switchover on detectable process restart
                        	**type**\:  bool
                        
                        .. attribute:: nssa_area_count
                        
                        	Number of NSSA Areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: number_nbrs_full
                        
                        	Num of full nbrs
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: opaque_capable
                        
                        	Opaque LSA capable
                        	**type**\:  bool
                        
                        .. attribute:: opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksum
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: opaque_lsa_count
                        
                        	Number of Opaque LSAs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution
                        
                        	Redistribution list
                        	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution>`
                        
                        .. attribute:: redistribution_limit
                        
                        	The number of redistributed prefixes allowed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_limit_warn
                        
                        	If true, only a syslog message is printed when redistribution prefix limit is reached
                        	**type**\:  bool
                        
                        .. attribute:: redistribution_threshold
                        
                        	When the number of redistributed prefixes reaches this threshold, a warning message is issued
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role
                        
                        	Role, V1/V2 Active/Standby
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: role_standby
                        
                        	If true, Role is Standby, Active otherwise
                        	**type**\:  bool
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: snmp_trap_enabled
                        
                        	If true, snmp trap is enabled
                        	**type**\:  bool
                        
                        .. attribute:: spf_hold_time
                        
                        	Minimum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFHoldTimeU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: spf_hold_time_u32
                        
                        	Minimum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_maximum_time
                        
                        	Maximum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFMaximumTimeU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: spf_maximum_time_u32
                        
                        	Maximum delay time between SPF runs (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_prefix_priority
                        
                        	If true, prefix\-priority policy is configured
                        	**type**\:  bool
                        
                        .. attribute:: spf_prefix_priority_route_policy
                        
                        	SPF Prefix\-priority route policy
                        	**type**\:  str
                        
                        .. attribute:: spf_start_time
                        
                        	Scheduling delay for SPF (ms) This is valid if configured below 64k Deprecated by SPFStartTimeU32]
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: spf_start_time_u32
                        
                        	Scheduling delay for SPF (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_strict_spf_cap
                        
                        	True if Segment Routing Strict\-SPF capable
                        	**type**\:  bool
                        
                        .. attribute:: srgb_configured
                        
                        	True if Segment Routing Global Block configured
                        	**type**\:  bool
                        
                        .. attribute:: srgb_end
                        
                        	Segment Routing Global Block end label value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: srgb_start
                        
                        	Segment Routing Global Block start label value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: srgb_status
                        
                        	Segment Routing Global Block allocation status
                        	**type**\:   :py:class:`OspfSrgbStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfSrgbStatus>`
                        
                        .. attribute:: stub_area_count
                        
                        	Number of Stub and Total Stub Areas
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: table_prefix_limit_reached
                        
                        	If true, prefix limit for table has been  reached
                        	**type**\:  bool
                        
                        .. attribute:: tos_options
                        
                        	Type of Service supported
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ucmp
                        
                        	If true, UCMP is enabled
                        	**type**\:  bool
                        
                        .. attribute:: ucmp_delay
                        
                        	Delay between end of SPF and start of UCMP calculation (ms)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ucmp_prefix_list
                        
                        	UCMP Prefix\-list
                        	**type**\:  str
                        
                        .. attribute:: ucmp_variance
                        
                        	UCMP Variance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: vrf_lite_enabled
                        
                        	If true, vrf lite is enabled
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary, self).__init__()

                            self.yang_name = "process-summary"
                            self.yang_parent_name = "process-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"domain-id" : ("domain_id", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId)}
                            self._child_list_classes = {"maximum-metric" : ("maximum_metric", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric), "redistribution" : ("redistribution", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution)}

                            self.adj_stag_init_num_nbr = YLeaf(YType.uint16, "adj-stag-init-num-nbr")

                            self.adj_stag_max_num_nbr = YLeaf(YType.uint16, "adj-stag-max-num-nbr")

                            self.adj_stag_num_nbr_forming = YLeaf(YType.uint16, "adj-stag-num-nbr-forming")

                            self.adj_stagger_enabled = YLeaf(YType.boolean, "adj-stagger-enabled")

                            self.area_border_router = YLeaf(YType.boolean, "area-border-router")

                            self.area_count = YLeaf(YType.uint16, "area-count")

                            self.as_border_router = YLeaf(YType.boolean, "as-border-router")

                            self.as_dc_bitless_lsa_count = YLeaf(YType.uint32, "as-dc-bitless-lsa-count")

                            self.as_dna_lsa_count = YLeaf(YType.uint32, "as-dna-lsa-count")

                            self.as_lsa_checksum = YLeaf(YType.uint32, "as-lsa-checksum")

                            self.as_lsa_count = YLeaf(YType.uint32, "as-lsa-count")

                            self.as_lsa_flood_list_length = YLeaf(YType.uint32, "as-lsa-flood-list-length")

                            self.context_name = YLeaf(YType.str, "context-name")

                            self.graceful_shutdown_retention_time = YLeaf(YType.uint32, "graceful-shutdown-retention-time")

                            self.graceful_shutdown_state = YLeaf(YType.enumeration, "graceful-shutdown-state")

                            self.if_flood_pacing_interval = YLeaf(YType.uint16, "if-flood-pacing-interval")

                            self.if_retrans_pacing_interval = YLeaf(YType.uint16, "if-retrans-pacing-interval")

                            self.igp_intact_on = YLeaf(YType.boolean, "igp-intact-on")

                            self.last_nsf_time = YLeaf(YType.uint32, "last-nsf-time")

                            self.lsa_hold_time = YLeaf(YType.uint32, "lsa-hold-time")

                            self.lsa_maximum_time = YLeaf(YType.uint32, "lsa-maximum-time")

                            self.lsa_refresh_interval = YLeaf(YType.uint32, "lsa-refresh-interval")

                            self.lsa_start_time = YLeaf(YType.int32, "lsa-start-time")

                            self.lsd_bound = YLeaf(YType.boolean, "lsd-bound")

                            self.lsd_connected = YLeaf(YType.boolean, "lsd-connected")

                            self.lsd_connection_revision = YLeaf(YType.uint32, "lsd-connection-revision")

                            self.lsd_registered = YLeaf(YType.boolean, "lsd-registered")

                            self.max_lsa_enabled = YLeaf(YType.boolean, "max-lsa-enabled")

                            self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                            self.max_lsa_ignore_limit = YLeaf(YType.uint32, "max-lsa-ignore-limit")

                            self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                            self.max_lsa_ignore_timer = YLeaf(YType.uint32, "max-lsa-ignore-timer")

                            self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                            self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                            self.max_lsa_reset_timer = YLeaf(YType.uint32, "max-lsa-reset-timer")

                            self.max_lsa_treshold = YLeaf(YType.uint32, "max-lsa-treshold")

                            self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")

                            self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                            self.maximum_metric_abr_off_buffer_time = YLeaf(YType.uint32, "maximum-metric-abr-off-buffer-time")

                            self.maximum_metric_abr_off_mode = YLeaf(YType.boolean, "maximum-metric-abr-off-mode")

                            self.maximum_metric_abr_off_reasons = YLeaf(YType.enumeration, "maximum-metric-abr-off-reasons")

                            self.maximum_metric_set_reason = YLeaf(YType.enumeration, "maximum-metric-set-reason")

                            self.maximum_metric_start = YLeaf(YType.boolean, "maximum-metric-start")

                            self.maximum_metric_start_timer = YLeaf(YType.uint32, "maximum-metric-start-timer")

                            self.microloop_avoidance_active = YLeaf(YType.boolean, "microloop-avoidance-active")

                            self.microloop_avoidance_delay = YLeaf(YType.uint32, "microloop-avoidance-delay")

                            self.microloop_avoidance_delay_expiry = YLeaf(YType.uint32, "microloop-avoidance-delay-expiry")

                            self.microloop_avoidance_type = YLeaf(YType.enumeration, "microloop-avoidance-type")

                            self.minimum_lsa_arrival_interval = YLeaf(YType.uint16, "minimum-lsa-arrival-interval")

                            self.minimum_lsa_arrival_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-arrival-interval-u32")

                            self.minimum_lsa_interval = YLeaf(YType.uint16, "minimum-lsa-interval")

                            self.minimum_lsa_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-interval-u32")

                            self.non_self_lsa_count = YLeaf(YType.uint32, "non-self-lsa-count")

                            self.normal_area_count = YLeaf(YType.uint16, "normal-area-count")

                            self.nsf_enabled = YLeaf(YType.boolean, "nsf-enabled")

                            self.nsf_time = YLeaf(YType.uint32, "nsf-time")

                            self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                            self.nsr_switchover_on_restart = YLeaf(YType.boolean, "nsr-switchover-on-restart")

                            self.nssa_area_count = YLeaf(YType.uint16, "nssa-area-count")

                            self.number_nbrs_full = YLeaf(YType.uint16, "number-nbrs-full")

                            self.opaque_capable = YLeaf(YType.boolean, "opaque-capable")

                            self.opaque_lsa_checksum = YLeaf(YType.uint32, "opaque-lsa-checksum")

                            self.opaque_lsa_count = YLeaf(YType.uint32, "opaque-lsa-count")

                            self.redistribution_limit = YLeaf(YType.uint32, "redistribution-limit")

                            self.redistribution_limit_warn = YLeaf(YType.boolean, "redistribution-limit-warn")

                            self.redistribution_threshold = YLeaf(YType.uint32, "redistribution-threshold")

                            self.role = YLeaf(YType.uint32, "role")

                            self.role_standby = YLeaf(YType.boolean, "role-standby")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                            self.spf_hold_time = YLeaf(YType.uint16, "spf-hold-time")

                            self.spf_hold_time_u32 = YLeaf(YType.uint32, "spf-hold-time-u32")

                            self.spf_maximum_time = YLeaf(YType.uint16, "spf-maximum-time")

                            self.spf_maximum_time_u32 = YLeaf(YType.uint32, "spf-maximum-time-u32")

                            self.spf_prefix_priority = YLeaf(YType.boolean, "spf-prefix-priority")

                            self.spf_prefix_priority_route_policy = YLeaf(YType.str, "spf-prefix-priority-route-policy")

                            self.spf_start_time = YLeaf(YType.uint16, "spf-start-time")

                            self.spf_start_time_u32 = YLeaf(YType.uint32, "spf-start-time-u32")

                            self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                            self.srgb_configured = YLeaf(YType.boolean, "srgb-configured")

                            self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                            self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                            self.srgb_status = YLeaf(YType.enumeration, "srgb-status")

                            self.stub_area_count = YLeaf(YType.uint16, "stub-area-count")

                            self.table_prefix_limit_reached = YLeaf(YType.boolean, "table-prefix-limit-reached")

                            self.tos_options = YLeaf(YType.uint8, "tos-options")

                            self.ucmp = YLeaf(YType.boolean, "ucmp")

                            self.ucmp_delay = YLeaf(YType.uint32, "ucmp-delay")

                            self.ucmp_prefix_list = YLeaf(YType.str, "ucmp-prefix-list")

                            self.ucmp_variance = YLeaf(YType.int32, "ucmp-variance")

                            self.vrf_lite_enabled = YLeaf(YType.boolean, "vrf-lite-enabled")

                            self.domain_id = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId()
                            self.domain_id.parent = self
                            self._children_name_map["domain_id"] = "domain-id"
                            self._children_yang_names.add("domain-id")

                            self.maximum_metric = YList(self)
                            self.redistribution = YList(self)
                            self._segment_path = lambda: "process-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary, ['adj_stag_init_num_nbr', 'adj_stag_max_num_nbr', 'adj_stag_num_nbr_forming', 'adj_stagger_enabled', 'area_border_router', 'area_count', 'as_border_router', 'as_dc_bitless_lsa_count', 'as_dna_lsa_count', 'as_lsa_checksum', 'as_lsa_count', 'as_lsa_flood_list_length', 'context_name', 'graceful_shutdown_retention_time', 'graceful_shutdown_state', 'if_flood_pacing_interval', 'if_retrans_pacing_interval', 'igp_intact_on', 'last_nsf_time', 'lsa_hold_time', 'lsa_maximum_time', 'lsa_refresh_interval', 'lsa_start_time', 'lsd_bound', 'lsd_connected', 'lsd_connection_revision', 'lsd_registered', 'max_lsa_enabled', 'max_lsa_ignore_count', 'max_lsa_ignore_limit', 'max_lsa_ignore_time', 'max_lsa_ignore_timer', 'max_lsa_limit', 'max_lsa_reset_time', 'max_lsa_reset_timer', 'max_lsa_treshold', 'max_lsa_warning_only', 'maximum_interfaces', 'maximum_metric_abr_off_buffer_time', 'maximum_metric_abr_off_mode', 'maximum_metric_abr_off_reasons', 'maximum_metric_set_reason', 'maximum_metric_start', 'maximum_metric_start_timer', 'microloop_avoidance_active', 'microloop_avoidance_delay', 'microloop_avoidance_delay_expiry', 'microloop_avoidance_type', 'minimum_lsa_arrival_interval', 'minimum_lsa_arrival_interval_u32', 'minimum_lsa_interval', 'minimum_lsa_interval_u32', 'non_self_lsa_count', 'normal_area_count', 'nsf_enabled', 'nsf_time', 'nsr_enabled', 'nsr_switchover_on_restart', 'nssa_area_count', 'number_nbrs_full', 'opaque_capable', 'opaque_lsa_checksum', 'opaque_lsa_count', 'redistribution_limit', 'redistribution_limit_warn', 'redistribution_threshold', 'role', 'role_standby', 'router_id', 'snmp_trap_enabled', 'spf_hold_time', 'spf_hold_time_u32', 'spf_maximum_time', 'spf_maximum_time_u32', 'spf_prefix_priority', 'spf_prefix_priority_route_policy', 'spf_start_time', 'spf_start_time_u32', 'sr_strict_spf_cap', 'srgb_configured', 'srgb_end', 'srgb_start', 'srgb_status', 'stub_area_count', 'table_prefix_limit_reached', 'tos_options', 'ucmp', 'ucmp_delay', 'ucmp_prefix_list', 'ucmp_variance', 'vrf_lite_enabled'], name, value)


                        class DomainId(Entity):
                            """
                            Domain ID information
                            
                            .. attribute:: primary_domain_id
                            
                            	Primary Domain ID
                            	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId>`
                            
                            .. attribute:: secondary_domain_id
                            
                            	List of secondary domain IDs
                            	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId, self).__init__()

                                self.yang_name = "domain-id"
                                self.yang_parent_name = "process-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"primary-domain-id" : ("primary_domain_id", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId)}
                                self._child_list_classes = {"secondary-domain-id" : ("secondary_domain_id", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId)}

                                self.primary_domain_id = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId()
                                self.primary_domain_id.parent = self
                                self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                self._children_yang_names.add("primary-domain-id")

                                self.secondary_domain_id = YList(self)
                                self._segment_path = lambda: "domain-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId, [], name, value)


                            class PrimaryDomainId(Entity):
                                """
                                Primary Domain ID
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__init__()

                                    self.yang_name = "primary-domain-id"
                                    self.yang_parent_name = "domain-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                    self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                    self._segment_path = lambda: "primary-domain-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                            class SecondaryDomainId(Entity):
                                """
                                List of secondary domain IDs
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__init__()

                                    self.yang_name = "secondary-domain-id"
                                    self.yang_parent_name = "domain-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                    self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                    self._segment_path = lambda: "secondary-domain-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                        class MaximumMetric(Entity):
                            """
                            Max\-metric list
                            
                            .. attribute:: max_metric_enabled
                            
                            	Max\-metric enabled
                            	**type**\:  bool
                            
                            .. attribute:: max_metric_reason
                            
                            	Max\-metric reason
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: maximum_metric_external_lsa
                            
                            	If true, advertise max\-metric in external\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_external_lsa_metric
                            
                            	Max\-metric value to advertise in external\-LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_include_stubs
                            
                            	If true, set max\-metric in stub links
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_originated_for
                            
                            	Time max\-metric was used for
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_start_time
                            
                            	Time remaining until we will start using normal metrics (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_summary_lsa
                            
                            	If true, advertise max\-metric in summary\-LSAs
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_summary_lsa_metric
                            
                            	Max\-metric value to advertise in summary\-LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric_time_unset
                            
                            	Time max\-metric condition was cleared
                            	**type**\:   :py:class:`MaximumMetricTimeUnset <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset>`
                            
                            .. attribute:: maximum_metric_unset_reason
                            
                            	Max\-metric unset reason
                            	**type**\:   :py:class:`MaxMetricUnsetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricUnsetReason>`
                            
                            .. attribute:: saved_startup_time
                            
                            	Hold time configured (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saved_unset_maximum_metric
                            
                            	Saved UnsetMaximumMetric
                            	**type**\:  bool
                            
                            .. attribute:: unset_maximum_metric
                            
                            	If true, BGP is up, no maximum metric Router LSA
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__init__()

                                self.yang_name = "maximum-metric"
                                self.yang_parent_name = "process-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"maximum-metric-time-unset" : ("maximum_metric_time_unset", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset)}
                                self._child_list_classes = {}

                                self.max_metric_enabled = YLeaf(YType.boolean, "max-metric-enabled")

                                self.max_metric_reason = YLeaf(YType.uint8, "max-metric-reason")

                                self.maximum_metric_external_lsa = YLeaf(YType.boolean, "maximum-metric-external-lsa")

                                self.maximum_metric_external_lsa_metric = YLeaf(YType.uint32, "maximum-metric-external-lsa-metric")

                                self.maximum_metric_include_stubs = YLeaf(YType.boolean, "maximum-metric-include-stubs")

                                self.maximum_metric_originated_for = YLeaf(YType.uint32, "maximum-metric-originated-for")

                                self.maximum_metric_start_time = YLeaf(YType.uint32, "maximum-metric-start-time")

                                self.maximum_metric_summary_lsa = YLeaf(YType.boolean, "maximum-metric-summary-lsa")

                                self.maximum_metric_summary_lsa_metric = YLeaf(YType.uint32, "maximum-metric-summary-lsa-metric")

                                self.maximum_metric_unset_reason = YLeaf(YType.enumeration, "maximum-metric-unset-reason")

                                self.saved_startup_time = YLeaf(YType.uint32, "saved-startup-time")

                                self.saved_unset_maximum_metric = YLeaf(YType.boolean, "saved-unset-maximum-metric")

                                self.unset_maximum_metric = YLeaf(YType.boolean, "unset-maximum-metric")

                                self.maximum_metric_time_unset = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset()
                                self.maximum_metric_time_unset.parent = self
                                self._children_name_map["maximum_metric_time_unset"] = "maximum-metric-time-unset"
                                self._children_yang_names.add("maximum-metric-time-unset")
                                self._segment_path = lambda: "maximum-metric"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric, ['max_metric_enabled', 'max_metric_reason', 'maximum_metric_external_lsa', 'maximum_metric_external_lsa_metric', 'maximum_metric_include_stubs', 'maximum_metric_originated_for', 'maximum_metric_start_time', 'maximum_metric_summary_lsa', 'maximum_metric_summary_lsa_metric', 'maximum_metric_unset_reason', 'saved_startup_time', 'saved_unset_maximum_metric', 'unset_maximum_metric'], name, value)


                            class MaximumMetricTimeUnset(Entity):
                                """
                                Time max\-metric condition was cleared
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__init__()

                                    self.yang_name = "maximum-metric-time-unset"
                                    self.yang_parent_name = "maximum-metric"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "maximum-metric-time-unset"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, ['nanosecond', 'second'], name, value)


                        class Redistribution(Entity):
                            """
                            Redistribution list
                            
                            .. attribute:: classless
                            
                            	Whether to use CIDR
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Route metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_flag
                            
                            	If true, Metric configured
                            	**type**\:  bool
                            
                            .. attribute:: nssa_only
                            
                            	To NSSA areas only
                            	**type**\:  bool
                            
                            .. attribute:: redistribution_protocol
                            
                            	Protocol Information
                            	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution, self).__init__()

                                self.yang_name = "redistribution"
                                self.yang_parent_name = "process-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"redistribution-protocol" : ("redistribution_protocol", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol)}
                                self._child_list_classes = {}

                                self.classless = YLeaf(YType.boolean, "classless")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                self.redistribution_protocol = Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol()
                                self.redistribution_protocol.parent = self
                                self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                self._children_yang_names.add("redistribution-protocol")
                                self._segment_path = lambda: "redistribution"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution, ['classless', 'metric', 'metric_flag', 'nssa_only'], name, value)


                            class RedistributionProtocol(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: connected_instance
                                
                                	Connected instance name
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	ISIS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol_type
                                
                                	ProtocolType
                                	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__init__()

                                    self.yang_name = "redistribution-protocol"
                                    self.yang_parent_name = "redistribution"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.connected_instance = YLeaf(YType.str, "connected-instance")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.protocol_type = YLeaf(YType.enumeration, "protocol-type")
                                    self._segment_path = lambda: "redistribution-protocol"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, ['bgp_as_number', 'connected_instance', 'eigrp_as_number', 'isis_instance_id', 'ospf_process_id', 'protocol_type'], name, value)


                    class ProtocolAreas(Entity):
                        """
                        Protocol Area table
                        
                        .. attribute:: protocol_area
                        
                        	Area information
                        	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas, self).__init__()

                            self.yang_name = "protocol-areas"
                            self.yang_parent_name = "process-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"protocol-area" : ("protocol_area", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea)}

                            self.protocol_area = YList(self)
                            self._segment_path = lambda: "protocol-areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas, [], name, value)


                        class ProtocolArea(Entity):
                            """
                            Area information
                            
                            .. attribute:: address
                            
                            	Area ID if in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	Area ID if in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: protcol_area
                            
                            	Area ID string in decimal and dotted\-decimal format
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: protocol_area_dist_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: protocol_interface
                            
                            	Interface list
                            	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                            
                            .. attribute:: protocol_mpls
                            
                            	MPLS\-TE enabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__init__()

                                self.yang_name = "protocol-area"
                                self.yang_parent_name = "protocol-areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"protocol-interface" : ("protocol_interface", Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface)}

                                self.address = YLeaf(YType.str, "address")

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.protcol_area = YLeaf(YType.str, "protcol-area")

                                self.protocol_area_dist_list_in = YLeaf(YType.str, "protocol-area-dist-list-in")

                                self.protocol_mpls = YLeaf(YType.boolean, "protocol-mpls")

                                self.protocol_interface = YList(self)
                                self._segment_path = lambda: "protocol-area"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea, ['address', 'area_id', 'protcol_area', 'protocol_area_dist_list_in', 'protocol_mpls'], name, value)


                            class ProtocolInterface(Entity):
                                """
                                Interface list
                                
                                .. attribute:: protocol_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: protocol_interface_dist_list_in
                                
                                	Distribute List In
                                	**type**\:  str
                                
                                .. attribute:: protocol_interface_name
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                    self.yang_name = "protocol-interface"
                                    self.yang_parent_name = "protocol-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.protocol_authentication_type = YLeaf(YType.enumeration, "protocol-authentication-type")

                                    self.protocol_interface_dist_list_in = YLeaf(YType.str, "protocol-interface-dist-list-in")

                                    self.protocol_interface_name = YLeaf(YType.str, "protocol-interface-name")
                                    self._segment_path = lambda: "protocol-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, ['protocol_authentication_type', 'protocol_interface_dist_list_in', 'protocol_interface_name'], name, value)


                    class ProtocolSummary(Entity):
                        """
                        Basic OSPF protocol information
                        
                        .. attribute:: administrative_distance_external
                        
                        	Administrative Distance for External routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_inter_area
                        
                        	Administrative Distance for Inter Area routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dist_list_in
                        
                        	Distribute List In
                        	**type**\:  str
                        
                        .. attribute:: protocol_distance
                        
                        	Administrative distance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_nsf
                        
                        	True if NSF enabled
                        	**type**\:  bool
                        
                        .. attribute:: protocol_router_id
                        
                        	Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary, self).__init__()

                            self.yang_name = "protocol-summary"
                            self.yang_parent_name = "process-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.administrative_distance_external = YLeaf(YType.uint32, "administrative-distance-external")

                            self.administrative_distance_inter_area = YLeaf(YType.uint32, "administrative-distance-inter-area")

                            self.dist_list_in = YLeaf(YType.str, "dist-list-in")

                            self.protocol_distance = YLeaf(YType.uint32, "protocol-distance")

                            self.protocol_nsf = YLeaf(YType.boolean, "protocol-nsf")

                            self.protocol_router_id = YLeaf(YType.str, "protocol-router-id")
                            self._segment_path = lambda: "protocol-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.ProtocolSummary, ['administrative_distance_external', 'administrative_distance_inter_area', 'dist_list_in', 'protocol_distance', 'protocol_nsf', 'protocol_router_id'], name, value)


                    class Redistributions(Entity):
                        """
                        Redistribution information table
                        
                        .. attribute:: redistribution
                        
                        	Redistribution information
                        	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions, self).__init__()

                            self.yang_name = "redistributions"
                            self.yang_parent_name = "process-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"redistribution" : ("redistribution", Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution)}

                            self.redistribution = YList(self)
                            self._segment_path = lambda: "redistributions"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions, [], name, value)


                        class Redistribution(Entity):
                            """
                            Redistribution information
                            
                            .. attribute:: classless
                            
                            	Whether to use CIDR
                            	**type**\:  bool
                            
                            .. attribute:: metric
                            
                            	Route metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: metric_flag
                            
                            	If true, Metric configured
                            	**type**\:  bool
                            
                            .. attribute:: nssa_only
                            
                            	To NSSA areas only
                            	**type**\:  bool
                            
                            .. attribute:: process_name
                            
                            	Process name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name
                            
                            	Protocol name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: redistribution_protocol
                            
                            	Protocol Information
                            	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution, self).__init__()

                                self.yang_name = "redistribution"
                                self.yang_parent_name = "redistributions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"redistribution-protocol" : ("redistribution_protocol", Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol)}
                                self._child_list_classes = {}

                                self.classless = YLeaf(YType.boolean, "classless")

                                self.metric = YLeaf(YType.uint32, "metric")

                                self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                self.process_name = YLeaf(YType.str, "process-name")

                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                self.redistribution_protocol = Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol()
                                self.redistribution_protocol.parent = self
                                self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                self._children_yang_names.add("redistribution-protocol")
                                self._segment_path = lambda: "redistribution"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution, ['classless', 'metric', 'metric_flag', 'nssa_only', 'process_name', 'protocol_name'], name, value)


                            class RedistributionProtocol(Entity):
                                """
                                Protocol Information
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: connected_instance
                                
                                	Connected instance name
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	ISIS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol_type
                                
                                	ProtocolType
                                	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__init__()

                                    self.yang_name = "redistribution-protocol"
                                    self.yang_parent_name = "redistribution"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.connected_instance = YLeaf(YType.str, "connected-instance")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.protocol_type = YLeaf(YType.enumeration, "protocol-type")
                                    self._segment_path = lambda: "redistribution-protocol"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, ['bgp_as_number', 'connected_instance', 'eigrp_as_number', 'isis_instance_id', 'ospf_process_id', 'protocol_type'], name, value)


                class RouteInformation(Entity):
                    """
                    Container for OSPF routing tables
                    
                    .. attribute:: backup_routes
                    
                    	OSPF Route Table Including Backup Paths
                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes>`
                    
                    .. attribute:: connected_routes
                    
                    	OSPF Connected Route Table
                    	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes>`
                    
                    .. attribute:: external_routes
                    
                    	OSPF External Route Table
                    	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes>`
                    
                    .. attribute:: local_routes
                    
                    	OSPF Local Route Table
                    	**type**\:   :py:class:`LocalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes>`
                    
                    .. attribute:: multicast_intact_backup_routes
                    
                    	OSPF Route Table Including Multicast intact Backup Paths
                    	**type**\:   :py:class:`MulticastIntactBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes>`
                    
                    .. attribute:: multicast_intact_route_table
                    
                    	OSPF Route Table including multicast\-intact routes
                    	**type**\:   :py:class:`MulticastIntactRouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable>`
                    
                    .. attribute:: route_areas
                    
                    	OSPF Area Route Table
                    	**type**\:   :py:class:`RouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas>`
                    
                    .. attribute:: route_table
                    
                    	OSPF Route Table
                    	**type**\:   :py:class:`RouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable>`
                    
                    .. attribute:: summary_information
                    
                    	OSPF route summary statistics
                    	**type**\:   :py:class:`SummaryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation, self).__init__()

                        self.yang_name = "route-information"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"backup-routes" : ("backup_routes", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes), "connected-routes" : ("connected_routes", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes), "external-routes" : ("external_routes", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes), "local-routes" : ("local_routes", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes), "multicast-intact-backup-routes" : ("multicast_intact_backup_routes", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes), "multicast-intact-route-table" : ("multicast_intact_route_table", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable), "route-areas" : ("route_areas", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas), "route-table" : ("route_table", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable), "summary-information" : ("summary_information", Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation)}
                        self._child_list_classes = {}

                        self.backup_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes()
                        self.backup_routes.parent = self
                        self._children_name_map["backup_routes"] = "backup-routes"
                        self._children_yang_names.add("backup-routes")

                        self.connected_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes()
                        self.connected_routes.parent = self
                        self._children_name_map["connected_routes"] = "connected-routes"
                        self._children_yang_names.add("connected-routes")

                        self.external_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes()
                        self.external_routes.parent = self
                        self._children_name_map["external_routes"] = "external-routes"
                        self._children_yang_names.add("external-routes")

                        self.local_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes()
                        self.local_routes.parent = self
                        self._children_name_map["local_routes"] = "local-routes"
                        self._children_yang_names.add("local-routes")

                        self.multicast_intact_backup_routes = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes()
                        self.multicast_intact_backup_routes.parent = self
                        self._children_name_map["multicast_intact_backup_routes"] = "multicast-intact-backup-routes"
                        self._children_yang_names.add("multicast-intact-backup-routes")

                        self.multicast_intact_route_table = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable()
                        self.multicast_intact_route_table.parent = self
                        self._children_name_map["multicast_intact_route_table"] = "multicast-intact-route-table"
                        self._children_yang_names.add("multicast-intact-route-table")

                        self.route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas()
                        self.route_areas.parent = self
                        self._children_name_map["route_areas"] = "route-areas"
                        self._children_yang_names.add("route-areas")

                        self.route_table = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable()
                        self.route_table.parent = self
                        self._children_name_map["route_table"] = "route-table"
                        self._children_yang_names.add("route-table")

                        self.summary_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation()
                        self.summary_information.parent = self
                        self._children_name_map["summary_information"] = "summary-information"
                        self._children_yang_names.add("summary-information")
                        self._segment_path = lambda: "route-information"


                    class BackupRoutes(Entity):
                        """
                        OSPF Route Table Including Backup Paths
                        
                        .. attribute:: backup_route
                        
                        	OSPF route including backup paths
                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes, self).__init__()

                            self.yang_name = "backup-routes"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"backup-route" : ("backup_route", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute)}

                            self.backup_route = YList(self)
                            self._segment_path = lambda: "backup-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes, [], name, value)


                        class BackupRoute(Entity):
                            """
                            OSPF route including backup paths
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute, self).__init__()

                                self.yang_name = "backup-route"
                                self.yang_parent_name = "backup-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "backup-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "backup-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime)}
                                    self._child_list_classes = {}

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")
                                    self._segment_path = lambda: "route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-fail-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-update-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "backup-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath)}
                                    self._child_list_classes = {}

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_remote_lfa
                                    
                                    	IP address of remote LFA
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_repair
                                    
                                    	Backup Repair List
                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                    
                                    .. attribute:: backup_repair_list_size
                                    
                                    	Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_tunnel_interface_name
                                    
                                    	Backup Tunnel Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair)}

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                        self.backup_repair = YList(self)
                                        self._segment_path = lambda: "route-backup-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                    class BackupRepair(Entity):
                                        """
                                        Backup Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                            self.yang_name = "backup-repair"
                                            self.yang_parent_name = "route-backup-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "backup-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)
                                        self._segment_path = lambda: "sr-microloop-avoidance-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "microloop-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class ConnectedRoutes(Entity):
                        """
                        OSPF Connected Route Table
                        
                        .. attribute:: connected_route
                        
                        	Connected route
                        	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes, self).__init__()

                            self.yang_name = "connected-routes"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"connected-route" : ("connected_route", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute)}

                            self.connected_route = YList(self)
                            self._segment_path = lambda: "connected-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes, [], name, value)


                        class ConnectedRoute(Entity):
                            """
                            Connected route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__init__()

                                self.yang_name = "connected-route"
                                self.yang_parent_name = "connected-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "connected-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "connected-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime)}
                                    self._child_list_classes = {}

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")
                                    self._segment_path = lambda: "route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-fail-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-update-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "connected-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath)}
                                    self._child_list_classes = {}

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)
                                        self._segment_path = lambda: "sr-microloop-avoidance-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "microloop-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class ExternalRoutes(Entity):
                        """
                        OSPF External Route Table
                        
                        .. attribute:: external_route
                        
                        	OSPF external route
                        	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes, self).__init__()

                            self.yang_name = "external-routes"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"external-route" : ("external_route", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute)}

                            self.external_route = YList(self)
                            self._segment_path = lambda: "external-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes, [], name, value)


                        class ExternalRoute(Entity):
                            """
                            OSPF external route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: protocol_name
                            
                            	Name of protocol from which the external route was redistributed
                            	**type**\:   :py:class:`ProtocolName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName>`
                            
                            .. attribute:: route_extended_community
                            
                            	Extended communities in the route
                            	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                            
                            .. attribute:: route_information
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__init__()

                                self.yang_name = "external-route"
                                self.yang_parent_name = "external-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"protocol-name" : ("protocol_name", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName), "route-extended-community" : ("route_extended_community", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity), "route-information" : ("route_information", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation)}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.protocol_name = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName()
                                self.protocol_name.parent = self
                                self._children_name_map["protocol_name"] = "protocol-name"
                                self._children_yang_names.add("protocol-name")

                                self.route_extended_community = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                self.route_extended_community.parent = self
                                self._children_name_map["route_extended_community"] = "route-extended-community"
                                self._children_yang_names.add("route-extended-community")

                                self.route_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation()
                                self.route_information.parent = self
                                self._children_name_map["route_information"] = "route-information"
                                self._children_yang_names.add("route-information")
                                self._segment_path = lambda: "external-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute, ['prefix', 'prefix_length'], name, value)


                            class ProtocolName(Entity):
                                """
                                Name of protocol from which the external route
                                was redistributed
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: connected_instance
                                
                                	Connected instance name
                                	**type**\:  str
                                
                                .. attribute:: eigrp_as_number
                                
                                	Autonomous System Number
                                	**type**\:  str
                                
                                .. attribute:: isis_instance_id
                                
                                	ISIS instance identifier
                                	**type**\:  str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\:  str
                                
                                .. attribute:: protocol_type
                                
                                	ProtocolType
                                	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__init__()

                                    self.yang_name = "protocol-name"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                    self.connected_instance = YLeaf(YType.str, "connected-instance")

                                    self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                    self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                    self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                    self.protocol_type = YLeaf(YType.enumeration, "protocol-type")
                                    self._segment_path = lambda: "protocol-name"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, ['bgp_as_number', 'connected_instance', 'eigrp_as_number', 'isis_instance_id', 'ospf_process_id', 'protocol_type'], name, value)


                            class RouteExtendedCommunity(Entity):
                                """
                                Extended communities in the route
                                
                                .. attribute:: extended_community_area_id
                                
                                	Area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_domain_id_value
                                
                                	Domain ID value
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extended_community_options
                                
                                	Route Options
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_route_type
                                
                                	Route type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_router_id
                                
                                	Router id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: extended_communityl_domain_id_type
                                
                                	Domain ID type
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                    self.yang_name = "route-extended-community"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.extended_community_area_id = YLeaf(YType.uint32, "extended-community-area-id")

                                    self.extended_community_domain_id_value = YLeaf(YType.str, "extended-community-domain-id-value")

                                    self.extended_community_options = YLeaf(YType.uint8, "extended-community-options")

                                    self.extended_community_route_type = YLeaf(YType.uint8, "extended-community-route-type")

                                    self.extended_community_router_id = YLeaf(YType.str, "extended-community-router-id")

                                    self.extended_communityl_domain_id_type = YLeaf(YType.uint16, "extended-communityl-domain-id-type")
                                    self._segment_path = lambda: "route-extended-community"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, ['extended_community_area_id', 'extended_community_domain_id_value', 'extended_community_options', 'extended_community_route_type', 'extended_community_router_id', 'extended_communityl_domain_id_type'], name, value)


                            class RouteInformation(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__init__()

                                    self.yang_name = "route-information"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath)}

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "route-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, ['route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "route-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "route-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class LocalRoutes(Entity):
                        """
                        OSPF Local Route Table
                        
                        .. attribute:: local_route
                        
                        	Local route
                        	**type**\: list of    :py:class:`LocalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes, self).__init__()

                            self.yang_name = "local-routes"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"local-route" : ("local_route", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute)}

                            self.local_route = YList(self)
                            self._segment_path = lambda: "local-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes, [], name, value)


                        class LocalRoute(Entity):
                            """
                            Local route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute, self).__init__()

                                self.yang_name = "local-route"
                                self.yang_parent_name = "local-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "local-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "local-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime)}
                                    self._child_list_classes = {}

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")
                                    self._segment_path = lambda: "route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-fail-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-update-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "local-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath)}
                                    self._child_list_classes = {}

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)
                                        self._segment_path = lambda: "sr-microloop-avoidance-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "microloop-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class MulticastIntactBackupRoutes(Entity):
                        """
                        OSPF Route Table Including Multicast intact
                        Backup Paths
                        
                        .. attribute:: multicast_intact_backup_route
                        
                        	OSPF route including multicast backup paths
                        	**type**\: list of    :py:class:`MulticastIntactBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes, self).__init__()

                            self.yang_name = "multicast-intact-backup-routes"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"multicast-intact-backup-route" : ("multicast_intact_backup_route", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute)}

                            self.multicast_intact_backup_route = YList(self)
                            self._segment_path = lambda: "multicast-intact-backup-routes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes, [], name, value)


                        class MulticastIntactBackupRoute(Entity):
                            """
                            OSPF route including multicast backup paths
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__init__()

                                self.yang_name = "multicast-intact-backup-route"
                                self.yang_parent_name = "multicast-intact-backup-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "multicast-intact-backup-route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "multicast-intact-backup-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime)}
                                    self._child_list_classes = {}

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")
                                    self._segment_path = lambda: "route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-fail-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-update-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "multicast-intact-backup-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath)}
                                    self._child_list_classes = {}

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"
                                    self._children_yang_names.add("route-backup-path")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_remote_lfa
                                    
                                    	IP address of remote LFA
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_repair
                                    
                                    	Backup Repair List
                                    	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                    
                                    .. attribute:: backup_repair_list_size
                                    
                                    	Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_tunnel_interface_name
                                    
                                    	Backup Tunnel Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\:  bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair)}

                                        self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                        self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                        self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                        self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                        self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                        self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                        self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                        self.downstream = YLeaf(YType.boolean, "downstream")

                                        self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                        self.node_protect = YLeaf(YType.boolean, "node-protect")

                                        self.primary_path = YLeaf(YType.boolean, "primary-path")

                                        self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                        self.backup_repair = YList(self)
                                        self._segment_path = lambda: "route-backup-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                    class BackupRepair(Entity):
                                        """
                                        Backup Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                            self.yang_name = "backup-repair"
                                            self.yang_parent_name = "route-backup-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "backup-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)
                                        self._segment_path = lambda: "sr-microloop-avoidance-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "microloop-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class MulticastIntactRouteTable(Entity):
                        """
                        OSPF Route Table including multicast\-intact
                        routes
                        
                        .. attribute:: route
                        
                        	An OSPF route
                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable, self).__init__()

                            self.yang_name = "multicast-intact-route-table"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route" : ("route", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route)}

                            self.route = YList(self)
                            self._segment_path = lambda: "multicast-intact-route-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable, [], name, value)


                        class Route(Entity):
                            """
                            An OSPF route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "multicast-intact-route-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime)}
                                    self._child_list_classes = {}

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")
                                    self._segment_path = lambda: "route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-fail-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-update-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath)}
                                    self._child_list_classes = {}

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)
                                        self._segment_path = lambda: "sr-microloop-avoidance-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "microloop-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class RouteAreas(Entity):
                        """
                        OSPF Area Route Table
                        
                        .. attribute:: route_area
                        
                        	OSPF Area Route
                        	**type**\: list of    :py:class:`RouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas, self).__init__()

                            self.yang_name = "route-areas"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route-area" : ("route_area", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea)}

                            self.route_area = YList(self)
                            self._segment_path = lambda: "route-areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas, [], name, value)


                        class RouteArea(Entity):
                            """
                            OSPF Area Route
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: backup_route_areas
                            
                            	OSPF Route Table Including Backup Paths in an area
                            	**type**\:   :py:class:`BackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas>`
                            
                            .. attribute:: connected_route_areas
                            
                            	OSPF Connected Route Table in an area
                            	**type**\:   :py:class:`ConnectedRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas>`
                            
                            .. attribute:: local_route_areas
                            
                            	OSPF Local Route Table
                            	**type**\:   :py:class:`LocalRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas>`
                            
                            .. attribute:: multicast_intact_backup_route_areas
                            
                            	OSPF Route Table Including Multicast Intace Backup Paths in an area
                            	**type**\:   :py:class:`MulticastIntactBackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas>`
                            
                            .. attribute:: multicast_intact_route_areas
                            
                            	OSPF Area multicast\-intact included route entry
                            	**type**\:   :py:class:`MulticastIntactRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas>`
                            
                            .. attribute:: route_area_informations
                            
                            	OSPF Area Route Entry
                            	**type**\:   :py:class:`RouteAreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations>`
                            
                            .. attribute:: summary_area_information
                            
                            	OSPF route summary statistics
                            	**type**\:   :py:class:`SummaryAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea, self).__init__()

                                self.yang_name = "route-area"
                                self.yang_parent_name = "route-areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"backup-route-areas" : ("backup_route_areas", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas), "connected-route-areas" : ("connected_route_areas", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas), "local-route-areas" : ("local_route_areas", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas), "multicast-intact-backup-route-areas" : ("multicast_intact_backup_route_areas", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas), "multicast-intact-route-areas" : ("multicast_intact_route_areas", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas), "route-area-informations" : ("route_area_informations", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations), "summary-area-information" : ("summary_area_information", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation)}
                                self._child_list_classes = {}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.backup_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas()
                                self.backup_route_areas.parent = self
                                self._children_name_map["backup_route_areas"] = "backup-route-areas"
                                self._children_yang_names.add("backup-route-areas")

                                self.connected_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas()
                                self.connected_route_areas.parent = self
                                self._children_name_map["connected_route_areas"] = "connected-route-areas"
                                self._children_yang_names.add("connected-route-areas")

                                self.local_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas()
                                self.local_route_areas.parent = self
                                self._children_name_map["local_route_areas"] = "local-route-areas"
                                self._children_yang_names.add("local-route-areas")

                                self.multicast_intact_backup_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas()
                                self.multicast_intact_backup_route_areas.parent = self
                                self._children_name_map["multicast_intact_backup_route_areas"] = "multicast-intact-backup-route-areas"
                                self._children_yang_names.add("multicast-intact-backup-route-areas")

                                self.multicast_intact_route_areas = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas()
                                self.multicast_intact_route_areas.parent = self
                                self._children_name_map["multicast_intact_route_areas"] = "multicast-intact-route-areas"
                                self._children_yang_names.add("multicast-intact-route-areas")

                                self.route_area_informations = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations()
                                self.route_area_informations.parent = self
                                self._children_name_map["route_area_informations"] = "route-area-informations"
                                self._children_yang_names.add("route-area-informations")

                                self.summary_area_information = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation()
                                self.summary_area_information.parent = self
                                self._children_name_map["summary_area_information"] = "summary-area-information"
                                self._children_yang_names.add("summary-area-information")
                                self._segment_path = lambda: "route-area" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea, ['area_id'], name, value)


                            class BackupRouteAreas(Entity):
                                """
                                OSPF Route Table Including Backup Paths in an
                                area
                                
                                .. attribute:: backup_route_area
                                
                                	OSPF route including backup paths
                                	**type**\: list of    :py:class:`BackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__init__()

                                    self.yang_name = "backup-route-areas"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"backup-route-area" : ("backup_route_area", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea)}

                                    self.backup_route_area = YList(self)
                                    self._segment_path = lambda: "backup-route-areas"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, [], name, value)


                                class BackupRouteArea(Entity):
                                    """
                                    OSPF route including backup paths
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__init__()

                                        self.yang_name = "backup-route-area"
                                        self.yang_parent_name = "backup-route-areas"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "backup-route-area"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "backup-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_backup_path
                                        
                                        	Backup Path Info
                                        	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath>`
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_id
                                        
                                        	Path ID of path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "backup-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath()
                                            self.route_backup_path.parent = self
                                            self._children_name_map["route_backup_path"] = "route-backup-path"
                                            self._children_yang_names.add("route-backup-path")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class RouteBackupPath(Entity):
                                            """
                                            Backup Path Info
                                            
                                            .. attribute:: backup_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_remote_lfa
                                            
                                            	IP address of remote LFA
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_repair
                                            
                                            	Backup Repair List
                                            	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                            
                                            .. attribute:: backup_repair_list_size
                                            
                                            	Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: backup_route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_tunnel_interface_name
                                            
                                            	Backup Tunnel Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: downstream
                                            
                                            	Downstream
                                            	**type**\:  bool
                                            
                                            .. attribute:: line_card_disjoint
                                            
                                            	Line Card Disjoint
                                            	**type**\:  bool
                                            
                                            .. attribute:: node_protect
                                            
                                            	Node Protect
                                            	**type**\:  bool
                                            
                                            .. attribute:: primary_path
                                            
                                            	Primary Path
                                            	**type**\:  bool
                                            
                                            .. attribute:: srlg_disjoint
                                            
                                            	SRLG Disjoint
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                self.yang_name = "route-backup-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair)}

                                                self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                self.downstream = YLeaf(YType.boolean, "downstream")

                                                self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                self.backup_repair = YList(self)
                                                self._segment_path = lambda: "route-backup-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                            class BackupRepair(Entity):
                                                """
                                                Backup Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                    self.yang_name = "backup-repair"
                                                    self.yang_parent_name = "route-backup-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "backup-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                            class ConnectedRouteAreas(Entity):
                                """
                                OSPF Connected Route Table in an area
                                
                                .. attribute:: connected_route_area
                                
                                	Connected route
                                	**type**\: list of    :py:class:`ConnectedRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__init__()

                                    self.yang_name = "connected-route-areas"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"connected-route-area" : ("connected_route_area", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea)}

                                    self.connected_route_area = YList(self)
                                    self._segment_path = lambda: "connected-route-areas"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, [], name, value)


                                class ConnectedRouteArea(Entity):
                                    """
                                    Connected route
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__init__()

                                        self.yang_name = "connected-route-area"
                                        self.yang_parent_name = "connected-route-areas"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "connected-route-area"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "connected-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "connected-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                            class LocalRouteAreas(Entity):
                                """
                                OSPF Local Route Table
                                
                                .. attribute:: local_route_area
                                
                                	Local route
                                	**type**\: list of    :py:class:`LocalRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__init__()

                                    self.yang_name = "local-route-areas"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"local-route-area" : ("local_route_area", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea)}

                                    self.local_route_area = YList(self)
                                    self._segment_path = lambda: "local-route-areas"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, [], name, value)


                                class LocalRouteArea(Entity):
                                    """
                                    Local route
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__init__()

                                        self.yang_name = "local-route-area"
                                        self.yang_parent_name = "local-route-areas"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "local-route-area"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "local-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "local-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                            class MulticastIntactBackupRouteAreas(Entity):
                                """
                                OSPF Route Table Including Multicast Intace
                                Backup Paths in an area
                                
                                .. attribute:: multicast_intact_backup_route_area
                                
                                	OSPF route including Multicast intact backup paths
                                	**type**\: list of    :py:class:`MulticastIntactBackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__init__()

                                    self.yang_name = "multicast-intact-backup-route-areas"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"multicast-intact-backup-route-area" : ("multicast_intact_backup_route_area", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea)}

                                    self.multicast_intact_backup_route_area = YList(self)
                                    self._segment_path = lambda: "multicast-intact-backup-route-areas"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, [], name, value)


                                class MulticastIntactBackupRouteArea(Entity):
                                    """
                                    OSPF route including Multicast intact backup
                                    paths
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__init__()

                                        self.yang_name = "multicast-intact-backup-route-area"
                                        self.yang_parent_name = "multicast-intact-backup-route-areas"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "multicast-intact-backup-route-area"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "multicast-intact-backup-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_backup_path
                                        
                                        	Backup Path Info
                                        	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath>`
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_id
                                        
                                        	Path ID of path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "multicast-intact-backup-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.route_backup_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath()
                                            self.route_backup_path.parent = self
                                            self._children_name_map["route_backup_path"] = "route-backup-path"
                                            self._children_yang_names.add("route-backup-path")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class RouteBackupPath(Entity):
                                            """
                                            Backup Path Info
                                            
                                            .. attribute:: backup_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_remote_lfa
                                            
                                            	IP address of remote LFA
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_repair
                                            
                                            	Backup Repair List
                                            	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                            
                                            .. attribute:: backup_repair_list_size
                                            
                                            	Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: backup_route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: backup_route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_tunnel_interface_name
                                            
                                            	Backup Tunnel Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: downstream
                                            
                                            	Downstream
                                            	**type**\:  bool
                                            
                                            .. attribute:: line_card_disjoint
                                            
                                            	Line Card Disjoint
                                            	**type**\:  bool
                                            
                                            .. attribute:: node_protect
                                            
                                            	Node Protect
                                            	**type**\:  bool
                                            
                                            .. attribute:: primary_path
                                            
                                            	Primary Path
                                            	**type**\:  bool
                                            
                                            .. attribute:: srlg_disjoint
                                            
                                            	SRLG Disjoint
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                self.yang_name = "route-backup-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair)}

                                                self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                self.downstream = YLeaf(YType.boolean, "downstream")

                                                self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                self.backup_repair = YList(self)
                                                self._segment_path = lambda: "route-backup-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                            class BackupRepair(Entity):
                                                """
                                                Backup Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                    self.yang_name = "backup-repair"
                                                    self.yang_parent_name = "route-backup-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "backup-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                            class MulticastIntactRouteAreas(Entity):
                                """
                                OSPF Area multicast\-intact included route
                                entry
                                
                                .. attribute:: multicast_intact_route_area
                                
                                	A Muliticast OSPF route in an area
                                	**type**\: list of    :py:class:`MulticastIntactRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__init__()

                                    self.yang_name = "multicast-intact-route-areas"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"multicast-intact-route-area" : ("multicast_intact_route_area", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea)}

                                    self.multicast_intact_route_area = YList(self)
                                    self._segment_path = lambda: "multicast-intact-route-areas"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, [], name, value)


                                class MulticastIntactRouteArea(Entity):
                                    """
                                    A Muliticast OSPF route in an area
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__init__()

                                        self.yang_name = "multicast-intact-route-area"
                                        self.yang_parent_name = "multicast-intact-route-areas"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "multicast-intact-route-area"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "multicast-intact-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "multicast-intact-route-area"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                            class RouteAreaInformations(Entity):
                                """
                                OSPF Area Route Entry
                                
                                .. attribute:: route_area_information
                                
                                	An OSPF route
                                	**type**\: list of    :py:class:`RouteAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__init__()

                                    self.yang_name = "route-area-informations"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"route-area-information" : ("route_area_information", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation)}

                                    self.route_area_information = YList(self)
                                    self._segment_path = lambda: "route-area-informations"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, [], name, value)


                                class RouteAreaInformation(Entity):
                                    """
                                    An OSPF route
                                    
                                    .. attribute:: prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..32
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__init__()

                                        self.yang_name = "route-area-information"
                                        self.yang_parent_name = "route-area-informations"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath)}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "route-area-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "route-area-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "route-area-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                            class SummaryAreaInformation(Entity):
                                """
                                OSPF route summary statistics
                                
                                .. attribute:: common
                                
                                	OSPF route summary Information
                                	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common>`
                                
                                .. attribute:: failure_address
                                
                                	Last failed address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: failure_time
                                
                                	Last time failed
                                	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime>`
                                
                                .. attribute:: failures
                                
                                	RIB failure count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__init__()

                                    self.yang_name = "summary-area-information"
                                    self.yang_parent_name = "route-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"common" : ("common", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common), "failure-time" : ("failure_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime)}
                                    self._child_list_classes = {}

                                    self.failure_address = YLeaf(YType.str, "failure-address")

                                    self.failures = YLeaf(YType.uint32, "failures")

                                    self.common = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common()
                                    self.common.parent = self
                                    self._children_name_map["common"] = "common"
                                    self._children_yang_names.add("common")

                                    self.failure_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime()
                                    self.failure_time.parent = self
                                    self._children_name_map["failure_time"] = "failure-time"
                                    self._children_yang_names.add("failure-time")
                                    self._segment_path = lambda: "summary-area-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, ['failure_address', 'failures'], name, value)


                                class Common(Entity):
                                    """
                                    OSPF route summary Information
                                    
                                    .. attribute:: external_nssa_type1s
                                    
                                    	External NSSA type 1 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_nssa_type2s
                                    
                                    	External NSSA type 2 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_type1s
                                    
                                    	External type 1 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_type2s
                                    
                                    	External type 2 count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_areas
                                    
                                    	Inter\-area count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_areas
                                    
                                    	Intra\-area count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: total
                                    
                                    	Total count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__init__()

                                        self.yang_name = "common"
                                        self.yang_parent_name = "summary-area-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                        self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                        self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                        self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                        self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                        self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                        self.total = YLeaf(YType.uint32, "total")
                                        self._segment_path = lambda: "common"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, ['external_nssa_type1s', 'external_nssa_type2s', 'external_type1s', 'external_type2s', 'inter_areas', 'intra_areas', 'total'], name, value)


                                class FailureTime(Entity):
                                    """
                                    Last time failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__init__()

                                        self.yang_name = "failure-time"
                                        self.yang_parent_name = "summary-area-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "failure-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, ['nanosecond', 'second'], name, value)


                    class RouteTable(Entity):
                        """
                        OSPF Route Table
                        
                        .. attribute:: route
                        
                        	An OSPF route
                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable, self).__init__()

                            self.yang_name = "route-table"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"route" : ("route", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route)}

                            self.route = YList(self)
                            self._segment_path = lambda: "route-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable, [], name, value)


                        class Route(Entity):
                            """
                            An OSPF route
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..32
                            
                            .. attribute:: route_connected
                            
                            	If true, connected route
                            	**type**\:  bool
                            
                            .. attribute:: route_info
                            
                            	Route information
                            	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo>`
                            
                            .. attribute:: route_metric
                            
                            	Metric
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath>`
                            
                            .. attribute:: route_prefix
                            
                            	Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "route-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo)}
                                self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath)}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_connected = YLeaf(YType.boolean, "route-connected")

                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                self.route_prefix = YLeaf(YType.str, "route-prefix")

                                self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                self.route_type = YLeaf(YType.enumeration, "route-type")

                                self.route_info = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo()
                                self.route_info.parent = self
                                self._children_name_map["route_info"] = "route-info"
                                self._children_yang_names.add("route-info")

                                self.route_path = YList(self)
                                self._segment_path = lambda: "route"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                            class RouteInfo(Entity):
                                """
                                Route information
                                
                                .. attribute:: route_area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_auto_excluded
                                
                                	If true, exclude from TE paths
                                	**type**\:  bool
                                
                                .. attribute:: route_fail_time
                                
                                	Last time update failed
                                	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime>`
                                
                                .. attribute:: route_forward_distance
                                
                                	Forward distance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_rib_version
                                
                                	RIB version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_source
                                
                                	Protocol source
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_spf_priority
                                
                                	SPF priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_spf_version
                                
                                	SPF version
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: route_srte_nbr_registered
                                
                                	SRTE registered neigbhor count on route
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: route_srte_prefix_registered
                                
                                	If true, SRTE registered prefix route
                                	**type**\:  bool
                                
                                .. attribute:: route_te_metric
                                
                                	TE metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_update_time
                                
                                	Last time updated
                                	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo, self).__init__()

                                    self.yang_name = "route-info"
                                    self.yang_parent_name = "route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime)}
                                    self._child_list_classes = {}

                                    self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                    self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                    self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                    self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                    self.route_source = YLeaf(YType.uint16, "route-source")

                                    self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                    self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                    self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                    self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                    self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                    self.route_fail_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime()
                                    self.route_fail_time.parent = self
                                    self._children_name_map["route_fail_time"] = "route-fail-time"
                                    self._children_yang_names.add("route-fail-time")

                                    self.route_update_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime()
                                    self.route_update_time.parent = self
                                    self._children_name_map["route_update_time"] = "route-update-time"
                                    self._children_yang_names.add("route-update-time")
                                    self._segment_path = lambda: "route-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                class RouteFailTime(Entity):
                                    """
                                    Last time update failed
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                        self.yang_name = "route-fail-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-fail-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                class RouteUpdateTime(Entity):
                                    """
                                    Last time updated
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                        self.yang_name = "route-update-time"
                                        self.yang_parent_name = "route-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "route-update-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: area_format
                                
                                	Area format IP or uint32
                                	**type**\:  bool
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type
                                
                                	LSA type, see RFC2328 etc
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: route_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: route_lsaid
                                
                                	LSA ID, see RFC2328
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_is_mcast_intact
                                
                                	Multicast\-intact path
                                	**type**\:  bool
                                
                                .. attribute:: route_path_is_ucmp_path
                                
                                	UCMP path
                                	**type**\:  bool
                                
                                .. attribute:: route_source
                                
                                	IP address of source of route
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_path
                                
                                	SR Microloop avoidance Path Info
                                	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath)}
                                    self._child_list_classes = {}

                                    self.area_format = YLeaf(YType.boolean, "area-format")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                    self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                    self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                    self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                    self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                    self.route_source = YLeaf(YType.str, "route-source")

                                    self.sr_microloop_avoidance_path = Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                    self.sr_microloop_avoidance_path.parent = self
                                    self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                    self._children_yang_names.add("sr-microloop-avoidance-path")
                                    self._segment_path = lambda: "route-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                class SrMicroloopAvoidancePath(Entity):
                                    """
                                    SR Microloop avoidance Path Info
                                    
                                    .. attribute:: microloop_repair
                                    
                                    	Microloop Repair List
                                    	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                    
                                    .. attribute:: microloop_repair_list_size
                                    
                                    	Microloop Repair List Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: microloop_strict_spf
                                    
                                    	Strict SPF SID
                                    	**type**\:  bool
                                    
                                    .. attribute:: microloop_tunnel_interface_name
                                    
                                    	Microloop Tunnel Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                        self.yang_name = "sr-microloop-avoidance-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                        self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                        self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                        self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                        self.microloop_repair = YList(self)
                                        self._segment_path = lambda: "sr-microloop-avoidance-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                    class MicroloopRepair(Entity):
                                        """
                                        Microloop Repair List
                                        
                                        .. attribute:: repair_element_id
                                        
                                        	Repair Element ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: repair_element_type
                                        
                                        	Repair Element Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: repair_label
                                        
                                        	Repair Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                            self.yang_name = "microloop-repair"
                                            self.yang_parent_name = "sr-microloop-avoidance-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                            self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                            self.repair_label = YLeaf(YType.uint32, "repair-label")
                                            self._segment_path = lambda: "microloop-repair"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                    class SummaryInformation(Entity):
                        """
                        OSPF route summary statistics
                        
                        .. attribute:: common
                        
                        	OSPF route summary Information
                        	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common>`
                        
                        .. attribute:: failure_address
                        
                        	Last failed address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: failure_time
                        
                        	Last time failed
                        	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime>`
                        
                        .. attribute:: failures
                        
                        	RIB failure count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation, self).__init__()

                            self.yang_name = "summary-information"
                            self.yang_parent_name = "route-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"common" : ("common", Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common), "failure-time" : ("failure_time", Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime)}
                            self._child_list_classes = {}

                            self.failure_address = YLeaf(YType.str, "failure-address")

                            self.failures = YLeaf(YType.uint32, "failures")

                            self.common = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common()
                            self.common.parent = self
                            self._children_name_map["common"] = "common"
                            self._children_yang_names.add("common")

                            self.failure_time = Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime()
                            self.failure_time.parent = self
                            self._children_name_map["failure_time"] = "failure-time"
                            self._children_yang_names.add("failure-time")
                            self._segment_path = lambda: "summary-information"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation, ['failure_address', 'failures'], name, value)


                        class Common(Entity):
                            """
                            OSPF route summary Information
                            
                            .. attribute:: external_nssa_type1s
                            
                            	External NSSA type 1 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_nssa_type2s
                            
                            	External NSSA type 2 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_type1s
                            
                            	External type 1 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_type2s
                            
                            	External type 2 count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_areas
                            
                            	Inter\-area count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_areas
                            
                            	Intra\-area count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total
                            
                            	Total count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common, self).__init__()

                                self.yang_name = "common"
                                self.yang_parent_name = "summary-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                self.total = YLeaf(YType.uint32, "total")
                                self._segment_path = lambda: "common"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.Common, ['external_nssa_type1s', 'external_nssa_type2s', 'external_type1s', 'external_type2s', 'inter_areas', 'intra_areas', 'total'], name, value)


                        class FailureTime(Entity):
                            """
                            Last time failed
                            
                            .. attribute:: nanosecond
                            
                            	Nanosecond
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: second
                            
                            	Second
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime, self).__init__()

                                self.yang_name = "failure-time"
                                self.yang_parent_name = "summary-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                self.second = YLeaf(YType.uint32, "second")
                                self._segment_path = lambda: "failure-time"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.RouteInformation.SummaryInformation.FailureTime, ['nanosecond', 'second'], name, value)


                class Statistics(Entity):
                    """
                    Container for Statistics
                    
                    .. attribute:: frr_stats
                    
                    	OSPF fast\-reroute statistics
                    	**type**\:   :py:class:`FrrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats>`
                    
                    .. attribute:: interface_stats_entries
                    
                    	Statistics innformation Interface table
                    	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries>`
                    
                    .. attribute:: issu_stats
                    
                    	OSPF ISSU statistics
                    	**type**\:   :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats>`
                    
                    .. attribute:: nsr_pl_stats
                    
                    	OSPF NSR packet library statistics
                    	**type**\:   :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats>`
                    
                    .. attribute:: nsr_stats
                    
                    	OSPF NSR thread statistics
                    	**type**\:   :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats>`
                    
                    .. attribute:: protocol_stats
                    
                    	OSPF Protocol statistics
                    	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats>`
                    
                    .. attribute:: raw_io_stats
                    
                    	OSPF RAW IO statistics
                    	**type**\:   :py:class:`RawIoStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats>`
                    
                    .. attribute:: rib_batch_stats
                    
                    	Stats concerning RIB route updates using the Batching API
                    	**type**\:   :py:class:`RibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats>`
                    
                    .. attribute:: rib_thread_stats
                    
                    	OSPF RIB thread statistics
                    	**type**\:   :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats>`
                    
                    .. attribute:: spf_stats
                    
                    	OSPF SPF statistics
                    	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats>`
                    
                    .. attribute:: te_stats
                    
                    	OSPF TE IO statistics
                    	**type**\:   :py:class:`TeStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.TeStats>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"frr-stats" : ("frr_stats", Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats), "interface-stats-entries" : ("interface_stats_entries", Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries), "issu-stats" : ("issu_stats", Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats), "nsr-pl-stats" : ("nsr_pl_stats", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats), "nsr-stats" : ("nsr_stats", Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats), "protocol-stats" : ("protocol_stats", Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats), "raw-io-stats" : ("raw_io_stats", Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats), "rib-batch-stats" : ("rib_batch_stats", Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats), "rib-thread-stats" : ("rib_thread_stats", Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats), "spf-stats" : ("spf_stats", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats), "te-stats" : ("te_stats", Ospf.Processes.Process.DefaultVrf.Statistics.TeStats)}
                        self._child_list_classes = {}

                        self.frr_stats = Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats()
                        self.frr_stats.parent = self
                        self._children_name_map["frr_stats"] = "frr-stats"
                        self._children_yang_names.add("frr-stats")

                        self.interface_stats_entries = Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries()
                        self.interface_stats_entries.parent = self
                        self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                        self._children_yang_names.add("interface-stats-entries")

                        self.issu_stats = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats()
                        self.issu_stats.parent = self
                        self._children_name_map["issu_stats"] = "issu-stats"
                        self._children_yang_names.add("issu-stats")

                        self.nsr_pl_stats = Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats()
                        self.nsr_pl_stats.parent = self
                        self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                        self._children_yang_names.add("nsr-pl-stats")

                        self.nsr_stats = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats()
                        self.nsr_stats.parent = self
                        self._children_name_map["nsr_stats"] = "nsr-stats"
                        self._children_yang_names.add("nsr-stats")

                        self.protocol_stats = Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats()
                        self.protocol_stats.parent = self
                        self._children_name_map["protocol_stats"] = "protocol-stats"
                        self._children_yang_names.add("protocol-stats")

                        self.raw_io_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats()
                        self.raw_io_stats.parent = self
                        self._children_name_map["raw_io_stats"] = "raw-io-stats"
                        self._children_yang_names.add("raw-io-stats")

                        self.rib_batch_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats()
                        self.rib_batch_stats.parent = self
                        self._children_name_map["rib_batch_stats"] = "rib-batch-stats"
                        self._children_yang_names.add("rib-batch-stats")

                        self.rib_thread_stats = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats()
                        self.rib_thread_stats.parent = self
                        self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                        self._children_yang_names.add("rib-thread-stats")

                        self.spf_stats = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats()
                        self.spf_stats.parent = self
                        self._children_name_map["spf_stats"] = "spf-stats"
                        self._children_yang_names.add("spf-stats")

                        self.te_stats = Ospf.Processes.Process.DefaultVrf.Statistics.TeStats()
                        self.te_stats.parent = self
                        self._children_name_map["te_stats"] = "te-stats"
                        self._children_yang_names.add("te-stats")
                        self._segment_path = lambda: "statistics"


                    class FrrStats(Entity):
                        """
                        OSPF fast\-reroute statistics
                        
                        .. attribute:: fs_paths
                        
                        	Number of IPFRR paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fs_paths_eligible
                        
                        	Number of paths enabled for protection
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fs_paths_protected
                        
                        	Number of paths protected
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats, self).__init__()

                            self.yang_name = "frr-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.fs_paths = YLeaf(YType.uint32, "fs-paths")

                            self.fs_paths_eligible = YLeaf(YType.uint32, "fs-paths-eligible")

                            self.fs_paths_protected = YLeaf(YType.uint32, "fs-paths-protected")
                            self._segment_path = lambda: "frr-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.FrrStats, ['fs_paths', 'fs_paths_eligible', 'fs_paths_protected'], name, value)


                    class InterfaceStatsEntries(Entity):
                        """
                        Statistics innformation Interface table
                        
                        .. attribute:: interface_stats_entry
                        
                        	Statistics information for a specific interface
                        	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries, self).__init__()

                            self.yang_name = "interface-stats-entries"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"interface-stats-entry" : ("interface_stats_entry", Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry)}

                            self.interface_stats_entry = YList(self)
                            self._segment_path = lambda: "interface-stats-entries"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries, [], name, value)


                        class InterfaceStatsEntry(Entity):
                            """
                            Statistics information for a specific interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: handle
                            
                            	interface handle type
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: if_entry
                            
                            	interface entry
                            	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                            
                            .. attribute:: if_name_str
                            
                            	interface name
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                self.yang_name = "interface-stats-entry"
                                self.yang_parent_name = "interface-stats-entries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"if-entry" : ("if_entry", Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.handle = YLeaf(YType.str, "handle")

                                self.if_name_str = YLeaf(YType.str, "if-name-str")

                                self.if_entry = YList(self)
                                self._segment_path = lambda: "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, ['interface_name', 'handle', 'if_name_str'], name, value)


                            class IfEntry(Entity):
                                """
                                interface entry
                                
                                .. attribute:: area_id
                                
                                	OSPF area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_id_str
                                
                                	OSPF aread id string
                                	**type**\:  str
                                
                                .. attribute:: if_stat
                                
                                	OSPF interface statistics
                                	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                
                                .. attribute:: madj_intf
                                
                                	OSPF madj interface
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                    self.yang_name = "if-entry"
                                    self.yang_parent_name = "interface-stats-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"if-stat" : ("if_stat", Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat)}

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.area_id_str = YLeaf(YType.str, "area-id-str")

                                    self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                    self.if_stat = YList(self)
                                    self._segment_path = lambda: "if-entry"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, ['area_id', 'area_id_str', 'madj_intf'], name, value)


                                class IfStat(Entity):
                                    """
                                    OSPF interface statistics
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                        self.yang_name = "if-stat"
                                        self.yang_parent_name = "if-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "if-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, ['entry'], name, value)


                    class IssuStats(Entity):
                        """
                        OSPF ISSU statistics
                        
                        .. attribute:: nsr_conn_to_active_attempts
                        
                        	nsr conn to active attempts
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_closes
                        
                        	nsr conn to active closes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_errors
                        
                        	nsr conn to active errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_fails
                        
                        	nsr conn to active fails
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_opens
                        
                        	nsr conn to active opens
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_fsm_state
                        
                        	nsr fsm state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_intf_seq_no
                        
                        	nsr intf seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_init_sync_pend_count
                        
                        	nsr lsa init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_lsa_qad_mdata_count
                        
                        	nsr lsa qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_qad_qid
                        
                        	nsr lsa qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_mtu
                        
                        	nsr mtu
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_init_sync_pend_count
                        
                        	nsr nbr init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_nbr_qad_mdata_count
                        
                        	nsr nbr qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_qad_qid
                        
                        	nsr nbr qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_seq_no
                        
                        	nsr nbr seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nodeid
                        
                        	nsr nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_nodeid
                        
                        	nsr peer nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_version
                        
                        	nsr peer version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_rev
                        
                        	nsr rev
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_rtr_thd_sched
                        
                        	nsr rtr thd sched
                        	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched>`
                        
                        .. attribute:: nsr_thd_sched
                        
                        	nsr thd sched
                        	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched>`
                        
                        .. attribute:: nsr_tmr_quant
                        
                        	nsr tmr quant
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_version
                        
                        	nsr version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats, self).__init__()

                            self.yang_name = "issu-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"nsr-rtr-thd-sched" : ("nsr_rtr_thd_sched", Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched), "nsr-thd-sched" : ("nsr_thd_sched", Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched)}
                            self._child_list_classes = {}

                            self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                            self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                            self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                            self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                            self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                            self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                            self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                            self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                            self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                            self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                            self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                            self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                            self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                            self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                            self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                            self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                            self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                            self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                            self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                            self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                            self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                            self.nsr_rtr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched()
                            self.nsr_rtr_thd_sched.parent = self
                            self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                            self._children_yang_names.add("nsr-rtr-thd-sched")

                            self.nsr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched()
                            self.nsr_thd_sched.parent = self
                            self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                            self._children_yang_names.add("nsr-thd-sched")
                            self._segment_path = lambda: "issu-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats, ['nsr_conn_to_active_attempts', 'nsr_conn_to_active_closes', 'nsr_conn_to_active_errors', 'nsr_conn_to_active_fails', 'nsr_conn_to_active_opens', 'nsr_fsm_state', 'nsr_intf_seq_no', 'nsr_lsa_init_sync_pend_count', 'nsr_lsa_qad_mdata_count', 'nsr_lsa_qad_qid', 'nsr_mtu', 'nsr_nbr_init_sync_pend_count', 'nsr_nbr_qad_mdata_count', 'nsr_nbr_qad_qid', 'nsr_nbr_seq_no', 'nsr_nodeid', 'nsr_peer_nodeid', 'nsr_peer_version', 'nsr_rev', 'nsr_tmr_quant', 'nsr_version'], name, value)


                        class NsrRtrThdSched(Entity):
                            """
                            nsr rtr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched, self).__init__()

                                self.yang_name = "nsr-rtr-thd-sched"
                                self.yang_parent_name = "issu-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri)}

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)
                                self._segment_path = lambda: "nsr-rtr-thd-sched"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-rtr-thd-sched"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                    self._segment_path = lambda: "nsr-pri"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                        class NsrThdSched(Entity):
                            """
                            nsr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched, self).__init__()

                                self.yang_name = "nsr-thd-sched"
                                self.yang_parent_name = "issu-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri)}

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)
                                self._segment_path = lambda: "nsr-thd-sched"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-thd-sched"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                    self._segment_path = lambda: "nsr-pri"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.IssuStats.NsrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                    class NsrPlStats(Entity):
                        """
                        OSPF NSR packet library statistics
                        
                        .. attribute:: ncd_pri
                        
                        	ncd pri
                        	**type**\: list of    :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats, self).__init__()

                            self.yang_name = "nsr-pl-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ncd-pri" : ("ncd_pri", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri)}

                            self.ncd_pri = YList(self)
                            self._segment_path = lambda: "nsr-pl-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats, [], name, value)


                        class NcdPri(Entity):
                            """
                            ncd pri
                            
                            .. attribute:: num_recv
                            
                            	Total recvd
                            	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv>`
                            
                            .. attribute:: num_recv_drop
                            
                            	Recv Errors/drops
                            	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                            
                            .. attribute:: num_sent
                            
                            	Total sent
                            	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent>`
                            
                            .. attribute:: num_sent_drop
                            
                            	Sent Error/drops
                            	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri, self).__init__()

                                self.yang_name = "ncd-pri"
                                self.yang_parent_name = "nsr-pl-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"num-recv" : ("num_recv", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv), "num-recv-drop" : ("num_recv_drop", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop), "num-sent" : ("num_sent", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent), "num-sent-drop" : ("num_sent_drop", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop)}

                                self.num_recv = YList(self)
                                self.num_recv_drop = YList(self)
                                self.num_sent = YList(self)
                                self.num_sent_drop = YList(self)
                                self._segment_path = lambda: "ncd-pri"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri, [], name, value)


                            class NumRecv(Entity):
                                """
                                Total recvd
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__init__()

                                    self.yang_name = "num-recv"
                                    self.yang_parent_name = "ncd-pri"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint64, "entry")
                                    self._segment_path = lambda: "num-recv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecv, ['entry'], name, value)


                            class NumRecvDrop(Entity):
                                """
                                Recv Errors/drops
                                
                                .. attribute:: nsr_pl_recv_drop_array
                                
                                	nsr pl recv drop array
                                	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__init__()

                                    self.yang_name = "num-recv-drop"
                                    self.yang_parent_name = "ncd-pri"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"nsr-pl-recv-drop-array" : ("nsr_pl_recv_drop_array", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray)}

                                    self.nsr_pl_recv_drop_array = YList(self)
                                    self._segment_path = lambda: "num-recv-drop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, [], name, value)


                                class NsrPlRecvDropArray(Entity):
                                    """
                                    nsr pl recv drop array
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                        self.yang_name = "nsr-pl-recv-drop-array"
                                        self.yang_parent_name = "num-recv-drop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "nsr-pl-recv-drop-array"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, ['entry'], name, value)


                            class NumSent(Entity):
                                """
                                Total sent
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__init__()

                                    self.yang_name = "num-sent"
                                    self.yang_parent_name = "ncd-pri"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.entry = YLeaf(YType.uint64, "entry")
                                    self._segment_path = lambda: "num-sent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSent, ['entry'], name, value)


                            class NumSentDrop(Entity):
                                """
                                Sent Error/drops
                                
                                .. attribute:: nsr_pl_send_drop_array
                                
                                	nsr pl send drop array
                                	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__init__()

                                    self.yang_name = "num-sent-drop"
                                    self.yang_parent_name = "ncd-pri"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"nsr-pl-send-drop-array" : ("nsr_pl_send_drop_array", Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray)}

                                    self.nsr_pl_send_drop_array = YList(self)
                                    self._segment_path = lambda: "num-sent-drop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, [], name, value)


                                class NsrPlSendDropArray(Entity):
                                    """
                                    nsr pl send drop array
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                        self.yang_name = "nsr-pl-send-drop-array"
                                        self.yang_parent_name = "num-sent-drop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "nsr-pl-send-drop-array"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, ['entry'], name, value)


                    class NsrStats(Entity):
                        """
                        OSPF NSR thread statistics
                        
                        .. attribute:: nsr_conn_to_active_attempts
                        
                        	nsr conn to active attempts
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_closes
                        
                        	nsr conn to active closes
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_errors
                        
                        	nsr conn to active errors
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_fails
                        
                        	nsr conn to active fails
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_conn_to_active_opens
                        
                        	nsr conn to active opens
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_fsm_state
                        
                        	nsr fsm state
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_intf_seq_no
                        
                        	nsr intf seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_init_sync_pend_count
                        
                        	nsr lsa init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_lsa_qad_mdata_count
                        
                        	nsr lsa qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_lsa_qad_qid
                        
                        	nsr lsa qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_mtu
                        
                        	nsr mtu
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_init_sync_pend_count
                        
                        	nsr nbr init sync pend count
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_nbr_qad_mdata_count
                        
                        	nsr nbr qad mdata count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_qad_qid
                        
                        	nsr nbr qad qid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nbr_seq_no
                        
                        	nsr nbr seq no
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_nodeid
                        
                        	nsr nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_nodeid
                        
                        	nsr peer nodeid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_peer_version
                        
                        	nsr peer version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_rev
                        
                        	nsr rev
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_rtr_thd_sched
                        
                        	nsr rtr thd sched
                        	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched>`
                        
                        .. attribute:: nsr_thd_sched
                        
                        	nsr thd sched
                        	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched>`
                        
                        .. attribute:: nsr_tmr_quant
                        
                        	nsr tmr quant
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_version
                        
                        	nsr version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats, self).__init__()

                            self.yang_name = "nsr-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"nsr-rtr-thd-sched" : ("nsr_rtr_thd_sched", Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched), "nsr-thd-sched" : ("nsr_thd_sched", Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched)}
                            self._child_list_classes = {}

                            self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                            self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                            self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                            self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                            self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                            self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                            self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                            self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                            self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                            self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                            self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                            self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                            self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                            self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                            self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                            self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                            self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                            self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                            self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                            self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                            self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                            self.nsr_rtr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched()
                            self.nsr_rtr_thd_sched.parent = self
                            self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                            self._children_yang_names.add("nsr-rtr-thd-sched")

                            self.nsr_thd_sched = Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched()
                            self.nsr_thd_sched.parent = self
                            self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                            self._children_yang_names.add("nsr-thd-sched")
                            self._segment_path = lambda: "nsr-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats, ['nsr_conn_to_active_attempts', 'nsr_conn_to_active_closes', 'nsr_conn_to_active_errors', 'nsr_conn_to_active_fails', 'nsr_conn_to_active_opens', 'nsr_fsm_state', 'nsr_intf_seq_no', 'nsr_lsa_init_sync_pend_count', 'nsr_lsa_qad_mdata_count', 'nsr_lsa_qad_qid', 'nsr_mtu', 'nsr_nbr_init_sync_pend_count', 'nsr_nbr_qad_mdata_count', 'nsr_nbr_qad_qid', 'nsr_nbr_seq_no', 'nsr_nodeid', 'nsr_peer_nodeid', 'nsr_peer_version', 'nsr_rev', 'nsr_tmr_quant', 'nsr_version'], name, value)


                        class NsrRtrThdSched(Entity):
                            """
                            nsr rtr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched, self).__init__()

                                self.yang_name = "nsr-rtr-thd-sched"
                                self.yang_parent_name = "nsr-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri)}

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)
                                self._segment_path = lambda: "nsr-rtr-thd-sched"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-rtr-thd-sched"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                    self._segment_path = lambda: "nsr-pri"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                        class NsrThdSched(Entity):
                            """
                            nsr thd sched
                            
                            .. attribute:: nsr_bad_pulses_rx
                            
                            	nsr bad pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_in_q
                            
                            	nsr events in q
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_events_rx
                            
                            	nsr events rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_events_tx
                            
                            	nsr events tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_good_pulses_rx
                            
                            	nsr good pulses rx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pri
                            
                            	nsr pri
                            	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri>`
                            
                            .. attribute:: nsr_pulse_quant
                            
                            	nsr pulse quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_pulse_tx_fails
                            
                            	nsr pulse tx fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_pulses_tx
                            
                            	nsr pulses tx
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched, self).__init__()

                                self.yang_name = "nsr-thd-sched"
                                self.yang_parent_name = "nsr-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri)}

                                self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                self.nsr_pri = YList(self)
                                self._segment_path = lambda: "nsr-thd-sched"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                            class NsrPri(Entity):
                                """
                                nsr pri
                                
                                .. attribute:: nsr_sched_enq_fails
                                
                                	nsr sched enq fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_deqd
                                
                                	nsr sched evs deqd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_evs_in_q
                                
                                	nsr sched evs in q
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_evs_qd
                                
                                	nsr sched evs qd
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_sched_max_evs
                                
                                	nsr sched max evs
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_peak_q_len
                                
                                	nsr sched peak q len
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: nsr_sched_pri
                                
                                	nsr sched pri
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_sched_quant
                                
                                	nsr sched quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: nsr_sched_remain_quant
                                
                                	nsr sched remain quant
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__init__()

                                    self.yang_name = "nsr-pri"
                                    self.yang_parent_name = "nsr-thd-sched"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                    self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                    self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                    self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                    self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                    self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                    self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                    self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                    self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                    self._segment_path = lambda: "nsr-pri"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.NsrStats.NsrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                    class ProtocolStats(Entity):
                        """
                        OSPF Protocol statistics
                        
                        .. attribute:: checksumerr
                        
                        	checksumerr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_ack
                        
                        	h input ack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_dbdes
                        
                        	h input dbdes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_lsupd
                        
                        	h input lsupd
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: h_input_req
                        
                        	h input req
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_ack
                        
                        	input ack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_ack_lsa
                        
                        	input ack lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_autherr
                        
                        	input autherr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_dbdes
                        
                        	input dbdes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_dbdes_lsa
                        
                        	input dbdes lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_hello
                        
                        	input hello
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_lsupd
                        
                        	input lsupd
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_lsupd_lsa
                        
                        	input lsupd lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_req
                        
                        	input req
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: input_req_lsa
                        
                        	input req lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inputs
                        
                        	inputs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_ack
                        
                        	output ack
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_ack_lsa
                        
                        	output ack lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_autherr
                        
                        	output autherr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_dbdes
                        
                        	output dbdes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_dbdes_lsa
                        
                        	output dbdes lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_hello
                        
                        	output hello
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_lsupd
                        
                        	output lsupd
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_lsupd_lsa
                        
                        	output lsupd lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_req
                        
                        	output req
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: output_req_lsa
                        
                        	output req lsa
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: outputs
                        
                        	outputs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats, self).__init__()

                            self.yang_name = "protocol-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.checksumerr = YLeaf(YType.uint32, "checksumerr")

                            self.h_input_ack = YLeaf(YType.uint32, "h-input-ack")

                            self.h_input_dbdes = YLeaf(YType.uint32, "h-input-dbdes")

                            self.h_input_lsupd = YLeaf(YType.uint32, "h-input-lsupd")

                            self.h_input_req = YLeaf(YType.uint32, "h-input-req")

                            self.input_ack = YLeaf(YType.uint32, "input-ack")

                            self.input_ack_lsa = YLeaf(YType.uint32, "input-ack-lsa")

                            self.input_autherr = YLeaf(YType.uint32, "input-autherr")

                            self.input_dbdes = YLeaf(YType.uint32, "input-dbdes")

                            self.input_dbdes_lsa = YLeaf(YType.uint32, "input-dbdes-lsa")

                            self.input_hello = YLeaf(YType.uint32, "input-hello")

                            self.input_lsupd = YLeaf(YType.uint32, "input-lsupd")

                            self.input_lsupd_lsa = YLeaf(YType.uint32, "input-lsupd-lsa")

                            self.input_req = YLeaf(YType.uint32, "input-req")

                            self.input_req_lsa = YLeaf(YType.uint32, "input-req-lsa")

                            self.inputs = YLeaf(YType.uint32, "inputs")

                            self.output_ack = YLeaf(YType.uint32, "output-ack")

                            self.output_ack_lsa = YLeaf(YType.uint32, "output-ack-lsa")

                            self.output_autherr = YLeaf(YType.uint32, "output-autherr")

                            self.output_dbdes = YLeaf(YType.uint32, "output-dbdes")

                            self.output_dbdes_lsa = YLeaf(YType.uint32, "output-dbdes-lsa")

                            self.output_hello = YLeaf(YType.uint32, "output-hello")

                            self.output_lsupd = YLeaf(YType.uint32, "output-lsupd")

                            self.output_lsupd_lsa = YLeaf(YType.uint32, "output-lsupd-lsa")

                            self.output_req = YLeaf(YType.uint32, "output-req")

                            self.output_req_lsa = YLeaf(YType.uint32, "output-req-lsa")

                            self.outputs = YLeaf(YType.uint32, "outputs")
                            self._segment_path = lambda: "protocol-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.ProtocolStats, ['checksumerr', 'h_input_ack', 'h_input_dbdes', 'h_input_lsupd', 'h_input_req', 'input_ack', 'input_ack_lsa', 'input_autherr', 'input_dbdes', 'input_dbdes_lsa', 'input_hello', 'input_lsupd', 'input_lsupd_lsa', 'input_req', 'input_req_lsa', 'inputs', 'output_ack', 'output_ack_lsa', 'output_autherr', 'output_dbdes', 'output_dbdes_lsa', 'output_hello', 'output_lsupd', 'output_lsupd_lsa', 'output_req', 'output_req_lsa', 'outputs'], name, value)


                    class RawIoStats(Entity):
                        """
                        OSPF RAW IO statistics
                        
                        .. attribute:: disconnects
                        
                        	disconnects
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_bytes_rcv
                        
                        	in bytes rcv
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_no_mem_discarded
                        
                        	in no mem discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_raw_event
                        
                        	in raw event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_rcv
                        
                        	in rcv
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_short_msg_discarded
                        
                        	in short msg discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: in_standby_discarded
                        
                        	in standby discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_not_ready_discarded
                        
                        	nsr not ready discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_bytes_sent
                        
                        	out bytes sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_ipv4_hdr_err_discarded
                        
                        	out ipv4 hdr err discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_no_conn_discarded
                        
                        	out no conn discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_no_pak_discarded
                        
                        	out no pak discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_null_src_discarded
                        
                        	out null src discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_send_pak_err_discarded
                        
                        	out send pak err discarded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_sent
                        
                        	out sent
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: raw_connected
                        
                        	raw connected
                        	**type**\:  bool
                        
                        .. attribute:: sl_raw_connected
                        
                        	sl raw connected
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats, self).__init__()

                            self.yang_name = "raw-io-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.disconnects = YLeaf(YType.uint32, "disconnects")

                            self.in_bytes_rcv = YLeaf(YType.uint32, "in-bytes-rcv")

                            self.in_no_mem_discarded = YLeaf(YType.uint32, "in-no-mem-discarded")

                            self.in_raw_event = YLeaf(YType.uint32, "in-raw-event")

                            self.in_rcv = YLeaf(YType.uint32, "in-rcv")

                            self.in_short_msg_discarded = YLeaf(YType.uint32, "in-short-msg-discarded")

                            self.in_standby_discarded = YLeaf(YType.uint32, "in-standby-discarded")

                            self.nsr_not_ready_discarded = YLeaf(YType.uint32, "nsr-not-ready-discarded")

                            self.out_bytes_sent = YLeaf(YType.uint32, "out-bytes-sent")

                            self.out_ipv4_hdr_err_discarded = YLeaf(YType.uint32, "out-ipv4-hdr-err-discarded")

                            self.out_no_conn_discarded = YLeaf(YType.uint32, "out-no-conn-discarded")

                            self.out_no_pak_discarded = YLeaf(YType.uint32, "out-no-pak-discarded")

                            self.out_null_src_discarded = YLeaf(YType.uint32, "out-null-src-discarded")

                            self.out_send_pak_err_discarded = YLeaf(YType.uint32, "out-send-pak-err-discarded")

                            self.out_sent = YLeaf(YType.uint32, "out-sent")

                            self.raw_connected = YLeaf(YType.boolean, "raw-connected")

                            self.sl_raw_connected = YLeaf(YType.boolean, "sl-raw-connected")
                            self._segment_path = lambda: "raw-io-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RawIoStats, ['disconnects', 'in_bytes_rcv', 'in_no_mem_discarded', 'in_raw_event', 'in_rcv', 'in_short_msg_discarded', 'in_standby_discarded', 'nsr_not_ready_discarded', 'out_bytes_sent', 'out_ipv4_hdr_err_discarded', 'out_no_conn_discarded', 'out_no_pak_discarded', 'out_null_src_discarded', 'out_send_pak_err_discarded', 'out_sent', 'raw_connected', 'sl_raw_connected'], name, value)


                    class RibBatchStats(Entity):
                        """
                        Stats concerning RIB route updates using the
                        Batching API
                        
                        .. attribute:: priority_batch
                        
                        	priority batch
                        	**type**\: list of    :py:class:`PriorityBatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats, self).__init__()

                            self.yang_name = "rib-batch-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"priority-batch" : ("priority_batch", Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch)}

                            self.priority_batch = YList(self)
                            self._segment_path = lambda: "rib-batch-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats, [], name, value)


                        class PriorityBatch(Entity):
                            """
                            priority batch
                            
                            .. attribute:: batches_sent
                            
                            	batches sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_add
                            
                            	lfas add
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_del
                            
                            	lfas del
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_pending
                            
                            	lfas pending
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lfas_sent
                            
                            	lfas sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_routes
                            
                            	max routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add
                            
                            	paths add
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add_errs
                            
                            	paths add errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del
                            
                            	paths del
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del_errs
                            
                            	paths del errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_pending
                            
                            	paths pending
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_sent
                            
                            	paths sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: priority_level
                            
                            	priority level
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: routes_pending
                            
                            	routes pending
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_sent
                            
                            	routes sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch, self).__init__()

                                self.yang_name = "priority-batch"
                                self.yang_parent_name = "rib-batch-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                                self.lfas_add = YLeaf(YType.uint32, "lfas-add")

                                self.lfas_del = YLeaf(YType.uint32, "lfas-del")

                                self.lfas_pending = YLeaf(YType.uint32, "lfas-pending")

                                self.lfas_sent = YLeaf(YType.uint32, "lfas-sent")

                                self.max_routes = YLeaf(YType.uint32, "max-routes")

                                self.paths_add = YLeaf(YType.uint32, "paths-add")

                                self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                                self.paths_del = YLeaf(YType.uint32, "paths-del")

                                self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                                self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                                self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                                self.priority_level = YLeaf(YType.str, "priority-level")

                                self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                                self.routes_sent = YLeaf(YType.uint32, "routes-sent")
                                self._segment_path = lambda: "priority-batch"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibBatchStats.PriorityBatch, ['batches_sent', 'lfas_add', 'lfas_del', 'lfas_pending', 'lfas_sent', 'max_routes', 'paths_add', 'paths_add_errs', 'paths_del', 'paths_del_errs', 'paths_pending', 'paths_sent', 'priority_level', 'routes_pending', 'routes_sent'], name, value)


                    class RibThreadStats(Entity):
                        """
                        OSPF RIB thread statistics
                        
                        .. attribute:: internalwq
                        
                        	internalwq
                        	**type**\:   :py:class:`Internalwq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq>`
                        
                        .. attribute:: ribqueue
                        
                        	ribqueue
                        	**type**\: list of    :py:class:`Ribqueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats, self).__init__()

                            self.yang_name = "rib-thread-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"internalwq" : ("internalwq", Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq)}
                            self._child_list_classes = {"ribqueue" : ("ribqueue", Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue)}

                            self.internalwq = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq()
                            self.internalwq.parent = self
                            self._children_name_map["internalwq"] = "internalwq"
                            self._children_yang_names.add("internalwq")

                            self.ribqueue = YList(self)
                            self._segment_path = lambda: "rib-thread-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats, [], name, value)


                        class Internalwq(Entity):
                            """
                            internalwq
                            
                            .. attribute:: priority_level
                            
                            	priority level
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: rib_base_clock
                            
                            	rib base clock
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: rib_base_time
                            
                            	rib base time
                            	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime>`
                            
                            .. attribute:: rib_dequeue_errs
                            
                            	rib dequeue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_after
                            
                            	rib drop after
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_before
                            
                            	rib drop before
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_conn
                            
                            	rib drop conn
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_empty_batches
                            
                            	rib empty batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pfx_limit_errs
                            
                            	rib pfx limit errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pkts_sent
                            
                            	rib pkts sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_queue_errs
                            
                            	rib queue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_send_errs
                            
                            	rib send errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_signals
                            
                            	rib signals
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_table_not_created
                            
                            	rib table not created
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_version
                            
                            	rib version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_dqtime
                            
                            	wq dqtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: wq_len_cur
                            
                            	wq len cur
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_len_max
                            
                            	wq len max
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_thread_active
                            
                            	wq thread active
                            	**type**\:  bool
                            
                            .. attribute:: wq_total_dequeued
                            
                            	wq total dequeued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_total_queued
                            
                            	wq total queued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wqe_qtime
                            
                            	wqe qtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq, self).__init__()

                                self.yang_name = "internalwq"
                                self.yang_parent_name = "rib-thread-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"rib-base-time" : ("rib_base_time", Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime)}
                                self._child_list_classes = {}

                                self.priority_level = YLeaf(YType.str, "priority-level")

                                self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                self.rib_version = YLeaf(YType.uint32, "rib-version")

                                self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                self.rib_base_time = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime()
                                self.rib_base_time.parent = self
                                self._children_name_map["rib_base_time"] = "rib-base-time"
                                self._children_yang_names.add("rib-base-time")
                                self._segment_path = lambda: "internalwq"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq, ['priority_level', 'rib_base_clock', 'rib_dequeue_errs', 'rib_drop_after', 'rib_drop_before', 'rib_drop_conn', 'rib_empty_batches', 'rib_pfx_limit_errs', 'rib_pkts_sent', 'rib_queue_errs', 'rib_send_errs', 'rib_signals', 'rib_table_not_created', 'rib_version', 'wq_dqtime', 'wq_len_cur', 'wq_len_max', 'wq_thread_active', 'wq_total_dequeued', 'wq_total_queued', 'wqe_qtime'], name, value)


                            class RibBaseTime(Entity):
                                """
                                rib base time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__init__()

                                    self.yang_name = "rib-base-time"
                                    self.yang_parent_name = "internalwq"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "rib-base-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, ['nanosecond', 'second'], name, value)


                        class Ribqueue(Entity):
                            """
                            ribqueue
                            
                            .. attribute:: priority_level
                            
                            	priority level
                            	**type**\:  str
                            
                            	**length:** 0..40
                            
                            .. attribute:: rib_base_clock
                            
                            	rib base clock
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: rib_base_time
                            
                            	rib base time
                            	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime>`
                            
                            .. attribute:: rib_dequeue_errs
                            
                            	rib dequeue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_after
                            
                            	rib drop after
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_before
                            
                            	rib drop before
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_drop_conn
                            
                            	rib drop conn
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_empty_batches
                            
                            	rib empty batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pfx_limit_errs
                            
                            	rib pfx limit errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_pkts_sent
                            
                            	rib pkts sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_queue_errs
                            
                            	rib queue errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_send_errs
                            
                            	rib send errs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_signals
                            
                            	rib signals
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_table_not_created
                            
                            	rib table not created
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_version
                            
                            	rib version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_dqtime
                            
                            	wq dqtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: wq_len_cur
                            
                            	wq len cur
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_len_max
                            
                            	wq len max
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: wq_thread_active
                            
                            	wq thread active
                            	**type**\:  bool
                            
                            .. attribute:: wq_total_dequeued
                            
                            	wq total dequeued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wq_total_queued
                            
                            	wq total queued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wqe_qtime
                            
                            	wqe qtime
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue, self).__init__()

                                self.yang_name = "ribqueue"
                                self.yang_parent_name = "rib-thread-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"rib-base-time" : ("rib_base_time", Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime)}
                                self._child_list_classes = {}

                                self.priority_level = YLeaf(YType.str, "priority-level")

                                self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                self.rib_version = YLeaf(YType.uint32, "rib-version")

                                self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                self.rib_base_time = Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime()
                                self.rib_base_time.parent = self
                                self._children_name_map["rib_base_time"] = "rib-base-time"
                                self._children_yang_names.add("rib-base-time")
                                self._segment_path = lambda: "ribqueue"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue, ['priority_level', 'rib_base_clock', 'rib_dequeue_errs', 'rib_drop_after', 'rib_drop_before', 'rib_drop_conn', 'rib_empty_batches', 'rib_pfx_limit_errs', 'rib_pkts_sent', 'rib_queue_errs', 'rib_send_errs', 'rib_signals', 'rib_table_not_created', 'rib_version', 'wq_dqtime', 'wq_len_cur', 'wq_len_max', 'wq_thread_active', 'wq_total_dequeued', 'wq_total_queued', 'wqe_qtime'], name, value)


                            class RibBaseTime(Entity):
                                """
                                rib base time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__init__()

                                    self.yang_name = "rib-base-time"
                                    self.yang_parent_name = "ribqueue"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "rib-base-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, ['nanosecond', 'second'], name, value)


                    class SpfStats(Entity):
                        """
                        OSPF SPF statistics
                        
                        .. attribute:: os_ex_runtime
                        
                        	os ex runtime
                        	**type**\: list of    :py:class:`OsExRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime>`
                        
                        .. attribute:: os_runtime
                        
                        	os runtime
                        	**type**\: list of    :py:class:`OsRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime>`
                        
                        .. attribute:: os_sum_runtime
                        
                        	os sum runtime
                        	**type**\: list of    :py:class:`OsSumRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime>`
                        
                        .. attribute:: runtime
                        
                        	runtime
                        	**type**\: list of    :py:class:`Runtime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime>`
                        
                        .. attribute:: spf_header
                        
                        	spf header
                        	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats, self).__init__()

                            self.yang_name = "spf-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"spf-header" : ("spf_header", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader)}
                            self._child_list_classes = {"os-ex-runtime" : ("os_ex_runtime", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime), "os-runtime" : ("os_runtime", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime), "os-sum-runtime" : ("os_sum_runtime", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime), "runtime" : ("runtime", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime)}

                            self.spf_header = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader()
                            self.spf_header.parent = self
                            self._children_name_map["spf_header"] = "spf-header"
                            self._children_yang_names.add("spf-header")

                            self.os_ex_runtime = YList(self)
                            self.os_runtime = YList(self)
                            self.os_sum_runtime = YList(self)
                            self.runtime = YList(self)
                            self._segment_path = lambda: "spf-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats, [], name, value)


                        class OsExRuntime(Entity):
                            """
                            os ex runtime
                            
                            .. attribute:: sp_adv_rtr_id
                            
                            	sp adv rtr id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_addr
                            
                            	sp dest addr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_count
                            
                            	sp dest count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_duration
                            
                            	sp duration
                            	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration>`
                            
                            .. attribute:: sp_start_time
                            
                            	sp start time
                            	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime, self).__init__()

                                self.yang_name = "os-ex-runtime"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sp-duration" : ("sp_duration", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration), "sp-start-time" : ("sp_start_time", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime)}
                                self._child_list_classes = {}

                                self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                self.sp_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration()
                                self.sp_duration.parent = self
                                self._children_name_map["sp_duration"] = "sp-duration"
                                self._children_yang_names.add("sp-duration")

                                self.sp_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime()
                                self.sp_start_time.parent = self
                                self._children_name_map["sp_start_time"] = "sp-start-time"
                                self._children_yang_names.add("sp-start-time")
                                self._segment_path = lambda: "os-ex-runtime"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime, ['sp_adv_rtr_id', 'sp_dest_addr', 'sp_dest_count'], name, value)


                            class SpDuration(Entity):
                                """
                                sp duration
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__init__()

                                    self.yang_name = "sp-duration"
                                    self.yang_parent_name = "os-ex-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "sp-duration"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpDuration, ['nanosecond', 'second'], name, value)


                            class SpStartTime(Entity):
                                """
                                sp start time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__init__()

                                    self.yang_name = "sp-start-time"
                                    self.yang_parent_name = "os-ex-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "sp-start-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsExRuntime.SpStartTime, ['nanosecond', 'second'], name, value)


                        class OsRuntime(Entity):
                            """
                            os runtime
                            
                            .. attribute:: si_area_id_str
                            
                            	si area id str
                            	**type**\:  str
                            
                            .. attribute:: si_change_flags
                            
                            	si change flags
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: si_duration
                            
                            	si duration
                            	**type**\:   :py:class:`SiDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration>`
                            
                            .. attribute:: si_start_time
                            
                            	si start time
                            	**type**\:   :py:class:`SiStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime, self).__init__()

                                self.yang_name = "os-runtime"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"si-duration" : ("si_duration", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration), "si-start-time" : ("si_start_time", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime)}
                                self._child_list_classes = {}

                                self.si_area_id_str = YLeaf(YType.str, "si-area-id-str")

                                self.si_change_flags = YLeaf(YType.uint16, "si-change-flags")

                                self.si_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration()
                                self.si_duration.parent = self
                                self._children_name_map["si_duration"] = "si-duration"
                                self._children_yang_names.add("si-duration")

                                self.si_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime()
                                self.si_start_time.parent = self
                                self._children_name_map["si_start_time"] = "si-start-time"
                                self._children_yang_names.add("si-start-time")
                                self._segment_path = lambda: "os-runtime"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime, ['si_area_id_str', 'si_change_flags'], name, value)


                            class SiDuration(Entity):
                                """
                                si duration
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__init__()

                                    self.yang_name = "si-duration"
                                    self.yang_parent_name = "os-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "si-duration"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiDuration, ['nanosecond', 'second'], name, value)


                            class SiStartTime(Entity):
                                """
                                si start time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__init__()

                                    self.yang_name = "si-start-time"
                                    self.yang_parent_name = "os-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "si-start-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsRuntime.SiStartTime, ['nanosecond', 'second'], name, value)


                        class OsSumRuntime(Entity):
                            """
                            os sum runtime
                            
                            .. attribute:: sp_adv_rtr_id
                            
                            	sp adv rtr id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_addr
                            
                            	sp dest addr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_dest_count
                            
                            	sp dest count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_duration
                            
                            	sp duration
                            	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration>`
                            
                            .. attribute:: sp_start_time
                            
                            	sp start time
                            	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime, self).__init__()

                                self.yang_name = "os-sum-runtime"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"sp-duration" : ("sp_duration", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration), "sp-start-time" : ("sp_start_time", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime)}
                                self._child_list_classes = {}

                                self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                self.sp_duration = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration()
                                self.sp_duration.parent = self
                                self._children_name_map["sp_duration"] = "sp-duration"
                                self._children_yang_names.add("sp-duration")

                                self.sp_start_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime()
                                self.sp_start_time.parent = self
                                self._children_name_map["sp_start_time"] = "sp-start-time"
                                self._children_yang_names.add("sp-start-time")
                                self._segment_path = lambda: "os-sum-runtime"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime, ['sp_adv_rtr_id', 'sp_dest_addr', 'sp_dest_count'], name, value)


                            class SpDuration(Entity):
                                """
                                sp duration
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__init__()

                                    self.yang_name = "sp-duration"
                                    self.yang_parent_name = "os-sum-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "sp-duration"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpDuration, ['nanosecond', 'second'], name, value)


                            class SpStartTime(Entity):
                                """
                                sp start time
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__init__()

                                    self.yang_name = "sp-start-time"
                                    self.yang_parent_name = "os-sum-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "sp-start-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, ['nanosecond', 'second'], name, value)


                        class Runtime(Entity):
                            """
                            runtime
                            
                            .. attribute:: area_stat
                            
                            	area stat
                            	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat>`
                            
                            .. attribute:: gbl_spf_time
                            
                            	gbl spf time
                            	**type**\:   :py:class:`GblSpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime>`
                            
                            .. attribute:: lsa_change_cnt
                            
                            	lsa change cnt
                            	**type**\:  int
                            
                            	**range:** \-32768..32767
                            
                            .. attribute:: lsa_info
                            
                            	lsa info
                            	**type**\: list of    :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo>`
                            
                            .. attribute:: spf_start_time
                            
                            	spf start time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime, self).__init__()

                                self.yang_name = "runtime"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"gbl-spf-time" : ("gbl_spf_time", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime)}
                                self._child_list_classes = {"area-stat" : ("area_stat", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat), "lsa-info" : ("lsa_info", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo)}

                                self.lsa_change_cnt = YLeaf(YType.int16, "lsa-change-cnt")

                                self.spf_start_time = YLeaf(YType.uint32, "spf-start-time")

                                self.gbl_spf_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime()
                                self.gbl_spf_time.parent = self
                                self._children_name_map["gbl_spf_time"] = "gbl-spf-time"
                                self._children_yang_names.add("gbl-spf-time")

                                self.area_stat = YList(self)
                                self.lsa_info = YList(self)
                                self._segment_path = lambda: "runtime"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime, ['lsa_change_cnt', 'spf_start_time'], name, value)


                            class AreaStat(Entity):
                                """
                                area stat
                                
                                .. attribute:: area_id
                                
                                	area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_type_cnt
                                
                                	lsa type cnt
                                	**type**\: list of    :py:class:`LsaTypeCnt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt>`
                                
                                .. attribute:: spf_time
                                
                                	spf time
                                	**type**\:   :py:class:`SpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat, self).__init__()

                                    self.yang_name = "area-stat"
                                    self.yang_parent_name = "runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"spf-time" : ("spf_time", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime)}
                                    self._child_list_classes = {"lsa-type-cnt" : ("lsa_type_cnt", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt)}

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.spf_time = Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime()
                                    self.spf_time.parent = self
                                    self._children_name_map["spf_time"] = "spf-time"
                                    self._children_yang_names.add("spf-time")

                                    self.lsa_type_cnt = YList(self)
                                    self._segment_path = lambda: "area-stat"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat, ['area_id'], name, value)


                                class LsaTypeCnt(Entity):
                                    """
                                    lsa type cnt
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__init__()

                                        self.yang_name = "lsa-type-cnt"
                                        self.yang_parent_name = "area-stat"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "lsa-type-cnt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, ['entry'], name, value)


                                class SpfTime(Entity):
                                    """
                                    spf time
                                    
                                    .. attribute:: spf_dijkstra
                                    
                                    	spf dijkstra
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix
                                    
                                    	spf ext prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix_del
                                    
                                    	spf ext prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix
                                    
                                    	spf inter prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix_del
                                    
                                    	spf inter prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix
                                    
                                    	spf intra prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix_del
                                    
                                    	spf intra prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__init__()

                                        self.yang_name = "spf-time"
                                        self.yang_parent_name = "area-stat"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                        self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                        self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                        self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                        self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                        self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                        self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")
                                        self._segment_path = lambda: "spf-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, ['spf_dijkstra', 'spf_ext_prefix', 'spf_ext_prefix_del', 'spf_inter_prefix', 'spf_inter_prefix_del', 'spf_intra_prefix', 'spf_intra_prefix_del'], name, value)


                            class GblSpfTime(Entity):
                                """
                                gbl spf time
                                
                                .. attribute:: spf_dijkstra
                                
                                	spf dijkstra
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_ext_prefix
                                
                                	spf ext prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_ext_prefix_del
                                
                                	spf ext prefix del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_inter_prefix
                                
                                	spf inter prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_inter_prefix_del
                                
                                	spf inter prefix del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_intra_prefix
                                
                                	spf intra prefix
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_intra_prefix_del
                                
                                	spf intra prefix del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__init__()

                                    self.yang_name = "gbl-spf-time"
                                    self.yang_parent_name = "runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                    self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                    self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                    self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                    self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                    self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                    self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")
                                    self._segment_path = lambda: "gbl-spf-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.GblSpfTime, ['spf_dijkstra', 'spf_ext_prefix', 'spf_ext_prefix_del', 'spf_inter_prefix', 'spf_inter_prefix_del', 'spf_intra_prefix', 'spf_intra_prefix_del'], name, value)


                            class LsaInfo(Entity):
                                """
                                lsa info
                                
                                .. attribute:: adv_rtr
                                
                                	adv rtr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flush
                                
                                	flush
                                	**type**\:  bool
                                
                                .. attribute:: id
                                
                                	id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo, self).__init__()

                                    self.yang_name = "lsa-info"
                                    self.yang_parent_name = "runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.adv_rtr = YLeaf(YType.str, "adv-rtr")

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.flush = YLeaf(YType.boolean, "flush")

                                    self.id = YLeaf(YType.str, "id")

                                    self.type = YLeaf(YType.uint8, "type")
                                    self._segment_path = lambda: "lsa-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.Runtime.LsaInfo, ['adv_rtr', 'area_id', 'flush', 'id', 'type'], name, value)


                        class SpfHeader(Entity):
                            """
                            spf header
                            
                            .. attribute:: area_summ
                            
                            	area summ
                            	**type**\: list of    :py:class:`AreaSumm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm>`
                            
                            .. attribute:: router_id
                            
                            	router id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: spf_count
                            
                            	spf count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader, self).__init__()

                                self.yang_name = "spf-header"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-summ" : ("area_summ", Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm)}

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.spf_count = YLeaf(YType.uint32, "spf-count")

                                self.area_summ = YList(self)
                                self._segment_path = lambda: "spf-header"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader, ['router_id', 'spf_count'], name, value)


                            class AreaSumm(Entity):
                                """
                                area summ
                                
                                .. attribute:: area_id
                                
                                	area id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_count
                                
                                	spf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__init__()

                                    self.yang_name = "area-summ"
                                    self.yang_parent_name = "spf-header"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.area_id = YLeaf(YType.uint32, "area-id")

                                    self.spf_count = YLeaf(YType.uint32, "spf-count")
                                    self._segment_path = lambda: "area-summ"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.SpfStats.SpfHeader.AreaSumm, ['area_id', 'spf_count'], name, value)


                    class TeStats(Entity):
                        """
                        OSPF TE IO statistics
                        
                        .. attribute:: adj_changes
                        
                        	adj changes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: adj_gets
                        
                        	adj gets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: control_batch_reads
                        
                        	control batch reads
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: control_batch_writes
                        
                        	control batch writes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: control_disconnects
                        
                        	control disconnects
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: data_trans_completes
                        
                        	data trans completes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fragment_announces
                        
                        	fragment announces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fragment_deletes
                        
                        	fragment deletes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_batch_reads
                        
                        	link batch reads
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_batch_writes
                        
                        	link batch writes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_floods
                        
                        	link floods
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_fragment_floods
                        
                        	link fragment floods
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsp_gets
                        
                        	lsp gets
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_br_lkup_num_dests
                        
                        	pce br lkup num dests
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_br_lookup
                        
                        	pce br lookup
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_br_resp_fails
                        
                        	pce br resp fails
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_flood
                        
                        	pce flood
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_get
                        
                        	pce get
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_listen
                        
                        	pce listen
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_node_announce_batches
                        
                        	pce node announce batches
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_node_delete_batches
                        
                        	pce node delete batches
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_node_send_fails
                        
                        	pce node send fails
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_num_node_announce
                        
                        	pce num node announce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_num_node_delete
                        
                        	pce num node delete
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pce_stoplisten
                        
                        	pce stoplisten
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_num_area_enabled
                        
                        	sr num area enabled
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: te_connected
                        
                        	te connected
                        	**type**\:  bool
                        
                        .. attribute:: te_disconnects
                        
                        	te disconnects
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: te_sr_idt_sent
                        
                        	te sr idt sent
                        	**type**\:  bool
                        
                        .. attribute:: te_sr_path_reg_idt_recvd
                        
                        	te sr path reg idt recvd
                        	**type**\:  bool
                        
                        .. attribute:: total_tunnels
                        
                        	total tunnels
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_announces
                        
                        	tunnel announces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.Statistics.TeStats, self).__init__()

                            self.yang_name = "te-stats"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.adj_changes = YLeaf(YType.uint32, "adj-changes")

                            self.adj_gets = YLeaf(YType.uint32, "adj-gets")

                            self.control_batch_reads = YLeaf(YType.uint32, "control-batch-reads")

                            self.control_batch_writes = YLeaf(YType.uint32, "control-batch-writes")

                            self.control_disconnects = YLeaf(YType.uint32, "control-disconnects")

                            self.data_trans_completes = YLeaf(YType.uint32, "data-trans-completes")

                            self.fragment_announces = YLeaf(YType.uint32, "fragment-announces")

                            self.fragment_deletes = YLeaf(YType.uint32, "fragment-deletes")

                            self.link_batch_reads = YLeaf(YType.uint32, "link-batch-reads")

                            self.link_batch_writes = YLeaf(YType.uint32, "link-batch-writes")

                            self.link_floods = YLeaf(YType.uint32, "link-floods")

                            self.link_fragment_floods = YLeaf(YType.uint32, "link-fragment-floods")

                            self.lsp_gets = YLeaf(YType.uint32, "lsp-gets")

                            self.pce_br_lkup_num_dests = YLeaf(YType.uint32, "pce-br-lkup-num-dests")

                            self.pce_br_lookup = YLeaf(YType.uint32, "pce-br-lookup")

                            self.pce_br_resp_fails = YLeaf(YType.uint32, "pce-br-resp-fails")

                            self.pce_flood = YLeaf(YType.uint32, "pce-flood")

                            self.pce_get = YLeaf(YType.uint32, "pce-get")

                            self.pce_listen = YLeaf(YType.uint32, "pce-listen")

                            self.pce_node_announce_batches = YLeaf(YType.uint32, "pce-node-announce-batches")

                            self.pce_node_delete_batches = YLeaf(YType.uint32, "pce-node-delete-batches")

                            self.pce_node_send_fails = YLeaf(YType.uint32, "pce-node-send-fails")

                            self.pce_num_node_announce = YLeaf(YType.uint32, "pce-num-node-announce")

                            self.pce_num_node_delete = YLeaf(YType.uint32, "pce-num-node-delete")

                            self.pce_stoplisten = YLeaf(YType.uint32, "pce-stoplisten")

                            self.sr_num_area_enabled = YLeaf(YType.uint32, "sr-num-area-enabled")

                            self.te_connected = YLeaf(YType.boolean, "te-connected")

                            self.te_disconnects = YLeaf(YType.uint32, "te-disconnects")

                            self.te_sr_idt_sent = YLeaf(YType.boolean, "te-sr-idt-sent")

                            self.te_sr_path_reg_idt_recvd = YLeaf(YType.boolean, "te-sr-path-reg-idt-recvd")

                            self.total_tunnels = YLeaf(YType.uint32, "total-tunnels")

                            self.tunnel_announces = YLeaf(YType.uint32, "tunnel-announces")
                            self._segment_path = lambda: "te-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.Statistics.TeStats, ['adj_changes', 'adj_gets', 'control_batch_reads', 'control_batch_writes', 'control_disconnects', 'data_trans_completes', 'fragment_announces', 'fragment_deletes', 'link_batch_reads', 'link_batch_writes', 'link_floods', 'link_fragment_floods', 'lsp_gets', 'pce_br_lkup_num_dests', 'pce_br_lookup', 'pce_br_resp_fails', 'pce_flood', 'pce_get', 'pce_listen', 'pce_node_announce_batches', 'pce_node_delete_batches', 'pce_node_send_fails', 'pce_num_node_announce', 'pce_num_node_delete', 'pce_stoplisten', 'sr_num_area_enabled', 'te_connected', 'te_disconnects', 'te_sr_idt_sent', 'te_sr_path_reg_idt_recvd', 'total_tunnels', 'tunnel_announces'], name, value)


                class SummaryPrefixes(Entity):
                    """
                    Summary prefix table
                    
                    .. attribute:: summary_prefix
                    
                    	Summary prefix information
                    	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, self).__init__()

                        self.yang_name = "summary-prefixes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"summary-prefix" : ("summary_prefix", Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix)}

                        self.summary_prefix = YList(self)
                        self._segment_path = lambda: "summary-prefixes"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes, [], name, value)


                    class SummaryPrefix(Entity):
                        """
                        Summary prefix information
                        
                        .. attribute:: netmask
                        
                        	Summary Mask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix
                        
                        	Summary Prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: summary_mask
                        
                        	Summary Netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: summary_metric
                        
                        	Cost of Summary
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: summary_metric_type
                        
                        	Type of Metric
                        	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: summary_tag
                        
                        	Tag associated with this summary prefix
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                            self.yang_name = "summary-prefix"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.summary_mask = YLeaf(YType.str, "summary-mask")

                            self.summary_metric = YLeaf(YType.uint32, "summary-metric")

                            self.summary_metric_type = YLeaf(YType.enumeration, "summary-metric-type")

                            self.summary_prefix = YLeaf(YType.str, "summary-prefix")

                            self.summary_tag = YLeaf(YType.uint32, "summary-tag")
                            self._segment_path = lambda: "summary-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, ['netmask', 'prefix', 'summary_mask', 'summary_metric', 'summary_metric_type', 'summary_prefix', 'summary_tag'], name, value)


            class Srms(Entity):
                """
                Segment Routing Mapping Server operational
                data
                
                .. attribute:: policy
                
                	Policy operational data
                	**type**\:   :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy>`
                
                

                """

                _prefix = 'ipv4-ospf-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(Ospf.Processes.Process.Srms, self).__init__()

                    self.yang_name = "srms"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"policy" : ("policy", Ospf.Processes.Process.Srms.Policy)}
                    self._child_list_classes = {}

                    self.policy = Ospf.Processes.Process.Srms.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"
                    self._children_yang_names.add("policy")
                    self._segment_path = lambda: "srms"


                class Policy(Entity):
                    """
                    Policy operational data
                    
                    .. attribute:: policy_ipv4
                    
                    	IPv4 policy operational data
                    	**type**\:   :py:class:`PolicyIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.Srms.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "srms"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"policy-ipv4" : ("policy_ipv4", Ospf.Processes.Process.Srms.Policy.PolicyIpv4)}
                        self._child_list_classes = {}

                        self.policy_ipv4 = Ospf.Processes.Process.Srms.Policy.PolicyIpv4()
                        self.policy_ipv4.parent = self
                        self._children_name_map["policy_ipv4"] = "policy-ipv4"
                        self._children_yang_names.add("policy-ipv4")
                        self._segment_path = lambda: "policy"


                    class PolicyIpv4(Entity):
                        """
                        IPv4 policy operational data
                        
                        .. attribute:: policy_ipv4_active
                        
                        	IPv4 active policy operational data
                        	**type**\:   :py:class:`PolicyIpv4Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active>`
                        
                        .. attribute:: policy_ipv4_backup
                        
                        	IPv4 backup policy operational data
                        	**type**\:   :py:class:`PolicyIpv4Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4, self).__init__()

                            self.yang_name = "policy-ipv4"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"policy-ipv4-active" : ("policy_ipv4_active", Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active), "policy-ipv4-backup" : ("policy_ipv4_backup", Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup)}
                            self._child_list_classes = {}

                            self.policy_ipv4_active = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active()
                            self.policy_ipv4_active.parent = self
                            self._children_name_map["policy_ipv4_active"] = "policy-ipv4-active"
                            self._children_yang_names.add("policy-ipv4-active")

                            self.policy_ipv4_backup = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup()
                            self.policy_ipv4_backup.parent = self
                            self._children_name_map["policy_ipv4_backup"] = "policy-ipv4-backup"
                            self._children_yang_names.add("policy-ipv4-backup")
                            self._segment_path = lambda: "policy-ipv4"


                        class PolicyIpv4Active(Entity):
                            """
                            IPv4 active policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__init__()

                                self.yang_name = "policy-ipv4-active"
                                self.yang_parent_name = "policy-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"policy-mi" : ("policy_mi", Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi)}

                                self.policy_mi = YList(self)
                                self._segment_path = lambda: "policy-ipv4-active"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active, [], name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-active"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"addr" : ("addr", Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr)}
                                    self._child_list_classes = {}

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")
                                    self._segment_path = lambda: "policy-mi" + "[mi-id='" + self.mi_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, ['mi_id', 'area', 'flag_attached', 'last_prefix', 'last_sid_index', 'prefix', 'router', 'sid_count', 'sid_start', 'src'], name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, ['af', 'ipv4', 'ipv6'], name, value)


                        class PolicyIpv4Backup(Entity):
                            """
                            IPv4 backup policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of    :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__init__()

                                self.yang_name = "policy-ipv4-backup"
                                self.yang_parent_name = "policy-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"policy-mi" : ("policy_mi", Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi)}

                                self.policy_mi = YList(self)
                                self._segment_path = lambda: "policy-ipv4-backup"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, [], name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  <key>
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:   :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr>`
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:   :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiFlagEB>`
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**length:** 0..30
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:   :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiSrcEB>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"addr" : ("addr", Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr)}
                                    self._child_list_classes = {}

                                    self.mi_id = YLeaf(YType.str, "mi-id")

                                    self.area = YLeaf(YType.str, "area")

                                    self.flag_attached = YLeaf(YType.enumeration, "flag-attached")

                                    self.last_prefix = YLeaf(YType.str, "last-prefix")

                                    self.last_sid_index = YLeaf(YType.uint32, "last-sid-index")

                                    self.prefix = YLeaf(YType.uint8, "prefix")

                                    self.router = YLeaf(YType.str, "router")

                                    self.sid_count = YLeaf(YType.uint32, "sid-count")

                                    self.sid_start = YLeaf(YType.uint32, "sid-start")

                                    self.src = YLeaf(YType.enumeration, "src")

                                    self.addr = Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._children_yang_names.add("addr")
                                    self._segment_path = lambda: "policy-mi" + "[mi-id='" + self.mi_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, ['mi_id', 'area', 'flag_attached', 'last_prefix', 'last_sid_index', 'prefix', 'router', 'sid_count', 'sid_start', 'src'], name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:   :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.af = YLeaf(YType.enumeration, "af")

                                        self.ipv4 = YLeaf(YType.str, "ipv4")

                                        self.ipv6 = YLeaf(YType.str, "ipv6")
                                        self._segment_path = lambda: "addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, ['af', 'ipv4', 'ipv6'], name, value)


            class Vrfs(Entity):
                """
                Table for each VRF
                
                .. attribute:: vrf
                
                	Operational data for a particular VRF (instance) in the OSPF process
                	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv4-ospf-oper'
                _revision = '2017-05-01'

                def __init__(self):
                    super(Ospf.Processes.Process.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"vrf" : ("vrf", Ospf.Processes.Process.Vrfs.Vrf)}

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospf.Processes.Process.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for a particular VRF
                    (instance) in the OSPF process
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF Name
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: adjacency_information
                    
                    	Container for OSPF Interfaces
                    	**type**\:   :py:class:`AdjacencyInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation>`
                    
                    .. attribute:: area_statistics
                    
                    	Container for Statistics
                    	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics>`
                    
                    .. attribute:: areas
                    
                    	Area table
                    	**type**\:   :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas>`
                    
                    .. attribute:: border_routers
                    
                    	Border router table
                    	**type**\:   :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.BorderRouters>`
                    
                    .. attribute:: database
                    
                    	OSPF Link State Database
                    	**type**\:   :py:class:`Database <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database>`
                    
                    .. attribute:: fast_reroute
                    
                    	Container for FastReroute
                    	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute>`
                    
                    .. attribute:: flood_list_table
                    
                    	Flood list table
                    	**type**\:   :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable>`
                    
                    .. attribute:: interface_information
                    
                    	Container for OSPF Interfaces/links
                    	**type**\:   :py:class:`InterfaceInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation>`
                    
                    .. attribute:: interface_vrf_information
                    
                    	Container for OSPF Interfaces/links under a VRF
                    	**type**\:   :py:class:`InterfaceVrfInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation>`
                    
                    .. attribute:: mpls_te
                    
                    	Container for MPLS TE
                    	**type**\:   :py:class:`MplsTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe>`
                    
                    .. attribute:: ospf_summary
                    
                    	Fast\-reroute topology information
                    	**type**\:   :py:class:`OspfSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.OspfSummary>`
                    
                    .. attribute:: process_information
                    
                    	Container for OSPF Process information
                    	**type**\:   :py:class:`ProcessInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation>`
                    
                    .. attribute:: route_information
                    
                    	Container for OSPF routing tables
                    	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation>`
                    
                    .. attribute:: statistics
                    
                    	Container for Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics>`
                    
                    .. attribute:: summary_prefixes
                    
                    	Summary prefix table
                    	**type**\:   :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    

                    """

                    _prefix = 'ipv4-ospf-oper'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(Ospf.Processes.Process.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"adjacency-information" : ("adjacency_information", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation), "area-statistics" : ("area_statistics", Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics), "areas" : ("areas", Ospf.Processes.Process.Vrfs.Vrf.Areas), "border-routers" : ("border_routers", Ospf.Processes.Process.Vrfs.Vrf.BorderRouters), "database" : ("database", Ospf.Processes.Process.Vrfs.Vrf.Database), "fast-reroute" : ("fast_reroute", Ospf.Processes.Process.Vrfs.Vrf.FastReroute), "flood-list-table" : ("flood_list_table", Ospf.Processes.Process.Vrfs.Vrf.FloodListTable), "interface-information" : ("interface_information", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation), "interface-vrf-information" : ("interface_vrf_information", Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation), "mpls-te" : ("mpls_te", Ospf.Processes.Process.Vrfs.Vrf.MplsTe), "ospf-summary" : ("ospf_summary", Ospf.Processes.Process.Vrfs.Vrf.OspfSummary), "process-information" : ("process_information", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation), "route-information" : ("route_information", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation), "statistics" : ("statistics", Ospf.Processes.Process.Vrfs.Vrf.Statistics), "summary-prefixes" : ("summary_prefixes", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes)}
                        self._child_list_classes = {}

                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                        self.adjacency_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation()
                        self.adjacency_information.parent = self
                        self._children_name_map["adjacency_information"] = "adjacency-information"
                        self._children_yang_names.add("adjacency-information")

                        self.area_statistics = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics()
                        self.area_statistics.parent = self
                        self._children_name_map["area_statistics"] = "area-statistics"
                        self._children_yang_names.add("area-statistics")

                        self.areas = Ospf.Processes.Process.Vrfs.Vrf.Areas()
                        self.areas.parent = self
                        self._children_name_map["areas"] = "areas"
                        self._children_yang_names.add("areas")

                        self.border_routers = Ospf.Processes.Process.Vrfs.Vrf.BorderRouters()
                        self.border_routers.parent = self
                        self._children_name_map["border_routers"] = "border-routers"
                        self._children_yang_names.add("border-routers")

                        self.database = Ospf.Processes.Process.Vrfs.Vrf.Database()
                        self.database.parent = self
                        self._children_name_map["database"] = "database"
                        self._children_yang_names.add("database")

                        self.fast_reroute = Ospf.Processes.Process.Vrfs.Vrf.FastReroute()
                        self.fast_reroute.parent = self
                        self._children_name_map["fast_reroute"] = "fast-reroute"
                        self._children_yang_names.add("fast-reroute")

                        self.flood_list_table = Ospf.Processes.Process.Vrfs.Vrf.FloodListTable()
                        self.flood_list_table.parent = self
                        self._children_name_map["flood_list_table"] = "flood-list-table"
                        self._children_yang_names.add("flood-list-table")

                        self.interface_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation()
                        self.interface_information.parent = self
                        self._children_name_map["interface_information"] = "interface-information"
                        self._children_yang_names.add("interface-information")

                        self.interface_vrf_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation()
                        self.interface_vrf_information.parent = self
                        self._children_name_map["interface_vrf_information"] = "interface-vrf-information"
                        self._children_yang_names.add("interface-vrf-information")

                        self.mpls_te = Ospf.Processes.Process.Vrfs.Vrf.MplsTe()
                        self.mpls_te.parent = self
                        self._children_name_map["mpls_te"] = "mpls-te"
                        self._children_yang_names.add("mpls-te")

                        self.ospf_summary = Ospf.Processes.Process.Vrfs.Vrf.OspfSummary()
                        self.ospf_summary.parent = self
                        self._children_name_map["ospf_summary"] = "ospf-summary"
                        self._children_yang_names.add("ospf-summary")

                        self.process_information = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation()
                        self.process_information.parent = self
                        self._children_name_map["process_information"] = "process-information"
                        self._children_yang_names.add("process-information")

                        self.route_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation()
                        self.route_information.parent = self
                        self._children_name_map["route_information"] = "route-information"
                        self._children_yang_names.add("route-information")

                        self.statistics = Ospf.Processes.Process.Vrfs.Vrf.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"
                        self._children_yang_names.add("statistics")

                        self.summary_prefixes = Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self._children_name_map["summary_prefixes"] = "summary-prefixes"
                        self._children_yang_names.add("summary-prefixes")
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf, ['vrf_name'], name, value)


                    class AdjacencyInformation(Entity):
                        """
                        Container for OSPF Interfaces
                        
                        .. attribute:: neighbor_details
                        
                        	Neighbor detail table
                        	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails>`
                        
                        .. attribute:: neighbors
                        
                        	Neighbor table
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors>`
                        
                        .. attribute:: requests
                        
                        	Request List table
                        	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests>`
                        
                        .. attribute:: retransmissions
                        
                        	Retransmission list table
                        	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation, self).__init__()

                            self.yang_name = "adjacency-information"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"neighbor-details" : ("neighbor_details", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails), "neighbors" : ("neighbors", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors), "requests" : ("requests", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests), "retransmissions" : ("retransmissions", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions)}
                            self._child_list_classes = {}

                            self.neighbor_details = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails()
                            self.neighbor_details.parent = self
                            self._children_name_map["neighbor_details"] = "neighbor-details"
                            self._children_yang_names.add("neighbor-details")

                            self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.requests = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests()
                            self.requests.parent = self
                            self._children_name_map["requests"] = "requests"
                            self._children_yang_names.add("requests")

                            self.retransmissions = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions()
                            self.retransmissions.parent = self
                            self._children_name_map["retransmissions"] = "retransmissions"
                            self._children_yang_names.add("retransmissions")
                            self._segment_path = lambda: "adjacency-information"


                        class NeighborDetails(Entity):
                            """
                            Neighbor detail table
                            
                            .. attribute:: neighbor_detail
                            
                            	A single neighbor's detail information
                            	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails, self).__init__()

                                self.yang_name = "neighbor-details"
                                self.yang_parent_name = "adjacency-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail)}

                                self.neighbor_detail = YList(self)
                                self._segment_path = lambda: "neighbor-details"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails, [], name, value)


                            class NeighborDetail(Entity):
                                """
                                A single neighbor's detail information
                                
                                .. attribute:: adjacency_sid_label
                                
                                	SR Adjacency SID Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adjacency_sid_protected
                                
                                	SR Adjacency SID Protected
                                	**type**\:  bool
                                
                                .. attribute:: adjacency_sid_unprotected_label
                                
                                	SR Adjacency SID Unprotected Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: last_oob_time
                                
                                	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: lfa_interface
                                
                                	LFA Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: lfa_neighbor_id
                                
                                	LFA Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lfa_neighbor_revision
                                
                                	LFA Neighbor Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfa_next_hop
                                
                                	LFA Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_area_id
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_filter
                                
                                	If true, filter outgoing LSAs
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Interface ID of neighbor recived via LLS
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_lls_option
                                
                                	This is a bitmask of Link Local signalling options received from the neighbor
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmaks of neighbor's option field received
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_retransmission_information
                                
                                	Retransmission information with this neighbor
                                	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                                
                                .. attribute:: neighbor_summary
                                
                                	Neighbor summary information
                                	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary>`
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nsf_router_state
                                
                                	For cisco NSF, the router is either Requester or Receiver
                                	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                                
                                .. attribute:: oob_resynchronization
                                
                                	Out\-Of\-Bound resynchronization in progress
                                	**type**\:  bool
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state_change_count
                                
                                	Number of state changes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-details"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation), "neighbor-retransmission-information" : ("neighbor_retransmission_information", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation), "neighbor-summary" : ("neighbor_summary", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary)}
                                    self._child_list_classes = {}

                                    self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                    self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                    self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                    self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                    self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                    self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                    self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                    self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                    self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                    self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                    self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                    self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                    self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                    self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                    self.neighbor_interface_id = YLeaf(YType.uint16, "neighbor-interface-id")

                                    self.neighbor_lls_option = YLeaf(YType.uint32, "neighbor-lls-option")

                                    self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                    self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                    self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                    self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                    self.pending_events = YLeaf(YType.uint16, "pending-events")

                                    self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                    self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")

                                    self.neighbor_retransmission_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                    self.neighbor_retransmission_information.parent = self
                                    self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                    self._children_yang_names.add("neighbor-retransmission-information")

                                    self.neighbor_summary = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary()
                                    self.neighbor_summary.parent = self
                                    self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                    self._children_yang_names.add("neighbor-summary")
                                    self._segment_path = lambda: "neighbor-detail"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail, ['adjacency_sid_label', 'adjacency_sid_protected', 'adjacency_sid_unprotected_label', 'interface_name', 'interface_type', 'last_oob_time', 'lfa_interface', 'lfa_neighbor_id', 'lfa_neighbor_revision', 'lfa_next_hop', 'neighbor_ack_list_count', 'neighbor_ack_list_high_watermark', 'neighbor_address', 'neighbor_area_id', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_filter', 'neighbor_interface_id', 'neighbor_lls_option', 'neighbor_option', 'next_poll_interval', 'nsf_router_state', 'oob_resynchronization', 'pending_events', 'poll_interval', 'state_change_count'], name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                class NeighborRetransmissionInformation(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: area_first_flood_information
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_information_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flooding_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_information_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_information_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_information_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_count
                                    
                                    	Number of DBD retransmissions during last exchange
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dbd_retransmission_total_count
                                    
                                    	Total number of DBD retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                        self.yang_name = "neighbor-retransmission-information"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                        self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                        self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                        self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                        self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                        self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                        self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                        self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                        self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                        self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                        self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                        self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                        self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                        self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                        self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                        self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                        self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                        self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                        self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                        self._segment_path = lambda: "neighbor-retransmission-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                                class NeighborSummary(Entity):
                                    """
                                    Neighbor summary information
                                    
                                    .. attribute:: dr_bdr_state
                                    
                                    	Designated Router state
                                    	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_name
                                    
                                    	Interface via which the neighbor is seen
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: neighbor_madj_interface
                                    
                                    	Interface is MADJ
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                        self.yang_name = "neighbor-summary"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation)}
                                        self._child_list_classes = {}

                                        self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                        self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                        self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")
                                        self._segment_path = lambda: "neighbor-summary"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary, ['dr_bdr_state', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                            self._segment_path = lambda: "neighbor-bfd-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                        class Neighbors(Entity):
                            """
                            Neighbor table
                            
                            .. attribute:: neighbor
                            
                            	Neighbor information
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "adjacency-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor)}

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                Neighbor information
                                
                                .. attribute:: dr_bdr_state
                                
                                	Designated Router state
                                	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_bfd_information
                                
                                	Neighbor BFD information
                                	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation>`
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_name
                                
                                	Interface via which the neighbor is seen
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_madj_interface
                                
                                	Interface is MADJ
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation)}
                                    self._child_list_classes = {}

                                    self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                    self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                    self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                    self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                    self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                    self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                    self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                    self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                    self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation()
                                    self.neighbor_bfd_information.parent = self
                                    self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                    self._children_yang_names.add("neighbor-bfd-information")
                                    self._segment_path = lambda: "neighbor"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor, ['dr_bdr_state', 'interface_name', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                class NeighborBfdInformation(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                        self.yang_name = "neighbor-bfd-information"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                        self._segment_path = lambda: "neighbor-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Neighbors.Neighbor.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                        class Requests(Entity):
                            """
                            Request List table
                            
                            .. attribute:: request
                            
                            	Request list for a particular adjacency
                            	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests, self).__init__()

                                self.yang_name = "requests"
                                self.yang_parent_name = "adjacency-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request)}

                                self.request = YList(self)
                                self._segment_path = lambda: "requests"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests, [], name, value)


                            class Request(Entity):
                                """
                                Request list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request>`
                                
                                .. attribute:: request_interface_name
                                
                                	Request list interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "requests"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                    self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                    self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                    self.request = YList(self)
                                    self._segment_path = lambda: "request"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request, ['interface_name', 'neighbor_address', 'request_interface_name', 'request_neighbor_address', 'request_neighbor_id'], name, value)


                                class Request(Entity):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "request"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Requests.Request.Request, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                        class Retransmissions(Entity):
                            """
                            Retransmission list table
                            
                            .. attribute:: retransmission
                            
                            	Retransmission list for a particular adjacency
                            	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions, self).__init__()

                                self.yang_name = "retransmissions"
                                self.yang_parent_name = "adjacency-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"retransmission" : ("retransmission", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission)}

                                self.retransmission = YList(self)
                                self._segment_path = lambda: "retransmissions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions, [], name, value)


                            class Retransmission(Entity):
                                """
                                Retransmission list for a particular adjacency
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of Area scope entries
                                	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS Scope entries
                                	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb>`
                                
                                .. attribute:: retransmission_count
                                
                                	Retransmission queue length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_interface_name
                                
                                	Retransmission list interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: retransmission_neighbor_id
                                
                                	Neighbor ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_neighbor_ip_address
                                
                                	Neighbor IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission, self).__init__()

                                    self.yang_name = "retransmission"
                                    self.yang_parent_name = "retransmissions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                    self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                    self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                    self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                    self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                    self.retransmission_area_db = YList(self)
                                    self.retransmission_asdb = YList(self)
                                    self._segment_path = lambda: "retransmission"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission, ['interface_name', 'neighbor_address', 'retransmission_count', 'retransmission_interface_name', 'retransmission_neighbor_id', 'retransmission_neighbor_ip_address', 'retransmission_timer'], name, value)


                                class RetransmissionAreaDb(Entity):
                                    """
                                    List of Area scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                        self.yang_name = "retransmission-area-db"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmission-area-db"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                                class RetransmissionAsdb(Entity):
                                    """
                                    List of AS Scope entries
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_ls_id
                                    
                                    	LSA ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_checksum
                                    
                                    	Checksum of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA Type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                        self.yang_name = "retransmission-asdb"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                        self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                        self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                        self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                        self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                        self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                        self._segment_path = lambda: "retransmission-asdb"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AdjacencyInformation.Retransmissions.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class AreaStatistics(Entity):
                        """
                        Container for Statistics
                        
                        .. attribute:: interface_stats_entries
                        
                        	Statistics innformation Interface table
                        	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics, self).__init__()

                            self.yang_name = "area-statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"interface-stats-entries" : ("interface_stats_entries", Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries)}
                            self._child_list_classes = {}

                            self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries()
                            self.interface_stats_entries.parent = self
                            self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                            self._children_yang_names.add("interface-stats-entries")
                            self._segment_path = lambda: "area-statistics"


                        class InterfaceStatsEntries(Entity):
                            """
                            Statistics innformation Interface table
                            
                            .. attribute:: interface_stats_entry
                            
                            	Statistics information for a specific interface
                            	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries, self).__init__()

                                self.yang_name = "interface-stats-entries"
                                self.yang_parent_name = "area-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface-stats-entry" : ("interface_stats_entry", Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry)}

                                self.interface_stats_entry = YList(self)
                                self._segment_path = lambda: "interface-stats-entries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries, [], name, value)


                            class InterfaceStatsEntry(Entity):
                                """
                                Statistics information for a specific interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: handle
                                
                                	interface handle type
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: if_entry
                                
                                	interface entry
                                	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                
                                .. attribute:: if_name_str
                                
                                	interface name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                    self.yang_name = "interface-stats-entry"
                                    self.yang_parent_name = "interface-stats-entries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"if-entry" : ("if_entry", Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.handle = YLeaf(YType.str, "handle")

                                    self.if_name_str = YLeaf(YType.str, "if-name-str")

                                    self.if_entry = YList(self)
                                    self._segment_path = lambda: "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, ['interface_name', 'handle', 'if_name_str'], name, value)


                                class IfEntry(Entity):
                                    """
                                    interface entry
                                    
                                    .. attribute:: area_id
                                    
                                    	OSPF area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_id_str
                                    
                                    	OSPF aread id string
                                    	**type**\:  str
                                    
                                    .. attribute:: if_stat
                                    
                                    	OSPF interface statistics
                                    	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                    
                                    .. attribute:: madj_intf
                                    
                                    	OSPF madj interface
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                        self.yang_name = "if-entry"
                                        self.yang_parent_name = "interface-stats-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"if-stat" : ("if_stat", Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat)}

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.area_id_str = YLeaf(YType.str, "area-id-str")

                                        self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                        self.if_stat = YList(self)
                                        self._segment_path = lambda: "if-entry"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, ['area_id', 'area_id_str', 'madj_intf'], name, value)


                                    class IfStat(Entity):
                                        """
                                        OSPF interface statistics
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                            self.yang_name = "if-stat"
                                            self.yang_parent_name = "if-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "if-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, ['entry'], name, value)


                    class Areas(Entity):
                        """
                        Area table
                        
                        .. attribute:: area
                        
                        	Container for per area data
                        	**type**\: list of    :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas, self).__init__()

                            self.yang_name = "areas"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"area" : ("area", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area)}

                            self.area = YList(self)
                            self._segment_path = lambda: "areas"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas, [], name, value)


                        class Area(Entity):
                            """
                            Container for per area data
                            
                            .. attribute:: area_id  <key>
                            
                            	Area ID
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: area_statistics
                            
                            	Container for Statistics
                            	**type**\:   :py:class:`AreaStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics>`
                            
                            .. attribute:: flood_list_area_table
                            
                            	Area specific flood list table
                            	**type**\:   :py:class:`FloodListAreaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable>`
                            
                            .. attribute:: interface_briefs
                            
                            	OSPF Interface Brief Table
                            	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs>`
                            
                            .. attribute:: interfaces
                            
                            	OSPF Interface Table
                            	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces>`
                            
                            .. attribute:: neighbor_details
                            
                            	Neighbor detail table
                            	**type**\:   :py:class:`NeighborDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails>`
                            
                            .. attribute:: neighbors
                            
                            	Neighbor table
                            	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors>`
                            
                            .. attribute:: requests
                            
                            	Request List table
                            	**type**\:   :py:class:`Requests <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests>`
                            
                            .. attribute:: retransmissions
                            
                            	Retransmission list table
                            	**type**\:   :py:class:`Retransmissions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"area-statistics" : ("area_statistics", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics), "flood-list-area-table" : ("flood_list_area_table", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable), "interface-briefs" : ("interface_briefs", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs), "interfaces" : ("interfaces", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces), "neighbor-details" : ("neighbor_details", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails), "neighbors" : ("neighbors", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors), "requests" : ("requests", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests), "retransmissions" : ("retransmissions", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions)}
                                self._child_list_classes = {}

                                self.area_id = YLeaf(YType.int32, "area-id")

                                self.area_statistics = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics()
                                self.area_statistics.parent = self
                                self._children_name_map["area_statistics"] = "area-statistics"
                                self._children_yang_names.add("area-statistics")

                                self.flood_list_area_table = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable()
                                self.flood_list_area_table.parent = self
                                self._children_name_map["flood_list_area_table"] = "flood-list-area-table"
                                self._children_yang_names.add("flood-list-area-table")

                                self.interface_briefs = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs()
                                self.interface_briefs.parent = self
                                self._children_name_map["interface_briefs"] = "interface-briefs"
                                self._children_yang_names.add("interface-briefs")

                                self.interfaces = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces()
                                self.interfaces.parent = self
                                self._children_name_map["interfaces"] = "interfaces"
                                self._children_yang_names.add("interfaces")

                                self.neighbor_details = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails()
                                self.neighbor_details.parent = self
                                self._children_name_map["neighbor_details"] = "neighbor-details"
                                self._children_yang_names.add("neighbor-details")

                                self.neighbors = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors()
                                self.neighbors.parent = self
                                self._children_name_map["neighbors"] = "neighbors"
                                self._children_yang_names.add("neighbors")

                                self.requests = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests()
                                self.requests.parent = self
                                self._children_name_map["requests"] = "requests"
                                self._children_yang_names.add("requests")

                                self.retransmissions = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions()
                                self.retransmissions.parent = self
                                self._children_name_map["retransmissions"] = "retransmissions"
                                self._children_yang_names.add("retransmissions")
                                self._segment_path = lambda: "area" + "[area-id='" + self.area_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area, ['area_id'], name, value)


                            class AreaStatistics(Entity):
                                """
                                Container for Statistics
                                
                                .. attribute:: interface_stats_entries
                                
                                	Statistics innformation Interface table
                                	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics, self).__init__()

                                    self.yang_name = "area-statistics"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"interface-stats-entries" : ("interface_stats_entries", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries)}
                                    self._child_list_classes = {}

                                    self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries()
                                    self.interface_stats_entries.parent = self
                                    self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                                    self._children_yang_names.add("interface-stats-entries")
                                    self._segment_path = lambda: "area-statistics"


                                class InterfaceStatsEntries(Entity):
                                    """
                                    Statistics innformation Interface table
                                    
                                    .. attribute:: interface_stats_entry
                                    
                                    	Statistics information for a specific interface
                                    	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, self).__init__()

                                        self.yang_name = "interface-stats-entries"
                                        self.yang_parent_name = "area-statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"interface-stats-entry" : ("interface_stats_entry", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry)}

                                        self.interface_stats_entry = YList(self)
                                        self._segment_path = lambda: "interface-stats-entries"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries, [], name, value)


                                    class InterfaceStatsEntry(Entity):
                                        """
                                        Statistics information for a specific interface
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: handle
                                        
                                        	interface handle type
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: if_entry
                                        
                                        	interface entry
                                        	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                        
                                        .. attribute:: if_name_str
                                        
                                        	interface name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                            self.yang_name = "interface-stats-entry"
                                            self.yang_parent_name = "interface-stats-entries"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"if-entry" : ("if_entry", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry)}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.handle = YLeaf(YType.str, "handle")

                                            self.if_name_str = YLeaf(YType.str, "if-name-str")

                                            self.if_entry = YList(self)
                                            self._segment_path = lambda: "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry, ['interface_name', 'handle', 'if_name_str'], name, value)


                                        class IfEntry(Entity):
                                            """
                                            interface entry
                                            
                                            .. attribute:: area_id
                                            
                                            	OSPF area id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_id_str
                                            
                                            	OSPF aread id string
                                            	**type**\:  str
                                            
                                            .. attribute:: if_stat
                                            
                                            	OSPF interface statistics
                                            	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                            
                                            .. attribute:: madj_intf
                                            
                                            	OSPF madj interface
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                                self.yang_name = "if-entry"
                                                self.yang_parent_name = "interface-stats-entry"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"if-stat" : ("if_stat", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat)}

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.area_id_str = YLeaf(YType.str, "area-id-str")

                                                self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                                self.if_stat = YList(self)
                                                self._segment_path = lambda: "if-entry"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, ['area_id', 'area_id_str', 'madj_intf'], name, value)


                                            class IfStat(Entity):
                                                """
                                                OSPF interface statistics
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                                    self.yang_name = "if-stat"
                                                    self.yang_parent_name = "if-entry"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "if-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.AreaStatistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, ['entry'], name, value)


                            class FloodListAreaTable(Entity):
                                """
                                Area specific flood list table
                                
                                .. attribute:: flood
                                
                                	Flooding information for a specific interface
                                	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable, self).__init__()

                                    self.yang_name = "flood-list-area-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"flood" : ("flood", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood)}

                                    self.flood = YList(self)
                                    self._segment_path = lambda: "flood-list-area-table"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable, [], name, value)


                                class Flood(Entity):
                                    """
                                    Flooding information for a specific interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: area_flood
                                    
                                    	Area scope floodlist
                                    	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood>`
                                    
                                    .. attribute:: as_flood
                                    
                                    	AS scope floodlist
                                    	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood>`
                                    
                                    .. attribute:: flood_interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: flood_lsa_count
                                    
                                    	Number of LSAs currently being flooded
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flood_pacing_timer
                                    
                                    	Time until next LS update due (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "flood-list-area-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"area-flood" : ("area_flood", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                                        self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                                        self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                                        self.area_flood = YList(self)
                                        self.as_flood = YList(self)
                                        self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood, ['interface_name', 'flood_interface_name', 'flood_lsa_count', 'flood_pacing_timer'], name, value)


                                    class AreaFlood(Entity):
                                        """
                                        Area scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, self).__init__()

                                            self.yang_name = "area-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                            self._segment_path = lambda: "area-flood"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AreaFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                                    class AsFlood(Entity):
                                        """
                                        AS scope floodlist
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, self).__init__()

                                            self.yang_name = "as-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                            self._segment_path = lambda: "as-flood"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListAreaTable.Flood.AsFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class InterfaceBriefs(Entity):
                                """
                                OSPF Interface Brief Table
                                
                                .. attribute:: interface_brief
                                
                                	OSPF interface brief information
                                	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs, self).__init__()

                                    self.yang_name = "interface-briefs"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface-brief" : ("interface_brief", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief)}

                                    self.interface_brief = YList(self)
                                    self._segment_path = lambda: "interface-briefs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs, [], name, value)


                                class InterfaceBrief(Entity):
                                    """
                                    OSPF interface brief information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_fast_detect_hold_down
                                    
                                    	Interface in fast detect hold down state
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_madj
                                    
                                    	Information for multi\-area on the interface
                                    	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                                    
                                    .. attribute:: interface_madj_count
                                    
                                    	Total number of multi\-area
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_mask
                                    
                                    	Interface IP Mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Total number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interfaceis_madj
                                    
                                    	If true, interface is multi\-area
                                    	**type**\:  bool
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief, self).__init__()

                                        self.yang_name = "interface-brief"
                                        self.yang_parent_name = "interface-briefs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface_address = YLeaf(YType.str, "interface-address")

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                        self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        self.interface_madj = YList(self)
                                        self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adj_neighbor_count', 'interface_area', 'interface_fast_detect_hold_down', 'interface_link_cost', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_neighbor_count', 'interfaceis_madj', 'ospf_interface_state'], name, value)


                                    class InterfaceMadj(Entity):
                                        """
                                        Information for multi\-area on the interface
                                        
                                        .. attribute:: interface_adj_neighbor_count
                                        
                                        	Total number of Adjacent Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_area
                                        
                                        	Area ID string in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: interface_link_cost
                                        
                                        	Interface link cost
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_neighbor_count
                                        
                                        	Number of Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: madj_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ospf_interface_state
                                        
                                        	Interface OSPF state
                                        	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                            self.yang_name = "interface-madj"
                                            self.yang_parent_name = "interface-brief"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                            self.interface_area = YLeaf(YType.str, "interface-area")

                                            self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                            self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                            self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                            self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                            self._segment_path = lambda: "interface-madj"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefs.InterfaceBrief.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                            class Interfaces(Entity):
                                """
                                OSPF Interface Table
                                
                                .. attribute:: interface
                                
                                	OSPF interface information
                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces, self).__init__()

                                    self.yang_name = "interfaces"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface" : ("interface", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface)}

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces, [], name, value)


                                class Interface(Entity):
                                    """
                                    OSPF interface information
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: active_interface
                                    
                                    	Active interface details
                                    	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface>`
                                    
                                    .. attribute:: backup_designated_router
                                    
                                    	If true, backup designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_designated_router_address
                                    
                                    	Backup designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_designated_router_id
                                    
                                    	Backup designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cfg_cost_fallback
                                    
                                    	If true, cost fallback is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: configured_demand_circuit
                                    
                                    	If true, configured as demand circuit
                                    	**type**\:  bool
                                    
                                    .. attribute:: configured_ldp_sync
                                    
                                    	If true, configured as LDP sync
                                    	**type**\:  bool
                                    
                                    .. attribute:: configured_ldp_sync_igp_shortcuts
                                    
                                    	If true, sync igp shortcuts
                                    	**type**\:  bool
                                    
                                    .. attribute:: cost_fallback_active
                                    
                                    	If true, cost fallback is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Configured dead interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: designated_router
                                    
                                    	If true, designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: designated_router_address
                                    
                                    	Designated router interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: designated_router_id
                                    
                                    	Designated router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: fast_detect_hold_down_time
                                    
                                    	Hold\-down time in ms for fast\-detect event
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fast_detect_hold_down_time_remaining
                                    
                                    	Remaining hold down time in ms
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fast_reroute_topology_independent_lfa
                                    
                                    	Topology Independent LFA
                                    	**type**\:  bool
                                    
                                    .. attribute:: fast_reroute_type
                                    
                                    	IP Fast Reroute Type
                                    	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Configured hello interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: hello_interval_ms
                                    
                                    	Configured hello interval (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ack_list_count
                                    
                                    	Ack List Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ack_list_high_watermark
                                    
                                    	Ack List High Watermark
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_bandwidth
                                    
                                    	Interface bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_bfd_information
                                    
                                    	BFD information
                                    	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation>`
                                    
                                    .. attribute:: interface_bkp_labels
                                    
                                    	Max number of backup labels
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_cost_fallback
                                    
                                    	Interface fallback cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_dc_bitless_lsa_count
                                    
                                    	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_demand_circuit
                                    
                                    	If true, interface running as demand circuit
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_fast_detect_hold_down
                                    
                                    	Link in hold\-down state due to fast detect event
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_forw
                                    
                                    	Forward reference interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_last_nsf
                                    
                                    	Time since last NSF restart (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_ldp_sync
                                    
                                    	If true, interface LDP sync is achieved
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_line_state
                                    
                                    	If true, line protocol is up
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_lsa_filter
                                    
                                    	Filter is configured for out going LSAs
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_madj
                                    
                                    	Information for multi\-area on the interface
                                    	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj>`
                                    
                                    .. attribute:: interface_madj_count
                                    
                                    	Total number of multi\-area
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_mask
                                    
                                    	Interface IP Mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name_xr
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_neighbor
                                    
                                    	Information for neighbors on the interface
                                    	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor>`
                                    
                                    .. attribute:: interface_nsf
                                    
                                    	If true, NSF restart in progress on this interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_nsf_enabled
                                    
                                    	If true, NSF is enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_pri_labels
                                    
                                    	Max number of primary labels
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_retransmission_interrval
                                    
                                    	Configured retransmit interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_router_id
                                    
                                    	Interface Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_sid
                                    
                                    	Interface SID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_sid_n_flag_clear
                                    
                                    	SID N\-Flag Clear
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_sid_php_off
                                    
                                    	SID PHP Off
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_srte_labels
                                    
                                    	Max number of SRTE labels
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_state
                                    
                                    	Interface state
                                    	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                                    
                                    .. attribute:: interface_strict_spf_sid
                                    
                                    	Interface Strict\-SPF SID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_strict_spf_sid_n_flag_clear
                                    
                                    	Strict\-SPF SID N\-Flag Clear
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_strict_spf_sid_php_off
                                    
                                    	Strict\-SPF SID PHP Off
                                    	**type**\:  bool
                                    
                                    .. attribute:: interface_tunnel_flags
                                    
                                    	Interface tunnel flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_unnum
                                    
                                    	Unnumbered interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interfaceis_madj
                                    
                                    	If true, interface is multi\-area
                                    	**type**\:  bool
                                    
                                    .. attribute:: ip_mtu
                                    
                                    	IP MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ip_sec_addr
                                    
                                    	Secondary IP address list
                                    	**type**\: list of    :py:class:`IpSecAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpSecAddr>`
                                    
                                    .. attribute:: ipfrr_tiebreakers
                                    
                                    	IPFRR\-Tiebreakers list
                                    	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers>`
                                    
                                    .. attribute:: is_loopback_stub_network
                                    
                                    	If true, loopback interface is advertised as a stub network
                                    	**type**\:  bool
                                    
                                    .. attribute:: maximum_packet_size
                                    
                                    	Maximum Packet Size
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network_lsa_flush_timer
                                    
                                    	The amount of time in seconds before flush timer for old network LSA expires
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                    
                                    .. attribute:: next_hello_time
                                    
                                    	Time until next Hello (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello_time_ms
                                    
                                    	Time until next Hello (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    .. attribute:: passive_interface
                                    
                                    	If true, passive interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_suppress_primary_addresses
                                    
                                    	Prefix Suppression for primary addresses
                                    	**type**\:  bool
                                    
                                    .. attribute:: prefix_suppress_secondary_addresses
                                    
                                    	Prefix Suppression for secondary addresses
                                    	**type**\:  bool
                                    
                                    .. attribute:: registered_for_link_down_fast_detection
                                    
                                    	Registered for Link Down Fast Detection
                                    	**type**\:  bool
                                    
                                    .. attribute:: srlg
                                    
                                    	SRLG Values
                                    	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg>`
                                    
                                    .. attribute:: transmission_delay
                                    
                                    	Interface Transmission delay
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ttl_security_enabled
                                    
                                    	TTL security enabled on the interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: ttl_security_hop_count
                                    
                                    	TTL security hop counts
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: wait_interval
                                    
                                    	Configured wait interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"active-interface" : ("active_interface", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface), "interface-bfd-information" : ("interface_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation)}
                                        self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj), "interface-neighbor" : ("interface_neighbor", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor), "ip-sec-addr" : ("ip_sec_addr", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpSecAddr), "ipfrr-tiebreakers" : ("ipfrr_tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers), "srlg" : ("srlg", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                        self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                        self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                        self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                        self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                        self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                        self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                        self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                        self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                        self.designated_router = YLeaf(YType.boolean, "designated-router")

                                        self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                        self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                        self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                        self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                        self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                        self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                        self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                        self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                        self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                        self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                        self.interface_address = YLeaf(YType.str, "interface-address")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                        self.interface_bkp_labels = YLeaf(YType.uint8, "interface-bkp-labels")

                                        self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                        self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                        self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                        self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                        self.interface_forw = YLeaf(YType.boolean, "interface-forw")

                                        self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                        self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                        self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                        self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                        self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                        self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                        self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                        self.interface_pri_labels = YLeaf(YType.uint8, "interface-pri-labels")

                                        self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                        self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                        self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                        self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                        self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                        self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                        self.interface_srte_labels = YLeaf(YType.uint8, "interface-srte-labels")

                                        self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                        self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                        self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                        self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                        self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                        self.interface_unnum = YLeaf(YType.str, "interface-unnum")

                                        self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                        self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                        self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                        self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                        self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                        self.network_type = YLeaf(YType.enumeration, "network-type")

                                        self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                        self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                        self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                        self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                        self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                        self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                        self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                        self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                        self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                        self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                        self.active_interface = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface()
                                        self.active_interface.parent = self
                                        self._children_name_map["active_interface"] = "active-interface"
                                        self._children_yang_names.add("active-interface")

                                        self.interface_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation()
                                        self.interface_bfd_information.parent = self
                                        self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                        self._children_yang_names.add("interface-bfd-information")

                                        self.interface_madj = YList(self)
                                        self.interface_neighbor = YList(self)
                                        self.ip_sec_addr = YList(self)
                                        self.ipfrr_tiebreakers = YList(self)
                                        self.srlg = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface, ['interface_name', 'backup_designated_router', 'backup_designated_router_address', 'backup_designated_router_id', 'cfg_cost_fallback', 'configured_demand_circuit', 'configured_ldp_sync', 'configured_ldp_sync_igp_shortcuts', 'cost_fallback_active', 'dead_interval', 'designated_router', 'designated_router_address', 'designated_router_id', 'fast_detect_hold_down_time', 'fast_detect_hold_down_time_remaining', 'fast_reroute_topology_independent_lfa', 'fast_reroute_type', 'hello_interval', 'hello_interval_ms', 'interface_ack_list_count', 'interface_ack_list_high_watermark', 'interface_address', 'interface_area', 'interface_bandwidth', 'interface_bkp_labels', 'interface_cost_fallback', 'interface_dc_bitless_lsa_count', 'interface_demand_circuit', 'interface_fast_detect_hold_down', 'interface_forw', 'interface_last_nsf', 'interface_ldp_sync', 'interface_line_state', 'interface_link_cost', 'interface_lsa_filter', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_nsf', 'interface_nsf_enabled', 'interface_pri_labels', 'interface_priority', 'interface_retransmission_interrval', 'interface_router_id', 'interface_sid', 'interface_sid_n_flag_clear', 'interface_sid_php_off', 'interface_srte_labels', 'interface_state', 'interface_strict_spf_sid', 'interface_strict_spf_sid_n_flag_clear', 'interface_strict_spf_sid_php_off', 'interface_tunnel_flags', 'interface_unnum', 'interfaceis_madj', 'ip_mtu', 'is_loopback_stub_network', 'maximum_packet_size', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'next_hello_time_ms', 'ospf_interface_state', 'passive_interface', 'prefix_suppress_primary_addresses', 'prefix_suppress_secondary_addresses', 'registered_for_link_down_fast_detection', 'transmission_delay', 'ttl_security_enabled', 'ttl_security_hop_count', 'wait_interval'], name, value)


                                    class ActiveInterface(Entity):
                                        """
                                        Active interface details
                                        
                                        .. attribute:: flood_scan_length
                                        
                                        	Last flood scan length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_flood_index
                                        
                                        	Area scope LSAs flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood
                                        
                                        	Next LSA to flood (Area scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood_index
                                        
                                        	Index of next LSA to flood (Area scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_flood_index
                                        
                                        	AS scope LSAs flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood
                                        
                                        	Next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood_index
                                        
                                        	Index of next LSA to flood (AS scope)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_authentication_type
                                        
                                        	Authentication type
                                        	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                        
                                        .. attribute:: interface_flood_length
                                        
                                        	Flood queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_flood_pacing_timer
                                        
                                        	Time until next flood pacing timer (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbor_count
                                        
                                        	Total number of Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: keychain_id
                                        
                                        	Keychain ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: last_flood_time
                                        
                                        	Last flood scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_length
                                        
                                        	Maximum flood length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_time
                                        
                                        	Maximum flood time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: md_keys
                                        
                                        	List of old MD keys
                                        	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys>`
                                        
                                        .. attribute:: old_md5_key_neighbor_count
                                        
                                        	Number of neighbors using the old key (if rollover in progress)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: suppress_hello_count
                                        
                                        	Number of neighbors for which hellos are suppressed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: wait_time
                                        
                                        	Wait time for DR/BDR selection (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: youngest_md_key
                                        
                                        	If true, MD key is configured
                                        	**type**\:  bool
                                        
                                        .. attribute:: youngest_md_key_id
                                        
                                        	Youngest MD key ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface, self).__init__()

                                            self.yang_name = "active-interface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"md-keys" : ("md_keys", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys)}

                                            self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                            self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                            self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                            self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                            self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                            self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                            self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                            self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                            self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                            self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                            self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                            self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                            self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                            self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                            self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                            self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                            self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                            self.wait_time = YLeaf(YType.uint32, "wait-time")

                                            self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                            self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                            self.md_keys = YList(self)
                                            self._segment_path = lambda: "active-interface"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface, ['flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_authentication_type', 'interface_flood_length', 'interface_flood_pacing_timer', 'interface_neighbor_count', 'keychain_id', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'old_md5_key_neighbor_count', 'suppress_hello_count', 'wait_time', 'youngest_md_key', 'youngest_md_key_id'], name, value)


                                        class MdKeys(Entity):
                                            """
                                            List of old MD keys
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                                self.yang_name = "md-keys"
                                                self.yang_parent_name = "active-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint16, "entry")
                                                self._segment_path = lambda: "md-keys"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.ActiveInterface.MdKeys, ['entry'], name, value)


                                    class InterfaceBfdInformation(Entity):
                                        """
                                        BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: detection_multiplier
                                        
                                        	BFD detection multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interval
                                        
                                        	BFD interval (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                            self.yang_name = "interface-bfd-information"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                            self.interval = YLeaf(YType.uint32, "interval")
                                            self._segment_path = lambda: "interface-bfd-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceBfdInformation, ['bfd_intf_enable_mode', 'detection_multiplier', 'interval'], name, value)


                                    class InterfaceMadj(Entity):
                                        """
                                        Information for multi\-area on the interface
                                        
                                        .. attribute:: interface_adj_neighbor_count
                                        
                                        	Total number of Adjacent Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_area
                                        
                                        	Area ID string in decimal or dotted\-decimal format
                                        	**type**\:  str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: interface_link_cost
                                        
                                        	Interface link cost
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: interface_neighbor_count
                                        
                                        	Number of Neighbors
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: madj_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ospf_interface_state
                                        
                                        	Interface OSPF state
                                        	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj, self).__init__()

                                            self.yang_name = "interface-madj"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                            self.interface_area = YLeaf(YType.str, "interface-area")

                                            self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                            self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                            self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                            self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                            self._segment_path = lambda: "interface-madj"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                                    class InterfaceNeighbor(Entity):
                                        """
                                        Information for neighbors on the interface
                                        
                                        .. attribute:: interface_neighbor_cost
                                        
                                        	Cost of link to neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbor_id
                                        
                                        	Neighbor Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_bdr
                                        
                                        	If true, Backup designated router
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_dr
                                        
                                        	If true, Designated router
                                        	**type**\:  bool
                                        
                                        .. attribute:: suppress_hello
                                        
                                        	If true, hellos suppressed
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                            self.yang_name = "interface-neighbor"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                            self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                            self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                            self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                            self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")
                                            self._segment_path = lambda: "interface-neighbor"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'neighbor_bdr', 'neighbor_dr', 'suppress_hello'], name, value)


                                    class IpSecAddr(Entity):
                                        """
                                        Secondary IP address list
                                        
                                        .. attribute:: secondary_addr
                                        
                                        	Secondary Address Type
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: secondary_prefix
                                        
                                        	Secondary Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpSecAddr, self).__init__()

                                            self.yang_name = "ip-sec-addr"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.secondary_addr = YLeaf(YType.str, "secondary-addr")

                                            self.secondary_prefix = YLeaf(YType.uint32, "secondary-prefix")
                                            self._segment_path = lambda: "ip-sec-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpSecAddr, ['secondary_addr', 'secondary_prefix'], name, value)


                                    class IpfrrTiebreakers(Entity):
                                        """
                                        IPFRR\-Tiebreakers list
                                        
                                        .. attribute:: tiebreaker_index
                                        
                                        	Tiebreaker Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tiebreaker_type
                                        
                                        	Tiebreaker Type
                                        	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                            self.yang_name = "ipfrr-tiebreakers"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                            self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")
                                            self._segment_path = lambda: "ipfrr-tiebreakers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.IpfrrTiebreakers, ['tiebreaker_index', 'tiebreaker_type'], name, value)


                                    class Srlg(Entity):
                                        """
                                        SRLG Values
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg, self).__init__()

                                            self.yang_name = "srlg"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "srlg"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Interfaces.Interface.Srlg, ['entry'], name, value)


                            class NeighborDetails(Entity):
                                """
                                Neighbor detail table
                                
                                .. attribute:: neighbor_detail
                                
                                	A single neighbor's detail information
                                	**type**\: list of    :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails, self).__init__()

                                    self.yang_name = "neighbor-details"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor-detail" : ("neighbor_detail", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail)}

                                    self.neighbor_detail = YList(self)
                                    self._segment_path = lambda: "neighbor-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails, [], name, value)


                                class NeighborDetail(Entity):
                                    """
                                    A single neighbor's detail information
                                    
                                    .. attribute:: adjacency_sid_label
                                    
                                    	SR Adjacency SID Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: adjacency_sid_protected
                                    
                                    	SR Adjacency SID Protected
                                    	**type**\:  bool
                                    
                                    .. attribute:: adjacency_sid_unprotected_label
                                    
                                    	SR Adjacency SID Unprotected Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                    
                                    .. attribute:: last_oob_time
                                    
                                    	The amount of time in seconds since last time Out\-Of\-Band resynchronization was done with this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: lfa_interface
                                    
                                    	LFA Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: lfa_neighbor_id
                                    
                                    	LFA Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lfa_neighbor_revision
                                    
                                    	LFA Neighbor Revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lfa_next_hop
                                    
                                    	LFA Next Hop
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_ack_list_count
                                    
                                    	Ack List Count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_ack_list_high_watermark
                                    
                                    	Ack List High Watermark
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_area_id
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_filter
                                    
                                    	If true, filter outgoing LSAs
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Interface ID of neighbor recived via LLS
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_lls_option
                                    
                                    	This is a bitmask of Link Local signalling options received from the neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmaks of neighbor's option field received
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_retransmission_information
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:   :py:class:`NeighborRetransmissionInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation>`
                                    
                                    .. attribute:: neighbor_summary
                                    
                                    	Neighbor summary information
                                    	**type**\:   :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary>`
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nsf_router_state
                                    
                                    	For cisco NSF, the router is either Requester or Receiver
                                    	**type**\:   :py:class:`NsfRtr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NsfRtr>`
                                    
                                    .. attribute:: oob_resynchronization
                                    
                                    	Out\-Of\-Bound resynchronization in progress
                                    	**type**\:  bool
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state_change_count
                                    
                                    	Number of state changes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation), "neighbor-retransmission-information" : ("neighbor_retransmission_information", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation), "neighbor-summary" : ("neighbor_summary", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary)}
                                        self._child_list_classes = {}

                                        self.adjacency_sid_label = YLeaf(YType.uint32, "adjacency-sid-label")

                                        self.adjacency_sid_protected = YLeaf(YType.boolean, "adjacency-sid-protected")

                                        self.adjacency_sid_unprotected_label = YLeaf(YType.uint32, "adjacency-sid-unprotected-label")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.interface_type = YLeaf(YType.enumeration, "interface-type")

                                        self.last_oob_time = YLeaf(YType.uint32, "last-oob-time")

                                        self.lfa_interface = YLeaf(YType.str, "lfa-interface")

                                        self.lfa_neighbor_id = YLeaf(YType.str, "lfa-neighbor-id")

                                        self.lfa_neighbor_revision = YLeaf(YType.uint32, "lfa-neighbor-revision")

                                        self.lfa_next_hop = YLeaf(YType.str, "lfa-next-hop")

                                        self.neighbor_ack_list_count = YLeaf(YType.uint32, "neighbor-ack-list-count")

                                        self.neighbor_ack_list_high_watermark = YLeaf(YType.uint32, "neighbor-ack-list-high-watermark")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.neighbor_area_id = YLeaf(YType.str, "neighbor-area-id")

                                        self.neighbor_backup_designated_router_address = YLeaf(YType.str, "neighbor-backup-designated-router-address")

                                        self.neighbor_cost = YLeaf(YType.uint16, "neighbor-cost")

                                        self.neighbor_designated_router_address = YLeaf(YType.str, "neighbor-designated-router-address")

                                        self.neighbor_filter = YLeaf(YType.boolean, "neighbor-filter")

                                        self.neighbor_interface_id = YLeaf(YType.uint16, "neighbor-interface-id")

                                        self.neighbor_lls_option = YLeaf(YType.uint32, "neighbor-lls-option")

                                        self.neighbor_option = YLeaf(YType.uint8, "neighbor-option")

                                        self.next_poll_interval = YLeaf(YType.uint32, "next-poll-interval")

                                        self.nsf_router_state = YLeaf(YType.enumeration, "nsf-router-state")

                                        self.oob_resynchronization = YLeaf(YType.boolean, "oob-resynchronization")

                                        self.pending_events = YLeaf(YType.uint16, "pending-events")

                                        self.poll_interval = YLeaf(YType.uint32, "poll-interval")

                                        self.state_change_count = YLeaf(YType.uint16, "state-change-count")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")

                                        self.neighbor_retransmission_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation()
                                        self.neighbor_retransmission_information.parent = self
                                        self._children_name_map["neighbor_retransmission_information"] = "neighbor-retransmission-information"
                                        self._children_yang_names.add("neighbor-retransmission-information")

                                        self.neighbor_summary = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary()
                                        self.neighbor_summary.parent = self
                                        self._children_name_map["neighbor_summary"] = "neighbor-summary"
                                        self._children_yang_names.add("neighbor-summary")
                                        self._segment_path = lambda: "neighbor-detail"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail, ['adjacency_sid_label', 'adjacency_sid_protected', 'adjacency_sid_unprotected_label', 'interface_name', 'interface_type', 'last_oob_time', 'lfa_interface', 'lfa_neighbor_id', 'lfa_neighbor_revision', 'lfa_next_hop', 'neighbor_ack_list_count', 'neighbor_ack_list_high_watermark', 'neighbor_address', 'neighbor_area_id', 'neighbor_backup_designated_router_address', 'neighbor_cost', 'neighbor_designated_router_address', 'neighbor_filter', 'neighbor_interface_id', 'neighbor_lls_option', 'neighbor_option', 'next_poll_interval', 'nsf_router_state', 'oob_resynchronization', 'pending_events', 'poll_interval', 'state_change_count'], name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                            self._segment_path = lambda: "neighbor-bfd-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                                    class NeighborRetransmissionInformation(Entity):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: area_first_flood_information
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_information_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flooding_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_count
                                        
                                        	Number of DBD retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_total_count
                                        
                                        	Total number of DBD retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission_count
                                        
                                        	Retransmission queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, self).__init__()

                                            self.yang_name = "neighbor-retransmission-information"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                            self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                            self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                            self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                            self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                            self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                            self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                            self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                            self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                            self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                            self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                            self._segment_path = lambda: "neighbor-retransmission-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborRetransmissionInformation, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                                    class NeighborSummary(Entity):
                                        """
                                        Neighbor summary information
                                        
                                        .. attribute:: dr_bdr_state
                                        
                                        	Designated Router state
                                        	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                        
                                        .. attribute:: neighbor_address_xr
                                        
                                        	Neighbor IP Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_bfd_information
                                        
                                        	Neighbor BFD information
                                        	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation>`
                                        
                                        .. attribute:: neighbor_dead_timer
                                        
                                        	Time until neighbor's dead timer expires (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_dr_priority
                                        
                                        	Neighbor's DR priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: neighbor_id
                                        
                                        	Neighbor ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_interface_name
                                        
                                        	Interface via which the neighbor is seen
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: neighbor_madj_interface
                                        
                                        	Interface is MADJ
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_state
                                        
                                        	Neighbor's state
                                        	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                        
                                        .. attribute:: neighbor_up_time
                                        
                                        	Amount of time since the adjacency is up (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, self).__init__()

                                            self.yang_name = "neighbor-summary"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation)}
                                            self._child_list_classes = {}

                                            self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                            self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                            self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                            self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                            self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                            self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                            self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                            self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                            self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                            self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation()
                                            self.neighbor_bfd_information.parent = self
                                            self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                            self._children_yang_names.add("neighbor-bfd-information")
                                            self._segment_path = lambda: "neighbor-summary"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary, ['dr_bdr_state', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                        class NeighborBfdInformation(Entity):
                                            """
                                            Neighbor BFD information
                                            
                                            .. attribute:: bfd_intf_enable_mode
                                            
                                            	BFD enable mode \- Default/Strict
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bfd_status_flag
                                            
                                            	Status of the BFD Session
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, self).__init__()

                                                self.yang_name = "neighbor-bfd-information"
                                                self.yang_parent_name = "neighbor-summary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                                self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                                self._segment_path = lambda: "neighbor-bfd-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetails.NeighborDetail.NeighborSummary.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                            class Neighbors(Entity):
                                """
                                Neighbor table
                                
                                .. attribute:: neighbor
                                
                                	Neighbor information
                                	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors, self).__init__()

                                    self.yang_name = "neighbors"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"neighbor" : ("neighbor", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor)}

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbors"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    Neighbor information
                                    
                                    .. attribute:: dr_bdr_state
                                    
                                    	Designated Router state
                                    	**type**\:   :py:class:`DrBdrState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.DrBdrState>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bfd_information
                                    
                                    	Neighbor BFD information
                                    	**type**\:   :py:class:`NeighborBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation>`
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_name
                                    
                                    	Interface via which the neighbor is seen
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: neighbor_madj_interface
                                    
                                    	Interface is MADJ
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbors"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"neighbor-bfd-information" : ("neighbor_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation)}
                                        self._child_list_classes = {}

                                        self.dr_bdr_state = YLeaf(YType.enumeration, "dr-bdr-state")

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.neighbor_address_xr = YLeaf(YType.str, "neighbor-address-xr")

                                        self.neighbor_dead_timer = YLeaf(YType.uint32, "neighbor-dead-timer")

                                        self.neighbor_dr_priority = YLeaf(YType.uint8, "neighbor-dr-priority")

                                        self.neighbor_id = YLeaf(YType.str, "neighbor-id")

                                        self.neighbor_interface_name = YLeaf(YType.str, "neighbor-interface-name")

                                        self.neighbor_madj_interface = YLeaf(YType.boolean, "neighbor-madj-interface")

                                        self.neighbor_state = YLeaf(YType.enumeration, "neighbor-state")

                                        self.neighbor_up_time = YLeaf(YType.uint32, "neighbor-up-time")

                                        self.neighbor_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation()
                                        self.neighbor_bfd_information.parent = self
                                        self._children_name_map["neighbor_bfd_information"] = "neighbor-bfd-information"
                                        self._children_yang_names.add("neighbor-bfd-information")
                                        self._segment_path = lambda: "neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor, ['dr_bdr_state', 'interface_name', 'neighbor_address', 'neighbor_address_xr', 'neighbor_dead_timer', 'neighbor_dr_priority', 'neighbor_id', 'neighbor_interface_name', 'neighbor_madj_interface', 'neighbor_state', 'neighbor_up_time'], name, value)


                                    class NeighborBfdInformation(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, self).__init__()

                                            self.yang_name = "neighbor-bfd-information"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                            self.bfd_status_flag = YLeaf(YType.uint8, "bfd-status-flag")
                                            self._segment_path = lambda: "neighbor-bfd-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Neighbors.Neighbor.NeighborBfdInformation, ['bfd_intf_enable_mode', 'bfd_status_flag'], name, value)


                            class Requests(Entity):
                                """
                                Request List table
                                
                                .. attribute:: request
                                
                                	Request list for a particular adjacency
                                	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests, self).__init__()

                                    self.yang_name = "requests"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request)}

                                    self.request = YList(self)
                                    self._segment_path = lambda: "requests"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests, [], name, value)


                                class Request(Entity):
                                    """
                                    Request list for a particular adjacency
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request
                                    
                                    	List of request list entries
                                    	**type**\: list of    :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request>`
                                    
                                    .. attribute:: request_interface_name
                                    
                                    	Request list interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: request_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request_neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "requests"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"request" : ("request", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.request_interface_name = YLeaf(YType.str, "request-interface-name")

                                        self.request_neighbor_address = YLeaf(YType.str, "request-neighbor-address")

                                        self.request_neighbor_id = YLeaf(YType.str, "request-neighbor-id")

                                        self.request = YList(self)
                                        self._segment_path = lambda: "request"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request, ['interface_name', 'neighbor_address', 'request_interface_name', 'request_neighbor_address', 'request_neighbor_id'], name, value)


                                    class Request(Entity):
                                        """
                                        List of request list entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request, self).__init__()

                                            self.yang_name = "request"
                                            self.yang_parent_name = "request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                            self._segment_path = lambda: "request"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Requests.Request.Request, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class Retransmissions(Entity):
                                """
                                Retransmission list table
                                
                                .. attribute:: retransmission
                                
                                	Retransmission list for a particular adjacency
                                	**type**\: list of    :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions, self).__init__()

                                    self.yang_name = "retransmissions"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"retransmission" : ("retransmission", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission)}

                                    self.retransmission = YList(self)
                                    self._segment_path = lambda: "retransmissions"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions, [], name, value)


                                class Retransmission(Entity):
                                    """
                                    Retransmission list for a particular adjacency
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_area_db
                                    
                                    	List of Area scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb>`
                                    
                                    .. attribute:: retransmission_asdb
                                    
                                    	List of AS Scope entries
                                    	**type**\: list of    :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb>`
                                    
                                    .. attribute:: retransmission_count
                                    
                                    	Retransmission queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_interface_name
                                    
                                    	Retransmission list interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: retransmission_neighbor_id
                                    
                                    	Neighbor ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_neighbor_ip_address
                                    
                                    	Neighbor IP Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_timer
                                    
                                    	Amount of time remaining on retransmission timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission, self).__init__()

                                        self.yang_name = "retransmission"
                                        self.yang_parent_name = "retransmissions"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"retransmission-area-db" : ("retransmission_area_db", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb), "retransmission-asdb" : ("retransmission_asdb", Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb)}

                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                        self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                        self.retransmission_count = YLeaf(YType.uint32, "retransmission-count")

                                        self.retransmission_interface_name = YLeaf(YType.str, "retransmission-interface-name")

                                        self.retransmission_neighbor_id = YLeaf(YType.str, "retransmission-neighbor-id")

                                        self.retransmission_neighbor_ip_address = YLeaf(YType.str, "retransmission-neighbor-ip-address")

                                        self.retransmission_timer = YLeaf(YType.uint32, "retransmission-timer")

                                        self.retransmission_area_db = YList(self)
                                        self.retransmission_asdb = YList(self)
                                        self._segment_path = lambda: "retransmission"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission, ['interface_name', 'neighbor_address', 'retransmission_count', 'retransmission_interface_name', 'retransmission_neighbor_id', 'retransmission_neighbor_ip_address', 'retransmission_timer'], name, value)


                                    class RetransmissionAreaDb(Entity):
                                        """
                                        List of Area scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, self).__init__()

                                            self.yang_name = "retransmission-area-db"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                            self._segment_path = lambda: "retransmission-area-db"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAreaDb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                                    class RetransmissionAsdb(Entity):
                                        """
                                        List of AS Scope entries
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the Advertising Router
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_ls_id
                                        
                                        	LSA ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_checksum
                                        
                                        	Checksum of the LSA
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA Type
                                        	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, self).__init__()

                                            self.yang_name = "retransmission-asdb"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                            self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                            self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                            self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                            self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                            self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                            self._segment_path = lambda: "retransmission-asdb"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Areas.Area.Retransmissions.Retransmission.RetransmissionAsdb, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class BorderRouters(Entity):
                        """
                        Border router table
                        
                        .. attribute:: border_router
                        
                        	Information for a particular border router
                        	**type**\: list of    :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters, self).__init__()

                            self.yang_name = "border-routers"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"border-router" : ("border_router", Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter)}

                            self.border_router = YList(self)
                            self._segment_path = lambda: "border-routers"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters, [], name, value)


                        class BorderRouter(Entity):
                            """
                            Information for a particular border router
                            
                            .. attribute:: border_router_id  <key>
                            
                            	Router address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_id_xr
                            
                            	Router ID of Border Router
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_path
                            
                            	List of Border Router paths
                            	**type**\: list of    :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, self).__init__()

                                self.yang_name = "border-router"
                                self.yang_parent_name = "border-routers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"border-router-path" : ("border_router_path", Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath)}

                                self.border_router_id = YLeaf(YType.str, "border-router-id")

                                self.border_router_id_xr = YLeaf(YType.str, "border-router-id-xr")

                                self.border_router_path = YList(self)
                                self._segment_path = lambda: "border-router" + "[border-router-id='" + self.border_router_id.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, ['border_router_id', 'border_router_id_xr'], name, value)


                            class BorderRouterPath(Entity):
                                """
                                List of Border Router paths
                                
                                .. attribute:: border_router_area_id
                                
                                	Area string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: border_router_next_hop
                                
                                	Next hop address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: border_router_next_hop_interface_name
                                
                                	Next hop Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: border_router_route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: border_router_route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                .. attribute:: border_router_type
                                
                                	Border router type
                                	**type**\:   :py:class:`OspfBr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfBr>`
                                
                                .. attribute:: spf_version
                                
                                	SPF run instance count
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                    self.yang_name = "border-router-path"
                                    self.yang_parent_name = "border-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.border_router_area_id = YLeaf(YType.str, "border-router-area-id")

                                    self.border_router_next_hop = YLeaf(YType.str, "border-router-next-hop")

                                    self.border_router_next_hop_interface_name = YLeaf(YType.str, "border-router-next-hop-interface-name")

                                    self.border_router_route_metric = YLeaf(YType.uint32, "border-router-route-metric")

                                    self.border_router_route_type = YLeaf(YType.enumeration, "border-router-route-type")

                                    self.border_router_type = YLeaf(YType.enumeration, "border-router-type")

                                    self.spf_version = YLeaf(YType.uint64, "spf-version")
                                    self._segment_path = lambda: "border-router-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, ['border_router_area_id', 'border_router_next_hop', 'border_router_next_hop_interface_name', 'border_router_route_metric', 'border_router_route_type', 'border_router_type', 'spf_version'], name, value)


                    class Database(Entity):
                        """
                        OSPF Link State Database
                        
                        .. attribute:: database_areas
                        
                        	Per\-Area view of Link state database
                        	**type**\:   :py:class:`DatabaseAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas>`
                        
                        .. attribute:: database_summaries
                        
                        	Link State database summary table
                        	**type**\:   :py:class:`DatabaseSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries>`
                        
                        .. attribute:: database_summary_as
                        
                        	Link State Database summary for the AS
                        	**type**\:   :py:class:`DatabaseSummaryAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs>`
                        
                        .. attribute:: lsa_summaries
                        
                        	Link state advertisement summary table
                        	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries>`
                        
                        .. attribute:: lsas
                        
                        	Link State Database Table
                        	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Database, self).__init__()

                            self.yang_name = "database"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"database-areas" : ("database_areas", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas), "database-summaries" : ("database_summaries", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries), "database-summary-as" : ("database_summary_as", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs), "lsa-summaries" : ("lsa_summaries", Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries), "lsas" : ("lsas", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas)}
                            self._child_list_classes = {}

                            self.database_areas = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas()
                            self.database_areas.parent = self
                            self._children_name_map["database_areas"] = "database-areas"
                            self._children_yang_names.add("database-areas")

                            self.database_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries()
                            self.database_summaries.parent = self
                            self._children_name_map["database_summaries"] = "database-summaries"
                            self._children_yang_names.add("database-summaries")

                            self.database_summary_as = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs()
                            self.database_summary_as.parent = self
                            self._children_name_map["database_summary_as"] = "database-summary-as"
                            self._children_yang_names.add("database-summary-as")

                            self.lsa_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries()
                            self.lsa_summaries.parent = self
                            self._children_name_map["lsa_summaries"] = "lsa-summaries"
                            self._children_yang_names.add("lsa-summaries")

                            self.lsas = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas()
                            self.lsas.parent = self
                            self._children_name_map["lsas"] = "lsas"
                            self._children_yang_names.add("lsas")
                            self._segment_path = lambda: "database"


                        class DatabaseAreas(Entity):
                            """
                            Per\-Area view of Link state database
                            
                            .. attribute:: database_area
                            
                            	Per\-Area Link State Database data
                            	**type**\: list of    :py:class:`DatabaseArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas, self).__init__()

                                self.yang_name = "database-areas"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"database-area" : ("database_area", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea)}

                                self.database_area = YList(self)
                                self._segment_path = lambda: "database-areas"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas, [], name, value)


                            class DatabaseArea(Entity):
                                """
                                Per\-Area Link State Database data
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_summaries
                                
                                	Link state advertisement summary table
                                	**type**\:   :py:class:`LsaSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries>`
                                
                                .. attribute:: lsas
                                
                                	Link State Database Table
                                	**type**\:   :py:class:`Lsas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea, self).__init__()

                                    self.yang_name = "database-area"
                                    self.yang_parent_name = "database-areas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-summaries" : ("lsa_summaries", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries), "lsas" : ("lsas", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas)}
                                    self._child_list_classes = {}

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.lsa_summaries = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries()
                                    self.lsa_summaries.parent = self
                                    self._children_name_map["lsa_summaries"] = "lsa-summaries"
                                    self._children_yang_names.add("lsa-summaries")

                                    self.lsas = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas()
                                    self.lsas.parent = self
                                    self._children_name_map["lsas"] = "lsas"
                                    self._children_yang_names.add("lsas")
                                    self._segment_path = lambda: "database-area" + "[area-id='" + self.area_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea, ['area_id'], name, value)


                                class LsaSummaries(Entity):
                                    """
                                    Link state advertisement summary table
                                    
                                    .. attribute:: lsa_summary
                                    
                                    	LSA summary information
                                    	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, self).__init__()

                                        self.yang_name = "lsa-summaries"
                                        self.yang_parent_name = "database-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"lsa-summary" : ("lsa_summary", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary)}

                                        self.lsa_summary = YList(self)
                                        self._segment_path = lambda: "lsa-summaries"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries, [], name, value)


                                    class LsaSummary(Entity):
                                        """
                                        LSA summary information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: link_count
                                        
                                        	Number of links
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ls_type
                                        
                                        	Link state type
                                        	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	LSA header information
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, self).__init__()

                                            self.yang_name = "lsa-summary"
                                            self.yang_parent_name = "lsa-summaries"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-header" : ("lsa_header", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader)}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.area_id = YLeaf(YType.int32, "area-id")

                                            self.external_tag = YLeaf(YType.uint32, "external-tag")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.link_count = YLeaf(YType.uint16, "link-count")

                                            self.ls_id = YLeaf(YType.str, "ls-id")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")
                                            self._segment_path = lambda: "lsa-summary"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary, ['advertising_router', 'area_id', 'external_tag', 'interface_name', 'link_count', 'ls_id', 'ls_type'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            LSA header information
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: dn_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_type
                                            
                                            	LSA type
                                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsid
                                            
                                            	LS ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: nsf
                                            
                                            	If true,  LSA received from neighbor during NSF
                                            	**type**\:  bool
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa-summary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsid = YLeaf(YType.str, "lsid")

                                                self.nsf = YLeaf(YType.boolean, "nsf")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.LsaSummaries.LsaSummary.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                                class Lsas(Entity):
                                    """
                                    Link State Database Table
                                    
                                    .. attribute:: lsa
                                    
                                    	Link State Advertisement information
                                    	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas, self).__init__()

                                        self.yang_name = "lsas"
                                        self.yang_parent_name = "database-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"lsa" : ("lsa", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa)}

                                        self.lsa = YList(self)
                                        self._segment_path = lambda: "lsas"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas, [], name, value)


                                    class Lsa(Entity):
                                        """
                                        Link State Advertisement information
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ls_type
                                        
                                        	Link state type
                                        	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                        
                                        .. attribute:: lsa_detail_data
                                        
                                        	Detailed LSA Information
                                        	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData>`
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information
                                        	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader>`
                                        
                                        .. attribute:: lsa_internal_data
                                        
                                        	Information pertaining to a specific LSA type
                                        	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, self).__init__()

                                            self.yang_name = "lsa"
                                            self.yang_parent_name = "lsas"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"lsa-detail-data" : ("lsa_detail_data", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData), "lsa-header" : ("lsa_header", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader), "lsa-internal-data" : ("lsa_internal_data", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData)}
                                            self._child_list_classes = {}

                                            self.advertising_router = YLeaf(YType.str, "advertising-router")

                                            self.area_id = YLeaf(YType.int32, "area-id")

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.ls_id = YLeaf(YType.str, "ls-id")

                                            self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                            self.lsa_detail_data = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData()
                                            self.lsa_detail_data.parent = self
                                            self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                            self._children_yang_names.add("lsa-detail-data")

                                            self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"
                                            self._children_yang_names.add("lsa-header")

                                            self.lsa_internal_data = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData()
                                            self.lsa_internal_data.parent = self
                                            self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                            self._children_yang_names.add("lsa-internal-data")
                                            self._segment_path = lambda: "lsa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                        class LsaDetailData(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\:  bool
                                            
                                            .. attribute:: ase_origin
                                            
                                            	External Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: demand_circuit
                                            
                                            	If true, capable of demand circuit as indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            .. attribute:: dn_bit
                                            
                                            	if true, DN bit set on the summary LSA indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            .. attribute:: in_sync
                                            
                                            	Not In Sync With Active
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: length
                                            
                                            	Length of the LSA
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\:  bool
                                            
                                            .. attribute:: lsa_last_updated_time
                                            
                                            	Time LSA was last updated
                                            	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                            
                                            .. attribute:: lsa_prefix_priority
                                            
                                            	Current LSA prefix priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: lsa_rate_limit_due_time
                                            
                                            	Due time for rate\-limit timer (ms)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_throttle_timer
                                            
                                            	LSA throttle timer table information
                                            	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                            
                                            .. attribute:: lsadb_base_clock
                                            
                                            	Clock stamp since boot
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: lsadb_base_time_stamp
                                            
                                            	Current time stamp
                                            	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                            
                                            .. attribute:: new_lsa_prefix_priority
                                            
                                            	New LSA prefix priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: not_delete
                                            
                                            	Reason why LSA is not deleted
                                            	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete>`
                                            
                                            .. attribute:: nssa_translation
                                            
                                            	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            .. attribute:: routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: sum_origin
                                            
                                            	Summary Origin
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tos_capable
                                            
                                            	If true, type of service capable indicated by LSA's option field
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, self).__init__()

                                                self.yang_name = "lsa-detail-data"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lsa-last-updated-time" : ("lsa_last_updated_time", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime), "lsa-throttle-timer" : ("lsa_throttle_timer", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer), "lsadb-base-time-stamp" : ("lsadb_base_time_stamp", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp), "not-delete" : ("not_delete", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete)}
                                                self._child_list_classes = {}

                                                self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                                self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                                self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                                self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                                self.in_sync = YLeaf(YType.uint8, "in-sync")

                                                self.length = YLeaf(YType.uint16, "length")

                                                self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                                self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                                self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                                self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                                self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                                self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                                self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                                self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                                self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                                self.lsa_last_updated_time = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                                self.lsa_last_updated_time.parent = self
                                                self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                                self._children_yang_names.add("lsa-last-updated-time")

                                                self.lsa_throttle_timer = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                                self.lsa_throttle_timer.parent = self
                                                self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                                self._children_yang_names.add("lsa-throttle-timer")

                                                self.lsadb_base_time_stamp = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                                self.lsadb_base_time_stamp.parent = self
                                                self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                                self._children_yang_names.add("lsadb-base-time-stamp")

                                                self.not_delete = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete()
                                                self.not_delete.parent = self
                                                self._children_name_map["not_delete"] = "not-delete"
                                                self._children_yang_names.add("not-delete")
                                                self._segment_path = lambda: "lsa-detail-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData, ['advertising_router_reachable', 'ase_origin', 'demand_circuit', 'dn_bit', 'in_sync', 'length', 'lsa_flood_required_post_fail_over', 'lsa_prefix_priority', 'lsa_rate_limit_due_time', 'lsadb_base_clock', 'new_lsa_prefix_priority', 'nssa_translation', 'routing_bit', 'sum_origin', 'tos_capable'], name, value)


                                            class LsaLastUpdatedTime(Entity):
                                                """
                                                Time LSA was last updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                                    self.yang_name = "lsa-last-updated-time"
                                                    self.yang_parent_name = "lsa-detail-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "lsa-last-updated-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, ['nanosecond', 'second'], name, value)


                                            class LsaThrottleTimer(Entity):
                                                """
                                                LSA throttle timer table information
                                                
                                                .. attribute:: last_inst_minute_table_index
                                                
                                                	Last Minute table index processed
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: last_inst_second_table_index
                                                
                                                	Last Second table index processed
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timer_location
                                                
                                                	Timer table
                                                	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                                
                                                .. attribute:: timer_type
                                                
                                                	Timer type
                                                	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                                    self.yang_name = "lsa-throttle-timer"
                                                    self.yang_parent_name = "lsa-detail-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                                    self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                                    self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                                    self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                                    self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                                    self.timer_type = YLeaf(YType.enumeration, "timer-type")
                                                    self._segment_path = lambda: "lsa-throttle-timer"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, ['last_inst_minute_table_index', 'last_inst_second_table_index', 'minute_table_index', 'second_table_index', 'timer_location', 'timer_type'], name, value)


                                            class LsadbBaseTimeStamp(Entity):
                                                """
                                                Current time stamp
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                                    self.yang_name = "lsadb-base-time-stamp"
                                                    self.yang_parent_name = "lsa-detail-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "lsadb-base-time-stamp"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, ['nanosecond', 'second'], name, value)


                                            class NotDelete(Entity):
                                                """
                                                Reason why LSA is not deleted
                                                
                                                .. attribute:: acknowledgement
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                                	**type**\:  bool
                                                
                                                .. attribute:: flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\:  bool
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: maximum_age
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\:  bool
                                                
                                                .. attribute:: no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\:  bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\:  bool
                                                
                                                .. attribute:: partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\:  bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\:  bool
                                                
                                                .. attribute:: routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                                	**type**\:  bool
                                                
                                                .. attribute:: sum_orig_pending
                                                
                                                	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                                    self.yang_name = "not-delete"
                                                    self.yang_parent_name = "lsa-detail-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                                    self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                                    self.free_time = YLeaf(YType.uint32, "free-time")

                                                    self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                                    self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                                    self.no_delete = YLeaf(YType.boolean, "no-delete")

                                                    self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                                    self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                                    self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                                    self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                                    self.routing_table = YLeaf(YType.boolean, "routing-table")

                                                    self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")
                                                    self._segment_path = lambda: "not-delete"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaDetailData.NotDelete, ['acknowledgement', 'flood_pending', 'free_time', 'maximum_age', 'neighbor_exchange', 'no_delete', 'nsr_ack_pending', 'nsr_flood_required', 'partial_spf', 'rate_limit', 'routing_table', 'sum_orig_pending'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: dn_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\:  bool
                                            
                                            .. attribute:: ls_type
                                            
                                            	LSA type
                                            	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\:  str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsid
                                            
                                            	LS ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: nsf
                                            
                                            	If true,  LSA received from neighbor during NSF
                                            	**type**\:  bool
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.advertising_router = YLeaf(YType.str, "advertising-router")

                                                self.checksum = YLeaf(YType.uint16, "checksum")

                                                self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                                self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                                self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                                self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                                self.lsid = YLeaf(YType.str, "lsid")

                                                self.nsf = YLeaf(YType.boolean, "nsf")

                                                self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                                self._segment_path = lambda: "lsa-header"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                                        class LsaInternalData(Entity):
                                            """
                                            Information pertaining to a specific LSA type
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                            
                                            .. attribute:: internal_lsa_type
                                            
                                            	InternalLSAType
                                            	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                            
                                            .. attribute:: opaque_el_lsa_type
                                            
                                            	Extended Link LSA type
                                            	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                            
                                            .. attribute:: opaque_ep_lsa_type
                                            
                                            	Extende Prefix LSA type
                                            	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                            
                                            .. attribute:: opaque_grace_lsa
                                            
                                            	Opaque\-link, opaque type 3 Grace LSA
                                            	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                            
                                            .. attribute:: opaque_link_lsa_type
                                            
                                            	Opaque\-Link LSA
                                            	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                            
                                            .. attribute:: opaque_mpls_te_lsa_type
                                            
                                            	Opaque\-Area, opaque type 1 LSA
                                            	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                            
                                            .. attribute:: opaque_router_info_lsa_type
                                            
                                            	Opaque Router Information LSA
                                            	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                            
                                            .. attribute:: summary_lsa_type
                                            
                                            	Summary LSA
                                            	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, self).__init__()

                                                self.yang_name = "lsa-internal-data"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType), "network-lsa-type" : ("network_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType), "opaque-el-lsa-type" : ("opaque_el_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType), "opaque-ep-lsa-type" : ("opaque_ep_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType), "opaque-grace-lsa" : ("opaque_grace_lsa", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa), "opaque-link-lsa-type" : ("opaque_link_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType), "opaque-mpls-te-lsa-type" : ("opaque_mpls_te_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType), "opaque-router-info-lsa-type" : ("opaque_router_info_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType), "router-lsa-type" : ("router_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType), "summary-lsa-type" : ("summary_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType)}
                                                self._child_list_classes = {}

                                                self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                                self.external_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                                self._children_yang_names.add("external-lsa-type")

                                                self.network_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                                self._children_yang_names.add("network-lsa-type")

                                                self.opaque_el_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                                self.opaque_el_lsa_type.parent = self
                                                self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                                self._children_yang_names.add("opaque-el-lsa-type")

                                                self.opaque_ep_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                                self.opaque_ep_lsa_type.parent = self
                                                self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                                self._children_yang_names.add("opaque-ep-lsa-type")

                                                self.opaque_grace_lsa = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                                self.opaque_grace_lsa.parent = self
                                                self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                                self._children_yang_names.add("opaque-grace-lsa")

                                                self.opaque_link_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                                self.opaque_link_lsa_type.parent = self
                                                self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                                self._children_yang_names.add("opaque-link-lsa-type")

                                                self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                                self.opaque_mpls_te_lsa_type.parent = self
                                                self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                                self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                                self.opaque_router_info_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                                self.opaque_router_info_lsa_type.parent = self
                                                self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                                self._children_yang_names.add("opaque-router-info-lsa-type")

                                                self.router_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                                self._children_yang_names.add("router-lsa-type")

                                                self.summary_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                                self.summary_lsa_type.parent = self
                                                self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                                self._children_yang_names.add("summary-lsa-type")
                                                self._segment_path = lambda: "lsa-internal-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData, ['internal_lsa_type'], name, value)


                                            class ExternalLsaType(Entity):
                                                """
                                                External LSA
                                                
                                                .. attribute:: external_prefix_length
                                                
                                                	Prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: external_tos_metric
                                                
                                                	Type of service information
                                                	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                                
                                                .. attribute:: internal_external_lsa
                                                
                                                	If true, internal max\-metric LSA
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                                    self.yang_name = "external-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"external-tos-metric" : ("external_tos_metric", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric)}

                                                    self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                                    self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                                    self.external_tos_metric = YList(self)
                                                    self._segment_path = lambda: "external-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType, ['external_prefix_length', 'internal_external_lsa'], name, value)


                                                class ExternalTosMetric(Entity):
                                                    """
                                                    Type of service information
                                                    
                                                    .. attribute:: external_metric
                                                    
                                                    	Cost of this route
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: external_metric_type
                                                    
                                                    	External LSA metric type
                                                    	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                                    
                                                    .. attribute:: external_tag
                                                    
                                                    	Route Tag
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: external_tos
                                                    
                                                    	Type of Service
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: forwarding_address
                                                    
                                                    	Forwarding Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                                        self.yang_name = "external-tos-metric"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.external_metric = YLeaf(YType.uint32, "external-metric")

                                                        self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                                        self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                        self.external_tos = YLeaf(YType.uint32, "external-tos")

                                                        self.forwarding_address = YLeaf(YType.str, "forwarding-address")
                                                        self._segment_path = lambda: "external-tos-metric"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, ['external_metric', 'external_metric_type', 'external_tag', 'external_tos', 'forwarding_address'], name, value)


                                            class NetworkLsaType(Entity):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                                
                                                .. attribute:: network_prefix_length
                                                
                                                	Network prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                                    self.yang_name = "network-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"neighbor-router" : ("neighbor_router", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter)}

                                                    self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                                    self.neighbor_router = YList(self)
                                                    self._segment_path = lambda: "network-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType, ['network_prefix_length'], name, value)


                                                class NeighborRouter(Entity):
                                                    """
                                                    Neighbor router list
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                                        self.yang_name = "neighbor-router"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.str, "entry")
                                                        self._segment_path = lambda: "neighbor-router"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, ['entry'], name, value)


                                            class OpaqueElLsaType(Entity):
                                                """
                                                Extended Link LSA type
                                                
                                                .. attribute:: tlv
                                                
                                                	List of TLVs
                                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                                    self.yang_name = "opaque-el-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv)}

                                                    self.tlv = YList(self)
                                                    self._segment_path = lambda: "opaque-el-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, [], name, value)


                                                class Tlv(Entity):
                                                    """
                                                    List of TLVs
                                                    
                                                    .. attribute:: mpls_dste_link
                                                    
                                                    	MPLS DS\-TE supported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: mpls_router_id
                                                    
                                                    	MPLS\-TE Router ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: te_link_sub_tlv
                                                    
                                                    	List of Sub\-TLVs
                                                    	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                                    
                                                    .. attribute:: tlv_data
                                                    
                                                    	TLV direct data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tlv_length
                                                    
                                                    	Length of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tlv_type
                                                    
                                                    	Type of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                                        self.yang_name = "tlv"
                                                        self.yang_parent_name = "opaque-el-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv)}

                                                        self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                        self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                        self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                        self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                        self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                        self.te_link_sub_tlv = YList(self)
                                                        self._segment_path = lambda: "tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                                    class TeLinkSubTlv(Entity):
                                                        """
                                                        List of Sub\-TLVs
                                                        
                                                        .. attribute:: sub_tlv_length
                                                        
                                                        	Length of sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sub_tlv_type
                                                        
                                                        	Type of sub TLV
                                                        	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                        
                                                        .. attribute:: sub_tlv_value
                                                        
                                                        	Value of sub TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                            self.yang_name = "te-link-sub-tlv"
                                                            self.yang_parent_name = "tlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                            self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                            self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                            self._segment_path = lambda: "te-link-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                            class OpaqueEpLsaType(Entity):
                                                """
                                                Extende Prefix LSA type
                                                
                                                .. attribute:: tlv
                                                
                                                	List of TLVs
                                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                                    self.yang_name = "opaque-ep-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv)}

                                                    self.tlv = YList(self)
                                                    self._segment_path = lambda: "opaque-ep-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, [], name, value)


                                                class Tlv(Entity):
                                                    """
                                                    List of TLVs
                                                    
                                                    .. attribute:: mpls_dste_link
                                                    
                                                    	MPLS DS\-TE supported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: mpls_router_id
                                                    
                                                    	MPLS\-TE Router ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: te_link_sub_tlv
                                                    
                                                    	List of Sub\-TLVs
                                                    	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                                    
                                                    .. attribute:: tlv_data
                                                    
                                                    	TLV direct data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tlv_length
                                                    
                                                    	Length of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tlv_type
                                                    
                                                    	Type of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                                        self.yang_name = "tlv"
                                                        self.yang_parent_name = "opaque-ep-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv)}

                                                        self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                        self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                        self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                        self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                        self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                        self.te_link_sub_tlv = YList(self)
                                                        self._segment_path = lambda: "tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                                    class TeLinkSubTlv(Entity):
                                                        """
                                                        List of Sub\-TLVs
                                                        
                                                        .. attribute:: sub_tlv_length
                                                        
                                                        	Length of sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sub_tlv_type
                                                        
                                                        	Type of sub TLV
                                                        	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                        
                                                        .. attribute:: sub_tlv_value
                                                        
                                                        	Value of sub TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                            self.yang_name = "te-link-sub-tlv"
                                                            self.yang_parent_name = "tlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                            self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                            self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                            self._segment_path = lambda: "te-link-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                            class OpaqueGraceLsa(Entity):
                                                """
                                                Opaque\-link, opaque type 3 Grace LSA
                                                
                                                .. attribute:: grace_period
                                                
                                                	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                                
                                                .. attribute:: ip_address
                                                
                                                	IP interface address on the subnet associated with the grace LSA
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                                    self.yang_name = "opaque-grace-lsa"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.grace_period = YLeaf(YType.uint32, "grace-period")

                                                    self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                                    self.ip_address = YLeaf(YType.str, "ip-address")
                                                    self._segment_path = lambda: "opaque-grace-lsa"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, ['grace_period', 'grace_reason', 'ip_address'], name, value)


                                            class OpaqueLinkLsaType(Entity):
                                                """
                                                Opaque\-Link LSA
                                                
                                                .. attribute:: opaque_interface_name
                                                
                                                	Interface on which the Opaque link LSA is received
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                                    self.yang_name = "opaque-link-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")
                                                    self._segment_path = lambda: "opaque-link-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, ['opaque_interface_name'], name, value)


                                            class OpaqueMplsTeLsaType(Entity):
                                                """
                                                Opaque\-Area, opaque type 1 LSA
                                                
                                                .. attribute:: tlv
                                                
                                                	List of TLVs
                                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                                    self.yang_name = "opaque-mpls-te-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv)}

                                                    self.tlv = YList(self)
                                                    self._segment_path = lambda: "opaque-mpls-te-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, [], name, value)


                                                class Tlv(Entity):
                                                    """
                                                    List of TLVs
                                                    
                                                    .. attribute:: mpls_dste_link
                                                    
                                                    	MPLS DS\-TE supported
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: mpls_router_id
                                                    
                                                    	MPLS\-TE Router ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: te_link_sub_tlv
                                                    
                                                    	List of Sub\-TLVs
                                                    	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                                    
                                                    .. attribute:: tlv_data
                                                    
                                                    	TLV direct data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                    
                                                    .. attribute:: tlv_length
                                                    
                                                    	Length of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: tlv_type
                                                    
                                                    	Type of top\-level TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                                        self.yang_name = "tlv"
                                                        self.yang_parent_name = "opaque-mpls-te-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv)}

                                                        self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                        self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                        self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                        self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                        self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                        self.te_link_sub_tlv = YList(self)
                                                        self._segment_path = lambda: "tlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                                    class TeLinkSubTlv(Entity):
                                                        """
                                                        List of Sub\-TLVs
                                                        
                                                        .. attribute:: sub_tlv_length
                                                        
                                                        	Length of sub TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sub_tlv_type
                                                        
                                                        	Type of sub TLV
                                                        	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                        
                                                        .. attribute:: sub_tlv_value
                                                        
                                                        	Value of sub TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                            self.yang_name = "te-link-sub-tlv"
                                                            self.yang_parent_name = "tlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                            self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                            self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                            self._segment_path = lambda: "te-link-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                            class OpaqueRouterInfoLsaType(Entity):
                                                """
                                                Opaque Router Information LSA
                                                
                                                .. attribute:: opaque_ri_interface_name
                                                
                                                	Interface on which this Link\-Local Opaque link LSA is received
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: opaque_rilsa_scope
                                                
                                                	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                                	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                                
                                                .. attribute:: opaque_ritlv
                                                
                                                	Router Information TLV
                                                	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                                    self.yang_name = "opaque-router-info-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"opaque-ritlv" : ("opaque_ritlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv)}

                                                    self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                                    self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                                    self.opaque_ritlv = YList(self)
                                                    self._segment_path = lambda: "opaque-router-info-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, ['opaque_ri_interface_name', 'opaque_rilsa_scope'], name, value)


                                                class OpaqueRitlv(Entity):
                                                    """
                                                    Router Information TLV
                                                    
                                                    .. attribute:: node_msdtlv
                                                    
                                                    	Node MSD TLV
                                                    	**type**\:   :py:class:`NodeMsdtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv>`
                                                    
                                                    .. attribute:: pcedtlv
                                                    
                                                    	PCE Discovery TLV
                                                    	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                                    
                                                    .. attribute:: ritlv_internal_type
                                                    
                                                    	RITLVInternalType
                                                    	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                                    
                                                    .. attribute:: rtr_cap_tlv
                                                    
                                                    	Rtr Cap TLV
                                                    	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                                    
                                                    .. attribute:: sr_algo_tlv
                                                    
                                                    	SR Algorithm TLV
                                                    	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                                    
                                                    .. attribute:: sr_range_tlv
                                                    
                                                    	SR Range TLV
                                                    	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                                    
                                                    .. attribute:: unknown_tlv
                                                    
                                                    	Unknown Rtr Info TLV
                                                    	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                                        self.yang_name = "opaque-ritlv"
                                                        self.yang_parent_name = "opaque-router-info-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"node-msdtlv" : ("node_msdtlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv), "pcedtlv" : ("pcedtlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv), "rtr-cap-tlv" : ("rtr_cap_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv), "sr-algo-tlv" : ("sr_algo_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv), "sr-range-tlv" : ("sr_range_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv), "unknown-tlv" : ("unknown_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv)}
                                                        self._child_list_classes = {}

                                                        self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                                        self.node_msdtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv()
                                                        self.node_msdtlv.parent = self
                                                        self._children_name_map["node_msdtlv"] = "node-msdtlv"
                                                        self._children_yang_names.add("node-msdtlv")

                                                        self.pcedtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                        self.pcedtlv.parent = self
                                                        self._children_name_map["pcedtlv"] = "pcedtlv"
                                                        self._children_yang_names.add("pcedtlv")

                                                        self.rtr_cap_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                        self.rtr_cap_tlv.parent = self
                                                        self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                        self._children_yang_names.add("rtr-cap-tlv")

                                                        self.sr_algo_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                        self.sr_algo_tlv.parent = self
                                                        self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                        self._children_yang_names.add("sr-algo-tlv")

                                                        self.sr_range_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                        self.sr_range_tlv.parent = self
                                                        self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                        self._children_yang_names.add("sr-range-tlv")

                                                        self.unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                        self.unknown_tlv.parent = self
                                                        self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                        self._children_yang_names.add("unknown-tlv")
                                                        self._segment_path = lambda: "opaque-ritlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, ['ritlv_internal_type'], name, value)


                                                    class NodeMsdtlv(Entity):
                                                        """
                                                        Node MSD TLV
                                                        
                                                        .. attribute:: node_msd_sub_types
                                                        
                                                        	Node MSD Subtypes
                                                        	**type**\:   :py:class:`NodeMsdSubTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes>`
                                                        
                                                        .. attribute:: node_msdtlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, self).__init__()

                                                            self.yang_name = "node-msdtlv"
                                                            self.yang_parent_name = "opaque-ritlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"node-msd-sub-types" : ("node_msd_sub_types", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes)}
                                                            self._child_list_classes = {}

                                                            self.node_msdtlv_length = YLeaf(YType.uint16, "node-msdtlv-length")

                                                            self.node_msd_sub_types = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes()
                                                            self.node_msd_sub_types.parent = self
                                                            self._children_name_map["node_msd_sub_types"] = "node-msd-sub-types"
                                                            self._children_yang_names.add("node-msd-sub-types")
                                                            self._segment_path = lambda: "node-msdtlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, ['node_msdtlv_length'], name, value)


                                                        class NodeMsdSubTypes(Entity):
                                                            """
                                                            Node MSD Subtypes
                                                            
                                                            .. attribute:: msd_sub_type
                                                            
                                                            	MSD SubType
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: msd_value
                                                            
                                                            	MSD Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, self).__init__()

                                                                self.yang_name = "node-msd-sub-types"
                                                                self.yang_parent_name = "node-msdtlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.msd_sub_type = YLeaf(YType.uint8, "msd-sub-type")

                                                                self.msd_value = YLeaf(YType.uint8, "msd-value")
                                                                self._segment_path = lambda: "node-msd-sub-types"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, ['msd_sub_type', 'msd_value'], name, value)


                                                    class Pcedtlv(Entity):
                                                        """
                                                        PCE Discovery TLV
                                                        
                                                        .. attribute:: pced_addr
                                                        
                                                        	PCE Address
                                                        	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                                        
                                                        .. attribute:: pced_scope
                                                        
                                                        	PCE Scope Information
                                                        	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                                        
                                                        .. attribute:: pcedtlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                            self.yang_name = "pcedtlv"
                                                            self.yang_parent_name = "opaque-ritlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"pced-addr" : ("pced_addr", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr), "pced-scope" : ("pced_scope", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope)}
                                                            self._child_list_classes = {}

                                                            self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                            self.pced_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                            self.pced_addr.parent = self
                                                            self._children_name_map["pced_addr"] = "pced-addr"
                                                            self._children_yang_names.add("pced-addr")

                                                            self.pced_scope = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                            self.pced_scope.parent = self
                                                            self._children_name_map["pced_scope"] = "pced-scope"
                                                            self._children_yang_names.add("pced-scope")
                                                            self._segment_path = lambda: "pcedtlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, ['pcedtlv_length'], name, value)


                                                        class PcedAddr(Entity):
                                                            """
                                                            PCE Address
                                                            
                                                            .. attribute:: ipv4pce_addr
                                                            
                                                            	IPv4 PCE Address
                                                            	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                            
                                                            .. attribute:: ipv6pce_addr
                                                            
                                                            	IPv6 PCE Address
                                                            	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                            
                                                            .. attribute:: pce_addr_type
                                                            
                                                            	PCEAddrType
                                                            	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                            
                                                            .. attribute:: pce_addr_unknown_tlv
                                                            
                                                            	Unknown PCE Addr TLV
                                                            	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                                self.yang_name = "pced-addr"
                                                                self.yang_parent_name = "pcedtlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"ipv4pce-addr" : ("ipv4pce_addr", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr), "ipv6pce-addr" : ("ipv6pce_addr", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr), "pce-addr-unknown-tlv" : ("pce_addr_unknown_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv)}
                                                                self._child_list_classes = {}

                                                                self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                                self.ipv4pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                                self.ipv4pce_addr.parent = self
                                                                self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                                self._children_yang_names.add("ipv4pce-addr")

                                                                self.ipv6pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                                self.ipv6pce_addr.parent = self
                                                                self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                                self._children_yang_names.add("ipv6pce-addr")

                                                                self.pce_addr_unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                                self.pce_addr_unknown_tlv.parent = self
                                                                self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                                self._children_yang_names.add("pce-addr-unknown-tlv")
                                                                self._segment_path = lambda: "pced-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, ['pce_addr_type'], name, value)


                                                            class Ipv4PceAddr(Entity):
                                                                """
                                                                IPv4 PCE Address
                                                                
                                                                .. attribute:: pceipv4_addr
                                                                
                                                                	PCE IPv4 Address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                                    self.yang_name = "ipv4pce-addr"
                                                                    self.yang_parent_name = "pced-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")
                                                                    self._segment_path = lambda: "ipv4pce-addr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, ['pceipv4_addr'], name, value)


                                                            class Ipv6PceAddr(Entity):
                                                                """
                                                                IPv6 PCE Address
                                                                
                                                                .. attribute:: pceipv6_addr
                                                                
                                                                	PCE IPv6 Address
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                                    self.yang_name = "ipv6pce-addr"
                                                                    self.yang_parent_name = "pced-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")
                                                                    self._segment_path = lambda: "ipv6pce-addr"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, ['pceipv6_addr'], name, value)


                                                            class PceAddrUnknownTlv(Entity):
                                                                """
                                                                Unknown PCE Addr TLV
                                                                
                                                                .. attribute:: ri_gen_tlv_length
                                                                
                                                                	Length of TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ri_gen_tlv_type
                                                                
                                                                	Type of TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ri_genvalue
                                                                
                                                                	Data in TLV
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                                    self.yang_name = "pce-addr-unknown-tlv"
                                                                    self.yang_parent_name = "pced-addr"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {}

                                                                    self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                                    self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                                    self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                                    self._segment_path = lambda: "pce-addr-unknown-tlv"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                                        class PcedScope(Entity):
                                                            """
                                                            PCE Scope Information
                                                            
                                                            .. attribute:: all_scope_info_bits
                                                            
                                                            	PCE Scope Information
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: lbit
                                                            
                                                            	L Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: pref_l
                                                            
                                                            	Pref L
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pref_r
                                                            
                                                            	Pref R
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pref_s
                                                            
                                                            	Pref S
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: pref_y
                                                            
                                                            	Pref Y
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: rbit
                                                            
                                                            	R Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: rd_bit
                                                            
                                                            	Rd Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: sbit
                                                            
                                                            	S Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: sd_bit
                                                            
                                                            	Sd Bit
                                                            	**type**\:  bool
                                                            
                                                            .. attribute:: ybit
                                                            
                                                            	Y Bit
                                                            	**type**\:  bool
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                                self.yang_name = "pced-scope"
                                                                self.yang_parent_name = "pcedtlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                                self.lbit = YLeaf(YType.boolean, "lbit")

                                                                self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                                self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                                self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                                self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                                self.rbit = YLeaf(YType.boolean, "rbit")

                                                                self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                                self.sbit = YLeaf(YType.boolean, "sbit")

                                                                self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                                self.ybit = YLeaf(YType.boolean, "ybit")
                                                                self._segment_path = lambda: "pced-scope"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, ['all_scope_info_bits', 'lbit', 'pref_l', 'pref_r', 'pref_s', 'pref_y', 'rbit', 'rd_bit', 'sbit', 'sd_bit', 'ybit'], name, value)


                                                    class RtrCapTlv(Entity):
                                                        """
                                                        Rtr Cap TLV
                                                        
                                                        .. attribute:: rtr_cap_additional_info
                                                        
                                                        	Additional Information in TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        .. attribute:: rtr_cap_all_bits
                                                        
                                                        	All capability bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: rtr_cap_area_te
                                                        
                                                        	Traffic Engineering capability of area
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_graceful_restart
                                                        
                                                        	Graceful Restart Capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_graceful_restart_helper
                                                        
                                                        	Graceful Restart Helper Capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_p2plan
                                                        
                                                        	P2P LAN Capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_stub_rtr
                                                        
                                                        	Stub Router capability
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_te_exp
                                                        
                                                        	TE Experimental bit
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: rtr_cap_tlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                            self.yang_name = "rtr-cap-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                            self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                            self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                            self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                            self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                            self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                            self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                            self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                            self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")
                                                            self._segment_path = lambda: "rtr-cap-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, ['rtr_cap_additional_info', 'rtr_cap_all_bits', 'rtr_cap_area_te', 'rtr_cap_graceful_restart', 'rtr_cap_graceful_restart_helper', 'rtr_cap_p2plan', 'rtr_cap_stub_rtr', 'rtr_cap_te_exp', 'rtr_cap_tlv_length'], name, value)


                                                    class SrAlgoTlv(Entity):
                                                        """
                                                        SR Algorithm TLV
                                                        
                                                        .. attribute:: sr_algo_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sr_algo_value
                                                        
                                                        	SR Algorithms
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                            self.yang_name = "sr-algo-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                            self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")
                                                            self._segment_path = lambda: "sr-algo-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, ['sr_algo_length', 'sr_algo_value'], name, value)


                                                    class SrRangeTlv(Entity):
                                                        """
                                                        SR Range TLV
                                                        
                                                        .. attribute:: sidtlv
                                                        
                                                        	SID sub\-TLV
                                                        	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                                        
                                                        .. attribute:: sr_range_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: sr_range_size
                                                        
                                                        	SR Range Size
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                            self.yang_name = "sr-range-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"sidtlv" : ("sidtlv", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv)}
                                                            self._child_list_classes = {}

                                                            self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                            self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                            self.sidtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                            self.sidtlv.parent = self
                                                            self._children_name_map["sidtlv"] = "sidtlv"
                                                            self._children_yang_names.add("sidtlv")
                                                            self._segment_path = lambda: "sr-range-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, ['sr_range_length', 'sr_range_size'], name, value)


                                                        class Sidtlv(Entity):
                                                            """
                                                            SID sub\-TLV
                                                            
                                                            .. attribute:: sr_sid_length
                                                            
                                                            	Length of sub\-TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: sr_sid_value
                                                            
                                                            	SID Value
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                                self.yang_name = "sidtlv"
                                                                self.yang_parent_name = "sr-range-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                                self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")
                                                                self._segment_path = lambda: "sidtlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, ['sr_sid_length', 'sr_sid_value'], name, value)


                                                    class UnknownTlv(Entity):
                                                        """
                                                        Unknown Rtr Info TLV
                                                        
                                                        .. attribute:: ri_gen_tlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_gen_tlv_type
                                                        
                                                        	Type of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_genvalue
                                                        
                                                        	Data in TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                            self.yang_name = "unknown-tlv"
                                                            self.yang_parent_name = "opaque-ritlv"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                            self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                            self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                            self._segment_path = lambda: "unknown-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                            class RouterLsaType(Entity):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: internal_link
                                                
                                                	List of links for internal LSA
                                                	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                                
                                                .. attribute:: internal_lsa
                                                
                                                	If true, internal LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                                
                                                .. attribute:: router_abr
                                                
                                                	If True, router is an Area Border Router
                                                	**type**\:  bool
                                                
                                                .. attribute:: router_asbr
                                                
                                                	If True, router is an Autonomous system Border Router
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                                    self.yang_name = "router-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"internal-link" : ("internal_link", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink), "link" : ("link", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link)}

                                                    self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                                    self.router_abr = YLeaf(YType.boolean, "router-abr")

                                                    self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                                    self.internal_link = YList(self)
                                                    self.link = YList(self)
                                                    self._segment_path = lambda: "router-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType, ['internal_lsa', 'router_abr', 'router_asbr'], name, value)


                                                class InternalLink(Entity):
                                                    """
                                                    List of links for internal LSA
                                                    
                                                    .. attribute:: link_data
                                                    
                                                    	Link Data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	Link ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	Cost for using this link
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_tos
                                                    
                                                    	List of type of service metrics
                                                    	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                                        self.yang_name = "internal-link"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos)}

                                                        self.link_data = YLeaf(YType.str, "link-data")

                                                        self.link_id = YLeaf(YType.str, "link-id")

                                                        self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                        self.link_type = YLeaf(YType.enumeration, "link-type")

                                                        self.link_tos = YList(self)
                                                        self._segment_path = lambda: "internal-link"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                                    class LinkTos(Entity):
                                                        """
                                                        List of type of service metrics
                                                        
                                                        .. attribute:: router_tos
                                                        
                                                        	Type of Service
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tos_cost
                                                        
                                                        	Type of service specific metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                            self.yang_name = "link-tos"
                                                            self.yang_parent_name = "internal-link"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                            self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                            self._segment_path = lambda: "link-tos"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                                class Link(Entity):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_data
                                                    
                                                    	Link Data
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	Link ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	Cost for using this link
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_tos
                                                    
                                                    	List of type of service metrics
                                                    	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                                        self.yang_name = "link"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos)}

                                                        self.link_data = YLeaf(YType.str, "link-data")

                                                        self.link_id = YLeaf(YType.str, "link-id")

                                                        self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                        self.link_type = YLeaf(YType.enumeration, "link-type")

                                                        self.link_tos = YList(self)
                                                        self._segment_path = lambda: "link"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                                    class LinkTos(Entity):
                                                        """
                                                        List of type of service metrics
                                                        
                                                        .. attribute:: router_tos
                                                        
                                                        	Type of Service
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: tos_cost
                                                        
                                                        	Type of service specific metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                            self.yang_name = "link-tos"
                                                            self.yang_parent_name = "link"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                            self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                            self._segment_path = lambda: "link-tos"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                            class SummaryLsaType(Entity):
                                                """
                                                Summary LSA
                                                
                                                .. attribute:: internal_sum_lsa
                                                
                                                	If true, internal max\-metric LSA
                                                	**type**\:  bool
                                                
                                                .. attribute:: summary_lsa_metric
                                                
                                                	Metric
                                                	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                                
                                                .. attribute:: summary_prefix_length
                                                
                                                	Summary LSA prefix length
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                                    self.yang_name = "summary-lsa-type"
                                                    self.yang_parent_name = "lsa-internal-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"summary-lsa-metric" : ("summary_lsa_metric", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric)}

                                                    self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                                    self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                                    self.summary_lsa_metric = YList(self)
                                                    self._segment_path = lambda: "summary-lsa-type"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType, ['internal_sum_lsa', 'summary_prefix_length'], name, value)


                                                class SummaryLsaMetric(Entity):
                                                    """
                                                    Metric
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                                        self.yang_name = "summary-lsa-metric"
                                                        self.yang_parent_name = "summary-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "summary-lsa-metric"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseAreas.DatabaseArea.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, ['entry'], name, value)


                        class DatabaseSummaries(Entity):
                            """
                            Link State database summary table
                            
                            .. attribute:: database_summary
                            
                            	Link State Database summary for a particular area
                            	**type**\: list of    :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries, self).__init__()

                                self.yang_name = "database-summaries"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"database-summary" : ("database_summary", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary)}

                                self.database_summary = YList(self)
                                self._segment_path = lambda: "database-summaries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries, [], name, value)


                            class DatabaseSummary(Entity):
                                """
                                Link State Database summary for a particular
                                area
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: area_lsa_counter
                                
                                	Summary counters for Area scope LSAs
                                	**type**\: list of    :py:class:`AreaLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter>`
                                
                                .. attribute:: dbase_sum_area_id_string
                                
                                	Area id
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary, self).__init__()

                                    self.yang_name = "database-summary"
                                    self.yang_parent_name = "database-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-lsa-counter" : ("area_lsa_counter", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter)}

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.dbase_sum_area_id_string = YLeaf(YType.str, "dbase-sum-area-id-string")

                                    self.area_lsa_counter = YList(self)
                                    self._segment_path = lambda: "database-summary" + "[area-id='" + self.area_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary, ['area_id', 'dbase_sum_area_id_string'], name, value)


                                class AreaLsaCounter(Entity):
                                    """
                                    Summary counters for Area scope LSAs
                                    
                                    .. attribute:: lsa_count
                                    
                                    	Number of LSAs of this type
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_delete_count
                                    
                                    	Number of deleted LSAs of this type
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_maxage_count
                                    
                                    	Number of MaxAged LSAs of this type
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_self_count
                                    
                                    	Number of self\-generated LSAs
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: lsa_type
                                    
                                    	Type of LSAs
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, self).__init__()

                                        self.yang_name = "area-lsa-counter"
                                        self.yang_parent_name = "database-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                        self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                        self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                        self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                        self.lsa_type = YLeaf(YType.enumeration, "lsa-type")
                                        self._segment_path = lambda: "area-lsa-counter"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaries.DatabaseSummary.AreaLsaCounter, ['lsa_count', 'lsa_delete_count', 'lsa_maxage_count', 'lsa_self_count', 'lsa_type'], name, value)


                        class DatabaseSummaryAs(Entity):
                            """
                            Link State Database summary for the AS
                            
                            .. attribute:: as_lsa_counter
                            
                            	Summary counter for AS scope LSAs
                            	**type**\: list of    :py:class:`AsLsaCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs, self).__init__()

                                self.yang_name = "database-summary-as"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"as-lsa-counter" : ("as_lsa_counter", Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter)}

                                self.as_lsa_counter = YList(self)
                                self._segment_path = lambda: "database-summary-as"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs, [], name, value)


                            class AsLsaCounter(Entity):
                                """
                                Summary counter for AS scope LSAs
                                
                                .. attribute:: lsa_count
                                
                                	Number of LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_delete_count
                                
                                	Number of deleted LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_maxage_count
                                
                                	Number of MaxAged LSAs of this type
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_self_count
                                
                                	Number of self\-generated LSAs
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: lsa_type
                                
                                	Type of LSAs
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter, self).__init__()

                                    self.yang_name = "as-lsa-counter"
                                    self.yang_parent_name = "database-summary-as"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.lsa_count = YLeaf(YType.int32, "lsa-count")

                                    self.lsa_delete_count = YLeaf(YType.int32, "lsa-delete-count")

                                    self.lsa_maxage_count = YLeaf(YType.int32, "lsa-maxage-count")

                                    self.lsa_self_count = YLeaf(YType.int32, "lsa-self-count")

                                    self.lsa_type = YLeaf(YType.enumeration, "lsa-type")
                                    self._segment_path = lambda: "as-lsa-counter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.DatabaseSummaryAs.AsLsaCounter, ['lsa_count', 'lsa_delete_count', 'lsa_maxage_count', 'lsa_self_count', 'lsa_type'], name, value)


                        class LsaSummaries(Entity):
                            """
                            Link state advertisement summary table
                            
                            .. attribute:: lsa_summary
                            
                            	LSA summary information
                            	**type**\: list of    :py:class:`LsaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries, self).__init__()

                                self.yang_name = "lsa-summaries"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"lsa-summary" : ("lsa_summary", Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary)}

                                self.lsa_summary = YList(self)
                                self._segment_path = lambda: "lsa-summaries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries, [], name, value)


                            class LsaSummary(Entity):
                                """
                                LSA summary information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: external_tag
                                
                                	Route Tag
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: link_count
                                
                                	Number of links
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ls_type
                                
                                	Link state type
                                	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                
                                .. attribute:: lsa_header
                                
                                	LSA header information
                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary, self).__init__()

                                    self.yang_name = "lsa-summary"
                                    self.yang_parent_name = "lsa-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-header" : ("lsa_header", Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader)}
                                    self._child_list_classes = {}

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.external_tag = YLeaf(YType.uint32, "external-tag")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.link_count = YLeaf(YType.uint16, "link-count")

                                    self.ls_id = YLeaf(YType.str, "ls-id")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader()
                                    self.lsa_header.parent = self
                                    self._children_name_map["lsa_header"] = "lsa-header"
                                    self._children_yang_names.add("lsa-header")
                                    self._segment_path = lambda: "lsa-summary"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary, ['advertising_router', 'area_id', 'external_tag', 'interface_name', 'link_count', 'ls_id', 'ls_type'], name, value)


                                class LsaHeader(Entity):
                                    """
                                    LSA header information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Router ID of Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: checksum
                                    
                                    	Checksum value
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dn_age_lsa
                                    
                                    	If true, Do Not Age this LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: lsa_age
                                    
                                    	LSA's Age (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: lsid
                                    
                                    	LS ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: nsf
                                    
                                    	If true,  LSA received from neighbor during NSF
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequence_number
                                    
                                    	Current Sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader, self).__init__()

                                        self.yang_name = "lsa-header"
                                        self.yang_parent_name = "lsa-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                        self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                        self.lsid = YLeaf(YType.str, "lsid")

                                        self.nsf = YLeaf(YType.boolean, "nsf")

                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                        self._segment_path = lambda: "lsa-header"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.LsaSummaries.LsaSummary.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                        class Lsas(Entity):
                            """
                            Link State Database Table
                            
                            .. attribute:: lsa
                            
                            	Link State Advertisement information
                            	**type**\: list of    :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas, self).__init__()

                                self.yang_name = "lsas"
                                self.yang_parent_name = "database"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"lsa" : ("lsa", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa)}

                                self.lsa = YList(self)
                                self._segment_path = lambda: "lsas"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas, [], name, value)


                            class Lsa(Entity):
                                """
                                Link State Advertisement information
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ls_type
                                
                                	Link state type
                                	**type**\:   :py:class:`OspfLs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLs>`
                                
                                .. attribute:: lsa_detail_data
                                
                                	Detailed LSA Information
                                	**type**\:   :py:class:`LsaDetailData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData>`
                                
                                .. attribute:: lsa_header
                                
                                	Header information
                                	**type**\:   :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader>`
                                
                                .. attribute:: lsa_internal_data
                                
                                	Information pertaining to a specific LSA type
                                	**type**\:   :py:class:`LsaInternalData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "lsas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"lsa-detail-data" : ("lsa_detail_data", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData), "lsa-header" : ("lsa_header", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader), "lsa-internal-data" : ("lsa_internal_data", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData)}
                                    self._child_list_classes = {}

                                    self.advertising_router = YLeaf(YType.str, "advertising-router")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.ls_id = YLeaf(YType.str, "ls-id")

                                    self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                    self.lsa_detail_data = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData()
                                    self.lsa_detail_data.parent = self
                                    self._children_name_map["lsa_detail_data"] = "lsa-detail-data"
                                    self._children_yang_names.add("lsa-detail-data")

                                    self.lsa_header = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader()
                                    self.lsa_header.parent = self
                                    self._children_name_map["lsa_header"] = "lsa-header"
                                    self._children_yang_names.add("lsa-header")

                                    self.lsa_internal_data = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData()
                                    self.lsa_internal_data.parent = self
                                    self._children_name_map["lsa_internal_data"] = "lsa-internal-data"
                                    self._children_yang_names.add("lsa-internal-data")
                                    self._segment_path = lambda: "lsa"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa, ['advertising_router', 'area_id', 'interface_name', 'ls_id', 'ls_type'], name, value)


                                class LsaDetailData(Entity):
                                    """
                                    Detailed LSA Information
                                    
                                    .. attribute:: advertising_router_reachable
                                    
                                    	If true, Advertising Router is reachable
                                    	**type**\:  bool
                                    
                                    .. attribute:: ase_origin
                                    
                                    	External Origin
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: demand_circuit
                                    
                                    	If true, capable of demand circuit as indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    .. attribute:: dn_bit
                                    
                                    	if true, DN bit set on the summary LSA indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    .. attribute:: in_sync
                                    
                                    	Not In Sync With Active
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: length
                                    
                                    	Length of the LSA
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_flood_required_post_fail_over
                                    
                                    	LSA flood required after FO
                                    	**type**\:  bool
                                    
                                    .. attribute:: lsa_last_updated_time
                                    
                                    	Time LSA was last updated
                                    	**type**\:   :py:class:`LsaLastUpdatedTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime>`
                                    
                                    .. attribute:: lsa_prefix_priority
                                    
                                    	Current LSA prefix priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lsa_rate_limit_due_time
                                    
                                    	Due time for rate\-limit timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_throttle_timer
                                    
                                    	LSA throttle timer table information
                                    	**type**\:   :py:class:`LsaThrottleTimer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer>`
                                    
                                    .. attribute:: lsadb_base_clock
                                    
                                    	Clock stamp since boot
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: lsadb_base_time_stamp
                                    
                                    	Current time stamp
                                    	**type**\:   :py:class:`LsadbBaseTimeStamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp>`
                                    
                                    .. attribute:: new_lsa_prefix_priority
                                    
                                    	New LSA prefix priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: not_delete
                                    
                                    	Reason why LSA is not deleted
                                    	**type**\:   :py:class:`NotDelete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete>`
                                    
                                    .. attribute:: nssa_translation
                                    
                                    	If true,  capable of type 7 to 5 translation indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    .. attribute:: routing_bit
                                    
                                    	If true, Routing Bit set on the LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: sum_origin
                                    
                                    	Summary Origin
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: tos_capable
                                    
                                    	If true, type of service capable indicated by LSA's option field
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData, self).__init__()

                                        self.yang_name = "lsa-detail-data"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"lsa-last-updated-time" : ("lsa_last_updated_time", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime), "lsa-throttle-timer" : ("lsa_throttle_timer", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer), "lsadb-base-time-stamp" : ("lsadb_base_time_stamp", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp), "not-delete" : ("not_delete", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete)}
                                        self._child_list_classes = {}

                                        self.advertising_router_reachable = YLeaf(YType.boolean, "advertising-router-reachable")

                                        self.ase_origin = YLeaf(YType.uint16, "ase-origin")

                                        self.demand_circuit = YLeaf(YType.boolean, "demand-circuit")

                                        self.dn_bit = YLeaf(YType.boolean, "dn-bit")

                                        self.in_sync = YLeaf(YType.uint8, "in-sync")

                                        self.length = YLeaf(YType.uint16, "length")

                                        self.lsa_flood_required_post_fail_over = YLeaf(YType.boolean, "lsa-flood-required-post-fail-over")

                                        self.lsa_prefix_priority = YLeaf(YType.uint8, "lsa-prefix-priority")

                                        self.lsa_rate_limit_due_time = YLeaf(YType.uint32, "lsa-rate-limit-due-time")

                                        self.lsadb_base_clock = YLeaf(YType.uint64, "lsadb-base-clock")

                                        self.new_lsa_prefix_priority = YLeaf(YType.uint8, "new-lsa-prefix-priority")

                                        self.nssa_translation = YLeaf(YType.boolean, "nssa-translation")

                                        self.routing_bit = YLeaf(YType.boolean, "routing-bit")

                                        self.sum_origin = YLeaf(YType.uint16, "sum-origin")

                                        self.tos_capable = YLeaf(YType.boolean, "tos-capable")

                                        self.lsa_last_updated_time = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime()
                                        self.lsa_last_updated_time.parent = self
                                        self._children_name_map["lsa_last_updated_time"] = "lsa-last-updated-time"
                                        self._children_yang_names.add("lsa-last-updated-time")

                                        self.lsa_throttle_timer = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer()
                                        self.lsa_throttle_timer.parent = self
                                        self._children_name_map["lsa_throttle_timer"] = "lsa-throttle-timer"
                                        self._children_yang_names.add("lsa-throttle-timer")

                                        self.lsadb_base_time_stamp = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp()
                                        self.lsadb_base_time_stamp.parent = self
                                        self._children_name_map["lsadb_base_time_stamp"] = "lsadb-base-time-stamp"
                                        self._children_yang_names.add("lsadb-base-time-stamp")

                                        self.not_delete = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete()
                                        self.not_delete.parent = self
                                        self._children_name_map["not_delete"] = "not-delete"
                                        self._children_yang_names.add("not-delete")
                                        self._segment_path = lambda: "lsa-detail-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData, ['advertising_router_reachable', 'ase_origin', 'demand_circuit', 'dn_bit', 'in_sync', 'length', 'lsa_flood_required_post_fail_over', 'lsa_prefix_priority', 'lsa_rate_limit_due_time', 'lsadb_base_clock', 'new_lsa_prefix_priority', 'nssa_translation', 'routing_bit', 'sum_origin', 'tos_capable'], name, value)


                                    class LsaLastUpdatedTime(Entity):
                                        """
                                        Time LSA was last updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, self).__init__()

                                            self.yang_name = "lsa-last-updated-time"
                                            self.yang_parent_name = "lsa-detail-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "lsa-last-updated-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaLastUpdatedTime, ['nanosecond', 'second'], name, value)


                                    class LsaThrottleTimer(Entity):
                                        """
                                        LSA throttle timer table information
                                        
                                        .. attribute:: last_inst_minute_table_index
                                        
                                        	Last Minute table index processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: last_inst_second_table_index
                                        
                                        	Last Second table index processed
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timer_location
                                        
                                        	Timer table
                                        	**type**\:   :py:class:`TimerTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.TimerTable>`
                                        
                                        .. attribute:: timer_type
                                        
                                        	Timer type
                                        	**type**\:   :py:class:`Timer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Timer>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, self).__init__()

                                            self.yang_name = "lsa-throttle-timer"
                                            self.yang_parent_name = "lsa-detail-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.last_inst_minute_table_index = YLeaf(YType.uint8, "last-inst-minute-table-index")

                                            self.last_inst_second_table_index = YLeaf(YType.uint8, "last-inst-second-table-index")

                                            self.minute_table_index = YLeaf(YType.uint8, "minute-table-index")

                                            self.second_table_index = YLeaf(YType.uint8, "second-table-index")

                                            self.timer_location = YLeaf(YType.enumeration, "timer-location")

                                            self.timer_type = YLeaf(YType.enumeration, "timer-type")
                                            self._segment_path = lambda: "lsa-throttle-timer"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsaThrottleTimer, ['last_inst_minute_table_index', 'last_inst_second_table_index', 'minute_table_index', 'second_table_index', 'timer_location', 'timer_type'], name, value)


                                    class LsadbBaseTimeStamp(Entity):
                                        """
                                        Current time stamp
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, self).__init__()

                                            self.yang_name = "lsadb-base-time-stamp"
                                            self.yang_parent_name = "lsa-detail-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "lsadb-base-time-stamp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.LsadbBaseTimeStamp, ['nanosecond', 'second'], name, value)


                                    class NotDelete(Entity):
                                        """
                                        Reason why LSA is not deleted
                                        
                                        .. attribute:: acknowledgement
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\:  bool
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_age
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\:  bool
                                        
                                        .. attribute:: no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\:  bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\:  bool
                                        
                                        .. attribute:: partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\:  bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\:  bool
                                        
                                        .. attribute:: routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table
                                        	**type**\:  bool
                                        
                                        .. attribute:: sum_orig_pending
                                        
                                        	If true, the reason not to delete this LSA is because it is pending summary LSA originating
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, self).__init__()

                                            self.yang_name = "not-delete"
                                            self.yang_parent_name = "lsa-detail-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.acknowledgement = YLeaf(YType.boolean, "acknowledgement")

                                            self.flood_pending = YLeaf(YType.boolean, "flood-pending")

                                            self.free_time = YLeaf(YType.uint32, "free-time")

                                            self.maximum_age = YLeaf(YType.boolean, "maximum-age")

                                            self.neighbor_exchange = YLeaf(YType.boolean, "neighbor-exchange")

                                            self.no_delete = YLeaf(YType.boolean, "no-delete")

                                            self.nsr_ack_pending = YLeaf(YType.boolean, "nsr-ack-pending")

                                            self.nsr_flood_required = YLeaf(YType.boolean, "nsr-flood-required")

                                            self.partial_spf = YLeaf(YType.boolean, "partial-spf")

                                            self.rate_limit = YLeaf(YType.boolean, "rate-limit")

                                            self.routing_table = YLeaf(YType.boolean, "routing-table")

                                            self.sum_orig_pending = YLeaf(YType.boolean, "sum-orig-pending")
                                            self._segment_path = lambda: "not-delete"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaDetailData.NotDelete, ['acknowledgement', 'flood_pending', 'free_time', 'maximum_age', 'neighbor_exchange', 'no_delete', 'nsr_ack_pending', 'nsr_flood_required', 'partial_spf', 'rate_limit', 'routing_table', 'sum_orig_pending'], name, value)


                                class LsaHeader(Entity):
                                    """
                                    Header information
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Router ID of Advertising Router
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: checksum
                                    
                                    	Checksum value
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dn_age_lsa
                                    
                                    	If true, Do Not Age this LSA
                                    	**type**\:  bool
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                    
                                    .. attribute:: lsa_age
                                    
                                    	LSA's Age (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: lsid
                                    
                                    	LS ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: nsf
                                    
                                    	If true,  LSA received from neighbor during NSF
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequence_number
                                    
                                    	Current Sequence number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader, self).__init__()

                                        self.yang_name = "lsa-header"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.advertising_router = YLeaf(YType.str, "advertising-router")

                                        self.checksum = YLeaf(YType.uint16, "checksum")

                                        self.dn_age_lsa = YLeaf(YType.boolean, "dn-age-lsa")

                                        self.ls_type = YLeaf(YType.enumeration, "ls-type")

                                        self.lsa_age = YLeaf(YType.uint16, "lsa-age")

                                        self.lsa_area_id = YLeaf(YType.str, "lsa-area-id")

                                        self.lsid = YLeaf(YType.str, "lsid")

                                        self.nsf = YLeaf(YType.boolean, "nsf")

                                        self.sequence_number = YLeaf(YType.uint32, "sequence-number")
                                        self._segment_path = lambda: "lsa-header"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaHeader, ['advertising_router', 'checksum', 'dn_age_lsa', 'ls_type', 'lsa_age', 'lsa_area_id', 'lsid', 'nsf', 'sequence_number'], name, value)


                                class LsaInternalData(Entity):
                                    """
                                    Information pertaining to a specific LSA type
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:   :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType>`
                                    
                                    .. attribute:: internal_lsa_type
                                    
                                    	InternalLSAType
                                    	**type**\:   :py:class:`OspfInternalLsaTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInternalLsaTypes>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:   :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType>`
                                    
                                    .. attribute:: opaque_el_lsa_type
                                    
                                    	Extended Link LSA type
                                    	**type**\:   :py:class:`OpaqueElLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType>`
                                    
                                    .. attribute:: opaque_ep_lsa_type
                                    
                                    	Extende Prefix LSA type
                                    	**type**\:   :py:class:`OpaqueEpLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType>`
                                    
                                    .. attribute:: opaque_grace_lsa
                                    
                                    	Opaque\-link, opaque type 3 Grace LSA
                                    	**type**\:   :py:class:`OpaqueGraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa>`
                                    
                                    .. attribute:: opaque_link_lsa_type
                                    
                                    	Opaque\-Link LSA
                                    	**type**\:   :py:class:`OpaqueLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType>`
                                    
                                    .. attribute:: opaque_mpls_te_lsa_type
                                    
                                    	Opaque\-Area, opaque type 1 LSA
                                    	**type**\:   :py:class:`OpaqueMplsTeLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType>`
                                    
                                    .. attribute:: opaque_router_info_lsa_type
                                    
                                    	Opaque Router Information LSA
                                    	**type**\:   :py:class:`OpaqueRouterInfoLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:   :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType>`
                                    
                                    .. attribute:: summary_lsa_type
                                    
                                    	Summary LSA
                                    	**type**\:   :py:class:`SummaryLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData, self).__init__()

                                        self.yang_name = "lsa-internal-data"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"external-lsa-type" : ("external_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType), "network-lsa-type" : ("network_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType), "opaque-el-lsa-type" : ("opaque_el_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType), "opaque-ep-lsa-type" : ("opaque_ep_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType), "opaque-grace-lsa" : ("opaque_grace_lsa", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa), "opaque-link-lsa-type" : ("opaque_link_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType), "opaque-mpls-te-lsa-type" : ("opaque_mpls_te_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType), "opaque-router-info-lsa-type" : ("opaque_router_info_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType), "router-lsa-type" : ("router_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType), "summary-lsa-type" : ("summary_lsa_type", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType)}
                                        self._child_list_classes = {}

                                        self.internal_lsa_type = YLeaf(YType.enumeration, "internal-lsa-type")

                                        self.external_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"
                                        self._children_yang_names.add("external-lsa-type")

                                        self.network_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"
                                        self._children_yang_names.add("network-lsa-type")

                                        self.opaque_el_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType()
                                        self.opaque_el_lsa_type.parent = self
                                        self._children_name_map["opaque_el_lsa_type"] = "opaque-el-lsa-type"
                                        self._children_yang_names.add("opaque-el-lsa-type")

                                        self.opaque_ep_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType()
                                        self.opaque_ep_lsa_type.parent = self
                                        self._children_name_map["opaque_ep_lsa_type"] = "opaque-ep-lsa-type"
                                        self._children_yang_names.add("opaque-ep-lsa-type")

                                        self.opaque_grace_lsa = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa()
                                        self.opaque_grace_lsa.parent = self
                                        self._children_name_map["opaque_grace_lsa"] = "opaque-grace-lsa"
                                        self._children_yang_names.add("opaque-grace-lsa")

                                        self.opaque_link_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType()
                                        self.opaque_link_lsa_type.parent = self
                                        self._children_name_map["opaque_link_lsa_type"] = "opaque-link-lsa-type"
                                        self._children_yang_names.add("opaque-link-lsa-type")

                                        self.opaque_mpls_te_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType()
                                        self.opaque_mpls_te_lsa_type.parent = self
                                        self._children_name_map["opaque_mpls_te_lsa_type"] = "opaque-mpls-te-lsa-type"
                                        self._children_yang_names.add("opaque-mpls-te-lsa-type")

                                        self.opaque_router_info_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType()
                                        self.opaque_router_info_lsa_type.parent = self
                                        self._children_name_map["opaque_router_info_lsa_type"] = "opaque-router-info-lsa-type"
                                        self._children_yang_names.add("opaque-router-info-lsa-type")

                                        self.router_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"
                                        self._children_yang_names.add("router-lsa-type")

                                        self.summary_lsa_type = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType()
                                        self.summary_lsa_type.parent = self
                                        self._children_name_map["summary_lsa_type"] = "summary-lsa-type"
                                        self._children_yang_names.add("summary-lsa-type")
                                        self._segment_path = lambda: "lsa-internal-data"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData, ['internal_lsa_type'], name, value)


                                    class ExternalLsaType(Entity):
                                        """
                                        External LSA
                                        
                                        .. attribute:: external_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_tos_metric
                                        
                                        	Type of service information
                                        	**type**\: list of    :py:class:`ExternalTosMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric>`
                                        
                                        .. attribute:: internal_external_lsa
                                        
                                        	If true, internal max\-metric LSA
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, self).__init__()

                                            self.yang_name = "external-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"external-tos-metric" : ("external_tos_metric", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric)}

                                            self.external_prefix_length = YLeaf(YType.uint32, "external-prefix-length")

                                            self.internal_external_lsa = YLeaf(YType.boolean, "internal-external-lsa")

                                            self.external_tos_metric = YList(self)
                                            self._segment_path = lambda: "external-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType, ['external_prefix_length', 'internal_external_lsa'], name, value)


                                        class ExternalTosMetric(Entity):
                                            """
                                            Type of service information
                                            
                                            .. attribute:: external_metric
                                            
                                            	Cost of this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: external_metric_type
                                            
                                            	External LSA metric type
                                            	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: external_tos
                                            
                                            	Type of Service
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, self).__init__()

                                                self.yang_name = "external-tos-metric"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.external_metric = YLeaf(YType.uint32, "external-metric")

                                                self.external_metric_type = YLeaf(YType.enumeration, "external-metric-type")

                                                self.external_tag = YLeaf(YType.uint32, "external-tag")

                                                self.external_tos = YLeaf(YType.uint32, "external-tos")

                                                self.forwarding_address = YLeaf(YType.str, "forwarding-address")
                                                self._segment_path = lambda: "external-tos-metric"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.ExternalLsaType.ExternalTosMetric, ['external_metric', 'external_metric_type', 'external_tag', 'external_tos', 'forwarding_address'], name, value)


                                    class NetworkLsaType(Entity):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\: list of    :py:class:`NeighborRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter>`
                                        
                                        .. attribute:: network_prefix_length
                                        
                                        	Network prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, self).__init__()

                                            self.yang_name = "network-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"neighbor-router" : ("neighbor_router", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter)}

                                            self.network_prefix_length = YLeaf(YType.uint32, "network-prefix-length")

                                            self.neighbor_router = YList(self)
                                            self._segment_path = lambda: "network-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType, ['network_prefix_length'], name, value)


                                        class NeighborRouter(Entity):
                                            """
                                            Neighbor router list
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, self).__init__()

                                                self.yang_name = "neighbor-router"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.str, "entry")
                                                self._segment_path = lambda: "neighbor-router"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.NetworkLsaType.NeighborRouter, ['entry'], name, value)


                                    class OpaqueElLsaType(Entity):
                                        """
                                        Extended Link LSA type
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLVs
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, self).__init__()

                                            self.yang_name = "opaque-el-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv)}

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "opaque-el-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType, [], name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLVs
                                            
                                            .. attribute:: mpls_dste_link
                                            
                                            	MPLS DS\-TE supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_router_id
                                            
                                            	MPLS\-TE Router ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: te_link_sub_tlv
                                            
                                            	List of Sub\-TLVs
                                            	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv>`
                                            
                                            .. attribute:: tlv_data
                                            
                                            	TLV direct data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tlv_length
                                            
                                            	Length of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tlv_type
                                            
                                            	Type of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "opaque-el-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv)}

                                                self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                self.te_link_sub_tlv = YList(self)
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                            class TeLinkSubTlv(Entity):
                                                """
                                                List of Sub\-TLVs
                                                
                                                .. attribute:: sub_tlv_length
                                                
                                                	Length of sub TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sub_tlv_type
                                                
                                                	Type of sub TLV
                                                	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                
                                                .. attribute:: sub_tlv_value
                                                
                                                	Value of sub TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                    self.yang_name = "te-link-sub-tlv"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                    self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                    self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                    self._segment_path = lambda: "te-link-sub-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueElLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                    class OpaqueEpLsaType(Entity):
                                        """
                                        Extende Prefix LSA type
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLVs
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, self).__init__()

                                            self.yang_name = "opaque-ep-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv)}

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "opaque-ep-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType, [], name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLVs
                                            
                                            .. attribute:: mpls_dste_link
                                            
                                            	MPLS DS\-TE supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_router_id
                                            
                                            	MPLS\-TE Router ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: te_link_sub_tlv
                                            
                                            	List of Sub\-TLVs
                                            	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv>`
                                            
                                            .. attribute:: tlv_data
                                            
                                            	TLV direct data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tlv_length
                                            
                                            	Length of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tlv_type
                                            
                                            	Type of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "opaque-ep-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv)}

                                                self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                self.te_link_sub_tlv = YList(self)
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                            class TeLinkSubTlv(Entity):
                                                """
                                                List of Sub\-TLVs
                                                
                                                .. attribute:: sub_tlv_length
                                                
                                                	Length of sub TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sub_tlv_type
                                                
                                                	Type of sub TLV
                                                	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                
                                                .. attribute:: sub_tlv_value
                                                
                                                	Value of sub TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                    self.yang_name = "te-link-sub-tlv"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                    self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                    self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                    self._segment_path = lambda: "te-link-sub-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueEpLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                    class OpaqueGraceLsa(Entity):
                                        """
                                        Opaque\-link, opaque type 3 Grace LSA
                                        
                                        .. attribute:: grace_period
                                        
                                        	The amount of time the router's neighbor should advertise it fully adjacent (s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:   :py:class:`OspfGrReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfGrReason>`
                                        
                                        .. attribute:: ip_address
                                        
                                        	IP interface address on the subnet associated with the grace LSA
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, self).__init__()

                                            self.yang_name = "opaque-grace-lsa"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.grace_period = YLeaf(YType.uint32, "grace-period")

                                            self.grace_reason = YLeaf(YType.enumeration, "grace-reason")

                                            self.ip_address = YLeaf(YType.str, "ip-address")
                                            self._segment_path = lambda: "opaque-grace-lsa"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueGraceLsa, ['grace_period', 'grace_reason', 'ip_address'], name, value)


                                    class OpaqueLinkLsaType(Entity):
                                        """
                                        Opaque\-Link LSA
                                        
                                        .. attribute:: opaque_interface_name
                                        
                                        	Interface on which the Opaque link LSA is received
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, self).__init__()

                                            self.yang_name = "opaque-link-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.opaque_interface_name = YLeaf(YType.str, "opaque-interface-name")
                                            self._segment_path = lambda: "opaque-link-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueLinkLsaType, ['opaque_interface_name'], name, value)


                                    class OpaqueMplsTeLsaType(Entity):
                                        """
                                        Opaque\-Area, opaque type 1 LSA
                                        
                                        .. attribute:: tlv
                                        
                                        	List of TLVs
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, self).__init__()

                                            self.yang_name = "opaque-mpls-te-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"tlv" : ("tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv)}

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "opaque-mpls-te-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType, [], name, value)


                                        class Tlv(Entity):
                                            """
                                            List of TLVs
                                            
                                            .. attribute:: mpls_dste_link
                                            
                                            	MPLS DS\-TE supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: mpls_router_id
                                            
                                            	MPLS\-TE Router ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: te_link_sub_tlv
                                            
                                            	List of Sub\-TLVs
                                            	**type**\: list of    :py:class:`TeLinkSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv>`
                                            
                                            .. attribute:: tlv_data
                                            
                                            	TLV direct data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: tlv_length
                                            
                                            	Length of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: tlv_type
                                            
                                            	Type of top\-level TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "opaque-mpls-te-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"te-link-sub-tlv" : ("te_link_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv)}

                                                self.mpls_dste_link = YLeaf(YType.boolean, "mpls-dste-link")

                                                self.mpls_router_id = YLeaf(YType.uint32, "mpls-router-id")

                                                self.tlv_data = YLeaf(YType.str, "tlv-data")

                                                self.tlv_length = YLeaf(YType.uint16, "tlv-length")

                                                self.tlv_type = YLeaf(YType.uint16, "tlv-type")

                                                self.te_link_sub_tlv = YList(self)
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv, ['mpls_dste_link', 'mpls_router_id', 'tlv_data', 'tlv_length', 'tlv_type'], name, value)


                                            class TeLinkSubTlv(Entity):
                                                """
                                                List of Sub\-TLVs
                                                
                                                .. attribute:: sub_tlv_length
                                                
                                                	Length of sub TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sub_tlv_type
                                                
                                                	Type of sub TLV
                                                	**type**\:   :py:class:`Stlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Stlv>`
                                                
                                                .. attribute:: sub_tlv_value
                                                
                                                	Value of sub TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, self).__init__()

                                                    self.yang_name = "te-link-sub-tlv"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.sub_tlv_length = YLeaf(YType.uint16, "sub-tlv-length")

                                                    self.sub_tlv_type = YLeaf(YType.enumeration, "sub-tlv-type")

                                                    self.sub_tlv_value = YLeaf(YType.str, "sub-tlv-value")
                                                    self._segment_path = lambda: "te-link-sub-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueMplsTeLsaType.Tlv.TeLinkSubTlv, ['sub_tlv_length', 'sub_tlv_type', 'sub_tlv_value'], name, value)


                                    class OpaqueRouterInfoLsaType(Entity):
                                        """
                                        Opaque Router Information LSA
                                        
                                        .. attribute:: opaque_ri_interface_name
                                        
                                        	Interface on which this Link\-Local Opaque link LSA is received
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: opaque_rilsa_scope
                                        
                                        	Opaque LSA flooding scope, a.k.a., Opaque LSA Type
                                        	**type**\:   :py:class:`OspfLsaOpqRiScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLsaOpqRiScope>`
                                        
                                        .. attribute:: opaque_ritlv
                                        
                                        	Router Information TLV
                                        	**type**\: list of    :py:class:`OpaqueRitlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, self).__init__()

                                            self.yang_name = "opaque-router-info-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"opaque-ritlv" : ("opaque_ritlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv)}

                                            self.opaque_ri_interface_name = YLeaf(YType.str, "opaque-ri-interface-name")

                                            self.opaque_rilsa_scope = YLeaf(YType.enumeration, "opaque-rilsa-scope")

                                            self.opaque_ritlv = YList(self)
                                            self._segment_path = lambda: "opaque-router-info-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType, ['opaque_ri_interface_name', 'opaque_rilsa_scope'], name, value)


                                        class OpaqueRitlv(Entity):
                                            """
                                            Router Information TLV
                                            
                                            .. attribute:: node_msdtlv
                                            
                                            	Node MSD TLV
                                            	**type**\:   :py:class:`NodeMsdtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv>`
                                            
                                            .. attribute:: pcedtlv
                                            
                                            	PCE Discovery TLV
                                            	**type**\:   :py:class:`Pcedtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv>`
                                            
                                            .. attribute:: ritlv_internal_type
                                            
                                            	RITLVInternalType
                                            	**type**\:   :py:class:`OspfShOpqRiTlvTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiTlvTypes>`
                                            
                                            .. attribute:: rtr_cap_tlv
                                            
                                            	Rtr Cap TLV
                                            	**type**\:   :py:class:`RtrCapTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv>`
                                            
                                            .. attribute:: sr_algo_tlv
                                            
                                            	SR Algorithm TLV
                                            	**type**\:   :py:class:`SrAlgoTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv>`
                                            
                                            .. attribute:: sr_range_tlv
                                            
                                            	SR Range TLV
                                            	**type**\:   :py:class:`SrRangeTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv>`
                                            
                                            .. attribute:: unknown_tlv
                                            
                                            	Unknown Rtr Info TLV
                                            	**type**\:   :py:class:`UnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, self).__init__()

                                                self.yang_name = "opaque-ritlv"
                                                self.yang_parent_name = "opaque-router-info-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"node-msdtlv" : ("node_msdtlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv), "pcedtlv" : ("pcedtlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv), "rtr-cap-tlv" : ("rtr_cap_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv), "sr-algo-tlv" : ("sr_algo_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv), "sr-range-tlv" : ("sr_range_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv), "unknown-tlv" : ("unknown_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv)}
                                                self._child_list_classes = {}

                                                self.ritlv_internal_type = YLeaf(YType.enumeration, "ritlv-internal-type")

                                                self.node_msdtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv()
                                                self.node_msdtlv.parent = self
                                                self._children_name_map["node_msdtlv"] = "node-msdtlv"
                                                self._children_yang_names.add("node-msdtlv")

                                                self.pcedtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv()
                                                self.pcedtlv.parent = self
                                                self._children_name_map["pcedtlv"] = "pcedtlv"
                                                self._children_yang_names.add("pcedtlv")

                                                self.rtr_cap_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv()
                                                self.rtr_cap_tlv.parent = self
                                                self._children_name_map["rtr_cap_tlv"] = "rtr-cap-tlv"
                                                self._children_yang_names.add("rtr-cap-tlv")

                                                self.sr_algo_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv()
                                                self.sr_algo_tlv.parent = self
                                                self._children_name_map["sr_algo_tlv"] = "sr-algo-tlv"
                                                self._children_yang_names.add("sr-algo-tlv")

                                                self.sr_range_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv()
                                                self.sr_range_tlv.parent = self
                                                self._children_name_map["sr_range_tlv"] = "sr-range-tlv"
                                                self._children_yang_names.add("sr-range-tlv")

                                                self.unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv()
                                                self.unknown_tlv.parent = self
                                                self._children_name_map["unknown_tlv"] = "unknown-tlv"
                                                self._children_yang_names.add("unknown-tlv")
                                                self._segment_path = lambda: "opaque-ritlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv, ['ritlv_internal_type'], name, value)


                                            class NodeMsdtlv(Entity):
                                                """
                                                Node MSD TLV
                                                
                                                .. attribute:: node_msd_sub_types
                                                
                                                	Node MSD Subtypes
                                                	**type**\:   :py:class:`NodeMsdSubTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes>`
                                                
                                                .. attribute:: node_msdtlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, self).__init__()

                                                    self.yang_name = "node-msdtlv"
                                                    self.yang_parent_name = "opaque-ritlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"node-msd-sub-types" : ("node_msd_sub_types", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes)}
                                                    self._child_list_classes = {}

                                                    self.node_msdtlv_length = YLeaf(YType.uint16, "node-msdtlv-length")

                                                    self.node_msd_sub_types = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes()
                                                    self.node_msd_sub_types.parent = self
                                                    self._children_name_map["node_msd_sub_types"] = "node-msd-sub-types"
                                                    self._children_yang_names.add("node-msd-sub-types")
                                                    self._segment_path = lambda: "node-msdtlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv, ['node_msdtlv_length'], name, value)


                                                class NodeMsdSubTypes(Entity):
                                                    """
                                                    Node MSD Subtypes
                                                    
                                                    .. attribute:: msd_sub_type
                                                    
                                                    	MSD SubType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: msd_value
                                                    
                                                    	MSD Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, self).__init__()

                                                        self.yang_name = "node-msd-sub-types"
                                                        self.yang_parent_name = "node-msdtlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.msd_sub_type = YLeaf(YType.uint8, "msd-sub-type")

                                                        self.msd_value = YLeaf(YType.uint8, "msd-value")
                                                        self._segment_path = lambda: "node-msd-sub-types"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.NodeMsdtlv.NodeMsdSubTypes, ['msd_sub_type', 'msd_value'], name, value)


                                            class Pcedtlv(Entity):
                                                """
                                                PCE Discovery TLV
                                                
                                                .. attribute:: pced_addr
                                                
                                                	PCE Address
                                                	**type**\:   :py:class:`PcedAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr>`
                                                
                                                .. attribute:: pced_scope
                                                
                                                	PCE Scope Information
                                                	**type**\:   :py:class:`PcedScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope>`
                                                
                                                .. attribute:: pcedtlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, self).__init__()

                                                    self.yang_name = "pcedtlv"
                                                    self.yang_parent_name = "opaque-ritlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"pced-addr" : ("pced_addr", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr), "pced-scope" : ("pced_scope", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope)}
                                                    self._child_list_classes = {}

                                                    self.pcedtlv_length = YLeaf(YType.uint16, "pcedtlv-length")

                                                    self.pced_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr()
                                                    self.pced_addr.parent = self
                                                    self._children_name_map["pced_addr"] = "pced-addr"
                                                    self._children_yang_names.add("pced-addr")

                                                    self.pced_scope = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope()
                                                    self.pced_scope.parent = self
                                                    self._children_name_map["pced_scope"] = "pced-scope"
                                                    self._children_yang_names.add("pced-scope")
                                                    self._segment_path = lambda: "pcedtlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv, ['pcedtlv_length'], name, value)


                                                class PcedAddr(Entity):
                                                    """
                                                    PCE Address
                                                    
                                                    .. attribute:: ipv4pce_addr
                                                    
                                                    	IPv4 PCE Address
                                                    	**type**\:   :py:class:`Ipv4PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr>`
                                                    
                                                    .. attribute:: ipv6pce_addr
                                                    
                                                    	IPv6 PCE Address
                                                    	**type**\:   :py:class:`Ipv6PceAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr>`
                                                    
                                                    .. attribute:: pce_addr_type
                                                    
                                                    	PCEAddrType
                                                    	**type**\:   :py:class:`OspfShOpqRiPceAddrTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfShOpqRiPceAddrTypes>`
                                                    
                                                    .. attribute:: pce_addr_unknown_tlv
                                                    
                                                    	Unknown PCE Addr TLV
                                                    	**type**\:   :py:class:`PceAddrUnknownTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, self).__init__()

                                                        self.yang_name = "pced-addr"
                                                        self.yang_parent_name = "pcedtlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ipv4pce-addr" : ("ipv4pce_addr", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr), "ipv6pce-addr" : ("ipv6pce_addr", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr), "pce-addr-unknown-tlv" : ("pce_addr_unknown_tlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv)}
                                                        self._child_list_classes = {}

                                                        self.pce_addr_type = YLeaf(YType.enumeration, "pce-addr-type")

                                                        self.ipv4pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr()
                                                        self.ipv4pce_addr.parent = self
                                                        self._children_name_map["ipv4pce_addr"] = "ipv4pce-addr"
                                                        self._children_yang_names.add("ipv4pce-addr")

                                                        self.ipv6pce_addr = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr()
                                                        self.ipv6pce_addr.parent = self
                                                        self._children_name_map["ipv6pce_addr"] = "ipv6pce-addr"
                                                        self._children_yang_names.add("ipv6pce-addr")

                                                        self.pce_addr_unknown_tlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv()
                                                        self.pce_addr_unknown_tlv.parent = self
                                                        self._children_name_map["pce_addr_unknown_tlv"] = "pce-addr-unknown-tlv"
                                                        self._children_yang_names.add("pce-addr-unknown-tlv")
                                                        self._segment_path = lambda: "pced-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr, ['pce_addr_type'], name, value)


                                                    class Ipv4PceAddr(Entity):
                                                        """
                                                        IPv4 PCE Address
                                                        
                                                        .. attribute:: pceipv4_addr
                                                        
                                                        	PCE IPv4 Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, self).__init__()

                                                            self.yang_name = "ipv4pce-addr"
                                                            self.yang_parent_name = "pced-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.pceipv4_addr = YLeaf(YType.str, "pceipv4-addr")
                                                            self._segment_path = lambda: "ipv4pce-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv4PceAddr, ['pceipv4_addr'], name, value)


                                                    class Ipv6PceAddr(Entity):
                                                        """
                                                        IPv6 PCE Address
                                                        
                                                        .. attribute:: pceipv6_addr
                                                        
                                                        	PCE IPv6 Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, self).__init__()

                                                            self.yang_name = "ipv6pce-addr"
                                                            self.yang_parent_name = "pced-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.pceipv6_addr = YLeaf(YType.str, "pceipv6-addr")
                                                            self._segment_path = lambda: "ipv6pce-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.Ipv6PceAddr, ['pceipv6_addr'], name, value)


                                                    class PceAddrUnknownTlv(Entity):
                                                        """
                                                        Unknown PCE Addr TLV
                                                        
                                                        .. attribute:: ri_gen_tlv_length
                                                        
                                                        	Length of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_gen_tlv_type
                                                        
                                                        	Type of TLV
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ri_genvalue
                                                        
                                                        	Data in TLV
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, self).__init__()

                                                            self.yang_name = "pce-addr-unknown-tlv"
                                                            self.yang_parent_name = "pced-addr"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                            self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                            self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                            self._segment_path = lambda: "pce-addr-unknown-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedAddr.PceAddrUnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                                class PcedScope(Entity):
                                                    """
                                                    PCE Scope Information
                                                    
                                                    .. attribute:: all_scope_info_bits
                                                    
                                                    	PCE Scope Information
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: lbit
                                                    
                                                    	L Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pref_l
                                                    
                                                    	Pref L
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pref_r
                                                    
                                                    	Pref R
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pref_s
                                                    
                                                    	Pref S
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pref_y
                                                    
                                                    	Pref Y
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rbit
                                                    
                                                    	R Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: rd_bit
                                                    
                                                    	Rd Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sbit
                                                    
                                                    	S Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: sd_bit
                                                    
                                                    	Sd Bit
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: ybit
                                                    
                                                    	Y Bit
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, self).__init__()

                                                        self.yang_name = "pced-scope"
                                                        self.yang_parent_name = "pcedtlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.all_scope_info_bits = YLeaf(YType.uint32, "all-scope-info-bits")

                                                        self.lbit = YLeaf(YType.boolean, "lbit")

                                                        self.pref_l = YLeaf(YType.uint8, "pref-l")

                                                        self.pref_r = YLeaf(YType.uint8, "pref-r")

                                                        self.pref_s = YLeaf(YType.uint8, "pref-s")

                                                        self.pref_y = YLeaf(YType.uint8, "pref-y")

                                                        self.rbit = YLeaf(YType.boolean, "rbit")

                                                        self.rd_bit = YLeaf(YType.boolean, "rd-bit")

                                                        self.sbit = YLeaf(YType.boolean, "sbit")

                                                        self.sd_bit = YLeaf(YType.boolean, "sd-bit")

                                                        self.ybit = YLeaf(YType.boolean, "ybit")
                                                        self._segment_path = lambda: "pced-scope"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.Pcedtlv.PcedScope, ['all_scope_info_bits', 'lbit', 'pref_l', 'pref_r', 'pref_s', 'pref_y', 'rbit', 'rd_bit', 'sbit', 'sd_bit', 'ybit'], name, value)


                                            class RtrCapTlv(Entity):
                                                """
                                                Rtr Cap TLV
                                                
                                                .. attribute:: rtr_cap_additional_info
                                                
                                                	Additional Information in TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: rtr_cap_all_bits
                                                
                                                	All capability bits
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rtr_cap_area_te
                                                
                                                	Traffic Engineering capability of area
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_graceful_restart
                                                
                                                	Graceful Restart Capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_graceful_restart_helper
                                                
                                                	Graceful Restart Helper Capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_p2plan
                                                
                                                	P2P LAN Capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_stub_rtr
                                                
                                                	Stub Router capability
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_te_exp
                                                
                                                	TE Experimental bit
                                                	**type**\:  bool
                                                
                                                .. attribute:: rtr_cap_tlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, self).__init__()

                                                    self.yang_name = "rtr-cap-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.rtr_cap_additional_info = YLeaf(YType.str, "rtr-cap-additional-info")

                                                    self.rtr_cap_all_bits = YLeaf(YType.uint32, "rtr-cap-all-bits")

                                                    self.rtr_cap_area_te = YLeaf(YType.boolean, "rtr-cap-area-te")

                                                    self.rtr_cap_graceful_restart = YLeaf(YType.boolean, "rtr-cap-graceful-restart")

                                                    self.rtr_cap_graceful_restart_helper = YLeaf(YType.boolean, "rtr-cap-graceful-restart-helper")

                                                    self.rtr_cap_p2plan = YLeaf(YType.boolean, "rtr-cap-p2plan")

                                                    self.rtr_cap_stub_rtr = YLeaf(YType.boolean, "rtr-cap-stub-rtr")

                                                    self.rtr_cap_te_exp = YLeaf(YType.boolean, "rtr-cap-te-exp")

                                                    self.rtr_cap_tlv_length = YLeaf(YType.uint16, "rtr-cap-tlv-length")
                                                    self._segment_path = lambda: "rtr-cap-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.RtrCapTlv, ['rtr_cap_additional_info', 'rtr_cap_all_bits', 'rtr_cap_area_te', 'rtr_cap_graceful_restart', 'rtr_cap_graceful_restart_helper', 'rtr_cap_p2plan', 'rtr_cap_stub_rtr', 'rtr_cap_te_exp', 'rtr_cap_tlv_length'], name, value)


                                            class SrAlgoTlv(Entity):
                                                """
                                                SR Algorithm TLV
                                                
                                                .. attribute:: sr_algo_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sr_algo_value
                                                
                                                	SR Algorithms
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, self).__init__()

                                                    self.yang_name = "sr-algo-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.sr_algo_length = YLeaf(YType.uint16, "sr-algo-length")

                                                    self.sr_algo_value = YLeaf(YType.str, "sr-algo-value")
                                                    self._segment_path = lambda: "sr-algo-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrAlgoTlv, ['sr_algo_length', 'sr_algo_value'], name, value)


                                            class SrRangeTlv(Entity):
                                                """
                                                SR Range TLV
                                                
                                                .. attribute:: sidtlv
                                                
                                                	SID sub\-TLV
                                                	**type**\:   :py:class:`Sidtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv>`
                                                
                                                .. attribute:: sr_range_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: sr_range_size
                                                
                                                	SR Range Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, self).__init__()

                                                    self.yang_name = "sr-range-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"sidtlv" : ("sidtlv", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv)}
                                                    self._child_list_classes = {}

                                                    self.sr_range_length = YLeaf(YType.uint16, "sr-range-length")

                                                    self.sr_range_size = YLeaf(YType.uint32, "sr-range-size")

                                                    self.sidtlv = Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv()
                                                    self.sidtlv.parent = self
                                                    self._children_name_map["sidtlv"] = "sidtlv"
                                                    self._children_yang_names.add("sidtlv")
                                                    self._segment_path = lambda: "sr-range-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv, ['sr_range_length', 'sr_range_size'], name, value)


                                                class Sidtlv(Entity):
                                                    """
                                                    SID sub\-TLV
                                                    
                                                    .. attribute:: sr_sid_length
                                                    
                                                    	Length of sub\-TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: sr_sid_value
                                                    
                                                    	SID Value
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, self).__init__()

                                                        self.yang_name = "sidtlv"
                                                        self.yang_parent_name = "sr-range-tlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.sr_sid_length = YLeaf(YType.uint16, "sr-sid-length")

                                                        self.sr_sid_value = YLeaf(YType.uint32, "sr-sid-value")
                                                        self._segment_path = lambda: "sidtlv"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.SrRangeTlv.Sidtlv, ['sr_sid_length', 'sr_sid_value'], name, value)


                                            class UnknownTlv(Entity):
                                                """
                                                Unknown Rtr Info TLV
                                                
                                                .. attribute:: ri_gen_tlv_length
                                                
                                                	Length of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ri_gen_tlv_type
                                                
                                                	Type of TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ri_genvalue
                                                
                                                	Data in TLV
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, self).__init__()

                                                    self.yang_name = "unknown-tlv"
                                                    self.yang_parent_name = "opaque-ritlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.ri_gen_tlv_length = YLeaf(YType.uint16, "ri-gen-tlv-length")

                                                    self.ri_gen_tlv_type = YLeaf(YType.uint16, "ri-gen-tlv-type")

                                                    self.ri_genvalue = YLeaf(YType.str, "ri-genvalue")
                                                    self._segment_path = lambda: "unknown-tlv"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.OpaqueRouterInfoLsaType.OpaqueRitlv.UnknownTlv, ['ri_gen_tlv_length', 'ri_gen_tlv_type', 'ri_genvalue'], name, value)


                                    class RouterLsaType(Entity):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: internal_link
                                        
                                        	List of links for internal LSA
                                        	**type**\: list of    :py:class:`InternalLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink>`
                                        
                                        .. attribute:: internal_lsa
                                        
                                        	If true, internal LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of    :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link>`
                                        
                                        .. attribute:: router_abr
                                        
                                        	If True, router is an Area Border Router
                                        	**type**\:  bool
                                        
                                        .. attribute:: router_asbr
                                        
                                        	If True, router is an Autonomous system Border Router
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, self).__init__()

                                            self.yang_name = "router-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"internal-link" : ("internal_link", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink), "link" : ("link", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link)}

                                            self.internal_lsa = YLeaf(YType.boolean, "internal-lsa")

                                            self.router_abr = YLeaf(YType.boolean, "router-abr")

                                            self.router_asbr = YLeaf(YType.boolean, "router-asbr")

                                            self.internal_link = YList(self)
                                            self.link = YList(self)
                                            self._segment_path = lambda: "router-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType, ['internal_lsa', 'router_abr', 'router_asbr'], name, value)


                                        class InternalLink(Entity):
                                            """
                                            List of links for internal LSA
                                            
                                            .. attribute:: link_data
                                            
                                            	Link Data
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_id
                                            
                                            	Link ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_metric
                                            
                                            	Cost for using this link
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_tos
                                            
                                            	List of type of service metrics
                                            	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos>`
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, self).__init__()

                                                self.yang_name = "internal-link"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos)}

                                                self.link_data = YLeaf(YType.str, "link-data")

                                                self.link_id = YLeaf(YType.str, "link-id")

                                                self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                self.link_type = YLeaf(YType.enumeration, "link-type")

                                                self.link_tos = YList(self)
                                                self._segment_path = lambda: "internal-link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                            class LinkTos(Entity):
                                                """
                                                List of type of service metrics
                                                
                                                .. attribute:: router_tos
                                                
                                                	Type of Service
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service specific metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, self).__init__()

                                                    self.yang_name = "link-tos"
                                                    self.yang_parent_name = "internal-link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                    self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                    self._segment_path = lambda: "link-tos"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.InternalLink.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                        class Link(Entity):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_data
                                            
                                            	Link Data
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_id
                                            
                                            	Link ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: link_metric
                                            
                                            	Cost for using this link
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_tos
                                            
                                            	List of type of service metrics
                                            	**type**\: list of    :py:class:`LinkTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos>`
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:   :py:class:`OspfLinkTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfLinkTypes>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, self).__init__()

                                                self.yang_name = "link"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"link-tos" : ("link_tos", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos)}

                                                self.link_data = YLeaf(YType.str, "link-data")

                                                self.link_id = YLeaf(YType.str, "link-id")

                                                self.link_metric = YLeaf(YType.uint16, "link-metric")

                                                self.link_type = YLeaf(YType.enumeration, "link-type")

                                                self.link_tos = YList(self)
                                                self._segment_path = lambda: "link"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link, ['link_data', 'link_id', 'link_metric', 'link_type'], name, value)


                                            class LinkTos(Entity):
                                                """
                                                List of type of service metrics
                                                
                                                .. attribute:: router_tos
                                                
                                                	Type of Service
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service specific metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, self).__init__()

                                                    self.yang_name = "link-tos"
                                                    self.yang_parent_name = "link"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.router_tos = YLeaf(YType.uint16, "router-tos")

                                                    self.tos_cost = YLeaf(YType.uint16, "tos-cost")
                                                    self._segment_path = lambda: "link-tos"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.RouterLsaType.Link.LinkTos, ['router_tos', 'tos_cost'], name, value)


                                    class SummaryLsaType(Entity):
                                        """
                                        Summary LSA
                                        
                                        .. attribute:: internal_sum_lsa
                                        
                                        	If true, internal max\-metric LSA
                                        	**type**\:  bool
                                        
                                        .. attribute:: summary_lsa_metric
                                        
                                        	Metric
                                        	**type**\: list of    :py:class:`SummaryLsaMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric>`
                                        
                                        .. attribute:: summary_prefix_length
                                        
                                        	Summary LSA prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, self).__init__()

                                            self.yang_name = "summary-lsa-type"
                                            self.yang_parent_name = "lsa-internal-data"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"summary-lsa-metric" : ("summary_lsa_metric", Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric)}

                                            self.internal_sum_lsa = YLeaf(YType.boolean, "internal-sum-lsa")

                                            self.summary_prefix_length = YLeaf(YType.uint32, "summary-prefix-length")

                                            self.summary_lsa_metric = YList(self)
                                            self._segment_path = lambda: "summary-lsa-type"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType, ['internal_sum_lsa', 'summary_prefix_length'], name, value)


                                        class SummaryLsaMetric(Entity):
                                            """
                                            Metric
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, self).__init__()

                                                self.yang_name = "summary-lsa-metric"
                                                self.yang_parent_name = "summary-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "summary-lsa-metric"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Database.Lsas.Lsa.LsaInternalData.SummaryLsaType.SummaryLsaMetric, ['entry'], name, value)


                    class FastReroute(Entity):
                        """
                        Container for FastReroute
                        
                        .. attribute:: topologies
                        
                        	Fast\-reroute topology information table
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"topologies" : ("topologies", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies)}
                            self._child_list_classes = {}

                            self.topologies = Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")
                            self._segment_path = lambda: "fast-reroute"


                        class Topologies(Entity):
                            """
                            Fast\-reroute topology information table
                            
                            .. attribute:: topology
                            
                            	Fast\-reroute topology information
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"topology" : ("topology", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology)}

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Fast\-reroute topology information
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: ipfrr_area_revision
                                
                                	IPFRR Topology Revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipfrr_router_id
                                
                                	OSPF Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipfrr_topo
                                
                                	IPFRR Topology entries
                                	**type**\: list of    :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo>`
                                
                                .. attribute:: ipfrr_topo_area_id
                                
                                	Area ID string in decimal or dotted decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: router_id
                                
                                	Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ipfrr-topo" : ("ipfrr_topo", Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo)}

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.ipfrr_area_revision = YLeaf(YType.uint32, "ipfrr-area-revision")

                                    self.ipfrr_router_id = YLeaf(YType.str, "ipfrr-router-id")

                                    self.ipfrr_topo_area_id = YLeaf(YType.str, "ipfrr-topo-area-id")

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.ipfrr_topo = YList(self)
                                    self._segment_path = lambda: "topology"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology, ['area_id', 'ipfrr_area_revision', 'ipfrr_router_id', 'ipfrr_topo_area_id', 'router_id'], name, value)


                                class IpfrrTopo(Entity):
                                    """
                                    IPFRR Topology entries
                                    
                                    .. attribute:: distance
                                    
                                    	IPFRR Topology Distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: distance_reverse
                                    
                                    	IPFRR Topology Reverse Distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dr
                                    
                                    	IPFRR Topology DR entry
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_sourced
                                    
                                    	IPFRR Topology Neighbor Sourced
                                    	**type**\:  bool
                                    
                                    .. attribute:: node_id
                                    
                                    	IPFRR Topology Node ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: poison
                                    
                                    	IPFRR Topology rSPT poison
                                    	**type**\:  bool
                                    
                                    .. attribute:: revision
                                    
                                    	IPFRR Topology Revision
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: type4
                                    
                                    	IPFRR Topoogy Type\-4 entry
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo, self).__init__()

                                        self.yang_name = "ipfrr-topo"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.distance = YLeaf(YType.uint32, "distance")

                                        self.distance_reverse = YLeaf(YType.uint32, "distance-reverse")

                                        self.dr = YLeaf(YType.boolean, "dr")

                                        self.neighbor_sourced = YLeaf(YType.boolean, "neighbor-sourced")

                                        self.node_id = YLeaf(YType.str, "node-id")

                                        self.poison = YLeaf(YType.boolean, "poison")

                                        self.revision = YLeaf(YType.uint32, "revision")

                                        self.type4 = YLeaf(YType.boolean, "type4")
                                        self._segment_path = lambda: "ipfrr-topo"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FastReroute.Topologies.Topology.IpfrrTopo, ['distance', 'distance_reverse', 'dr', 'neighbor_sourced', 'node_id', 'poison', 'revision', 'type4'], name, value)


                    class FloodListTable(Entity):
                        """
                        Flood list table
                        
                        .. attribute:: flood
                        
                        	Flooding information for a specific interface
                        	**type**\: list of    :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable, self).__init__()

                            self.yang_name = "flood-list-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flood" : ("flood", Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood)}

                            self.flood = YList(self)
                            self._segment_path = lambda: "flood-list-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable, [], name, value)


                        class Flood(Entity):
                            """
                            Flooding information for a specific interface
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: area_flood
                            
                            	Area scope floodlist
                            	**type**\: list of    :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood>`
                            
                            .. attribute:: as_flood
                            
                            	AS scope floodlist
                            	**type**\: list of    :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood>`
                            
                            .. attribute:: flood_interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: flood_lsa_count
                            
                            	Number of LSAs currently being flooded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_pacing_timer
                            
                            	Time until next LS update due (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood, self).__init__()

                                self.yang_name = "flood"
                                self.yang_parent_name = "flood-list-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"area-flood" : ("area_flood", Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood), "as-flood" : ("as_flood", Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood)}

                                self.interface_name = YLeaf(YType.str, "interface-name")

                                self.flood_interface_name = YLeaf(YType.str, "flood-interface-name")

                                self.flood_lsa_count = YLeaf(YType.uint32, "flood-lsa-count")

                                self.flood_pacing_timer = YLeaf(YType.uint32, "flood-pacing-timer")

                                self.area_flood = YList(self)
                                self.as_flood = YList(self)
                                self._segment_path = lambda: "flood" + "[interface-name='" + self.interface_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood, ['interface_name', 'flood_interface_name', 'flood_lsa_count', 'flood_pacing_timer'], name, value)


                            class AreaFlood(Entity):
                                """
                                Area scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood, self).__init__()

                                    self.yang_name = "area-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                    self._segment_path = lambda: "area-flood"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AreaFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                            class AsFlood(Entity):
                                """
                                AS scope floodlist
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the Advertising Router
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_ls_id
                                
                                	LSA ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (s)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_checksum
                                
                                	Checksum of the LSA
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA Type
                                	**type**\:   :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Lsa>`
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood, self).__init__()

                                    self.yang_name = "as-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.header_advertising_router = YLeaf(YType.str, "header-advertising-router")

                                    self.header_ls_id = YLeaf(YType.str, "header-ls-id")

                                    self.header_lsa_age = YLeaf(YType.uint16, "header-lsa-age")

                                    self.header_lsa_checksum = YLeaf(YType.uint16, "header-lsa-checksum")

                                    self.header_lsa_type = YLeaf(YType.enumeration, "header-lsa-type")

                                    self.header_sequence_number = YLeaf(YType.uint32, "header-sequence-number")
                                    self._segment_path = lambda: "as-flood"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.FloodListTable.Flood.AsFlood, ['header_advertising_router', 'header_ls_id', 'header_lsa_age', 'header_lsa_checksum', 'header_lsa_type', 'header_sequence_number'], name, value)


                    class InterfaceInformation(Entity):
                        """
                        Container for OSPF Interfaces/links
                        
                        .. attribute:: interface_briefs
                        
                        	OSPF Interface Brief Table
                        	**type**\:   :py:class:`InterfaceBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs>`
                        
                        .. attribute:: interfaces
                        
                        	OSPF Interface Table
                        	**type**\:   :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces>`
                        
                        .. attribute:: virtual_links
                        
                        	Virtual Link table
                        	**type**\:   :py:class:`VirtualLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation, self).__init__()

                            self.yang_name = "interface-information"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"interface-briefs" : ("interface_briefs", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs), "interfaces" : ("interfaces", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces), "virtual-links" : ("virtual_links", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks)}
                            self._child_list_classes = {}

                            self.interface_briefs = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs()
                            self.interface_briefs.parent = self
                            self._children_name_map["interface_briefs"] = "interface-briefs"
                            self._children_yang_names.add("interface-briefs")

                            self.interfaces = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces()
                            self.interfaces.parent = self
                            self._children_name_map["interfaces"] = "interfaces"
                            self._children_yang_names.add("interfaces")

                            self.virtual_links = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks()
                            self.virtual_links.parent = self
                            self._children_name_map["virtual_links"] = "virtual-links"
                            self._children_yang_names.add("virtual-links")
                            self._segment_path = lambda: "interface-information"


                        class InterfaceBriefs(Entity):
                            """
                            OSPF Interface Brief Table
                            
                            .. attribute:: interface_brief
                            
                            	OSPF interface brief information
                            	**type**\: list of    :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs, self).__init__()

                                self.yang_name = "interface-briefs"
                                self.yang_parent_name = "interface-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface-brief" : ("interface_brief", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief)}

                                self.interface_brief = YList(self)
                                self._segment_path = lambda: "interface-briefs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs, [], name, value)


                            class InterfaceBrief(Entity):
                                """
                                OSPF interface brief information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_adj_neighbor_count
                                
                                	Total number of Adjacent Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Interface in fast detect hold down state
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_neighbor_count
                                
                                	Total number of Neighbors
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, self).__init__()

                                    self.yang_name = "interface-brief"
                                    self.yang_parent_name = "interface-briefs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.interface_madj = YList(self)
                                    self._segment_path = lambda: "interface-brief" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief, ['interface_name', 'interface_address', 'interface_adj_neighbor_count', 'interface_area', 'interface_fast_detect_hold_down', 'interface_link_cost', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_neighbor_count', 'interfaceis_madj', 'ospf_interface_state'], name, value)


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface-brief"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                        self._segment_path = lambda: "interface-madj"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.InterfaceBriefs.InterfaceBrief.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                        class Interfaces(Entity):
                            """
                            OSPF Interface Table
                            
                            .. attribute:: interface
                            
                            	OSPF interface information
                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces, self).__init__()

                                self.yang_name = "interfaces"
                                self.yang_parent_name = "interface-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface" : ("interface", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface)}

                                self.interface = YList(self)
                                self._segment_path = lambda: "interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces, [], name, value)


                            class Interface(Entity):
                                """
                                OSPF interface information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: active_interface
                                
                                	Active interface details
                                	**type**\:   :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface>`
                                
                                .. attribute:: backup_designated_router
                                
                                	If true, backup designated router
                                	**type**\:  bool
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: cfg_cost_fallback
                                
                                	If true, cost fallback is configured
                                	**type**\:  bool
                                
                                .. attribute:: configured_demand_circuit
                                
                                	If true, configured as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\:  bool
                                
                                .. attribute:: configured_ldp_sync_igp_shortcuts
                                
                                	If true, sync igp shortcuts
                                	**type**\:  bool
                                
                                .. attribute:: cost_fallback_active
                                
                                	If true, cost fallback is active
                                	**type**\:  bool
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: designated_router
                                
                                	If true, designated router
                                	**type**\:  bool
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: fast_detect_hold_down_time
                                
                                	Hold\-down time in ms for fast\-detect event
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_detect_hold_down_time_remaining
                                
                                	Remaining hold down time in ms
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fast_reroute_topology_independent_lfa
                                
                                	Topology Independent LFA
                                	**type**\:  bool
                                
                                .. attribute:: fast_reroute_type
                                
                                	IP Fast Reroute Type
                                	**type**\:   :py:class:`Ipfrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ipfrr>`
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hello_interval_ms
                                
                                	Configured hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_count
                                
                                	Ack List Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ack_list_high_watermark
                                
                                	Ack List High Watermark
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_address
                                
                                	Interface IP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_area
                                
                                	Area ID string in decimal or dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: interface_bandwidth
                                
                                	Interface bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_bfd_information
                                
                                	BFD information
                                	**type**\:   :py:class:`InterfaceBfdInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation>`
                                
                                .. attribute:: interface_bkp_labels
                                
                                	Max number of backup labels
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_cost_fallback
                                
                                	Interface fallback cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_dc_bitless_lsa_count
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: interface_fast_detect_hold_down
                                
                                	Link in hold\-down state due to fast detect event
                                	**type**\:  bool
                                
                                .. attribute:: interface_forw
                                
                                	Forward reference interface
                                	**type**\:  bool
                                
                                .. attribute:: interface_last_nsf
                                
                                	Time since last NSF restart (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\:  bool
                                
                                .. attribute:: interface_line_state
                                
                                	If true, line protocol is up
                                	**type**\:  bool
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_lsa_filter
                                
                                	Filter is configured for out going LSAs
                                	**type**\:  bool
                                
                                .. attribute:: interface_madj
                                
                                	Information for multi\-area on the interface
                                	**type**\: list of    :py:class:`InterfaceMadj <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj>`
                                
                                .. attribute:: interface_madj_count
                                
                                	Total number of multi\-area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_mask
                                
                                	Interface IP Mask
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name_xr
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of    :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor>`
                                
                                .. attribute:: interface_nsf
                                
                                	If true, NSF restart in progress on this interface
                                	**type**\:  bool
                                
                                .. attribute:: interface_nsf_enabled
                                
                                	If true, NSF is enabled
                                	**type**\:  bool
                                
                                .. attribute:: interface_pri_labels
                                
                                	Max number of primary labels
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_retransmission_interrval
                                
                                	Configured retransmit interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_sid
                                
                                	Interface SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_sid_n_flag_clear
                                
                                	SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_sid_php_off
                                
                                	SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_srte_labels
                                
                                	Max number of SRTE labels
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:   :py:class:`InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.InterfaceState>`
                                
                                .. attribute:: interface_strict_spf_sid
                                
                                	Interface Strict\-SPF SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_strict_spf_sid_n_flag_clear
                                
                                	Strict\-SPF SID N\-Flag Clear
                                	**type**\:  bool
                                
                                .. attribute:: interface_strict_spf_sid_php_off
                                
                                	Strict\-SPF SID PHP Off
                                	**type**\:  bool
                                
                                .. attribute:: interface_tunnel_flags
                                
                                	Interface tunnel flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_unnum
                                
                                	Unnumbered interface
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: interfaceis_madj
                                
                                	If true, interface is multi\-area
                                	**type**\:  bool
                                
                                .. attribute:: ip_mtu
                                
                                	IP MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ip_sec_addr
                                
                                	Secondary IP address list
                                	**type**\: list of    :py:class:`IpSecAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpSecAddr>`
                                
                                .. attribute:: ipfrr_tiebreakers
                                
                                	IPFRR\-Tiebreakers list
                                	**type**\: list of    :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers>`
                                
                                .. attribute:: is_loopback_stub_network
                                
                                	If true, loopback interface is advertised as a stub network
                                	**type**\:  bool
                                
                                .. attribute:: maximum_packet_size
                                
                                	Maximum Packet Size
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Interface>`
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hello_time_ms
                                
                                	Time until next Hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: passive_interface
                                
                                	If true, passive interface
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_primary_addresses
                                
                                	Prefix Suppression for primary addresses
                                	**type**\:  bool
                                
                                .. attribute:: prefix_suppress_secondary_addresses
                                
                                	Prefix Suppression for secondary addresses
                                	**type**\:  bool
                                
                                .. attribute:: registered_for_link_down_fast_detection
                                
                                	Registered for Link Down Fast Detection
                                	**type**\:  bool
                                
                                .. attribute:: srlg
                                
                                	SRLG Values
                                	**type**\: list of    :py:class:`Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg>`
                                
                                .. attribute:: transmission_delay
                                
                                	Interface Transmission delay
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ttl_security_enabled
                                
                                	TTL security enabled on the interface
                                	**type**\:  bool
                                
                                .. attribute:: ttl_security_hop_count
                                
                                	TTL security hop counts
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"active-interface" : ("active_interface", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface), "interface-bfd-information" : ("interface_bfd_information", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation)}
                                    self._child_list_classes = {"interface-madj" : ("interface_madj", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj), "interface-neighbor" : ("interface_neighbor", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor), "ip-sec-addr" : ("ip_sec_addr", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpSecAddr), "ipfrr-tiebreakers" : ("ipfrr_tiebreakers", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers), "srlg" : ("srlg", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.backup_designated_router = YLeaf(YType.boolean, "backup-designated-router")

                                    self.backup_designated_router_address = YLeaf(YType.str, "backup-designated-router-address")

                                    self.backup_designated_router_id = YLeaf(YType.str, "backup-designated-router-id")

                                    self.cfg_cost_fallback = YLeaf(YType.boolean, "cfg-cost-fallback")

                                    self.configured_demand_circuit = YLeaf(YType.boolean, "configured-demand-circuit")

                                    self.configured_ldp_sync = YLeaf(YType.boolean, "configured-ldp-sync")

                                    self.configured_ldp_sync_igp_shortcuts = YLeaf(YType.boolean, "configured-ldp-sync-igp-shortcuts")

                                    self.cost_fallback_active = YLeaf(YType.boolean, "cost-fallback-active")

                                    self.dead_interval = YLeaf(YType.uint32, "dead-interval")

                                    self.designated_router = YLeaf(YType.boolean, "designated-router")

                                    self.designated_router_address = YLeaf(YType.str, "designated-router-address")

                                    self.designated_router_id = YLeaf(YType.str, "designated-router-id")

                                    self.fast_detect_hold_down_time = YLeaf(YType.uint32, "fast-detect-hold-down-time")

                                    self.fast_detect_hold_down_time_remaining = YLeaf(YType.uint32, "fast-detect-hold-down-time-remaining")

                                    self.fast_reroute_topology_independent_lfa = YLeaf(YType.boolean, "fast-reroute-topology-independent-lfa")

                                    self.fast_reroute_type = YLeaf(YType.enumeration, "fast-reroute-type")

                                    self.hello_interval = YLeaf(YType.uint32, "hello-interval")

                                    self.hello_interval_ms = YLeaf(YType.uint32, "hello-interval-ms")

                                    self.interface_ack_list_count = YLeaf(YType.uint32, "interface-ack-list-count")

                                    self.interface_ack_list_high_watermark = YLeaf(YType.uint32, "interface-ack-list-high-watermark")

                                    self.interface_address = YLeaf(YType.str, "interface-address")

                                    self.interface_area = YLeaf(YType.str, "interface-area")

                                    self.interface_bandwidth = YLeaf(YType.uint32, "interface-bandwidth")

                                    self.interface_bkp_labels = YLeaf(YType.uint8, "interface-bkp-labels")

                                    self.interface_cost_fallback = YLeaf(YType.uint16, "interface-cost-fallback")

                                    self.interface_dc_bitless_lsa_count = YLeaf(YType.uint32, "interface-dc-bitless-lsa-count")

                                    self.interface_demand_circuit = YLeaf(YType.boolean, "interface-demand-circuit")

                                    self.interface_fast_detect_hold_down = YLeaf(YType.boolean, "interface-fast-detect-hold-down")

                                    self.interface_forw = YLeaf(YType.boolean, "interface-forw")

                                    self.interface_last_nsf = YLeaf(YType.uint32, "interface-last-nsf")

                                    self.interface_ldp_sync = YLeaf(YType.boolean, "interface-ldp-sync")

                                    self.interface_line_state = YLeaf(YType.boolean, "interface-line-state")

                                    self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                    self.interface_lsa_filter = YLeaf(YType.boolean, "interface-lsa-filter")

                                    self.interface_madj_count = YLeaf(YType.uint16, "interface-madj-count")

                                    self.interface_mask = YLeaf(YType.uint32, "interface-mask")

                                    self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                    self.interface_nsf = YLeaf(YType.boolean, "interface-nsf")

                                    self.interface_nsf_enabled = YLeaf(YType.boolean, "interface-nsf-enabled")

                                    self.interface_pri_labels = YLeaf(YType.uint8, "interface-pri-labels")

                                    self.interface_priority = YLeaf(YType.uint8, "interface-priority")

                                    self.interface_retransmission_interrval = YLeaf(YType.uint32, "interface-retransmission-interrval")

                                    self.interface_router_id = YLeaf(YType.str, "interface-router-id")

                                    self.interface_sid = YLeaf(YType.uint32, "interface-sid")

                                    self.interface_sid_n_flag_clear = YLeaf(YType.boolean, "interface-sid-n-flag-clear")

                                    self.interface_sid_php_off = YLeaf(YType.boolean, "interface-sid-php-off")

                                    self.interface_srte_labels = YLeaf(YType.uint8, "interface-srte-labels")

                                    self.interface_state = YLeaf(YType.enumeration, "interface-state")

                                    self.interface_strict_spf_sid = YLeaf(YType.uint32, "interface-strict-spf-sid")

                                    self.interface_strict_spf_sid_n_flag_clear = YLeaf(YType.boolean, "interface-strict-spf-sid-n-flag-clear")

                                    self.interface_strict_spf_sid_php_off = YLeaf(YType.boolean, "interface-strict-spf-sid-php-off")

                                    self.interface_tunnel_flags = YLeaf(YType.uint32, "interface-tunnel-flags")

                                    self.interface_unnum = YLeaf(YType.str, "interface-unnum")

                                    self.interfaceis_madj = YLeaf(YType.boolean, "interfaceis-madj")

                                    self.ip_mtu = YLeaf(YType.uint16, "ip-mtu")

                                    self.is_loopback_stub_network = YLeaf(YType.boolean, "is-loopback-stub-network")

                                    self.maximum_packet_size = YLeaf(YType.uint16, "maximum-packet-size")

                                    self.network_lsa_flush_timer = YLeaf(YType.uint32, "network-lsa-flush-timer")

                                    self.network_type = YLeaf(YType.enumeration, "network-type")

                                    self.next_hello_time = YLeaf(YType.uint32, "next-hello-time")

                                    self.next_hello_time_ms = YLeaf(YType.uint32, "next-hello-time-ms")

                                    self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")

                                    self.passive_interface = YLeaf(YType.boolean, "passive-interface")

                                    self.prefix_suppress_primary_addresses = YLeaf(YType.boolean, "prefix-suppress-primary-addresses")

                                    self.prefix_suppress_secondary_addresses = YLeaf(YType.boolean, "prefix-suppress-secondary-addresses")

                                    self.registered_for_link_down_fast_detection = YLeaf(YType.boolean, "registered-for-link-down-fast-detection")

                                    self.transmission_delay = YLeaf(YType.uint16, "transmission-delay")

                                    self.ttl_security_enabled = YLeaf(YType.boolean, "ttl-security-enabled")

                                    self.ttl_security_hop_count = YLeaf(YType.uint32, "ttl-security-hop-count")

                                    self.wait_interval = YLeaf(YType.uint32, "wait-interval")

                                    self.active_interface = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self._children_name_map["active_interface"] = "active-interface"
                                    self._children_yang_names.add("active-interface")

                                    self.interface_bfd_information = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation()
                                    self.interface_bfd_information.parent = self
                                    self._children_name_map["interface_bfd_information"] = "interface-bfd-information"
                                    self._children_yang_names.add("interface-bfd-information")

                                    self.interface_madj = YList(self)
                                    self.interface_neighbor = YList(self)
                                    self.ip_sec_addr = YList(self)
                                    self.ipfrr_tiebreakers = YList(self)
                                    self.srlg = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface, ['interface_name', 'backup_designated_router', 'backup_designated_router_address', 'backup_designated_router_id', 'cfg_cost_fallback', 'configured_demand_circuit', 'configured_ldp_sync', 'configured_ldp_sync_igp_shortcuts', 'cost_fallback_active', 'dead_interval', 'designated_router', 'designated_router_address', 'designated_router_id', 'fast_detect_hold_down_time', 'fast_detect_hold_down_time_remaining', 'fast_reroute_topology_independent_lfa', 'fast_reroute_type', 'hello_interval', 'hello_interval_ms', 'interface_ack_list_count', 'interface_ack_list_high_watermark', 'interface_address', 'interface_area', 'interface_bandwidth', 'interface_bkp_labels', 'interface_cost_fallback', 'interface_dc_bitless_lsa_count', 'interface_demand_circuit', 'interface_fast_detect_hold_down', 'interface_forw', 'interface_last_nsf', 'interface_ldp_sync', 'interface_line_state', 'interface_link_cost', 'interface_lsa_filter', 'interface_madj_count', 'interface_mask', 'interface_name_xr', 'interface_nsf', 'interface_nsf_enabled', 'interface_pri_labels', 'interface_priority', 'interface_retransmission_interrval', 'interface_router_id', 'interface_sid', 'interface_sid_n_flag_clear', 'interface_sid_php_off', 'interface_srte_labels', 'interface_state', 'interface_strict_spf_sid', 'interface_strict_spf_sid_n_flag_clear', 'interface_strict_spf_sid_php_off', 'interface_tunnel_flags', 'interface_unnum', 'interfaceis_madj', 'ip_mtu', 'is_loopback_stub_network', 'maximum_packet_size', 'network_lsa_flush_timer', 'network_type', 'next_hello_time', 'next_hello_time_ms', 'ospf_interface_state', 'passive_interface', 'prefix_suppress_primary_addresses', 'prefix_suppress_secondary_addresses', 'registered_for_link_down_fast_detection', 'transmission_delay', 'ttl_security_enabled', 'ttl_security_hop_count', 'wait_interval'], name, value)


                                class ActiveInterface(Entity):
                                    """
                                    Active interface details
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                    
                                    .. attribute:: interface_flood_length
                                    
                                    	Flood queue length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Total number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: keychain_id
                                    
                                    	Keychain ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: md_keys
                                    
                                    	List of old MD keys
                                    	**type**\: list of    :py:class:`MdKeys <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys>`
                                    
                                    .. attribute:: old_md5_key_neighbor_count
                                    
                                    	Number of neighbors using the old key (if rollover in progress)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: suppress_hello_count
                                    
                                    	Number of neighbors for which hellos are suppressed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: youngest_md_key
                                    
                                    	If true, MD key is configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: youngest_md_key_id
                                    
                                    	Youngest MD key ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, self).__init__()

                                        self.yang_name = "active-interface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"md-keys" : ("md_keys", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys)}

                                        self.flood_scan_length = YLeaf(YType.uint32, "flood-scan-length")

                                        self.interface_area_flood_index = YLeaf(YType.uint32, "interface-area-flood-index")

                                        self.interface_area_next_flood = YLeaf(YType.uint32, "interface-area-next-flood")

                                        self.interface_area_next_flood_index = YLeaf(YType.uint32, "interface-area-next-flood-index")

                                        self.interface_as_flood_index = YLeaf(YType.uint32, "interface-as-flood-index")

                                        self.interface_as_next_flood = YLeaf(YType.uint32, "interface-as-next-flood")

                                        self.interface_as_next_flood_index = YLeaf(YType.uint32, "interface-as-next-flood-index")

                                        self.interface_authentication_type = YLeaf(YType.enumeration, "interface-authentication-type")

                                        self.interface_flood_length = YLeaf(YType.uint32, "interface-flood-length")

                                        self.interface_flood_pacing_timer = YLeaf(YType.uint32, "interface-flood-pacing-timer")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.keychain_id = YLeaf(YType.uint64, "keychain-id")

                                        self.last_flood_time = YLeaf(YType.uint32, "last-flood-time")

                                        self.maximum_flood_length = YLeaf(YType.uint32, "maximum-flood-length")

                                        self.maximum_flood_time = YLeaf(YType.uint32, "maximum-flood-time")

                                        self.old_md5_key_neighbor_count = YLeaf(YType.uint32, "old-md5-key-neighbor-count")

                                        self.suppress_hello_count = YLeaf(YType.uint16, "suppress-hello-count")

                                        self.wait_time = YLeaf(YType.uint32, "wait-time")

                                        self.youngest_md_key = YLeaf(YType.boolean, "youngest-md-key")

                                        self.youngest_md_key_id = YLeaf(YType.uint16, "youngest-md-key-id")

                                        self.md_keys = YList(self)
                                        self._segment_path = lambda: "active-interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface, ['flood_scan_length', 'interface_area_flood_index', 'interface_area_next_flood', 'interface_area_next_flood_index', 'interface_as_flood_index', 'interface_as_next_flood', 'interface_as_next_flood_index', 'interface_authentication_type', 'interface_flood_length', 'interface_flood_pacing_timer', 'interface_neighbor_count', 'keychain_id', 'last_flood_time', 'maximum_flood_length', 'maximum_flood_time', 'old_md5_key_neighbor_count', 'suppress_hello_count', 'wait_time', 'youngest_md_key', 'youngest_md_key_id'], name, value)


                                    class MdKeys(Entity):
                                        """
                                        List of old MD keys
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, self).__init__()

                                            self.yang_name = "md-keys"
                                            self.yang_parent_name = "active-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint16, "entry")
                                            self._segment_path = lambda: "md-keys"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.ActiveInterface.MdKeys, ['entry'], name, value)


                                class InterfaceBfdInformation(Entity):
                                    """
                                    BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: detection_multiplier
                                    
                                    	BFD detection multiplier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interval
                                    
                                    	BFD interval (ms)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, self).__init__()

                                        self.yang_name = "interface-bfd-information"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bfd_intf_enable_mode = YLeaf(YType.uint32, "bfd-intf-enable-mode")

                                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                        self.interval = YLeaf(YType.uint32, "interval")
                                        self._segment_path = lambda: "interface-bfd-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceBfdInformation, ['bfd_intf_enable_mode', 'detection_multiplier', 'interval'], name, value)


                                class InterfaceMadj(Entity):
                                    """
                                    Information for multi\-area on the interface
                                    
                                    .. attribute:: interface_adj_neighbor_count
                                    
                                    	Total number of Adjacent Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_area
                                    
                                    	Area ID string in decimal or dotted\-decimal format
                                    	**type**\:  str
                                    
                                    	**length:** 0..16
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_neighbor_count
                                    
                                    	Number of Neighbors
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: madj_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, self).__init__()

                                        self.yang_name = "interface-madj"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_adj_neighbor_count = YLeaf(YType.uint16, "interface-adj-neighbor-count")

                                        self.interface_area = YLeaf(YType.str, "interface-area")

                                        self.interface_link_cost = YLeaf(YType.uint16, "interface-link-cost")

                                        self.interface_neighbor_count = YLeaf(YType.uint16, "interface-neighbor-count")

                                        self.madj_area_id = YLeaf(YType.uint32, "madj-area-id")

                                        self.ospf_interface_state = YLeaf(YType.enumeration, "ospf-interface-state")
                                        self._segment_path = lambda: "interface-madj"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceMadj, ['interface_adj_neighbor_count', 'interface_area', 'interface_link_cost', 'interface_neighbor_count', 'madj_area_id', 'ospf_interface_state'], name, value)


                                class InterfaceNeighbor(Entity):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_bdr
                                    
                                    	If true, Backup designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: neighbor_dr
                                    
                                    	If true, Designated router
                                    	**type**\:  bool
                                    
                                    .. attribute:: suppress_hello
                                    
                                    	If true, hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, self).__init__()

                                        self.yang_name = "interface-neighbor"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_neighbor_cost = YLeaf(YType.uint32, "interface-neighbor-cost")

                                        self.interface_neighbor_id = YLeaf(YType.str, "interface-neighbor-id")

                                        self.neighbor_bdr = YLeaf(YType.boolean, "neighbor-bdr")

                                        self.neighbor_dr = YLeaf(YType.boolean, "neighbor-dr")

                                        self.suppress_hello = YLeaf(YType.boolean, "suppress-hello")
                                        self._segment_path = lambda: "interface-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.InterfaceNeighbor, ['interface_neighbor_cost', 'interface_neighbor_id', 'neighbor_bdr', 'neighbor_dr', 'suppress_hello'], name, value)


                                class IpSecAddr(Entity):
                                    """
                                    Secondary IP address list
                                    
                                    .. attribute:: secondary_addr
                                    
                                    	Secondary Address Type
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: secondary_prefix
                                    
                                    	Secondary Prefix Length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpSecAddr, self).__init__()

                                        self.yang_name = "ip-sec-addr"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.secondary_addr = YLeaf(YType.str, "secondary-addr")

                                        self.secondary_prefix = YLeaf(YType.uint32, "secondary-prefix")
                                        self._segment_path = lambda: "ip-sec-addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpSecAddr, ['secondary_addr', 'secondary_prefix'], name, value)


                                class IpfrrTiebreakers(Entity):
                                    """
                                    IPFRR\-Tiebreakers list
                                    
                                    .. attribute:: tiebreaker_index
                                    
                                    	Tiebreaker Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tiebreaker_type
                                    
                                    	Tiebreaker Type
                                    	**type**\:   :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IpfrrTbrkr>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, self).__init__()

                                        self.yang_name = "ipfrr-tiebreakers"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.tiebreaker_index = YLeaf(YType.uint32, "tiebreaker-index")

                                        self.tiebreaker_type = YLeaf(YType.enumeration, "tiebreaker-type")
                                        self._segment_path = lambda: "ipfrr-tiebreakers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.IpfrrTiebreakers, ['tiebreaker_index', 'tiebreaker_type'], name, value)


                                class Srlg(Entity):
                                    """
                                    SRLG Values
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg, self).__init__()

                                        self.yang_name = "srlg"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "srlg"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.Interfaces.Interface.Srlg, ['entry'], name, value)


                        class VirtualLinks(Entity):
                            """
                            Virtual Link table
                            
                            .. attribute:: virtual_link
                            
                            	Information for one Virtual link
                            	**type**\: list of    :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks, self).__init__()

                                self.yang_name = "virtual-links"
                                self.yang_parent_name = "interface-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"virtual-link" : ("virtual_link", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink)}

                                self.virtual_link = YList(self)
                                self._segment_path = lambda: "virtual-links"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks, [], name, value)


                            class VirtualLink(Entity):
                                """
                                Information for one Virtual link
                                
                                .. attribute:: virtual_link_name  <key>
                                
                                	Virtual link
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: transit_area
                                
                                	Transit area id
                                	**type**\:  str
                                
                                .. attribute:: virtaul_link_retransmission_interval
                                
                                	Retransmission interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: virtual_link_cost
                                
                                	Cost of the virtual link
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virtual_link_dc_bitless_lsa
                                
                                	Number of LSA's with demand circuit bit not set
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_dead_interval
                                
                                	Dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_demand_circuit
                                
                                	If true, the link runs as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_hello_interval
                                
                                	Hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_hello_interval_ms
                                
                                	Hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_interface_name
                                
                                	Interface on which this virtual link is formed
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: virtual_link_keychain_id
                                
                                	Virtual Link Keychain ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: virtual_link_last_nsf
                                
                                	Time in seconds since last NSF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: virtual_link_md_key
                                
                                	List of old MD keys (if any)
                                	**type**\: list of    :py:class:`VirtualLinkMdKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey>`
                                
                                .. attribute:: virtual_link_name_xr
                                
                                	Virtual link name
                                	**type**\:  str
                                
                                .. attribute:: virtual_link_neighbor
                                
                                	Neighbor information
                                	**type**\:   :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor>`
                                
                                .. attribute:: virtual_link_neighbor_id
                                
                                	Neighbor on other end of this virtual link
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_link_next_hello
                                
                                	Time until next hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_next_hello_ms
                                
                                	Time until next hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_nsf
                                
                                	If true, NSF restart in progress on the virtual link
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_nsf_enabled
                                
                                	If true, NSF enabled
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_old_md_key_count
                                
                                	Number of neighbors still using the old key (rollover in progress)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_passive
                                
                                	If true, interface is passive
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_state
                                
                                	OSPF interface state for the virtual link
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: virtual_link_wait_interval
                                
                                	Wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: virtual_link_youngest_md_key
                                
                                	If true, MD key configured
                                	**type**\:  bool
                                
                                .. attribute:: virtual_link_youngest_md_key_id
                                
                                	Youngest MD key ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: virual_link_transmission_delay
                                
                                	Transmission delay in seconds
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink, self).__init__()

                                    self.yang_name = "virtual-link"
                                    self.yang_parent_name = "virtual-links"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"virtual-link-neighbor" : ("virtual_link_neighbor", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor)}
                                    self._child_list_classes = {"virtual-link-md-key" : ("virtual_link_md_key", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey)}

                                    self.virtual_link_name = YLeaf(YType.str, "virtual-link-name")

                                    self.transit_area = YLeaf(YType.str, "transit-area")

                                    self.virtaul_link_retransmission_interval = YLeaf(YType.uint32, "virtaul-link-retransmission-interval")

                                    self.virtual_link_authentication_type = YLeaf(YType.enumeration, "virtual-link-authentication-type")

                                    self.virtual_link_cost = YLeaf(YType.uint16, "virtual-link-cost")

                                    self.virtual_link_dc_bitless_lsa = YLeaf(YType.uint32, "virtual-link-dc-bitless-lsa")

                                    self.virtual_link_dead_interval = YLeaf(YType.uint32, "virtual-link-dead-interval")

                                    self.virtual_link_demand_circuit = YLeaf(YType.boolean, "virtual-link-demand-circuit")

                                    self.virtual_link_hello_interval = YLeaf(YType.uint32, "virtual-link-hello-interval")

                                    self.virtual_link_hello_interval_ms = YLeaf(YType.uint32, "virtual-link-hello-interval-ms")

                                    self.virtual_link_interface_name = YLeaf(YType.str, "virtual-link-interface-name")

                                    self.virtual_link_keychain_id = YLeaf(YType.uint64, "virtual-link-keychain-id")

                                    self.virtual_link_last_nsf = YLeaf(YType.uint32, "virtual-link-last-nsf")

                                    self.virtual_link_name_xr = YLeaf(YType.str, "virtual-link-name-xr")

                                    self.virtual_link_neighbor_id = YLeaf(YType.str, "virtual-link-neighbor-id")

                                    self.virtual_link_next_hello = YLeaf(YType.uint32, "virtual-link-next-hello")

                                    self.virtual_link_next_hello_ms = YLeaf(YType.uint32, "virtual-link-next-hello-ms")

                                    self.virtual_link_nsf = YLeaf(YType.boolean, "virtual-link-nsf")

                                    self.virtual_link_nsf_enabled = YLeaf(YType.boolean, "virtual-link-nsf-enabled")

                                    self.virtual_link_old_md_key_count = YLeaf(YType.uint32, "virtual-link-old-md-key-count")

                                    self.virtual_link_passive = YLeaf(YType.boolean, "virtual-link-passive")

                                    self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                    self.virtual_link_wait_interval = YLeaf(YType.uint32, "virtual-link-wait-interval")

                                    self.virtual_link_youngest_md_key = YLeaf(YType.boolean, "virtual-link-youngest-md-key")

                                    self.virtual_link_youngest_md_key_id = YLeaf(YType.uint16, "virtual-link-youngest-md-key-id")

                                    self.virual_link_transmission_delay = YLeaf(YType.uint16, "virual-link-transmission-delay")

                                    self.virtual_link_neighbor = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor()
                                    self.virtual_link_neighbor.parent = self
                                    self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                                    self._children_yang_names.add("virtual-link-neighbor")

                                    self.virtual_link_md_key = YList(self)
                                    self._segment_path = lambda: "virtual-link" + "[virtual-link-name='" + self.virtual_link_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink, ['virtual_link_name', 'transit_area', 'virtaul_link_retransmission_interval', 'virtual_link_authentication_type', 'virtual_link_cost', 'virtual_link_dc_bitless_lsa', 'virtual_link_dead_interval', 'virtual_link_demand_circuit', 'virtual_link_hello_interval', 'virtual_link_hello_interval_ms', 'virtual_link_interface_name', 'virtual_link_keychain_id', 'virtual_link_last_nsf', 'virtual_link_name_xr', 'virtual_link_neighbor_id', 'virtual_link_next_hello', 'virtual_link_next_hello_ms', 'virtual_link_nsf', 'virtual_link_nsf_enabled', 'virtual_link_old_md_key_count', 'virtual_link_passive', 'virtual_link_state', 'virtual_link_wait_interval', 'virtual_link_youngest_md_key', 'virtual_link_youngest_md_key_id', 'virual_link_transmission_delay'], name, value)


                                class VirtualLinkMdKey(Entity):
                                    """
                                    List of old MD keys (if any)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, self).__init__()

                                        self.yang_name = "virtual-link-md-key"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint16, "entry")
                                        self._segment_path = lambda: "virtual-link-md-key"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkMdKey, ['entry'], name, value)


                                class VirtualLinkNeighbor(Entity):
                                    """
                                    Neighbor information
                                    
                                    .. attribute:: virtual_link_retransmissoin
                                    
                                    	Neighbor retransmission info
                                    	**type**\:   :py:class:`VirtualLinkRetransmissoin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin>`
                                    
                                    .. attribute:: virtual_link_state
                                    
                                    	Adjacency state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: virtual_link_suppress_hello
                                    
                                    	If true Hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, self).__init__()

                                        self.yang_name = "virtual-link-neighbor"
                                        self.yang_parent_name = "virtual-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"virtual-link-retransmissoin" : ("virtual_link_retransmissoin", Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin)}
                                        self._child_list_classes = {}

                                        self.virtual_link_state = YLeaf(YType.enumeration, "virtual-link-state")

                                        self.virtual_link_suppress_hello = YLeaf(YType.boolean, "virtual-link-suppress-hello")

                                        self.virtual_link_retransmissoin = Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin()
                                        self.virtual_link_retransmissoin.parent = self
                                        self._children_name_map["virtual_link_retransmissoin"] = "virtual-link-retransmissoin"
                                        self._children_yang_names.add("virtual-link-retransmissoin")
                                        self._segment_path = lambda: "virtual-link-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor, ['virtual_link_state', 'virtual_link_suppress_hello'], name, value)


                                    class VirtualLinkRetransmissoin(Entity):
                                        """
                                        Neighbor retransmission info
                                        
                                        .. attribute:: area_first_flood_information
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_information_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flooding_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_count
                                        
                                        	Number of DBD retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_total_count
                                        
                                        	Total number of DBD retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission_count
                                        
                                        	Retransmission queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, self).__init__()

                                            self.yang_name = "virtual-link-retransmissoin"
                                            self.yang_parent_name = "virtual-link-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                            self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                            self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                            self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                            self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                            self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                            self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                            self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                            self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                            self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                            self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                            self._segment_path = lambda: "virtual-link-retransmissoin"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceInformation.VirtualLinks.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmissoin, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                    class InterfaceVrfInformation(Entity):
                        """
                        Container for OSPF Interfaces/links under a
                        VRF
                        
                        .. attribute:: sham_links
                        
                        	Sham Link table
                        	**type**\:   :py:class:`ShamLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation, self).__init__()

                            self.yang_name = "interface-vrf-information"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"sham-links" : ("sham_links", Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks)}
                            self._child_list_classes = {}

                            self.sham_links = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks()
                            self.sham_links.parent = self
                            self._children_name_map["sham_links"] = "sham-links"
                            self._children_yang_names.add("sham-links")
                            self._segment_path = lambda: "interface-vrf-information"


                        class ShamLinks(Entity):
                            """
                            Sham Link table
                            
                            .. attribute:: sham_link
                            
                            	Information for one Sham link
                            	**type**\: list of    :py:class:`ShamLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks, self).__init__()

                                self.yang_name = "sham-links"
                                self.yang_parent_name = "interface-vrf-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"sham-link" : ("sham_link", Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink)}

                                self.sham_link = YList(self)
                                self._segment_path = lambda: "sham-links"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks, [], name, value)


                            class ShamLink(Entity):
                                """
                                Information for one Sham link
                                
                                .. attribute:: sham_link_name  <key>
                                
                                	Sham link
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: sham_link_area
                                
                                	Area id
                                	**type**\:  str
                                
                                .. attribute:: sham_link_authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: sham_link_cost
                                
                                	Cost of the sham link
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: sham_link_dc_bitless_lsa
                                
                                	Number of LSA's with demand circuit bit not set
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_dead_interval
                                
                                	Dead interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_demand_circuit
                                
                                	If true, the link runs as demand circuit
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_dest_address
                                
                                	Sham\-link dest
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sham_link_hello_interval
                                
                                	Hello interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_hello_interval_ms
                                
                                	Hello interval (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_ifindex
                                
                                	Sham\-link ifindex
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_keychain_id
                                
                                	Sham Link Keychain ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sham_link_last_nsf
                                
                                	Time in seconds since last NSF
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: sham_link_md_key
                                
                                	List of old MD keys (if any)
                                	**type**\: list of    :py:class:`ShamLinkMdKey <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey>`
                                
                                .. attribute:: sham_link_name_xr
                                
                                	Sham link name
                                	**type**\:  str
                                
                                .. attribute:: sham_link_neighbor
                                
                                	Neighbor information
                                	**type**\:   :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor>`
                                
                                .. attribute:: sham_link_neighbor_id
                                
                                	Neighbor on other end of this sham link
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sham_link_next_hello
                                
                                	Time until next hello (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_next_hello_ms
                                
                                	Time until next hello (ms)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_nsf
                                
                                	If true, NSF restart in progress on the sham link
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_nsf_enabled
                                
                                	If true, NSF enabled
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_old_md_key_count
                                
                                	Number of neighbors still using the old key (rollover in progress)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_passive
                                
                                	If true, interface is passive
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_retransmission_interval
                                
                                	Retransmission interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_source_address
                                
                                	Sham\-link source
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sham_link_state
                                
                                	OSPF interface state for the sham link
                                	**type**\:   :py:class:`OspfInterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfInterfaceState>`
                                
                                .. attribute:: sham_link_transmission_delay
                                
                                	Transmission delay in seconds
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: sham_link_wait_interval
                                
                                	Wait interval (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sham_link_youngest_md_key
                                
                                	If true, MD key configured
                                	**type**\:  bool
                                
                                .. attribute:: sham_link_youngest_md_key_id
                                
                                	Youngest MD key ID
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink, self).__init__()

                                    self.yang_name = "sham-link"
                                    self.yang_parent_name = "sham-links"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sham-link-neighbor" : ("sham_link_neighbor", Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor)}
                                    self._child_list_classes = {"sham-link-md-key" : ("sham_link_md_key", Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey)}

                                    self.sham_link_name = YLeaf(YType.str, "sham-link-name")

                                    self.sham_link_area = YLeaf(YType.str, "sham-link-area")

                                    self.sham_link_authentication_type = YLeaf(YType.enumeration, "sham-link-authentication-type")

                                    self.sham_link_cost = YLeaf(YType.uint16, "sham-link-cost")

                                    self.sham_link_dc_bitless_lsa = YLeaf(YType.uint32, "sham-link-dc-bitless-lsa")

                                    self.sham_link_dead_interval = YLeaf(YType.uint32, "sham-link-dead-interval")

                                    self.sham_link_demand_circuit = YLeaf(YType.boolean, "sham-link-demand-circuit")

                                    self.sham_link_dest_address = YLeaf(YType.str, "sham-link-dest-address")

                                    self.sham_link_hello_interval = YLeaf(YType.uint32, "sham-link-hello-interval")

                                    self.sham_link_hello_interval_ms = YLeaf(YType.uint32, "sham-link-hello-interval-ms")

                                    self.sham_link_ifindex = YLeaf(YType.uint32, "sham-link-ifindex")

                                    self.sham_link_keychain_id = YLeaf(YType.uint64, "sham-link-keychain-id")

                                    self.sham_link_last_nsf = YLeaf(YType.uint32, "sham-link-last-nsf")

                                    self.sham_link_name_xr = YLeaf(YType.str, "sham-link-name-xr")

                                    self.sham_link_neighbor_id = YLeaf(YType.str, "sham-link-neighbor-id")

                                    self.sham_link_next_hello = YLeaf(YType.uint32, "sham-link-next-hello")

                                    self.sham_link_next_hello_ms = YLeaf(YType.uint32, "sham-link-next-hello-ms")

                                    self.sham_link_nsf = YLeaf(YType.boolean, "sham-link-nsf")

                                    self.sham_link_nsf_enabled = YLeaf(YType.boolean, "sham-link-nsf-enabled")

                                    self.sham_link_old_md_key_count = YLeaf(YType.uint32, "sham-link-old-md-key-count")

                                    self.sham_link_passive = YLeaf(YType.boolean, "sham-link-passive")

                                    self.sham_link_retransmission_interval = YLeaf(YType.uint32, "sham-link-retransmission-interval")

                                    self.sham_link_source_address = YLeaf(YType.str, "sham-link-source-address")

                                    self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                                    self.sham_link_transmission_delay = YLeaf(YType.uint16, "sham-link-transmission-delay")

                                    self.sham_link_wait_interval = YLeaf(YType.uint32, "sham-link-wait-interval")

                                    self.sham_link_youngest_md_key = YLeaf(YType.boolean, "sham-link-youngest-md-key")

                                    self.sham_link_youngest_md_key_id = YLeaf(YType.uint16, "sham-link-youngest-md-key-id")

                                    self.sham_link_neighbor = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor()
                                    self.sham_link_neighbor.parent = self
                                    self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                                    self._children_yang_names.add("sham-link-neighbor")

                                    self.sham_link_md_key = YList(self)
                                    self._segment_path = lambda: "sham-link" + "[sham-link-name='" + self.sham_link_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink, ['sham_link_name', 'sham_link_area', 'sham_link_authentication_type', 'sham_link_cost', 'sham_link_dc_bitless_lsa', 'sham_link_dead_interval', 'sham_link_demand_circuit', 'sham_link_dest_address', 'sham_link_hello_interval', 'sham_link_hello_interval_ms', 'sham_link_ifindex', 'sham_link_keychain_id', 'sham_link_last_nsf', 'sham_link_name_xr', 'sham_link_neighbor_id', 'sham_link_next_hello', 'sham_link_next_hello_ms', 'sham_link_nsf', 'sham_link_nsf_enabled', 'sham_link_old_md_key_count', 'sham_link_passive', 'sham_link_retransmission_interval', 'sham_link_source_address', 'sham_link_state', 'sham_link_transmission_delay', 'sham_link_wait_interval', 'sham_link_youngest_md_key', 'sham_link_youngest_md_key_id'], name, value)


                                class ShamLinkMdKey(Entity):
                                    """
                                    List of old MD keys (if any)
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey, self).__init__()

                                        self.yang_name = "sham-link-md-key"
                                        self.yang_parent_name = "sham-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint16, "entry")
                                        self._segment_path = lambda: "sham-link-md-key"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkMdKey, ['entry'], name, value)


                                class ShamLinkNeighbor(Entity):
                                    """
                                    Neighbor information
                                    
                                    .. attribute:: sham_link_retransmissoin
                                    
                                    	Neighbor retransmission info
                                    	**type**\:   :py:class:`ShamLinkRetransmissoin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin>`
                                    
                                    .. attribute:: sham_link_state
                                    
                                    	Adjacency state
                                    	**type**\:   :py:class:`NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.NeighborState>`
                                    
                                    .. attribute:: sham_link_suppress_hello
                                    
                                    	If true Hellos suppressed
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor, self).__init__()

                                        self.yang_name = "sham-link-neighbor"
                                        self.yang_parent_name = "sham-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sham-link-retransmissoin" : ("sham_link_retransmissoin", Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin)}
                                        self._child_list_classes = {}

                                        self.sham_link_state = YLeaf(YType.enumeration, "sham-link-state")

                                        self.sham_link_suppress_hello = YLeaf(YType.boolean, "sham-link-suppress-hello")

                                        self.sham_link_retransmissoin = Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin()
                                        self.sham_link_retransmissoin.parent = self
                                        self._children_name_map["sham_link_retransmissoin"] = "sham-link-retransmissoin"
                                        self._children_yang_names.add("sham-link-retransmissoin")
                                        self._segment_path = lambda: "sham-link-neighbor"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor, ['sham_link_state', 'sham_link_suppress_hello'], name, value)


                                    class ShamLinkRetransmissoin(Entity):
                                        """
                                        Neighbor retransmission info
                                        
                                        .. attribute:: area_first_flood_information
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_information_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flooding_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_information_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_information_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_information_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_count
                                        
                                        	Number of DBD retransmissions during last exchange
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dbd_retransmission_total_count
                                        
                                        	Total number of DBD retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmission_count
                                        
                                        	Retransmission queue length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: number_of_retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin, self).__init__()

                                            self.yang_name = "sham-link-retransmissoin"
                                            self.yang_parent_name = "sham-link-neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.area_first_flood_information = YLeaf(YType.uint32, "area-first-flood-information")

                                            self.area_first_flood_information_index = YLeaf(YType.uint32, "area-first-flood-information-index")

                                            self.area_flooding_index = YLeaf(YType.uint32, "area-flooding-index")

                                            self.area_next_flood_information = YLeaf(YType.uint32, "area-next-flood-information")

                                            self.area_next_flood_information_index = YLeaf(YType.uint32, "area-next-flood-information-index")

                                            self.as_first_flood_information = YLeaf(YType.uint32, "as-first-flood-information")

                                            self.as_first_flood_information_index = YLeaf(YType.uint32, "as-first-flood-information-index")

                                            self.as_flood_index = YLeaf(YType.uint32, "as-flood-index")

                                            self.as_next_flood_information = YLeaf(YType.uint32, "as-next-flood-information")

                                            self.as_next_flood_information_index = YLeaf(YType.uint32, "as-next-flood-information-index")

                                            self.dbd_retransmission_count = YLeaf(YType.uint32, "dbd-retransmission-count")

                                            self.dbd_retransmission_total_count = YLeaf(YType.uint32, "dbd-retransmission-total-count")

                                            self.last_retransmission_length = YLeaf(YType.uint32, "last-retransmission-length")

                                            self.last_retransmission_time = YLeaf(YType.uint32, "last-retransmission-time")

                                            self.lsa_retransmission_timer = YLeaf(YType.uint32, "lsa-retransmission-timer")

                                            self.maximum_retransmission_length = YLeaf(YType.uint32, "maximum-retransmission-length")

                                            self.maximum_retransmission_time = YLeaf(YType.uint32, "maximum-retransmission-time")

                                            self.neighbor_retransmission_count = YLeaf(YType.uint32, "neighbor-retransmission-count")

                                            self.number_of_retransmissions = YLeaf(YType.uint32, "number-of-retransmissions")
                                            self._segment_path = lambda: "sham-link-retransmissoin"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.InterfaceVrfInformation.ShamLinks.ShamLink.ShamLinkNeighbor.ShamLinkRetransmissoin, ['area_first_flood_information', 'area_first_flood_information_index', 'area_flooding_index', 'area_next_flood_information', 'area_next_flood_information_index', 'as_first_flood_information', 'as_first_flood_information_index', 'as_flood_index', 'as_next_flood_information', 'as_next_flood_information_index', 'dbd_retransmission_count', 'dbd_retransmission_total_count', 'last_retransmission_length', 'last_retransmission_time', 'lsa_retransmission_timer', 'maximum_retransmission_length', 'maximum_retransmission_time', 'neighbor_retransmission_count', 'number_of_retransmissions'], name, value)


                    class MplsTe(Entity):
                        """
                        Container for MPLS TE
                        
                        .. attribute:: mpls_te_fragments
                        
                        	MPLS TE Fragment information table
                        	**type**\:   :py:class:`MplsTeFragments <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments>`
                        
                        .. attribute:: mpls_te_links
                        
                        	MPLS TE link information table
                        	**type**\:   :py:class:`MplsTeLinks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe, self).__init__()

                            self.yang_name = "mpls-te"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"mpls-te-fragments" : ("mpls_te_fragments", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments), "mpls-te-links" : ("mpls_te_links", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks)}
                            self._child_list_classes = {}

                            self.mpls_te_fragments = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments()
                            self.mpls_te_fragments.parent = self
                            self._children_name_map["mpls_te_fragments"] = "mpls-te-fragments"
                            self._children_yang_names.add("mpls-te-fragments")

                            self.mpls_te_links = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks()
                            self.mpls_te_links.parent = self
                            self._children_name_map["mpls_te_links"] = "mpls-te-links"
                            self._children_yang_names.add("mpls-te-links")
                            self._segment_path = lambda: "mpls-te"


                        class MplsTeFragments(Entity):
                            """
                            MPLS TE Fragment information table
                            
                            .. attribute:: mpls_te_fragment
                            
                            	MPLS TE Fragment
                            	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments, self).__init__()

                                self.yang_name = "mpls-te-fragments"
                                self.yang_parent_name = "mpls-te"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"mpls-te-fragment" : ("mpls_te_fragment", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment)}

                                self.mpls_te_fragment = YList(self)
                                self._segment_path = lambda: "mpls-te-fragments"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments, [], name, value)


                            class MplsTeFragment(Entity):
                                """
                                MPLS TE Fragment
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mpls_te_area_id
                                
                                	Area ID string in decimal or dotted decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: mpls_te_area_instance
                                
                                	Area information instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_enabled
                                
                                	If true, MPLS\-TE enabled in area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_fragment
                                
                                	MPLS TE fragments in the area
                                	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment>`
                                
                                .. attribute:: mpls_te_initialized
                                
                                	If true, MPLS\-TE initialized in the area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_link
                                
                                	MPLS\-TE links in the area
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink>`
                                
                                .. attribute:: mpls_te_next_fragment_id
                                
                                	Next MPLS\-TE fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_router_address
                                
                                	MPLS\-TE router address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mpls_te_router_id
                                
                                	OSPF MPLS\-TE router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: spacious_fragment
                                
                                	If true, fragment has space for next link
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment, self).__init__()

                                    self.yang_name = "mpls-te-fragment"
                                    self.yang_parent_name = "mpls-te-fragments"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"mpls-te-fragment" : ("mpls_te_fragment", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment), "mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink)}

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                    self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                    self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                    self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                    self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                    self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                    self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                    self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                    self.mpls_te_fragment = YList(self)
                                    self.mpls_te_link = YList(self)
                                    self._segment_path = lambda: "mpls-te-fragment" + "[area-id='" + self.area_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment, ['area_id', 'mpls_te_area_id', 'mpls_te_area_instance', 'mpls_te_enabled', 'mpls_te_initialized', 'mpls_te_next_fragment_id', 'mpls_te_router_address', 'mpls_te_router_id', 'spacious_fragment'], name, value)


                                class MplsTeFragment(Entity):
                                    """
                                    MPLS TE fragments in the area
                                    
                                    .. attribute:: dste_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fragment_instance
                                    
                                    	Fragment instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_te_link
                                    
                                    	List of fragment links
                                    	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink>`
                                    
                                    .. attribute:: same_fragment_count
                                    
                                    	Number of fragment links which haven't changed since the last update
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, self).__init__()

                                        self.yang_name = "mpls-te-fragment"
                                        self.yang_parent_name = "mpls-te-fragment"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink)}

                                        self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                        self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                        self.mpls_te_link = YList(self)
                                        self._segment_path = lambda: "mpls-te-fragment"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment, ['dste_model_id', 'fragment_id', 'fragment_instance', 'same_fragment_count'], name, value)


                                    class MplsTeLink(Entity):
                                        """
                                        List of fragment links
                                        
                                        .. attribute:: affinity
                                        
                                        	Affinity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dste_allocation_model_id
                                        
                                        	DS\-TE Allocation Model ID
                                        	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                        
                                        .. attribute:: dste_in_use
                                        
                                        	A DS\-TE Allocation Model in use
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_admin_group_list
                                        
                                        	Extended Admin Group
                                        	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                        
                                        .. attribute:: fragment_id
                                        
                                        	Fragment ID for this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: global_unreserve_bw_per_priority
                                        
                                        	Global pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                        
                                        .. attribute:: igp_metric
                                        
                                        	Link IGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: input_interface_id
                                        
                                        	Input interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_address
                                        
                                        	The local interface address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_protocol_priority_capability
                                        
                                        	Link protocol and protocol priority capability
                                        	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                        
                                        .. attribute:: link_sw_capability
                                        
                                        	Link switching capability
                                        	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                        
                                        .. attribute:: maximum_link_bw
                                        
                                        	Maximum link bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_reservable_bw
                                        
                                        	Maximum link global pool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_sub_reservable_bw
                                        
                                        	Maximum link subpool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: mpls_link_instance
                                        
                                        	Link instance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mpls_link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                        
                                        .. attribute:: mplste_link_opt_tlv
                                        
                                        	List of Optional TLVs
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                        
                                        .. attribute:: neighbor_ip_address
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_system_id
                                        
                                        	Neighbor system ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: new_link
                                        
                                        	If true, Link is new
                                        	**type**\:  bool
                                        
                                        .. attribute:: number_of_optional_tl_vs
                                        
                                        	Number of Optional TLVs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: output_interface_id
                                        
                                        	Output interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority_count
                                        
                                        	Number of priorities
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_pool_unreserve_bw_per_priority
                                        
                                        	Sub pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                        
                                        .. attribute:: te_metric
                                        
                                        	Link TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, self).__init__()

                                            self.yang_name = "mpls-te-link"
                                            self.yang_parent_name = "mpls-te-fragment"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                            self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv)}

                                            self.affinity = YLeaf(YType.uint32, "affinity")

                                            self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                            self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                            self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                            self.link_address = YLeaf(YType.str, "link-address")

                                            self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                            self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                            self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                            self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                            self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                            self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                            self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                            self.new_link = YLeaf(YType.boolean, "new-link")

                                            self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                            self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                            self.priority_count = YLeaf(YType.int32, "priority-count")

                                            self.te_metric = YLeaf(YType.uint32, "te-metric")

                                            self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                            self.extended_admin_group_list.parent = self
                                            self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            self._children_yang_names.add("extended-admin-group-list")

                                            self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                            self.global_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            self._children_yang_names.add("global-unreserve-bw-per-priority")

                                            self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                            self.link_protocol_priority_capability.parent = self
                                            self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            self._children_yang_names.add("link-protocol-priority-capability")

                                            self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                            self.link_sw_capability.parent = self
                                            self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            self._children_yang_names.add("link-sw-capability")

                                            self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                            self.sub_pool_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                            self.mplste_link_opt_tlv = YList(self)
                                            self._segment_path = lambda: "mpls-te-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                        class ExtendedAdminGroupList(Entity):
                                            """
                                            Extended Admin Group
                                            
                                            .. attribute:: ext_admin_data
                                            
                                            	Value of Extended Admin Group
                                            	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                            
                                            .. attribute:: extended_admin_size
                                            
                                            	Size of the extended admin group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                                self.yang_name = "extended-admin-group-list"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                                self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                                self.ext_admin_data = YList(self)
                                                self._segment_path = lambda: "extended-admin-group-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                            class ExtAdminData(Entity):
                                                """
                                                Value of Extended Admin Group
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                    self.yang_name = "ext-admin-data"
                                                    self.yang_parent_name = "extended-admin-group-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "ext-admin-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                        class GlobalUnreserveBwPerPriority(Entity):
                                            """
                                            Global pool unreserved bandwidth for each
                                            priority (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "global-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                                self.bw_per_priority = YList(self)
                                                self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "global-unreserve-bw-per-priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "bw-per-priority"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                        class LinkProtocolPriorityCapability(Entity):
                                            """
                                            Link protocol and protocol priority capability
                                            
                                            .. attribute:: link_protocol_capability
                                            
                                            	Link protocol capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_protocol_priority
                                            
                                            	Link protocol priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                                self.yang_name = "link-protocol-priority-capability"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                                self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                                self._segment_path = lambda: "link-protocol-priority-capability"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                        class LinkSwCapability(Entity):
                                            """
                                            Link switching capability
                                            
                                            .. attribute:: link_encoding
                                            
                                            	Link Encoding
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_mtu
                                            
                                            	Link MTU size (bytes)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: link_switching_capability
                                            
                                            	Link Switching Capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: maximum_lsp_bw_per_priority
                                            
                                            	Maximum LSP bandwidth for each priority  (bytes/s)
                                            	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                            
                                            .. attribute:: minimum_lsp_bw
                                            
                                            	Minimum LSP bandwidth (bytes/s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                                self.yang_name = "link-sw-capability"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                                self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                                self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                                self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                                self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                                self.maximum_lsp_bw_per_priority = YList(self)
                                                self._segment_path = lambda: "link-sw-capability"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                            class MaximumLspBwPerPriority(Entity):
                                                """
                                                Maximum LSP bandwidth for each priority
                                                
                                                (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                    self.yang_name = "maximum-lsp-bw-per-priority"
                                                    self.yang_parent_name = "link-sw-capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                        class MplsteLinkOptTlv(Entity):
                                            """
                                            List of Optional TLVs
                                            
                                            .. attribute:: mplste_link_opt_tlv_len
                                            
                                            	Length of Opt TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mplste_link_opt_tlv_type
                                            
                                            	Type of Opt TLV
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: mplste_link_opt_tlv_value
                                            
                                            	Value of Opt TLV
                                            	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                                self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                                self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                                self.mplste_link_opt_tlv_value = YList(self)
                                                self._segment_path = lambda: "mplste-link-opt-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                            class MplsteLinkOptTlvValue(Entity):
                                                """
                                                Value of Opt TLV
                                                
                                                .. attribute:: bctlv_value
                                                
                                                	Value of Bandwidth Constraints TLV
                                                	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                                
                                                .. attribute:: ixcdtlv_value
                                                
                                                	Value of IXCD TLV
                                                	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                                
                                                .. attribute:: opaque_tlv_type
                                                
                                                	OpaqueTLVType
                                                	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                                
                                                .. attribute:: srlgtlv_value
                                                
                                                	Value of SRLG TLV
                                                	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                                
                                                .. attribute:: unidtlv_value
                                                
                                                	Value of Uni Delay TLV
                                                	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                    self.yang_name = "mplste-link-opt-tlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                                    self._child_list_classes = {}

                                                    self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                    self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                    self.bctlv_value.parent = self
                                                    self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    self._children_yang_names.add("bctlv-value")

                                                    self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                    self.ixcdtlv_value.parent = self
                                                    self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    self._children_yang_names.add("ixcdtlv-value")

                                                    self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                    self.srlgtlv_value.parent = self
                                                    self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    self._children_yang_names.add("srlgtlv-value")

                                                    self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                    self.unidtlv_value.parent = self
                                                    self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    self._children_yang_names.add("unidtlv-value")
                                                    self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                                class BctlvValue(Entity):
                                                    """
                                                    Value of Bandwidth Constraints TLV
                                                    
                                                    .. attribute:: model_id
                                                    
                                                    	Allocation Model ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mplste_link_bc_bandwidth
                                                    
                                                    	Value of BC TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                    
                                                    .. attribute:: num_b_cs
                                                    
                                                    	Number of BC TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                        self.yang_name = "bctlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                        self.model_id = YLeaf(YType.uint8, "model-id")

                                                        self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                        self.mplste_link_bc_bandwidth = YList(self)
                                                        self._segment_path = lambda: "bctlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                                    class MplsteLinkBcBandwidth(Entity):
                                                        """
                                                        Value of BC TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                            self.yang_name = "mplste-link-bc-bandwidth"
                                                            self.yang_parent_name = "bctlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                            self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                                class IxcdtlvValue(Entity):
                                                    """
                                                    Value of IXCD TLV
                                                    
                                                    .. attribute:: fixed_scsi_count
                                                    
                                                    	Fixed SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flex_scsi_count
                                                    
                                                    	Flexible SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ixcd_switching_cap_type
                                                    
                                                    	Switching Cap type
                                                    	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                    
                                                    .. attribute:: max_lspbw
                                                    
                                                    	Max LSP bandwidth array
                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                    
                                                    .. attribute:: rile_len_code
                                                    
                                                    	Rile LenCode
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: switching_cap
                                                    
                                                    	SCap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                        self.yang_name = "ixcdtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                        self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                        self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                        self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                        self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                        self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                        self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                        self.ixcd_switching_cap_type.parent = self
                                                        self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        self._children_yang_names.add("ixcd-switching-cap-type")

                                                        self.max_lspbw = YList(self)
                                                        self._segment_path = lambda: "ixcdtlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                                    class IxcdSwitchingCapType(Entity):
                                                        """
                                                        Switching Cap type
                                                        
                                                        .. attribute:: ixcdbw_sub_tlv
                                                        
                                                        	Sub TLVs
                                                        	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                        
                                                        .. attribute:: ixcdpsc_info
                                                        
                                                        	IXCD PSC information
                                                        	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                        
                                                        .. attribute:: switching_cap_type
                                                        
                                                        	SwitchingCapType
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                            self.yang_name = "ixcd-switching-cap-type"
                                                            self.yang_parent_name = "ixcdtlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                            self._child_list_classes = {}

                                                            self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                            self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                            self.ixcdbw_sub_tlv.parent = self
                                                            self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            self._children_yang_names.add("ixcdbw-sub-tlv")

                                                            self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                            self.ixcdpsc_info.parent = self
                                                            self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            self._children_yang_names.add("ixcdpsc-info")
                                                            self._segment_path = lambda: "ixcd-switching-cap-type"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                        class IxcdbwSubTlv(Entity):
                                                            """
                                                            Sub TLVs
                                                            
                                                            .. attribute:: arr_bw_sub_tlv
                                                            
                                                            	Array of sub tlvs
                                                            	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                                self.yang_name = "ixcdbw-sub-tlv"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                                self.arr_bw_sub_tlv = YList(self)
                                                                self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                            class ArrBwSubTlv(Entity):
                                                                """
                                                                Array of sub tlvs
                                                                
                                                                .. attribute:: bw_sub_tlv_length
                                                                
                                                                	Length of BW Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_type
                                                                
                                                                	Type of Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_value
                                                                
                                                                	Value of BW Sub TLV
                                                                	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                    self.yang_name = "arr-bw-sub-tlv"
                                                                    self.yang_parent_name = "ixcdbw-sub-tlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                                    self._child_list_classes = {}

                                                                    self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                    self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                    self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                    self.bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    self._children_yang_names.add("bw-sub-tlv-value")
                                                                    self._segment_path = lambda: "arr-bw-sub-tlv"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                                class BwSubTlvValue(Entity):
                                                                    """
                                                                    Value of BW Sub TLV
                                                                    
                                                                    .. attribute:: fixed_bw_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: flex_bw_sub_tlv_value
                                                                    
                                                                    	Value of Flex Sub TLV
                                                                    	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: ixcdbw_sub_tlv_type
                                                                    
                                                                    	IXCDBWSubTLVType
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                        self.yang_name = "bw-sub-tlv-value"
                                                                        self.yang_parent_name = "arr-bw-sub-tlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                        self._child_list_classes = {}

                                                                        self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                        self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                        self.fixed_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                        self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                        self.flex_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                        self._segment_path = lambda: "bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                                    class FixedBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: fixed_sub_tlv_value
                                                                        
                                                                        	Value of Fixed Sub TLV
                                                                        	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                        
                                                                        .. attribute:: unres_oduj_prio
                                                                        
                                                                        	Array of Unres Oduj Prio
                                                                        	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                            self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                            self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                            self.fixed_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            self._children_yang_names.add("fixed-sub-tlv-value")

                                                                            self.unres_oduj_prio = YList(self)
                                                                            self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                        class FixedSubTlvValue(Entity):
                                                                            """
                                                                            Value of Fixed Sub TLV
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                                self.yang_name = "fixed-sub-tlv-value"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")
                                                                                self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                        class UnresOdujPrio(Entity):
                                                                            """
                                                                            Array of Unres Oduj Prio
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                                self.yang_name = "unres-oduj-prio"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                                self._segment_path = lambda: "unres-oduj-prio"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                                    class FlexBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Flex Sub TLV
                                                                        
                                                                        .. attribute:: flex_sub_tlv_value_common
                                                                        
                                                                        	Flex Sub TLV Value
                                                                        	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                        
                                                                        .. attribute:: max_lspbw
                                                                        
                                                                        	Max LSP BW Array
                                                                        	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                        
                                                                        .. attribute:: unres_lspbw
                                                                        
                                                                        	Array of Unres LSP BW
                                                                        	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "flex-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                            self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                            self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                            self.flex_sub_tlv_value_common.parent = self
                                                                            self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                            self.max_lspbw = YList(self)
                                                                            self.unres_lspbw = YList(self)
                                                                            self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                        class FlexSubTlvValueCommon(Entity):
                                                                            """
                                                                            Flex Sub TLV Value
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                                self.yang_name = "flex-sub-tlv-value-common"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")
                                                                                self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                        class MaxLspbw(Entity):
                                                                            """
                                                                            Max LSP BW Array
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                                self.yang_name = "max-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.entry = YLeaf(YType.uint64, "entry")
                                                                                self._segment_path = lambda: "max-lspbw"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                        class UnresLspbw(Entity):
                                                                            """
                                                                            Array of Unres LSP BW
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                                self.yang_name = "unres-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.entry = YLeaf(YType.uint64, "entry")
                                                                                self._segment_path = lambda: "unres-lspbw"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                        class IxcdpscInfo(Entity):
                                                            """
                                                            IXCD PSC information
                                                            
                                                            .. attribute:: min_lsp_bandwidth
                                                            
                                                            	Min LSP bandwidth
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: psc_interface_mtu
                                                            
                                                            	 Interface MTU
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                                self.yang_name = "ixcdpsc-info"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                                self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                                self._segment_path = lambda: "ixcdpsc-info"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                                    class MaxLspbw(Entity):
                                                        """
                                                        Max LSP bandwidth array
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-9223372036854775808..9223372036854775807
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                            self.yang_name = "max-lspbw"
                                                            self.yang_parent_name = "ixcdtlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.int64, "entry")
                                                            self._segment_path = lambda: "max-lspbw"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                                class SrlgtlvValue(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: mplste_link_srlg_data
                                                    
                                                    	Value of SRLG TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                    
                                                    .. attribute:: num_srl_gs
                                                    
                                                    	Number of SRLG TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: srlg_len
                                                    
                                                    	Length of SRLG TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                        self.yang_name = "srlgtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                        self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                        self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                        self.mplste_link_srlg_data = YList(self)
                                                        self._segment_path = lambda: "srlgtlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                                    class MplsteLinkSrlgData(Entity):
                                                        """
                                                        Value of SRLG TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                            self.yang_name = "mplste-link-srlg-data"
                                                            self.yang_parent_name = "srlgtlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "mplste-link-srlg-data"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                                class UnidtlvValue(Entity):
                                                    """
                                                    Value of Uni Delay TLV
                                                    
                                                    .. attribute:: uni_dir_delay
                                                    
                                                    	Uni Dir Delay
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                        self.yang_name = "unidtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                        self._segment_path = lambda: "unidtlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                        class SubPoolUnreserveBwPerPriority(Entity):
                                            """
                                            Sub pool unreserved bandwidth for each priority
                                            (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                                self.bw_per_priority = YList(self)
                                                self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "bw-per-priority"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                class MplsTeLink(Entity):
                                    """
                                    MPLS\-TE links in the area
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-fragment"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                        self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv)}

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)
                                        self._segment_path = lambda: "mpls-te-link"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)
                                            self._segment_path = lambda: "extended-admin-group-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "ext-admin-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                            self._segment_path = lambda: "link-protocol-priority-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)
                                            self._segment_path = lambda: "link-sw-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)
                                            self._segment_path = lambda: "mplste-link-opt-tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                                self._child_list_classes = {}

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")
                                                self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)
                                                    self._segment_path = lambda: "bctlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                        self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                    self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)
                                                    self._segment_path = lambda: "ixcdtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                        self._child_list_classes = {}

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")
                                                        self._segment_path = lambda: "ixcd-switching-cap-type"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                            self.arr_bw_sub_tlv = YList(self)
                                                            self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                                self._child_list_classes = {}

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")
                                                                self._segment_path = lambda: "arr-bw-sub-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                    self._child_list_classes = {}

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                    self._segment_path = lambda: "bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                        self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)
                                                                        self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                                            self._segment_path = lambda: "unres-oduj-prio"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                        self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)
                                                                        self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "max-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "unres-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                            self._segment_path = lambda: "ixcdpsc-info"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.int64, "entry")
                                                        self._segment_path = lambda: "max-lspbw"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)
                                                    self._segment_path = lambda: "srlgtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "mplste-link-srlg-data"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                    self._segment_path = lambda: "unidtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeFragments.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                        class MplsTeLinks(Entity):
                            """
                            MPLS TE link information table
                            
                            .. attribute:: mpls_te_link
                            
                            	MPLS TE link information
                            	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks, self).__init__()

                                self.yang_name = "mpls-te-links"
                                self.yang_parent_name = "mpls-te"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink)}

                                self.mpls_te_link = YList(self)
                                self._segment_path = lambda: "mpls-te-links"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks, [], name, value)


                            class MplsTeLink(Entity):
                                """
                                MPLS TE link information
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: mpls_te_area_id
                                
                                	Area ID string in decimal or dotted decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: mpls_te_area_instance
                                
                                	Area information instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_enabled
                                
                                	If true, MPLS\-TE enabled in area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_fragment
                                
                                	MPLS TE fragments in the area
                                	**type**\: list of    :py:class:`MplsTeFragment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment>`
                                
                                .. attribute:: mpls_te_initialized
                                
                                	If true, MPLS\-TE initialized in the area
                                	**type**\:  bool
                                
                                .. attribute:: mpls_te_link
                                
                                	MPLS\-TE links in the area
                                	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink>`
                                
                                .. attribute:: mpls_te_next_fragment_id
                                
                                	Next MPLS\-TE fragment ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_te_router_address
                                
                                	MPLS\-TE router address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mpls_te_router_id
                                
                                	OSPF MPLS\-TE router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: spacious_fragment
                                
                                	If true, fragment has space for next link
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink, self).__init__()

                                    self.yang_name = "mpls-te-link"
                                    self.yang_parent_name = "mpls-te-links"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"mpls-te-fragment" : ("mpls_te_fragment", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment), "mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink)}

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.mpls_te_area_id = YLeaf(YType.str, "mpls-te-area-id")

                                    self.mpls_te_area_instance = YLeaf(YType.uint32, "mpls-te-area-instance")

                                    self.mpls_te_enabled = YLeaf(YType.boolean, "mpls-te-enabled")

                                    self.mpls_te_initialized = YLeaf(YType.boolean, "mpls-te-initialized")

                                    self.mpls_te_next_fragment_id = YLeaf(YType.uint32, "mpls-te-next-fragment-id")

                                    self.mpls_te_router_address = YLeaf(YType.str, "mpls-te-router-address")

                                    self.mpls_te_router_id = YLeaf(YType.str, "mpls-te-router-id")

                                    self.spacious_fragment = YLeaf(YType.boolean, "spacious-fragment")

                                    self.mpls_te_fragment = YList(self)
                                    self.mpls_te_link = YList(self)
                                    self._segment_path = lambda: "mpls-te-link" + "[area-id='" + self.area_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink, ['area_id', 'mpls_te_area_id', 'mpls_te_area_instance', 'mpls_te_enabled', 'mpls_te_initialized', 'mpls_te_next_fragment_id', 'mpls_te_router_address', 'mpls_te_router_id', 'spacious_fragment'], name, value)


                                class MplsTeFragment(Entity):
                                    """
                                    MPLS TE fragments in the area
                                    
                                    .. attribute:: dste_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fragment_instance
                                    
                                    	Fragment instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_te_link
                                    
                                    	List of fragment links
                                    	**type**\: list of    :py:class:`MplsTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink>`
                                    
                                    .. attribute:: same_fragment_count
                                    
                                    	Number of fragment links which haven't changed since the last update
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, self).__init__()

                                        self.yang_name = "mpls-te-fragment"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"mpls-te-link" : ("mpls_te_link", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink)}

                                        self.dste_model_id = YLeaf(YType.uint8, "dste-model-id")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.fragment_instance = YLeaf(YType.uint32, "fragment-instance")

                                        self.same_fragment_count = YLeaf(YType.uint8, "same-fragment-count")

                                        self.mpls_te_link = YList(self)
                                        self._segment_path = lambda: "mpls-te-fragment"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment, ['dste_model_id', 'fragment_id', 'fragment_instance', 'same_fragment_count'], name, value)


                                    class MplsTeLink(Entity):
                                        """
                                        List of fragment links
                                        
                                        .. attribute:: affinity
                                        
                                        	Affinity
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: dste_allocation_model_id
                                        
                                        	DS\-TE Allocation Model ID
                                        	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                        
                                        .. attribute:: dste_in_use
                                        
                                        	A DS\-TE Allocation Model in use
                                        	**type**\:  bool
                                        
                                        .. attribute:: extended_admin_group_list
                                        
                                        	Extended Admin Group
                                        	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList>`
                                        
                                        .. attribute:: fragment_id
                                        
                                        	Fragment ID for this link
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: global_unreserve_bw_per_priority
                                        
                                        	Global pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                        
                                        .. attribute:: igp_metric
                                        
                                        	Link IGP metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: input_interface_id
                                        
                                        	Input interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_address
                                        
                                        	The local interface address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: link_protocol_priority_capability
                                        
                                        	Link protocol and protocol priority capability
                                        	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability>`
                                        
                                        .. attribute:: link_sw_capability
                                        
                                        	Link switching capability
                                        	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability>`
                                        
                                        .. attribute:: maximum_link_bw
                                        
                                        	Maximum link bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_reservable_bw
                                        
                                        	Maximum link global pool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: maximum_link_sub_reservable_bw
                                        
                                        	Maximum link subpool reservable bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: byte/s
                                        
                                        .. attribute:: mpls_link_instance
                                        
                                        	Link instance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mpls_link_type
                                        
                                        	Type of link
                                        	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                        
                                        .. attribute:: mplste_link_opt_tlv
                                        
                                        	List of Optional TLVs
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv>`
                                        
                                        .. attribute:: neighbor_ip_address
                                        
                                        	Neighbor IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_system_id
                                        
                                        	Neighbor system ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: new_link
                                        
                                        	If true, Link is new
                                        	**type**\:  bool
                                        
                                        .. attribute:: number_of_optional_tl_vs
                                        
                                        	Number of Optional TLVs
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: output_interface_id
                                        
                                        	Output interface ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority_count
                                        
                                        	Number of priorities
                                        	**type**\:  int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        .. attribute:: sub_pool_unreserve_bw_per_priority
                                        
                                        	Sub pool unreserved bandwidth for each priority (bytes/s)
                                        	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                        
                                        .. attribute:: te_metric
                                        
                                        	Link TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, self).__init__()

                                            self.yang_name = "mpls-te-link"
                                            self.yang_parent_name = "mpls-te-fragment"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                            self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv)}

                                            self.affinity = YLeaf(YType.uint32, "affinity")

                                            self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                            self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                            self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                            self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                            self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                            self.link_address = YLeaf(YType.str, "link-address")

                                            self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                            self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                            self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                            self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                            self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                            self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                            self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                            self.new_link = YLeaf(YType.boolean, "new-link")

                                            self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                            self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                            self.priority_count = YLeaf(YType.int32, "priority-count")

                                            self.te_metric = YLeaf(YType.uint32, "te-metric")

                                            self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList()
                                            self.extended_admin_group_list.parent = self
                                            self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                            self._children_yang_names.add("extended-admin-group-list")

                                            self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority()
                                            self.global_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                            self._children_yang_names.add("global-unreserve-bw-per-priority")

                                            self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability()
                                            self.link_protocol_priority_capability.parent = self
                                            self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                            self._children_yang_names.add("link-protocol-priority-capability")

                                            self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability()
                                            self.link_sw_capability.parent = self
                                            self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                            self._children_yang_names.add("link-sw-capability")

                                            self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                            self.sub_pool_unreserve_bw_per_priority.parent = self
                                            self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                            self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                            self.mplste_link_opt_tlv = YList(self)
                                            self._segment_path = lambda: "mpls-te-link"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                        class ExtendedAdminGroupList(Entity):
                                            """
                                            Extended Admin Group
                                            
                                            .. attribute:: ext_admin_data
                                            
                                            	Value of Extended Admin Group
                                            	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                            
                                            .. attribute:: extended_admin_size
                                            
                                            	Size of the extended admin group
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                                self.yang_name = "extended-admin-group-list"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                                self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                                self.ext_admin_data = YList(self)
                                                self._segment_path = lambda: "extended-admin-group-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                            class ExtAdminData(Entity):
                                                """
                                                Value of Extended Admin Group
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                    self.yang_name = "ext-admin-data"
                                                    self.yang_parent_name = "extended-admin-group-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint32, "entry")
                                                    self._segment_path = lambda: "ext-admin-data"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                        class GlobalUnreserveBwPerPriority(Entity):
                                            """
                                            Global pool unreserved bandwidth for each
                                            priority (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "global-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                                self.bw_per_priority = YList(self)
                                                self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "global-unreserve-bw-per-priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "bw-per-priority"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                        class LinkProtocolPriorityCapability(Entity):
                                            """
                                            Link protocol and protocol priority capability
                                            
                                            .. attribute:: link_protocol_capability
                                            
                                            	Link protocol capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_protocol_priority
                                            
                                            	Link protocol priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                                self.yang_name = "link-protocol-priority-capability"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                                self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                                self._segment_path = lambda: "link-protocol-priority-capability"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                        class LinkSwCapability(Entity):
                                            """
                                            Link switching capability
                                            
                                            .. attribute:: link_encoding
                                            
                                            	Link Encoding
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link_mtu
                                            
                                            	Link MTU size (bytes)
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: link_switching_capability
                                            
                                            	Link Switching Capability
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: maximum_lsp_bw_per_priority
                                            
                                            	Maximum LSP bandwidth for each priority  (bytes/s)
                                            	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                            
                                            .. attribute:: minimum_lsp_bw
                                            
                                            	Minimum LSP bandwidth (bytes/s)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, self).__init__()

                                                self.yang_name = "link-sw-capability"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                                self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                                self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                                self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                                self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                                self.maximum_lsp_bw_per_priority = YList(self)
                                                self._segment_path = lambda: "link-sw-capability"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                            class MaximumLspBwPerPriority(Entity):
                                                """
                                                Maximum LSP bandwidth for each priority
                                                
                                                (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                    self.yang_name = "maximum-lsp-bw-per-priority"
                                                    self.yang_parent_name = "link-sw-capability"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                        class MplsteLinkOptTlv(Entity):
                                            """
                                            List of Optional TLVs
                                            
                                            .. attribute:: mplste_link_opt_tlv_len
                                            
                                            	Length of Opt TLV
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: mplste_link_opt_tlv_type
                                            
                                            	Type of Opt TLV
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: mplste_link_opt_tlv_value
                                            
                                            	Value of Opt TLV
                                            	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                                self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                                self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                                self.mplste_link_opt_tlv_value = YList(self)
                                                self._segment_path = lambda: "mplste-link-opt-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                            class MplsteLinkOptTlvValue(Entity):
                                                """
                                                Value of Opt TLV
                                                
                                                .. attribute:: bctlv_value
                                                
                                                	Value of Bandwidth Constraints TLV
                                                	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                                
                                                .. attribute:: ixcdtlv_value
                                                
                                                	Value of IXCD TLV
                                                	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                                
                                                .. attribute:: opaque_tlv_type
                                                
                                                	OpaqueTLVType
                                                	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                                
                                                .. attribute:: srlgtlv_value
                                                
                                                	Value of SRLG TLV
                                                	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                                
                                                .. attribute:: unidtlv_value
                                                
                                                	Value of Uni Delay TLV
                                                	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                    self.yang_name = "mplste-link-opt-tlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                                    self._child_list_classes = {}

                                                    self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                    self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                    self.bctlv_value.parent = self
                                                    self._children_name_map["bctlv_value"] = "bctlv-value"
                                                    self._children_yang_names.add("bctlv-value")

                                                    self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                    self.ixcdtlv_value.parent = self
                                                    self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                    self._children_yang_names.add("ixcdtlv-value")

                                                    self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                    self.srlgtlv_value.parent = self
                                                    self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                    self._children_yang_names.add("srlgtlv-value")

                                                    self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                    self.unidtlv_value.parent = self
                                                    self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                    self._children_yang_names.add("unidtlv-value")
                                                    self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                                class BctlvValue(Entity):
                                                    """
                                                    Value of Bandwidth Constraints TLV
                                                    
                                                    .. attribute:: model_id
                                                    
                                                    	Allocation Model ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: mplste_link_bc_bandwidth
                                                    
                                                    	Value of BC TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                    
                                                    .. attribute:: num_b_cs
                                                    
                                                    	Number of BC TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                        self.yang_name = "bctlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                        self.model_id = YLeaf(YType.uint8, "model-id")

                                                        self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                        self.mplste_link_bc_bandwidth = YList(self)
                                                        self._segment_path = lambda: "bctlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                                    class MplsteLinkBcBandwidth(Entity):
                                                        """
                                                        Value of BC TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                            self.yang_name = "mplste-link-bc-bandwidth"
                                                            self.yang_parent_name = "bctlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                            self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                                class IxcdtlvValue(Entity):
                                                    """
                                                    Value of IXCD TLV
                                                    
                                                    .. attribute:: fixed_scsi_count
                                                    
                                                    	Fixed SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flex_scsi_count
                                                    
                                                    	Flexible SCSI count
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ixcd_switching_cap_type
                                                    
                                                    	Switching Cap type
                                                    	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                    
                                                    .. attribute:: max_lspbw
                                                    
                                                    	Max LSP bandwidth array
                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                    
                                                    .. attribute:: rile_len_code
                                                    
                                                    	Rile LenCode
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: switching_cap
                                                    
                                                    	SCap
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                        self.yang_name = "ixcdtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                        self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                        self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                        self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                        self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                        self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                        self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                        self.ixcd_switching_cap_type.parent = self
                                                        self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                        self._children_yang_names.add("ixcd-switching-cap-type")

                                                        self.max_lspbw = YList(self)
                                                        self._segment_path = lambda: "ixcdtlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                                    class IxcdSwitchingCapType(Entity):
                                                        """
                                                        Switching Cap type
                                                        
                                                        .. attribute:: ixcdbw_sub_tlv
                                                        
                                                        	Sub TLVs
                                                        	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                        
                                                        .. attribute:: ixcdpsc_info
                                                        
                                                        	IXCD PSC information
                                                        	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                        
                                                        .. attribute:: switching_cap_type
                                                        
                                                        	SwitchingCapType
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                            self.yang_name = "ixcd-switching-cap-type"
                                                            self.yang_parent_name = "ixcdtlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                            self._child_list_classes = {}

                                                            self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                            self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                            self.ixcdbw_sub_tlv.parent = self
                                                            self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                            self._children_yang_names.add("ixcdbw-sub-tlv")

                                                            self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                            self.ixcdpsc_info.parent = self
                                                            self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                            self._children_yang_names.add("ixcdpsc-info")
                                                            self._segment_path = lambda: "ixcd-switching-cap-type"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                        class IxcdbwSubTlv(Entity):
                                                            """
                                                            Sub TLVs
                                                            
                                                            .. attribute:: arr_bw_sub_tlv
                                                            
                                                            	Array of sub tlvs
                                                            	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                                self.yang_name = "ixcdbw-sub-tlv"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                                self.arr_bw_sub_tlv = YList(self)
                                                                self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                            class ArrBwSubTlv(Entity):
                                                                """
                                                                Array of sub tlvs
                                                                
                                                                .. attribute:: bw_sub_tlv_length
                                                                
                                                                	Length of BW Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_type
                                                                
                                                                	Type of Sub TLV
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: bw_sub_tlv_value
                                                                
                                                                	Value of BW Sub TLV
                                                                	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                    self.yang_name = "arr-bw-sub-tlv"
                                                                    self.yang_parent_name = "ixcdbw-sub-tlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                                    self._child_list_classes = {}

                                                                    self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                    self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                    self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                    self.bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                    self._children_yang_names.add("bw-sub-tlv-value")
                                                                    self._segment_path = lambda: "arr-bw-sub-tlv"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                                class BwSubTlvValue(Entity):
                                                                    """
                                                                    Value of BW Sub TLV
                                                                    
                                                                    .. attribute:: fixed_bw_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: flex_bw_sub_tlv_value
                                                                    
                                                                    	Value of Flex Sub TLV
                                                                    	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                    
                                                                    .. attribute:: ixcdbw_sub_tlv_type
                                                                    
                                                                    	IXCDBWSubTLVType
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..65535
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                        self.yang_name = "bw-sub-tlv-value"
                                                                        self.yang_parent_name = "arr-bw-sub-tlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                        self._child_list_classes = {}

                                                                        self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                        self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                        self.fixed_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                        self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                        self.flex_bw_sub_tlv_value.parent = self
                                                                        self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                        self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                        self._segment_path = lambda: "bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                                    class FixedBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: fixed_sub_tlv_value
                                                                        
                                                                        	Value of Fixed Sub TLV
                                                                        	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                        
                                                                        .. attribute:: unres_oduj_prio
                                                                        
                                                                        	Array of Unres Oduj Prio
                                                                        	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                            self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                            self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                            self.fixed_sub_tlv_value.parent = self
                                                                            self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                            self._children_yang_names.add("fixed-sub-tlv-value")

                                                                            self.unres_oduj_prio = YList(self)
                                                                            self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                        class FixedSubTlvValue(Entity):
                                                                            """
                                                                            Value of Fixed Sub TLV
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                                self.yang_name = "fixed-sub-tlv-value"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")
                                                                                self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                        class UnresOdujPrio(Entity):
                                                                            """
                                                                            Array of Unres Oduj Prio
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                                self.yang_name = "unres-oduj-prio"
                                                                                self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                                self._segment_path = lambda: "unres-oduj-prio"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                                    class FlexBwSubTlvValue(Entity):
                                                                        """
                                                                        Value of Flex Sub TLV
                                                                        
                                                                        .. attribute:: flex_sub_tlv_value_common
                                                                        
                                                                        	Flex Sub TLV Value
                                                                        	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                        
                                                                        .. attribute:: max_lspbw
                                                                        
                                                                        	Max LSP BW Array
                                                                        	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                        
                                                                        .. attribute:: unres_lspbw
                                                                        
                                                                        	Array of Unres LSP BW
                                                                        	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                            self.yang_name = "flex-bw-sub-tlv-value"
                                                                            self.yang_parent_name = "bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                            self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                            self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                            self.flex_sub_tlv_value_common.parent = self
                                                                            self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                            self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                            self.max_lspbw = YList(self)
                                                                            self.unres_lspbw = YList(self)
                                                                            self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                        class FlexSubTlvValueCommon(Entity):
                                                                            """
                                                                            Flex Sub TLV Value
                                                                            
                                                                            .. attribute:: num_stages
                                                                            
                                                                            	Number of stages
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit0
                                                                            
                                                                            	Priority 0
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit1
                                                                            
                                                                            	Priority 1
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit2
                                                                            
                                                                            	Priority 2
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit3
                                                                            
                                                                            	Priority 3
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit4
                                                                            
                                                                            	Priority 4
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit5
                                                                            
                                                                            	Priority 5
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit6
                                                                            
                                                                            	Priority 6
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: priority_bit7
                                                                            
                                                                            	Priority 7
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: res
                                                                            
                                                                            	Res
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: sbit
                                                                            
                                                                            	S Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: signal_type
                                                                            
                                                                            	Signal Type
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: stage
                                                                            
                                                                            	Array of Stages
                                                                            	**type**\:  str
                                                                            
                                                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                            
                                                                            .. attribute:: tbit
                                                                            
                                                                            	T Bit
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            .. attribute:: tsg
                                                                            
                                                                            	TSG
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..255
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                                self.yang_name = "flex-sub-tlv-value-common"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                                self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                                self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                                self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                                self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                                self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                                self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                                self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                                self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                                self.res = YLeaf(YType.uint8, "res")

                                                                                self.sbit = YLeaf(YType.uint8, "sbit")

                                                                                self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                                self.stage = YLeaf(YType.str, "stage")

                                                                                self.tbit = YLeaf(YType.uint8, "tbit")

                                                                                self.tsg = YLeaf(YType.uint8, "tsg")
                                                                                self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                        class MaxLspbw(Entity):
                                                                            """
                                                                            Max LSP BW Array
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                                self.yang_name = "max-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.entry = YLeaf(YType.uint64, "entry")
                                                                                self._segment_path = lambda: "max-lspbw"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                        class UnresLspbw(Entity):
                                                                            """
                                                                            Array of Unres LSP BW
                                                                            
                                                                            .. attribute:: entry
                                                                            
                                                                            	
                                                                            	**type**\:  int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'ipv4-ospf-oper'
                                                                            _revision = '2017-05-01'

                                                                            def __init__(self):
                                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                                self.yang_name = "unres-lspbw"
                                                                                self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self._child_container_classes = {}
                                                                                self._child_list_classes = {}

                                                                                self.entry = YLeaf(YType.uint64, "entry")
                                                                                self._segment_path = lambda: "unres-lspbw"

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                        class IxcdpscInfo(Entity):
                                                            """
                                                            IXCD PSC information
                                                            
                                                            .. attribute:: min_lsp_bandwidth
                                                            
                                                            	Min LSP bandwidth
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..18446744073709551615
                                                            
                                                            .. attribute:: psc_interface_mtu
                                                            
                                                            	 Interface MTU
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                                self.yang_name = "ixcdpsc-info"
                                                                self.yang_parent_name = "ixcd-switching-cap-type"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                                self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                                self._segment_path = lambda: "ixcdpsc-info"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                                    class MaxLspbw(Entity):
                                                        """
                                                        Max LSP bandwidth array
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** \-9223372036854775808..9223372036854775807
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                            self.yang_name = "max-lspbw"
                                                            self.yang_parent_name = "ixcdtlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.int64, "entry")
                                                            self._segment_path = lambda: "max-lspbw"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                                class SrlgtlvValue(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: mplste_link_srlg_data
                                                    
                                                    	Value of SRLG TLV
                                                    	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                    
                                                    .. attribute:: num_srl_gs
                                                    
                                                    	Number of SRLG TLVs
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: srlg_len
                                                    
                                                    	Length of SRLG TLV
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                        self.yang_name = "srlgtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                        self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                        self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                        self.mplste_link_srlg_data = YList(self)
                                                        self._segment_path = lambda: "srlgtlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                                    class MplsteLinkSrlgData(Entity):
                                                        """
                                                        Value of SRLG TLV
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                            self.yang_name = "mplste-link-srlg-data"
                                                            self.yang_parent_name = "srlgtlv-value"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "mplste-link-srlg-data"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                                class UnidtlvValue(Entity):
                                                    """
                                                    Value of Uni Delay TLV
                                                    
                                                    .. attribute:: uni_dir_delay
                                                    
                                                    	Uni Dir Delay
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                        self.yang_name = "unidtlv-value"
                                                        self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                        self._segment_path = lambda: "unidtlv-value"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                        class SubPoolUnreserveBwPerPriority(Entity):
                                            """
                                            Sub pool unreserved bandwidth for each priority
                                            (bytes/s)
                                            
                                            .. attribute:: bw_per_priority
                                            
                                            	Unreserved bandwidth for each priority (bytes/s)
                                            	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                                self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                                self.yang_parent_name = "mpls-te-link"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                                self.bw_per_priority = YList(self)
                                                self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                            class BwPerPriority(Entity):
                                                """
                                                Unreserved bandwidth for each priority (bytes/s)
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte/s
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                    self.yang_name = "bw-per-priority"
                                                    self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.entry = YLeaf(YType.uint64, "entry")
                                                    self._segment_path = lambda: "bw-per-priority"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeFragment.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                class MplsTeLink(Entity):
                                    """
                                    MPLS\-TE links in the area
                                    
                                    .. attribute:: affinity
                                    
                                    	Affinity
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dste_allocation_model_id
                                    
                                    	DS\-TE Allocation Model ID
                                    	**type**\:   :py:class:`IgpteLibBwModel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.IgpteLibBwModel>`
                                    
                                    .. attribute:: dste_in_use
                                    
                                    	A DS\-TE Allocation Model in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: extended_admin_group_list
                                    
                                    	Extended Admin Group
                                    	**type**\:   :py:class:`ExtendedAdminGroupList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList>`
                                    
                                    .. attribute:: fragment_id
                                    
                                    	Fragment ID for this link
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: global_unreserve_bw_per_priority
                                    
                                    	Global pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`GlobalUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority>`
                                    
                                    .. attribute:: igp_metric
                                    
                                    	Link IGP metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: input_interface_id
                                    
                                    	Input interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_address
                                    
                                    	The local interface address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: link_protocol_priority_capability
                                    
                                    	Link protocol and protocol priority capability
                                    	**type**\:   :py:class:`LinkProtocolPriorityCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability>`
                                    
                                    .. attribute:: link_sw_capability
                                    
                                    	Link switching capability
                                    	**type**\:   :py:class:`LinkSwCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability>`
                                    
                                    .. attribute:: maximum_link_bw
                                    
                                    	Maximum link bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_reservable_bw
                                    
                                    	Maximum link global pool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: maximum_link_sub_reservable_bw
                                    
                                    	Maximum link subpool reservable bandwidth (bytes/s)
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: byte/s
                                    
                                    .. attribute:: mpls_link_instance
                                    
                                    	Link instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mpls_link_type
                                    
                                    	Type of link
                                    	**type**\:   :py:class:`LinkSubnet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.LinkSubnet>`
                                    
                                    .. attribute:: mplste_link_opt_tlv
                                    
                                    	List of Optional TLVs
                                    	**type**\: list of    :py:class:`MplsteLinkOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: new_link
                                    
                                    	If true, Link is new
                                    	**type**\:  bool
                                    
                                    .. attribute:: number_of_optional_tl_vs
                                    
                                    	Number of Optional TLVs
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: output_interface_id
                                    
                                    	Output interface ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority_count
                                    
                                    	Number of priorities
                                    	**type**\:  int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: sub_pool_unreserve_bw_per_priority
                                    
                                    	Sub pool unreserved bandwidth for each priority (bytes/s)
                                    	**type**\:   :py:class:`SubPoolUnreserveBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority>`
                                    
                                    .. attribute:: te_metric
                                    
                                    	Link TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, self).__init__()

                                        self.yang_name = "mpls-te-link"
                                        self.yang_parent_name = "mpls-te-link"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"extended-admin-group-list" : ("extended_admin_group_list", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList), "global-unreserve-bw-per-priority" : ("global_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority), "link-protocol-priority-capability" : ("link_protocol_priority_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability), "link-sw-capability" : ("link_sw_capability", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability), "sub-pool-unreserve-bw-per-priority" : ("sub_pool_unreserve_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority)}
                                        self._child_list_classes = {"mplste-link-opt-tlv" : ("mplste_link_opt_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv)}

                                        self.affinity = YLeaf(YType.uint32, "affinity")

                                        self.dste_allocation_model_id = YLeaf(YType.enumeration, "dste-allocation-model-id")

                                        self.dste_in_use = YLeaf(YType.boolean, "dste-in-use")

                                        self.fragment_id = YLeaf(YType.uint32, "fragment-id")

                                        self.igp_metric = YLeaf(YType.uint32, "igp-metric")

                                        self.input_interface_id = YLeaf(YType.uint32, "input-interface-id")

                                        self.link_address = YLeaf(YType.str, "link-address")

                                        self.maximum_link_bw = YLeaf(YType.uint32, "maximum-link-bw")

                                        self.maximum_link_reservable_bw = YLeaf(YType.uint32, "maximum-link-reservable-bw")

                                        self.maximum_link_sub_reservable_bw = YLeaf(YType.uint32, "maximum-link-sub-reservable-bw")

                                        self.mpls_link_instance = YLeaf(YType.uint32, "mpls-link-instance")

                                        self.mpls_link_type = YLeaf(YType.enumeration, "mpls-link-type")

                                        self.neighbor_ip_address = YLeaf(YType.str, "neighbor-ip-address")

                                        self.neighbor_system_id = YLeaf(YType.str, "neighbor-system-id")

                                        self.new_link = YLeaf(YType.boolean, "new-link")

                                        self.number_of_optional_tl_vs = YLeaf(YType.uint8, "number-of-optional-tl-vs")

                                        self.output_interface_id = YLeaf(YType.uint32, "output-interface-id")

                                        self.priority_count = YLeaf(YType.int32, "priority-count")

                                        self.te_metric = YLeaf(YType.uint32, "te-metric")

                                        self.extended_admin_group_list = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList()
                                        self.extended_admin_group_list.parent = self
                                        self._children_name_map["extended_admin_group_list"] = "extended-admin-group-list"
                                        self._children_yang_names.add("extended-admin-group-list")

                                        self.global_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority()
                                        self.global_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["global_unreserve_bw_per_priority"] = "global-unreserve-bw-per-priority"
                                        self._children_yang_names.add("global-unreserve-bw-per-priority")

                                        self.link_protocol_priority_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability()
                                        self.link_protocol_priority_capability.parent = self
                                        self._children_name_map["link_protocol_priority_capability"] = "link-protocol-priority-capability"
                                        self._children_yang_names.add("link-protocol-priority-capability")

                                        self.link_sw_capability = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability()
                                        self.link_sw_capability.parent = self
                                        self._children_name_map["link_sw_capability"] = "link-sw-capability"
                                        self._children_yang_names.add("link-sw-capability")

                                        self.sub_pool_unreserve_bw_per_priority = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority()
                                        self.sub_pool_unreserve_bw_per_priority.parent = self
                                        self._children_name_map["sub_pool_unreserve_bw_per_priority"] = "sub-pool-unreserve-bw-per-priority"
                                        self._children_yang_names.add("sub-pool-unreserve-bw-per-priority")

                                        self.mplste_link_opt_tlv = YList(self)
                                        self._segment_path = lambda: "mpls-te-link"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink, ['affinity', 'dste_allocation_model_id', 'dste_in_use', 'fragment_id', 'igp_metric', 'input_interface_id', 'link_address', 'maximum_link_bw', 'maximum_link_reservable_bw', 'maximum_link_sub_reservable_bw', 'mpls_link_instance', 'mpls_link_type', 'neighbor_ip_address', 'neighbor_system_id', 'new_link', 'number_of_optional_tl_vs', 'output_interface_id', 'priority_count', 'te_metric'], name, value)


                                    class ExtendedAdminGroupList(Entity):
                                        """
                                        Extended Admin Group
                                        
                                        .. attribute:: ext_admin_data
                                        
                                        	Value of Extended Admin Group
                                        	**type**\: list of    :py:class:`ExtAdminData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData>`
                                        
                                        .. attribute:: extended_admin_size
                                        
                                        	Size of the extended admin group
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, self).__init__()

                                            self.yang_name = "extended-admin-group-list"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"ext-admin-data" : ("ext_admin_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData)}

                                            self.extended_admin_size = YLeaf(YType.uint32, "extended-admin-size")

                                            self.ext_admin_data = YList(self)
                                            self._segment_path = lambda: "extended-admin-group-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList, ['extended_admin_size'], name, value)


                                        class ExtAdminData(Entity):
                                            """
                                            Value of Extended Admin Group
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, self).__init__()

                                                self.yang_name = "ext-admin-data"
                                                self.yang_parent_name = "extended-admin-group-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint32, "entry")
                                                self._segment_path = lambda: "ext-admin-data"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.ExtendedAdminGroupList.ExtAdminData, ['entry'], name, value)


                                    class GlobalUnreserveBwPerPriority(Entity):
                                        """
                                        Global pool unreserved bandwidth for each
                                        priority (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "global-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "global-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "global-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.GlobalUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                                    class LinkProtocolPriorityCapability(Entity):
                                        """
                                        Link protocol and protocol priority capability
                                        
                                        .. attribute:: link_protocol_capability
                                        
                                        	Link protocol capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_protocol_priority
                                        
                                        	Link protocol priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, self).__init__()

                                            self.yang_name = "link-protocol-priority-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.link_protocol_capability = YLeaf(YType.uint8, "link-protocol-capability")

                                            self.link_protocol_priority = YLeaf(YType.uint8, "link-protocol-priority")
                                            self._segment_path = lambda: "link-protocol-priority-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkProtocolPriorityCapability, ['link_protocol_capability', 'link_protocol_priority'], name, value)


                                    class LinkSwCapability(Entity):
                                        """
                                        Link switching capability
                                        
                                        .. attribute:: link_encoding
                                        
                                        	Link Encoding
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link_mtu
                                        
                                        	Link MTU size (bytes)
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: link_switching_capability
                                        
                                        	Link Switching Capability
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: maximum_lsp_bw_per_priority
                                        
                                        	Maximum LSP bandwidth for each priority  (bytes/s)
                                        	**type**\: list of    :py:class:`MaximumLspBwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority>`
                                        
                                        .. attribute:: minimum_lsp_bw
                                        
                                        	Minimum LSP bandwidth (bytes/s)
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte/s
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, self).__init__()

                                            self.yang_name = "link-sw-capability"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"maximum-lsp-bw-per-priority" : ("maximum_lsp_bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority)}

                                            self.link_encoding = YLeaf(YType.uint8, "link-encoding")

                                            self.link_mtu = YLeaf(YType.uint16, "link-mtu")

                                            self.link_switching_capability = YLeaf(YType.uint8, "link-switching-capability")

                                            self.minimum_lsp_bw = YLeaf(YType.uint64, "minimum-lsp-bw")

                                            self.maximum_lsp_bw_per_priority = YList(self)
                                            self._segment_path = lambda: "link-sw-capability"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability, ['link_encoding', 'link_mtu', 'link_switching_capability', 'minimum_lsp_bw'], name, value)


                                        class MaximumLspBwPerPriority(Entity):
                                            """
                                            Maximum LSP bandwidth for each priority
                                            
                                            (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, self).__init__()

                                                self.yang_name = "maximum-lsp-bw-per-priority"
                                                self.yang_parent_name = "link-sw-capability"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "maximum-lsp-bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.LinkSwCapability.MaximumLspBwPerPriority, ['entry'], name, value)


                                    class MplsteLinkOptTlv(Entity):
                                        """
                                        List of Optional TLVs
                                        
                                        .. attribute:: mplste_link_opt_tlv_len
                                        
                                        	Length of Opt TLV
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: mplste_link_opt_tlv_type
                                        
                                        	Type of Opt TLV
                                        	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                        
                                        .. attribute:: mplste_link_opt_tlv_value
                                        
                                        	Value of Opt TLV
                                        	**type**\: list of    :py:class:`MplsteLinkOptTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, self).__init__()

                                            self.yang_name = "mplste-link-opt-tlv"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"mplste-link-opt-tlv-value" : ("mplste_link_opt_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue)}

                                            self.mplste_link_opt_tlv_len = YLeaf(YType.uint16, "mplste-link-opt-tlv-len")

                                            self.mplste_link_opt_tlv_type = YLeaf(YType.enumeration, "mplste-link-opt-tlv-type")

                                            self.mplste_link_opt_tlv_value = YList(self)
                                            self._segment_path = lambda: "mplste-link-opt-tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv, ['mplste_link_opt_tlv_len', 'mplste_link_opt_tlv_type'], name, value)


                                        class MplsteLinkOptTlvValue(Entity):
                                            """
                                            Value of Opt TLV
                                            
                                            .. attribute:: bctlv_value
                                            
                                            	Value of Bandwidth Constraints TLV
                                            	**type**\:   :py:class:`BctlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue>`
                                            
                                            .. attribute:: ixcdtlv_value
                                            
                                            	Value of IXCD TLV
                                            	**type**\:   :py:class:`IxcdtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue>`
                                            
                                            .. attribute:: opaque_tlv_type
                                            
                                            	OpaqueTLVType
                                            	**type**\:   :py:class:`MplsTeOptTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MplsTeOptTlv>`
                                            
                                            .. attribute:: srlgtlv_value
                                            
                                            	Value of SRLG TLV
                                            	**type**\:   :py:class:`SrlgtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue>`
                                            
                                            .. attribute:: unidtlv_value
                                            
                                            	Value of Uni Delay TLV
                                            	**type**\:   :py:class:`UnidtlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, self).__init__()

                                                self.yang_name = "mplste-link-opt-tlv-value"
                                                self.yang_parent_name = "mplste-link-opt-tlv"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"bctlv-value" : ("bctlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue), "ixcdtlv-value" : ("ixcdtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue), "srlgtlv-value" : ("srlgtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue), "unidtlv-value" : ("unidtlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue)}
                                                self._child_list_classes = {}

                                                self.opaque_tlv_type = YLeaf(YType.enumeration, "opaque-tlv-type")

                                                self.bctlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue()
                                                self.bctlv_value.parent = self
                                                self._children_name_map["bctlv_value"] = "bctlv-value"
                                                self._children_yang_names.add("bctlv-value")

                                                self.ixcdtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue()
                                                self.ixcdtlv_value.parent = self
                                                self._children_name_map["ixcdtlv_value"] = "ixcdtlv-value"
                                                self._children_yang_names.add("ixcdtlv-value")

                                                self.srlgtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue()
                                                self.srlgtlv_value.parent = self
                                                self._children_name_map["srlgtlv_value"] = "srlgtlv-value"
                                                self._children_yang_names.add("srlgtlv-value")

                                                self.unidtlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue()
                                                self.unidtlv_value.parent = self
                                                self._children_name_map["unidtlv_value"] = "unidtlv-value"
                                                self._children_yang_names.add("unidtlv-value")
                                                self._segment_path = lambda: "mplste-link-opt-tlv-value"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue, ['opaque_tlv_type'], name, value)


                                            class BctlvValue(Entity):
                                                """
                                                Value of Bandwidth Constraints TLV
                                                
                                                .. attribute:: model_id
                                                
                                                	Allocation Model ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: mplste_link_bc_bandwidth
                                                
                                                	Value of BC TLV
                                                	**type**\: list of    :py:class:`MplsteLinkBcBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth>`
                                                
                                                .. attribute:: num_b_cs
                                                
                                                	Number of BC TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, self).__init__()

                                                    self.yang_name = "bctlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-bc-bandwidth" : ("mplste_link_bc_bandwidth", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth)}

                                                    self.model_id = YLeaf(YType.uint8, "model-id")

                                                    self.num_b_cs = YLeaf(YType.uint32, "num-b-cs")

                                                    self.mplste_link_bc_bandwidth = YList(self)
                                                    self._segment_path = lambda: "bctlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue, ['model_id', 'num_b_cs'], name, value)


                                                class MplsteLinkBcBandwidth(Entity):
                                                    """
                                                    Value of BC TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, self).__init__()

                                                        self.yang_name = "mplste-link-bc-bandwidth"
                                                        self.yang_parent_name = "bctlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint64, "entry")
                                                        self._segment_path = lambda: "mplste-link-bc-bandwidth"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.BctlvValue.MplsteLinkBcBandwidth, ['entry'], name, value)


                                            class IxcdtlvValue(Entity):
                                                """
                                                Value of IXCD TLV
                                                
                                                .. attribute:: fixed_scsi_count
                                                
                                                	Fixed SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flex_scsi_count
                                                
                                                	Flexible SCSI count
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ixcd_switching_cap_type
                                                
                                                	Switching Cap type
                                                	**type**\:   :py:class:`IxcdSwitchingCapType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType>`
                                                
                                                .. attribute:: max_lspbw
                                                
                                                	Max LSP bandwidth array
                                                	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw>`
                                                
                                                .. attribute:: rile_len_code
                                                
                                                	Rile LenCode
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: switching_cap
                                                
                                                	SCap
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, self).__init__()

                                                    self.yang_name = "ixcdtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"ixcd-switching-cap-type" : ("ixcd_switching_cap_type", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType)}
                                                    self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw)}

                                                    self.fixed_scsi_count = YLeaf(YType.uint32, "fixed-scsi-count")

                                                    self.flex_scsi_count = YLeaf(YType.uint32, "flex-scsi-count")

                                                    self.rile_len_code = YLeaf(YType.uint8, "rile-len-code")

                                                    self.switching_cap = YLeaf(YType.uint8, "switching-cap")

                                                    self.ixcd_switching_cap_type = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType()
                                                    self.ixcd_switching_cap_type.parent = self
                                                    self._children_name_map["ixcd_switching_cap_type"] = "ixcd-switching-cap-type"
                                                    self._children_yang_names.add("ixcd-switching-cap-type")

                                                    self.max_lspbw = YList(self)
                                                    self._segment_path = lambda: "ixcdtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue, ['fixed_scsi_count', 'flex_scsi_count', 'rile_len_code', 'switching_cap'], name, value)


                                                class IxcdSwitchingCapType(Entity):
                                                    """
                                                    Switching Cap type
                                                    
                                                    .. attribute:: ixcdbw_sub_tlv
                                                    
                                                    	Sub TLVs
                                                    	**type**\:   :py:class:`IxcdbwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv>`
                                                    
                                                    .. attribute:: ixcdpsc_info
                                                    
                                                    	IXCD PSC information
                                                    	**type**\:   :py:class:`IxcdpscInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo>`
                                                    
                                                    .. attribute:: switching_cap_type
                                                    
                                                    	SwitchingCapType
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, self).__init__()

                                                        self.yang_name = "ixcd-switching-cap-type"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {"ixcdbw-sub-tlv" : ("ixcdbw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv), "ixcdpsc-info" : ("ixcdpsc_info", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo)}
                                                        self._child_list_classes = {}

                                                        self.switching_cap_type = YLeaf(YType.uint8, "switching-cap-type")

                                                        self.ixcdbw_sub_tlv = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv()
                                                        self.ixcdbw_sub_tlv.parent = self
                                                        self._children_name_map["ixcdbw_sub_tlv"] = "ixcdbw-sub-tlv"
                                                        self._children_yang_names.add("ixcdbw-sub-tlv")

                                                        self.ixcdpsc_info = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo()
                                                        self.ixcdpsc_info.parent = self
                                                        self._children_name_map["ixcdpsc_info"] = "ixcdpsc-info"
                                                        self._children_yang_names.add("ixcdpsc-info")
                                                        self._segment_path = lambda: "ixcd-switching-cap-type"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType, ['switching_cap_type'], name, value)


                                                    class IxcdbwSubTlv(Entity):
                                                        """
                                                        Sub TLVs
                                                        
                                                        .. attribute:: arr_bw_sub_tlv
                                                        
                                                        	Array of sub tlvs
                                                        	**type**\: list of    :py:class:`ArrBwSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, self).__init__()

                                                            self.yang_name = "ixcdbw-sub-tlv"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"arr-bw-sub-tlv" : ("arr_bw_sub_tlv", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv)}

                                                            self.arr_bw_sub_tlv = YList(self)
                                                            self._segment_path = lambda: "ixcdbw-sub-tlv"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv, [], name, value)


                                                        class ArrBwSubTlv(Entity):
                                                            """
                                                            Array of sub tlvs
                                                            
                                                            .. attribute:: bw_sub_tlv_length
                                                            
                                                            	Length of BW Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_type
                                                            
                                                            	Type of Sub TLV
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: bw_sub_tlv_value
                                                            
                                                            	Value of BW Sub TLV
                                                            	**type**\:   :py:class:`BwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ipv4-ospf-oper'
                                                            _revision = '2017-05-01'

                                                            def __init__(self):
                                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, self).__init__()

                                                                self.yang_name = "arr-bw-sub-tlv"
                                                                self.yang_parent_name = "ixcdbw-sub-tlv"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {"bw-sub-tlv-value" : ("bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue)}
                                                                self._child_list_classes = {}

                                                                self.bw_sub_tlv_length = YLeaf(YType.uint16, "bw-sub-tlv-length")

                                                                self.bw_sub_tlv_type = YLeaf(YType.uint16, "bw-sub-tlv-type")

                                                                self.bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue()
                                                                self.bw_sub_tlv_value.parent = self
                                                                self._children_name_map["bw_sub_tlv_value"] = "bw-sub-tlv-value"
                                                                self._children_yang_names.add("bw-sub-tlv-value")
                                                                self._segment_path = lambda: "arr-bw-sub-tlv"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv, ['bw_sub_tlv_length', 'bw_sub_tlv_type'], name, value)


                                                            class BwSubTlvValue(Entity):
                                                                """
                                                                Value of BW Sub TLV
                                                                
                                                                .. attribute:: fixed_bw_sub_tlv_value
                                                                
                                                                	Value of Fixed Sub TLV
                                                                	**type**\:   :py:class:`FixedBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue>`
                                                                
                                                                .. attribute:: flex_bw_sub_tlv_value
                                                                
                                                                	Value of Flex Sub TLV
                                                                	**type**\:   :py:class:`FlexBwSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue>`
                                                                
                                                                .. attribute:: ixcdbw_sub_tlv_type
                                                                
                                                                	IXCDBWSubTLVType
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'ipv4-ospf-oper'
                                                                _revision = '2017-05-01'

                                                                def __init__(self):
                                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, self).__init__()

                                                                    self.yang_name = "bw-sub-tlv-value"
                                                                    self.yang_parent_name = "arr-bw-sub-tlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {"fixed-bw-sub-tlv-value" : ("fixed_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue), "flex-bw-sub-tlv-value" : ("flex_bw_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue)}
                                                                    self._child_list_classes = {}

                                                                    self.ixcdbw_sub_tlv_type = YLeaf(YType.uint16, "ixcdbw-sub-tlv-type")

                                                                    self.fixed_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue()
                                                                    self.fixed_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["fixed_bw_sub_tlv_value"] = "fixed-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("fixed-bw-sub-tlv-value")

                                                                    self.flex_bw_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue()
                                                                    self.flex_bw_sub_tlv_value.parent = self
                                                                    self._children_name_map["flex_bw_sub_tlv_value"] = "flex-bw-sub-tlv-value"
                                                                    self._children_yang_names.add("flex-bw-sub-tlv-value")
                                                                    self._segment_path = lambda: "bw-sub-tlv-value"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue, ['ixcdbw_sub_tlv_type'], name, value)


                                                                class FixedBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Fixed Sub TLV
                                                                    
                                                                    .. attribute:: fixed_sub_tlv_value
                                                                    
                                                                    	Value of Fixed Sub TLV
                                                                    	**type**\:   :py:class:`FixedSubTlvValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue>`
                                                                    
                                                                    .. attribute:: unres_oduj_prio
                                                                    
                                                                    	Array of Unres Oduj Prio
                                                                    	**type**\: list of    :py:class:`UnresOdujPrio <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "fixed-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"fixed-sub-tlv-value" : ("fixed_sub_tlv_value", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue)}
                                                                        self._child_list_classes = {"unres-oduj-prio" : ("unres_oduj_prio", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio)}

                                                                        self.fixed_sub_tlv_value = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue()
                                                                        self.fixed_sub_tlv_value.parent = self
                                                                        self._children_name_map["fixed_sub_tlv_value"] = "fixed-sub-tlv-value"
                                                                        self._children_yang_names.add("fixed-sub-tlv-value")

                                                                        self.unres_oduj_prio = YList(self)
                                                                        self._segment_path = lambda: "fixed-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue, [], name, value)


                                                                    class FixedSubTlvValue(Entity):
                                                                        """
                                                                        Value of Fixed Sub TLV
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, self).__init__()

                                                                            self.yang_name = "fixed-sub-tlv-value"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "fixed-sub-tlv-value"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.FixedSubTlvValue, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class UnresOdujPrio(Entity):
                                                                        """
                                                                        Array of Unres Oduj Prio
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..4294967295
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, self).__init__()

                                                                            self.yang_name = "unres-oduj-prio"
                                                                            self.yang_parent_name = "fixed-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                                            self._segment_path = lambda: "unres-oduj-prio"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FixedBwSubTlvValue.UnresOdujPrio, ['entry'], name, value)


                                                                class FlexBwSubTlvValue(Entity):
                                                                    """
                                                                    Value of Flex Sub TLV
                                                                    
                                                                    .. attribute:: flex_sub_tlv_value_common
                                                                    
                                                                    	Flex Sub TLV Value
                                                                    	**type**\:   :py:class:`FlexSubTlvValueCommon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon>`
                                                                    
                                                                    .. attribute:: max_lspbw
                                                                    
                                                                    	Max LSP BW Array
                                                                    	**type**\: list of    :py:class:`MaxLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw>`
                                                                    
                                                                    .. attribute:: unres_lspbw
                                                                    
                                                                    	Array of Unres LSP BW
                                                                    	**type**\: list of    :py:class:`UnresLspbw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ipv4-ospf-oper'
                                                                    _revision = '2017-05-01'

                                                                    def __init__(self):
                                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, self).__init__()

                                                                        self.yang_name = "flex-bw-sub-tlv-value"
                                                                        self.yang_parent_name = "bw-sub-tlv-value"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {"flex-sub-tlv-value-common" : ("flex_sub_tlv_value_common", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon)}
                                                                        self._child_list_classes = {"max-lspbw" : ("max_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw), "unres-lspbw" : ("unres_lspbw", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw)}

                                                                        self.flex_sub_tlv_value_common = Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon()
                                                                        self.flex_sub_tlv_value_common.parent = self
                                                                        self._children_name_map["flex_sub_tlv_value_common"] = "flex-sub-tlv-value-common"
                                                                        self._children_yang_names.add("flex-sub-tlv-value-common")

                                                                        self.max_lspbw = YList(self)
                                                                        self.unres_lspbw = YList(self)
                                                                        self._segment_path = lambda: "flex-bw-sub-tlv-value"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue, [], name, value)


                                                                    class FlexSubTlvValueCommon(Entity):
                                                                        """
                                                                        Flex Sub TLV Value
                                                                        
                                                                        .. attribute:: num_stages
                                                                        
                                                                        	Number of stages
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit0
                                                                        
                                                                        	Priority 0
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit1
                                                                        
                                                                        	Priority 1
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit2
                                                                        
                                                                        	Priority 2
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit3
                                                                        
                                                                        	Priority 3
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit4
                                                                        
                                                                        	Priority 4
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit5
                                                                        
                                                                        	Priority 5
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit6
                                                                        
                                                                        	Priority 6
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: priority_bit7
                                                                        
                                                                        	Priority 7
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: res
                                                                        
                                                                        	Res
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: sbit
                                                                        
                                                                        	S Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: signal_type
                                                                        
                                                                        	Signal Type
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: stage
                                                                        
                                                                        	Array of Stages
                                                                        	**type**\:  str
                                                                        
                                                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                                        
                                                                        .. attribute:: tbit
                                                                        
                                                                        	T Bit
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: tsg
                                                                        
                                                                        	TSG
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, self).__init__()

                                                                            self.yang_name = "flex-sub-tlv-value-common"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.num_stages = YLeaf(YType.uint8, "num-stages")

                                                                            self.priority_bit0 = YLeaf(YType.uint8, "priority-bit0")

                                                                            self.priority_bit1 = YLeaf(YType.uint8, "priority-bit1")

                                                                            self.priority_bit2 = YLeaf(YType.uint8, "priority-bit2")

                                                                            self.priority_bit3 = YLeaf(YType.uint8, "priority-bit3")

                                                                            self.priority_bit4 = YLeaf(YType.uint8, "priority-bit4")

                                                                            self.priority_bit5 = YLeaf(YType.uint8, "priority-bit5")

                                                                            self.priority_bit6 = YLeaf(YType.uint8, "priority-bit6")

                                                                            self.priority_bit7 = YLeaf(YType.uint8, "priority-bit7")

                                                                            self.res = YLeaf(YType.uint8, "res")

                                                                            self.sbit = YLeaf(YType.uint8, "sbit")

                                                                            self.signal_type = YLeaf(YType.uint8, "signal-type")

                                                                            self.stage = YLeaf(YType.str, "stage")

                                                                            self.tbit = YLeaf(YType.uint8, "tbit")

                                                                            self.tsg = YLeaf(YType.uint8, "tsg")
                                                                            self._segment_path = lambda: "flex-sub-tlv-value-common"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.FlexSubTlvValueCommon, ['num_stages', 'priority_bit0', 'priority_bit1', 'priority_bit2', 'priority_bit3', 'priority_bit4', 'priority_bit5', 'priority_bit6', 'priority_bit7', 'res', 'sbit', 'signal_type', 'stage', 'tbit', 'tsg'], name, value)


                                                                    class MaxLspbw(Entity):
                                                                        """
                                                                        Max LSP BW Array
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, self).__init__()

                                                                            self.yang_name = "max-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "max-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.MaxLspbw, ['entry'], name, value)


                                                                    class UnresLspbw(Entity):
                                                                        """
                                                                        Array of Unres LSP BW
                                                                        
                                                                        .. attribute:: entry
                                                                        
                                                                        	
                                                                        	**type**\:  int
                                                                        
                                                                        	**range:** 0..18446744073709551615
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'ipv4-ospf-oper'
                                                                        _revision = '2017-05-01'

                                                                        def __init__(self):
                                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, self).__init__()

                                                                            self.yang_name = "unres-lspbw"
                                                                            self.yang_parent_name = "flex-bw-sub-tlv-value"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self._child_container_classes = {}
                                                                            self._child_list_classes = {}

                                                                            self.entry = YLeaf(YType.uint64, "entry")
                                                                            self._segment_path = lambda: "unres-lspbw"

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdbwSubTlv.ArrBwSubTlv.BwSubTlvValue.FlexBwSubTlvValue.UnresLspbw, ['entry'], name, value)


                                                    class IxcdpscInfo(Entity):
                                                        """
                                                        IXCD PSC information
                                                        
                                                        .. attribute:: min_lsp_bandwidth
                                                        
                                                        	Min LSP bandwidth
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: psc_interface_mtu
                                                        
                                                        	 Interface MTU
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        

                                                        """

                                                        _prefix = 'ipv4-ospf-oper'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, self).__init__()

                                                            self.yang_name = "ixcdpsc-info"
                                                            self.yang_parent_name = "ixcd-switching-cap-type"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.min_lsp_bandwidth = YLeaf(YType.uint64, "min-lsp-bandwidth")

                                                            self.psc_interface_mtu = YLeaf(YType.uint16, "psc-interface-mtu")
                                                            self._segment_path = lambda: "ixcdpsc-info"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.IxcdSwitchingCapType.IxcdpscInfo, ['min_lsp_bandwidth', 'psc_interface_mtu'], name, value)


                                                class MaxLspbw(Entity):
                                                    """
                                                    Max LSP bandwidth array
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** \-9223372036854775808..9223372036854775807
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, self).__init__()

                                                        self.yang_name = "max-lspbw"
                                                        self.yang_parent_name = "ixcdtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.int64, "entry")
                                                        self._segment_path = lambda: "max-lspbw"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.IxcdtlvValue.MaxLspbw, ['entry'], name, value)


                                            class SrlgtlvValue(Entity):
                                                """
                                                Value of SRLG TLV
                                                
                                                .. attribute:: mplste_link_srlg_data
                                                
                                                	Value of SRLG TLV
                                                	**type**\: list of    :py:class:`MplsteLinkSrlgData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData>`
                                                
                                                .. attribute:: num_srl_gs
                                                
                                                	Number of SRLG TLVs
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: srlg_len
                                                
                                                	Length of SRLG TLV
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, self).__init__()

                                                    self.yang_name = "srlgtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"mplste-link-srlg-data" : ("mplste_link_srlg_data", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData)}

                                                    self.num_srl_gs = YLeaf(YType.uint32, "num-srl-gs")

                                                    self.srlg_len = YLeaf(YType.uint32, "srlg-len")

                                                    self.mplste_link_srlg_data = YList(self)
                                                    self._segment_path = lambda: "srlgtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue, ['num_srl_gs', 'srlg_len'], name, value)


                                                class MplsteLinkSrlgData(Entity):
                                                    """
                                                    Value of SRLG TLV
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, self).__init__()

                                                        self.yang_name = "mplste-link-srlg-data"
                                                        self.yang_parent_name = "srlgtlv-value"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                        self._segment_path = lambda: "mplste-link-srlg-data"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.SrlgtlvValue.MplsteLinkSrlgData, ['entry'], name, value)


                                            class UnidtlvValue(Entity):
                                                """
                                                Value of Uni Delay TLV
                                                
                                                .. attribute:: uni_dir_delay
                                                
                                                	Uni Dir Delay
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, self).__init__()

                                                    self.yang_name = "unidtlv-value"
                                                    self.yang_parent_name = "mplste-link-opt-tlv-value"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.uni_dir_delay = YLeaf(YType.uint32, "uni-dir-delay")
                                                    self._segment_path = lambda: "unidtlv-value"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.MplsteLinkOptTlv.MplsteLinkOptTlvValue.UnidtlvValue, ['uni_dir_delay'], name, value)


                                    class SubPoolUnreserveBwPerPriority(Entity):
                                        """
                                        Sub pool unreserved bandwidth for each priority
                                        (bytes/s)
                                        
                                        .. attribute:: bw_per_priority
                                        
                                        	Unreserved bandwidth for each priority (bytes/s)
                                        	**type**\: list of    :py:class:`BwPerPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, self).__init__()

                                            self.yang_name = "sub-pool-unreserve-bw-per-priority"
                                            self.yang_parent_name = "mpls-te-link"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"bw-per-priority" : ("bw_per_priority", Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority)}

                                            self.bw_per_priority = YList(self)
                                            self._segment_path = lambda: "sub-pool-unreserve-bw-per-priority"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority, [], name, value)


                                        class BwPerPriority(Entity):
                                            """
                                            Unreserved bandwidth for each priority (bytes/s)
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte/s
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, self).__init__()

                                                self.yang_name = "bw-per-priority"
                                                self.yang_parent_name = "sub-pool-unreserve-bw-per-priority"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.entry = YLeaf(YType.uint64, "entry")
                                                self._segment_path = lambda: "bw-per-priority"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.MplsTe.MplsTeLinks.MplsTeLink.MplsTeLink.SubPoolUnreserveBwPerPriority.BwPerPriority, ['entry'], name, value)


                    class OspfSummary(Entity):
                        """
                        Fast\-reroute topology information
                        
                        .. attribute:: sa_lsa_cnt_type_7ase
                        
                        	sa lsa cnt type 7ase
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_8_ignore
                        
                        	sa lsa cnt type 8 ignore
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_ase
                        
                        	sa lsa cnt type ase
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_mospf
                        
                        	sa lsa cnt type mospf
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_net
                        
                        	sa lsa cnt type net
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_opq_area
                        
                        	sa lsa cnt type opq area
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_opq_as
                        
                        	sa lsa cnt type opq as
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_opq_link
                        
                        	sa lsa cnt type opq link
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_rtr
                        
                        	sa lsa cnt type rtr
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_sum_asb
                        
                        	sa lsa cnt type sum asb
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_lsa_cnt_type_sum_net
                        
                        	sa lsa cnt type sum net
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_areas
                        
                        	sa num areas
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_intf
                        
                        	sa num intf
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_intf_up
                        
                        	sa num intf up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_nbrs
                        
                        	sa num nbrs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_nbrs_up
                        
                        	sa num nbrs up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_slintf_up
                        
                        	sa num slintf up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sa_num_vintf_up
                        
                        	sa num vintf up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.OspfSummary, self).__init__()

                            self.yang_name = "ospf-summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.sa_lsa_cnt_type_7ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-7ase")

                            self.sa_lsa_cnt_type_8_ignore = YLeaf(YType.uint32, "sa-lsa-cnt-type-8-ignore")

                            self.sa_lsa_cnt_type_ase = YLeaf(YType.uint32, "sa-lsa-cnt-type-ase")

                            self.sa_lsa_cnt_type_mospf = YLeaf(YType.uint32, "sa-lsa-cnt-type-mospf")

                            self.sa_lsa_cnt_type_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-net")

                            self.sa_lsa_cnt_type_opq_area = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-area")

                            self.sa_lsa_cnt_type_opq_as = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-as")

                            self.sa_lsa_cnt_type_opq_link = YLeaf(YType.uint32, "sa-lsa-cnt-type-opq-link")

                            self.sa_lsa_cnt_type_rtr = YLeaf(YType.uint32, "sa-lsa-cnt-type-rtr")

                            self.sa_lsa_cnt_type_sum_asb = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-asb")

                            self.sa_lsa_cnt_type_sum_net = YLeaf(YType.uint32, "sa-lsa-cnt-type-sum-net")

                            self.sa_num_areas = YLeaf(YType.uint32, "sa-num-areas")

                            self.sa_num_intf = YLeaf(YType.uint32, "sa-num-intf")

                            self.sa_num_intf_up = YLeaf(YType.uint32, "sa-num-intf-up")

                            self.sa_num_nbrs = YLeaf(YType.uint32, "sa-num-nbrs")

                            self.sa_num_nbrs_up = YLeaf(YType.uint32, "sa-num-nbrs-up")

                            self.sa_num_slintf_up = YLeaf(YType.uint32, "sa-num-slintf-up")

                            self.sa_num_vintf_up = YLeaf(YType.uint32, "sa-num-vintf-up")
                            self._segment_path = lambda: "ospf-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.OspfSummary, ['sa_lsa_cnt_type_7ase', 'sa_lsa_cnt_type_8_ignore', 'sa_lsa_cnt_type_ase', 'sa_lsa_cnt_type_mospf', 'sa_lsa_cnt_type_net', 'sa_lsa_cnt_type_opq_area', 'sa_lsa_cnt_type_opq_as', 'sa_lsa_cnt_type_opq_link', 'sa_lsa_cnt_type_rtr', 'sa_lsa_cnt_type_sum_asb', 'sa_lsa_cnt_type_sum_net', 'sa_num_areas', 'sa_num_intf', 'sa_num_intf_up', 'sa_num_nbrs', 'sa_num_nbrs_up', 'sa_num_slintf_up', 'sa_num_vintf_up'], name, value)


                    class ProcessInformation(Entity):
                        """
                        Container for OSPF Process information
                        
                        .. attribute:: process_areas
                        
                        	Process Area table
                        	**type**\:   :py:class:`ProcessAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas>`
                        
                        .. attribute:: process_summary
                        
                        	Basic OSPF summary information
                        	**type**\:   :py:class:`ProcessSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary>`
                        
                        .. attribute:: protocol_areas
                        
                        	Protocol Area table
                        	**type**\:   :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas>`
                        
                        .. attribute:: protocol_summary
                        
                        	Basic OSPF protocol information
                        	**type**\:   :py:class:`ProtocolSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary>`
                        
                        .. attribute:: redistributions
                        
                        	Redistribution information table
                        	**type**\:   :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation, self).__init__()

                            self.yang_name = "process-information"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"process-areas" : ("process_areas", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas), "process-summary" : ("process_summary", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary), "protocol-areas" : ("protocol_areas", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas), "protocol-summary" : ("protocol_summary", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary), "redistributions" : ("redistributions", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions)}
                            self._child_list_classes = {}

                            self.process_areas = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas()
                            self.process_areas.parent = self
                            self._children_name_map["process_areas"] = "process-areas"
                            self._children_yang_names.add("process-areas")

                            self.process_summary = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary()
                            self.process_summary.parent = self
                            self._children_name_map["process_summary"] = "process-summary"
                            self._children_yang_names.add("process-summary")

                            self.protocol_areas = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas()
                            self.protocol_areas.parent = self
                            self._children_name_map["protocol_areas"] = "protocol-areas"
                            self._children_yang_names.add("protocol-areas")

                            self.protocol_summary = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary()
                            self.protocol_summary.parent = self
                            self._children_name_map["protocol_summary"] = "protocol-summary"
                            self._children_yang_names.add("protocol-summary")

                            self.redistributions = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions()
                            self.redistributions.parent = self
                            self._children_name_map["redistributions"] = "redistributions"
                            self._children_yang_names.add("redistributions")
                            self._segment_path = lambda: "process-information"


                        class ProcessAreas(Entity):
                            """
                            Process Area table
                            
                            .. attribute:: process_area
                            
                            	Detailed information for a particular area
                            	**type**\: list of    :py:class:`ProcessArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas, self).__init__()

                                self.yang_name = "process-areas"
                                self.yang_parent_name = "process-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"process-area" : ("process_area", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea)}

                                self.process_area = YList(self)
                                self._segment_path = lambda: "process-areas"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas, [], name, value)


                            class ProcessArea(Entity):
                                """
                                Detailed information for a particular area
                                
                                .. attribute:: address
                                
                                	Area ID if in IP address format
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_adj_stag_num_nbr_forming
                                
                                	Num of nbrs currently forming
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: area_dc_bitless_lsa_count
                                
                                	Number of LSA with demand circuit bit not set
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_id
                                
                                	Area ID if in integer format
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: area_id_string
                                
                                	Area ID string
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: area_interface_count
                                
                                	Number of interfaces in the area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: area_lfa_interface_count
                                
                                	Number of LFA enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_lfa_revision
                                
                                	Area LFA revision
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_lsa_checksum
                                
                                	Sum of all area LSAs checksum
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_lsa_count
                                
                                	Number of LSAs in the Area
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_nssa
                                
                                	If true, area is a NSSA
                                	**type**\:  bool
                                
                                .. attribute:: area_num_nbr_full
                                
                                	Num of full nbrs in area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: area_opaque_lsa_checksum
                                
                                	Sum of opaque LSA checksums
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_opaque_lsa_count
                                
                                	Number of Opaque LSAs in the Area
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_per_prefix_lfa_interface_count
                                
                                	Number of Per Prefix LFA enabled interfaces
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_policy_in
                                
                                	If true, inbound policy is configured
                                	**type**\:  bool
                                
                                .. attribute:: area_policy_in_name
                                
                                	Inbound summary lsa filtering policy
                                	**type**\:  str
                                
                                .. attribute:: area_policy_out
                                
                                	If true, outbound policy is configured
                                	**type**\:  bool
                                
                                .. attribute:: area_policy_out_name
                                
                                	Outbound summary lsa filtering policy
                                	**type**\:  str
                                
                                .. attribute:: area_range
                                
                                	List of ranges to summarize
                                	**type**\: list of    :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange>`
                                
                                .. attribute:: area_stub
                                
                                	If true, stub area
                                	**type**\:  bool
                                
                                .. attribute:: area_total_stub
                                
                                	If true, totally stubby area
                                	**type**\:  bool
                                
                                .. attribute:: authentication_type
                                
                                	Authentication type
                                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                
                                .. attribute:: backbone_area_active
                                
                                	If true, Backbone area is active
                                	**type**\:  bool
                                
                                .. attribute:: dna_lsa_count
                                
                                	Number of DoNotAge LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_out
                                
                                	If true, advertise intra\-area prefixes as external
                                	**type**\:  bool
                                
                                .. attribute:: flood_list_length
                                
                                	Number of LSAs which need to be flooded
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: indication_lsa_count
                                
                                	Number of indication LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nssa_default
                                
                                	If true, generate NSSA default route
                                	**type**\:  bool
                                
                                .. attribute:: nssa_no_redistribution
                                
                                	If true, No redistribution into this NSSA area
                                	**type**\:  bool
                                
                                .. attribute:: nssa_translate
                                
                                	If true, perform 7/5 translation
                                	**type**\:  bool
                                
                                .. attribute:: segment_routing
                                
                                	If true, Segment Routing enabled
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_count
                                
                                	Number of SPF calculations run
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sr_microloop_avoidance_active
                                
                                	If true, Segment routing Uloop avoidance         is currently active in this area
                                	**type**\:  bool
                                
                                .. attribute:: sr_microloop_avoidance_event_type
                                
                                	Event for which SR uloop is triggered            Link Up/Link Down
                                	**type**\:   :py:class:`SrUloopEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.SrUloopEvent>`
                                
                                .. attribute:: sr_microloop_avoidance_far_end_id
                                
                                	Link State ID of the far end                     of the topology change
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_near_end_id
                                
                                	Link State ID of the near end                    of the topology change
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_microloop_avoidance_pseudonode_id
                                
                                	Link State ID of the pseudo node,                if the change is on a broadcast link
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: sr_strict_spf_cap
                                
                                	If true, All routers in Area are SR Strict\-SPF Capable
                                	**type**\:  bool
                                
                                .. attribute:: sr_strict_spfsids_available
                                
                                	If true, All routers in Area have SR Strict\-SPF SIDs
                                	**type**\:  bool
                                
                                .. attribute:: stub_default_cost
                                
                                	Default cost for Stub or NSSA area
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: summary_in
                                
                                	If true, advertise redistributedprefixes as summary
                                	**type**\:  bool
                                
                                .. attribute:: te_enabled
                                
                                	If true, MPLS\-TE enabled
                                	**type**\:  bool
                                
                                .. attribute:: te_topology_version
                                
                                	TE area topology version number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea, self).__init__()

                                    self.yang_name = "process-area"
                                    self.yang_parent_name = "process-areas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-range" : ("area_range", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange)}

                                    self.address = YLeaf(YType.str, "address")

                                    self.area_adj_stag_num_nbr_forming = YLeaf(YType.uint16, "area-adj-stag-num-nbr-forming")

                                    self.area_dc_bitless_lsa_count = YLeaf(YType.uint32, "area-dc-bitless-lsa-count")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.area_id_string = YLeaf(YType.str, "area-id-string")

                                    self.area_interface_count = YLeaf(YType.uint16, "area-interface-count")

                                    self.area_lfa_interface_count = YLeaf(YType.uint32, "area-lfa-interface-count")

                                    self.area_lfa_revision = YLeaf(YType.uint32, "area-lfa-revision")

                                    self.area_lsa_checksum = YLeaf(YType.uint32, "area-lsa-checksum")

                                    self.area_lsa_count = YLeaf(YType.uint32, "area-lsa-count")

                                    self.area_nssa = YLeaf(YType.boolean, "area-nssa")

                                    self.area_num_nbr_full = YLeaf(YType.uint16, "area-num-nbr-full")

                                    self.area_opaque_lsa_checksum = YLeaf(YType.uint32, "area-opaque-lsa-checksum")

                                    self.area_opaque_lsa_count = YLeaf(YType.uint32, "area-opaque-lsa-count")

                                    self.area_per_prefix_lfa_interface_count = YLeaf(YType.uint32, "area-per-prefix-lfa-interface-count")

                                    self.area_policy_in = YLeaf(YType.boolean, "area-policy-in")

                                    self.area_policy_in_name = YLeaf(YType.str, "area-policy-in-name")

                                    self.area_policy_out = YLeaf(YType.boolean, "area-policy-out")

                                    self.area_policy_out_name = YLeaf(YType.str, "area-policy-out-name")

                                    self.area_stub = YLeaf(YType.boolean, "area-stub")

                                    self.area_total_stub = YLeaf(YType.boolean, "area-total-stub")

                                    self.authentication_type = YLeaf(YType.enumeration, "authentication-type")

                                    self.backbone_area_active = YLeaf(YType.boolean, "backbone-area-active")

                                    self.dna_lsa_count = YLeaf(YType.uint32, "dna-lsa-count")

                                    self.external_out = YLeaf(YType.boolean, "external-out")

                                    self.flood_list_length = YLeaf(YType.uint32, "flood-list-length")

                                    self.indication_lsa_count = YLeaf(YType.uint32, "indication-lsa-count")

                                    self.nssa_default = YLeaf(YType.boolean, "nssa-default")

                                    self.nssa_no_redistribution = YLeaf(YType.boolean, "nssa-no-redistribution")

                                    self.nssa_translate = YLeaf(YType.boolean, "nssa-translate")

                                    self.segment_routing = YLeaf(YType.uint32, "segment-routing")

                                    self.spf_count = YLeaf(YType.uint32, "spf-count")

                                    self.sr_microloop_avoidance_active = YLeaf(YType.boolean, "sr-microloop-avoidance-active")

                                    self.sr_microloop_avoidance_event_type = YLeaf(YType.enumeration, "sr-microloop-avoidance-event-type")

                                    self.sr_microloop_avoidance_far_end_id = YLeaf(YType.str, "sr-microloop-avoidance-far-end-id")

                                    self.sr_microloop_avoidance_near_end_id = YLeaf(YType.str, "sr-microloop-avoidance-near-end-id")

                                    self.sr_microloop_avoidance_pseudonode_id = YLeaf(YType.str, "sr-microloop-avoidance-pseudonode-id")

                                    self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                                    self.sr_strict_spfsids_available = YLeaf(YType.boolean, "sr-strict-spfsids-available")

                                    self.stub_default_cost = YLeaf(YType.uint16, "stub-default-cost")

                                    self.summary_in = YLeaf(YType.boolean, "summary-in")

                                    self.te_enabled = YLeaf(YType.boolean, "te-enabled")

                                    self.te_topology_version = YLeaf(YType.uint32, "te-topology-version")

                                    self.area_range = YList(self)
                                    self._segment_path = lambda: "process-area"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea, ['address', 'area_adj_stag_num_nbr_forming', 'area_dc_bitless_lsa_count', 'area_id', 'area_id_string', 'area_interface_count', 'area_lfa_interface_count', 'area_lfa_revision', 'area_lsa_checksum', 'area_lsa_count', 'area_nssa', 'area_num_nbr_full', 'area_opaque_lsa_checksum', 'area_opaque_lsa_count', 'area_per_prefix_lfa_interface_count', 'area_policy_in', 'area_policy_in_name', 'area_policy_out', 'area_policy_out_name', 'area_stub', 'area_total_stub', 'authentication_type', 'backbone_area_active', 'dna_lsa_count', 'external_out', 'flood_list_length', 'indication_lsa_count', 'nssa_default', 'nssa_no_redistribution', 'nssa_translate', 'segment_routing', 'spf_count', 'sr_microloop_avoidance_active', 'sr_microloop_avoidance_event_type', 'sr_microloop_avoidance_far_end_id', 'sr_microloop_avoidance_near_end_id', 'sr_microloop_avoidance_pseudonode_id', 'sr_strict_spf_cap', 'sr_strict_spfsids_available', 'stub_default_cost', 'summary_in', 'te_enabled', 'te_topology_version'], name, value)


                                class AreaRange(Entity):
                                    """
                                    List of ranges to summarize
                                    
                                    .. attribute:: advertise_flag
                                    
                                    	Whether to advertise Summary LSAs for this range
                                    	**type**\:  bool
                                    
                                    .. attribute:: cost
                                    
                                    	Cost
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: range_mask
                                    
                                    	Network mask
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: range_prefix
                                    
                                    	IP prefix for summarization
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, self).__init__()

                                        self.yang_name = "area-range"
                                        self.yang_parent_name = "process-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.advertise_flag = YLeaf(YType.boolean, "advertise-flag")

                                        self.cost = YLeaf(YType.uint32, "cost")

                                        self.range_mask = YLeaf(YType.str, "range-mask")

                                        self.range_prefix = YLeaf(YType.str, "range-prefix")
                                        self._segment_path = lambda: "area-range"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessAreas.ProcessArea.AreaRange, ['advertise_flag', 'cost', 'range_mask', 'range_prefix'], name, value)


                        class ProcessSummary(Entity):
                            """
                            Basic OSPF summary information
                            
                            .. attribute:: adj_stag_init_num_nbr
                            
                            	Num of nbrs brought up initially per area
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: adj_stag_max_num_nbr
                            
                            	Max num of nbrs brought up simultaneously per OSPF instance
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: adj_stag_num_nbr_forming
                            
                            	Num of nbrs currently forming for OSPF instance
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: adj_stagger_enabled
                            
                            	If true, OSPF Adjacency Staggering is configured
                            	**type**\:  bool
                            
                            .. attribute:: area_border_router
                            
                            	If true, is an Area Border Router
                            	**type**\:  bool
                            
                            .. attribute:: area_count
                            
                            	Number of areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_border_router
                            
                            	If true, is an AS Border Router
                            	**type**\:  bool
                            
                            .. attribute:: as_dc_bitless_lsa_count
                            
                            	Number of External and AS Opaque LSAs with demand circut bit not set
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_dna_lsa_count
                            
                            	Number of External and AS Opaque LSAs with DoNotAge set 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_checksum
                            
                            	Sum of AS scope LSA checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_count
                            
                            	Number of AS scope LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_lsa_flood_list_length
                            
                            	Length of AS LSAs flood list
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context_name
                            
                            	Context name
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: domain_id
                            
                            	Domain ID information
                            	**type**\:   :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId>`
                            
                            .. attribute:: graceful_shutdown_retention_time
                            
                            	Amount of time routes are retained after graceful shutdown (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: graceful_shutdown_state
                            
                            	State of graceful shutdown
                            	**type**\:   :py:class:`GsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.GsState>`
                            
                            .. attribute:: if_flood_pacing_interval
                            
                            	Flood pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: if_retrans_pacing_interval
                            
                            	Retransmission pacing timer (ms)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: igp_intact_on
                            
                            	If true, running in IGP\-Intact mode
                            	**type**\:  bool
                            
                            .. attribute:: last_nsf_time
                            
                            	 Length of time since the last NSF (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_hold_time
                            
                            	Second delay before generating next LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_maximum_time
                            
                            	Maximum delay before generating an LSA (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_refresh_interval
                            
                            	LSA refresh interval (sec)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_start_time
                            
                            	Inital LSA throttle delay (ms)
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: lsd_bound
                            
                            	True if bound to LSD
                            	**type**\:  bool
                            
                            .. attribute:: lsd_connected
                            
                            	True if connected to LSD
                            	**type**\:  bool
                            
                            .. attribute:: lsd_connection_revision
                            
                            	LSD Connection Revision
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_registered
                            
                            	True if registered with LSD
                            	**type**\:  bool
                            
                            .. attribute:: max_lsa_enabled
                            
                            	If true, max\-lsa protection enabled
                            	**type**\:  bool
                            
                            .. attribute:: max_lsa_ignore_count
                            
                            	How many times ignore state has been entered
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_ignore_limit
                            
                            	Max allowed number of entering ignore state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_ignore_time
                            
                            	Time ignoring new LSAs after max\-lsa reached
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_ignore_timer
                            
                            	Remaining time when ignore timer is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_limit
                            
                            	Maximum allowed number of non self\-generated LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_reset_time
                            
                            	Time after which LSA protection counter is reset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_reset_timer
                            
                            	Remaining time when reset timer is running
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_treshold
                            
                            	max\-lsa protection warning threshold
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_lsa_warning_only
                            
                            	Warning only when max\-lsa reached
                            	**type**\:  bool
                            
                            .. attribute:: maximum_interfaces
                            
                            	Maximum number of interfaces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_metric
                            
                            	Max\-metric list
                            	**type**\: list of    :py:class:`MaximumMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric>`
                            
                            .. attribute:: maximum_metric_abr_off_buffer_time
                            
                            	Buffer time in seconds since last neighbor activity, to remain in max\-metric ABR off state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: maximum_metric_abr_off_mode
                            
                            	If true, ABR duties temporarily disabled
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_abr_off_reasons
                            
                            	Reasons for ABR duties being temporarily disabled
                            	**type**\:   :py:class:`OspfMaxMetricAbrOffReasons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfMaxMetricAbrOffReasons>`
                            
                            .. attribute:: maximum_metric_set_reason
                            
                            	Max\-metric set reason
                            	**type**\:   :py:class:`MaxMetricSetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricSetReason>`
                            
                            .. attribute:: maximum_metric_start
                            
                            	If true, originate Router LSA with maximum metric
                            	**type**\:  bool
                            
                            .. attribute:: maximum_metric_start_timer
                            
                            	Time remaining for hold down timer (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: microloop_avoidance_active
                            
                            	If true, Uloop is active
                            	**type**\:  bool
                            
                            .. attribute:: microloop_avoidance_delay
                            
                            	Microloop delay time after which actual          post convergence paths are given to RIB (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: microloop_avoidance_delay_expiry
                            
                            	Remaining time for uloop delay timer             to expire (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: microloop_avoidance_type
                            
                            	Microloop avoidance type configured
                            	**type**\:   :py:class:`UloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.UloopAvoidance>`
                            
                            .. attribute:: minimum_lsa_arrival_interval
                            
                            	Minimum time between accepting LSAs (ms) Rel 4.0 .1, deprecated by MinimumLSAArrivalIntervalU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: minimum_lsa_arrival_interval_u32
                            
                            	Minimum time between accepting LSAs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: minimum_lsa_interval
                            
                            	Minimum time between LSA regeneration (ms) Rel 4 .0.1, deprecated by MinimumLSAIntervalU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: minimum_lsa_interval_u32
                            
                            	Minimum time between LSA regeneration (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: non_self_lsa_count
                            
                            	Non self\-generated LSA count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: normal_area_count
                            
                            	Number of normal Areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsf_enabled
                            
                            	If true, NSF enabled
                            	**type**\:  bool
                            
                            .. attribute:: nsf_time
                            
                            	Total time to complete NSF (s)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_enabled
                            
                            	If true, NSR is enabled
                            	**type**\:  bool
                            
                            .. attribute:: nsr_switchover_on_restart
                            
                            	Trigger RP Switchover on detectable process restart
                            	**type**\:  bool
                            
                            .. attribute:: nssa_area_count
                            
                            	Number of NSSA Areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: number_nbrs_full
                            
                            	Num of full nbrs
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: opaque_capable
                            
                            	Opaque LSA capable
                            	**type**\:  bool
                            
                            .. attribute:: opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksum
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: opaque_lsa_count
                            
                            	Number of Opaque LSAs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution
                            
                            	Redistribution list
                            	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution>`
                            
                            .. attribute:: redistribution_limit
                            
                            	The number of redistributed prefixes allowed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_limit_warn
                            
                            	If true, only a syslog message is printed when redistribution prefix limit is reached
                            	**type**\:  bool
                            
                            .. attribute:: redistribution_threshold
                            
                            	When the number of redistributed prefixes reaches this threshold, a warning message is issued
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: role
                            
                            	Role, V1/V2 Active/Standby
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: role_standby
                            
                            	If true, Role is Standby, Active otherwise
                            	**type**\:  bool
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: snmp_trap_enabled
                            
                            	If true, snmp trap is enabled
                            	**type**\:  bool
                            
                            .. attribute:: spf_hold_time
                            
                            	Minimum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFHoldTimeU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: spf_hold_time_u32
                            
                            	Minimum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_maximum_time
                            
                            	Maximum delay time between SPF runs (ms) This is valid if configured below 64k Deprecated by SPFMaximumTimeU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: spf_maximum_time_u32
                            
                            	Maximum delay time between SPF runs (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_prefix_priority
                            
                            	If true, prefix\-priority policy is configured
                            	**type**\:  bool
                            
                            .. attribute:: spf_prefix_priority_route_policy
                            
                            	SPF Prefix\-priority route policy
                            	**type**\:  str
                            
                            .. attribute:: spf_start_time
                            
                            	Scheduling delay for SPF (ms) This is valid if configured below 64k Deprecated by SPFStartTimeU32]
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: spf_start_time_u32
                            
                            	Scheduling delay for SPF (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_strict_spf_cap
                            
                            	True if Segment Routing Strict\-SPF capable
                            	**type**\:  bool
                            
                            .. attribute:: srgb_configured
                            
                            	True if Segment Routing Global Block configured
                            	**type**\:  bool
                            
                            .. attribute:: srgb_end
                            
                            	Segment Routing Global Block end label value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_start
                            
                            	Segment Routing Global Block start label value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: srgb_status
                            
                            	Segment Routing Global Block allocation status
                            	**type**\:   :py:class:`OspfSrgbStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfSrgbStatus>`
                            
                            .. attribute:: stub_area_count
                            
                            	Number of Stub and Total Stub Areas
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: table_prefix_limit_reached
                            
                            	If true, prefix limit for table has been  reached
                            	**type**\:  bool
                            
                            .. attribute:: tos_options
                            
                            	Type of Service supported
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ucmp
                            
                            	If true, UCMP is enabled
                            	**type**\:  bool
                            
                            .. attribute:: ucmp_delay
                            
                            	Delay between end of SPF and start of UCMP calculation (ms)
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ucmp_prefix_list
                            
                            	UCMP Prefix\-list
                            	**type**\:  str
                            
                            .. attribute:: ucmp_variance
                            
                            	UCMP Variance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: vrf_lite_enabled
                            
                            	If true, vrf lite is enabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary, self).__init__()

                                self.yang_name = "process-summary"
                                self.yang_parent_name = "process-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"domain-id" : ("domain_id", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId)}
                                self._child_list_classes = {"maximum-metric" : ("maximum_metric", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric), "redistribution" : ("redistribution", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution)}

                                self.adj_stag_init_num_nbr = YLeaf(YType.uint16, "adj-stag-init-num-nbr")

                                self.adj_stag_max_num_nbr = YLeaf(YType.uint16, "adj-stag-max-num-nbr")

                                self.adj_stag_num_nbr_forming = YLeaf(YType.uint16, "adj-stag-num-nbr-forming")

                                self.adj_stagger_enabled = YLeaf(YType.boolean, "adj-stagger-enabled")

                                self.area_border_router = YLeaf(YType.boolean, "area-border-router")

                                self.area_count = YLeaf(YType.uint16, "area-count")

                                self.as_border_router = YLeaf(YType.boolean, "as-border-router")

                                self.as_dc_bitless_lsa_count = YLeaf(YType.uint32, "as-dc-bitless-lsa-count")

                                self.as_dna_lsa_count = YLeaf(YType.uint32, "as-dna-lsa-count")

                                self.as_lsa_checksum = YLeaf(YType.uint32, "as-lsa-checksum")

                                self.as_lsa_count = YLeaf(YType.uint32, "as-lsa-count")

                                self.as_lsa_flood_list_length = YLeaf(YType.uint32, "as-lsa-flood-list-length")

                                self.context_name = YLeaf(YType.str, "context-name")

                                self.graceful_shutdown_retention_time = YLeaf(YType.uint32, "graceful-shutdown-retention-time")

                                self.graceful_shutdown_state = YLeaf(YType.enumeration, "graceful-shutdown-state")

                                self.if_flood_pacing_interval = YLeaf(YType.uint16, "if-flood-pacing-interval")

                                self.if_retrans_pacing_interval = YLeaf(YType.uint16, "if-retrans-pacing-interval")

                                self.igp_intact_on = YLeaf(YType.boolean, "igp-intact-on")

                                self.last_nsf_time = YLeaf(YType.uint32, "last-nsf-time")

                                self.lsa_hold_time = YLeaf(YType.uint32, "lsa-hold-time")

                                self.lsa_maximum_time = YLeaf(YType.uint32, "lsa-maximum-time")

                                self.lsa_refresh_interval = YLeaf(YType.uint32, "lsa-refresh-interval")

                                self.lsa_start_time = YLeaf(YType.int32, "lsa-start-time")

                                self.lsd_bound = YLeaf(YType.boolean, "lsd-bound")

                                self.lsd_connected = YLeaf(YType.boolean, "lsd-connected")

                                self.lsd_connection_revision = YLeaf(YType.uint32, "lsd-connection-revision")

                                self.lsd_registered = YLeaf(YType.boolean, "lsd-registered")

                                self.max_lsa_enabled = YLeaf(YType.boolean, "max-lsa-enabled")

                                self.max_lsa_ignore_count = YLeaf(YType.uint32, "max-lsa-ignore-count")

                                self.max_lsa_ignore_limit = YLeaf(YType.uint32, "max-lsa-ignore-limit")

                                self.max_lsa_ignore_time = YLeaf(YType.uint32, "max-lsa-ignore-time")

                                self.max_lsa_ignore_timer = YLeaf(YType.uint32, "max-lsa-ignore-timer")

                                self.max_lsa_limit = YLeaf(YType.uint32, "max-lsa-limit")

                                self.max_lsa_reset_time = YLeaf(YType.uint32, "max-lsa-reset-time")

                                self.max_lsa_reset_timer = YLeaf(YType.uint32, "max-lsa-reset-timer")

                                self.max_lsa_treshold = YLeaf(YType.uint32, "max-lsa-treshold")

                                self.max_lsa_warning_only = YLeaf(YType.boolean, "max-lsa-warning-only")

                                self.maximum_interfaces = YLeaf(YType.uint32, "maximum-interfaces")

                                self.maximum_metric_abr_off_buffer_time = YLeaf(YType.uint32, "maximum-metric-abr-off-buffer-time")

                                self.maximum_metric_abr_off_mode = YLeaf(YType.boolean, "maximum-metric-abr-off-mode")

                                self.maximum_metric_abr_off_reasons = YLeaf(YType.enumeration, "maximum-metric-abr-off-reasons")

                                self.maximum_metric_set_reason = YLeaf(YType.enumeration, "maximum-metric-set-reason")

                                self.maximum_metric_start = YLeaf(YType.boolean, "maximum-metric-start")

                                self.maximum_metric_start_timer = YLeaf(YType.uint32, "maximum-metric-start-timer")

                                self.microloop_avoidance_active = YLeaf(YType.boolean, "microloop-avoidance-active")

                                self.microloop_avoidance_delay = YLeaf(YType.uint32, "microloop-avoidance-delay")

                                self.microloop_avoidance_delay_expiry = YLeaf(YType.uint32, "microloop-avoidance-delay-expiry")

                                self.microloop_avoidance_type = YLeaf(YType.enumeration, "microloop-avoidance-type")

                                self.minimum_lsa_arrival_interval = YLeaf(YType.uint16, "minimum-lsa-arrival-interval")

                                self.minimum_lsa_arrival_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-arrival-interval-u32")

                                self.minimum_lsa_interval = YLeaf(YType.uint16, "minimum-lsa-interval")

                                self.minimum_lsa_interval_u32 = YLeaf(YType.uint32, "minimum-lsa-interval-u32")

                                self.non_self_lsa_count = YLeaf(YType.uint32, "non-self-lsa-count")

                                self.normal_area_count = YLeaf(YType.uint16, "normal-area-count")

                                self.nsf_enabled = YLeaf(YType.boolean, "nsf-enabled")

                                self.nsf_time = YLeaf(YType.uint32, "nsf-time")

                                self.nsr_enabled = YLeaf(YType.boolean, "nsr-enabled")

                                self.nsr_switchover_on_restart = YLeaf(YType.boolean, "nsr-switchover-on-restart")

                                self.nssa_area_count = YLeaf(YType.uint16, "nssa-area-count")

                                self.number_nbrs_full = YLeaf(YType.uint16, "number-nbrs-full")

                                self.opaque_capable = YLeaf(YType.boolean, "opaque-capable")

                                self.opaque_lsa_checksum = YLeaf(YType.uint32, "opaque-lsa-checksum")

                                self.opaque_lsa_count = YLeaf(YType.uint32, "opaque-lsa-count")

                                self.redistribution_limit = YLeaf(YType.uint32, "redistribution-limit")

                                self.redistribution_limit_warn = YLeaf(YType.boolean, "redistribution-limit-warn")

                                self.redistribution_threshold = YLeaf(YType.uint32, "redistribution-threshold")

                                self.role = YLeaf(YType.uint32, "role")

                                self.role_standby = YLeaf(YType.boolean, "role-standby")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.snmp_trap_enabled = YLeaf(YType.boolean, "snmp-trap-enabled")

                                self.spf_hold_time = YLeaf(YType.uint16, "spf-hold-time")

                                self.spf_hold_time_u32 = YLeaf(YType.uint32, "spf-hold-time-u32")

                                self.spf_maximum_time = YLeaf(YType.uint16, "spf-maximum-time")

                                self.spf_maximum_time_u32 = YLeaf(YType.uint32, "spf-maximum-time-u32")

                                self.spf_prefix_priority = YLeaf(YType.boolean, "spf-prefix-priority")

                                self.spf_prefix_priority_route_policy = YLeaf(YType.str, "spf-prefix-priority-route-policy")

                                self.spf_start_time = YLeaf(YType.uint16, "spf-start-time")

                                self.spf_start_time_u32 = YLeaf(YType.uint32, "spf-start-time-u32")

                                self.sr_strict_spf_cap = YLeaf(YType.boolean, "sr-strict-spf-cap")

                                self.srgb_configured = YLeaf(YType.boolean, "srgb-configured")

                                self.srgb_end = YLeaf(YType.uint32, "srgb-end")

                                self.srgb_start = YLeaf(YType.uint32, "srgb-start")

                                self.srgb_status = YLeaf(YType.enumeration, "srgb-status")

                                self.stub_area_count = YLeaf(YType.uint16, "stub-area-count")

                                self.table_prefix_limit_reached = YLeaf(YType.boolean, "table-prefix-limit-reached")

                                self.tos_options = YLeaf(YType.uint8, "tos-options")

                                self.ucmp = YLeaf(YType.boolean, "ucmp")

                                self.ucmp_delay = YLeaf(YType.uint32, "ucmp-delay")

                                self.ucmp_prefix_list = YLeaf(YType.str, "ucmp-prefix-list")

                                self.ucmp_variance = YLeaf(YType.int32, "ucmp-variance")

                                self.vrf_lite_enabled = YLeaf(YType.boolean, "vrf-lite-enabled")

                                self.domain_id = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId()
                                self.domain_id.parent = self
                                self._children_name_map["domain_id"] = "domain-id"
                                self._children_yang_names.add("domain-id")

                                self.maximum_metric = YList(self)
                                self.redistribution = YList(self)
                                self._segment_path = lambda: "process-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary, ['adj_stag_init_num_nbr', 'adj_stag_max_num_nbr', 'adj_stag_num_nbr_forming', 'adj_stagger_enabled', 'area_border_router', 'area_count', 'as_border_router', 'as_dc_bitless_lsa_count', 'as_dna_lsa_count', 'as_lsa_checksum', 'as_lsa_count', 'as_lsa_flood_list_length', 'context_name', 'graceful_shutdown_retention_time', 'graceful_shutdown_state', 'if_flood_pacing_interval', 'if_retrans_pacing_interval', 'igp_intact_on', 'last_nsf_time', 'lsa_hold_time', 'lsa_maximum_time', 'lsa_refresh_interval', 'lsa_start_time', 'lsd_bound', 'lsd_connected', 'lsd_connection_revision', 'lsd_registered', 'max_lsa_enabled', 'max_lsa_ignore_count', 'max_lsa_ignore_limit', 'max_lsa_ignore_time', 'max_lsa_ignore_timer', 'max_lsa_limit', 'max_lsa_reset_time', 'max_lsa_reset_timer', 'max_lsa_treshold', 'max_lsa_warning_only', 'maximum_interfaces', 'maximum_metric_abr_off_buffer_time', 'maximum_metric_abr_off_mode', 'maximum_metric_abr_off_reasons', 'maximum_metric_set_reason', 'maximum_metric_start', 'maximum_metric_start_timer', 'microloop_avoidance_active', 'microloop_avoidance_delay', 'microloop_avoidance_delay_expiry', 'microloop_avoidance_type', 'minimum_lsa_arrival_interval', 'minimum_lsa_arrival_interval_u32', 'minimum_lsa_interval', 'minimum_lsa_interval_u32', 'non_self_lsa_count', 'normal_area_count', 'nsf_enabled', 'nsf_time', 'nsr_enabled', 'nsr_switchover_on_restart', 'nssa_area_count', 'number_nbrs_full', 'opaque_capable', 'opaque_lsa_checksum', 'opaque_lsa_count', 'redistribution_limit', 'redistribution_limit_warn', 'redistribution_threshold', 'role', 'role_standby', 'router_id', 'snmp_trap_enabled', 'spf_hold_time', 'spf_hold_time_u32', 'spf_maximum_time', 'spf_maximum_time_u32', 'spf_prefix_priority', 'spf_prefix_priority_route_policy', 'spf_start_time', 'spf_start_time_u32', 'sr_strict_spf_cap', 'srgb_configured', 'srgb_end', 'srgb_start', 'srgb_status', 'stub_area_count', 'table_prefix_limit_reached', 'tos_options', 'ucmp', 'ucmp_delay', 'ucmp_prefix_list', 'ucmp_variance', 'vrf_lite_enabled'], name, value)


                            class DomainId(Entity):
                                """
                                Domain ID information
                                
                                .. attribute:: primary_domain_id
                                
                                	Primary Domain ID
                                	**type**\:   :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId>`
                                
                                .. attribute:: secondary_domain_id
                                
                                	List of secondary domain IDs
                                	**type**\: list of    :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId, self).__init__()

                                    self.yang_name = "domain-id"
                                    self.yang_parent_name = "process-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"primary-domain-id" : ("primary_domain_id", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId)}
                                    self._child_list_classes = {"secondary-domain-id" : ("secondary_domain_id", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId)}

                                    self.primary_domain_id = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId()
                                    self.primary_domain_id.parent = self
                                    self._children_name_map["primary_domain_id"] = "primary-domain-id"
                                    self._children_yang_names.add("primary-domain-id")

                                    self.secondary_domain_id = YList(self)
                                    self._segment_path = lambda: "domain-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId, [], name, value)


                                class PrimaryDomainId(Entity):
                                    """
                                    Primary Domain ID
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, self).__init__()

                                        self.yang_name = "primary-domain-id"
                                        self.yang_parent_name = "domain-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                        self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                        self._segment_path = lambda: "primary-domain-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.PrimaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                                class SecondaryDomainId(Entity):
                                    """
                                    List of secondary domain IDs
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, self).__init__()

                                        self.yang_name = "secondary-domain-id"
                                        self.yang_parent_name = "domain-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.domain_id_type = YLeaf(YType.uint16, "domain-id-type")

                                        self.domain_id_value = YLeaf(YType.str, "domain-id-value")
                                        self._segment_path = lambda: "secondary-domain-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.DomainId.SecondaryDomainId, ['domain_id_type', 'domain_id_value'], name, value)


                            class MaximumMetric(Entity):
                                """
                                Max\-metric list
                                
                                .. attribute:: max_metric_enabled
                                
                                	Max\-metric enabled
                                	**type**\:  bool
                                
                                .. attribute:: max_metric_reason
                                
                                	Max\-metric reason
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: maximum_metric_external_lsa
                                
                                	If true, advertise max\-metric in external\-LSAs
                                	**type**\:  bool
                                
                                .. attribute:: maximum_metric_external_lsa_metric
                                
                                	Max\-metric value to advertise in external\-LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_include_stubs
                                
                                	If true, set max\-metric in stub links
                                	**type**\:  bool
                                
                                .. attribute:: maximum_metric_originated_for
                                
                                	Time max\-metric was used for
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_start_time
                                
                                	Time remaining until we will start using normal metrics (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_summary_lsa
                                
                                	If true, advertise max\-metric in summary\-LSAs
                                	**type**\:  bool
                                
                                .. attribute:: maximum_metric_summary_lsa_metric
                                
                                	Max\-metric value to advertise in summary\-LSAs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_metric_time_unset
                                
                                	Time max\-metric condition was cleared
                                	**type**\:   :py:class:`MaximumMetricTimeUnset <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset>`
                                
                                .. attribute:: maximum_metric_unset_reason
                                
                                	Max\-metric unset reason
                                	**type**\:   :py:class:`MaxMetricUnsetReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.MaxMetricUnsetReason>`
                                
                                .. attribute:: saved_startup_time
                                
                                	Hold time configured (s)
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saved_unset_maximum_metric
                                
                                	Saved UnsetMaximumMetric
                                	**type**\:  bool
                                
                                .. attribute:: unset_maximum_metric
                                
                                	If true, BGP is up, no maximum metric Router LSA
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric, self).__init__()

                                    self.yang_name = "maximum-metric"
                                    self.yang_parent_name = "process-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"maximum-metric-time-unset" : ("maximum_metric_time_unset", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset)}
                                    self._child_list_classes = {}

                                    self.max_metric_enabled = YLeaf(YType.boolean, "max-metric-enabled")

                                    self.max_metric_reason = YLeaf(YType.uint8, "max-metric-reason")

                                    self.maximum_metric_external_lsa = YLeaf(YType.boolean, "maximum-metric-external-lsa")

                                    self.maximum_metric_external_lsa_metric = YLeaf(YType.uint32, "maximum-metric-external-lsa-metric")

                                    self.maximum_metric_include_stubs = YLeaf(YType.boolean, "maximum-metric-include-stubs")

                                    self.maximum_metric_originated_for = YLeaf(YType.uint32, "maximum-metric-originated-for")

                                    self.maximum_metric_start_time = YLeaf(YType.uint32, "maximum-metric-start-time")

                                    self.maximum_metric_summary_lsa = YLeaf(YType.boolean, "maximum-metric-summary-lsa")

                                    self.maximum_metric_summary_lsa_metric = YLeaf(YType.uint32, "maximum-metric-summary-lsa-metric")

                                    self.maximum_metric_unset_reason = YLeaf(YType.enumeration, "maximum-metric-unset-reason")

                                    self.saved_startup_time = YLeaf(YType.uint32, "saved-startup-time")

                                    self.saved_unset_maximum_metric = YLeaf(YType.boolean, "saved-unset-maximum-metric")

                                    self.unset_maximum_metric = YLeaf(YType.boolean, "unset-maximum-metric")

                                    self.maximum_metric_time_unset = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset()
                                    self.maximum_metric_time_unset.parent = self
                                    self._children_name_map["maximum_metric_time_unset"] = "maximum-metric-time-unset"
                                    self._children_yang_names.add("maximum-metric-time-unset")
                                    self._segment_path = lambda: "maximum-metric"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric, ['max_metric_enabled', 'max_metric_reason', 'maximum_metric_external_lsa', 'maximum_metric_external_lsa_metric', 'maximum_metric_include_stubs', 'maximum_metric_originated_for', 'maximum_metric_start_time', 'maximum_metric_summary_lsa', 'maximum_metric_summary_lsa_metric', 'maximum_metric_unset_reason', 'saved_startup_time', 'saved_unset_maximum_metric', 'unset_maximum_metric'], name, value)


                                class MaximumMetricTimeUnset(Entity):
                                    """
                                    Time max\-metric condition was cleared
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, self).__init__()

                                        self.yang_name = "maximum-metric-time-unset"
                                        self.yang_parent_name = "maximum-metric"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "maximum-metric-time-unset"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.MaximumMetric.MaximumMetricTimeUnset, ['nanosecond', 'second'], name, value)


                            class Redistribution(Entity):
                                """
                                Redistribution list
                                
                                .. attribute:: classless
                                
                                	Whether to use CIDR
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Route metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_flag
                                
                                	If true, Metric configured
                                	**type**\:  bool
                                
                                .. attribute:: nssa_only
                                
                                	To NSSA areas only
                                	**type**\:  bool
                                
                                .. attribute:: redistribution_protocol
                                
                                	Protocol Information
                                	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution, self).__init__()

                                    self.yang_name = "redistribution"
                                    self.yang_parent_name = "process-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"redistribution-protocol" : ("redistribution_protocol", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol)}
                                    self._child_list_classes = {}

                                    self.classless = YLeaf(YType.boolean, "classless")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                    self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                    self.redistribution_protocol = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol()
                                    self.redistribution_protocol.parent = self
                                    self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                    self._children_yang_names.add("redistribution-protocol")
                                    self._segment_path = lambda: "redistribution"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution, ['classless', 'metric', 'metric_flag', 'nssa_only'], name, value)


                                class RedistributionProtocol(Entity):
                                    """
                                    Protocol Information
                                    
                                    .. attribute:: bgp_as_number
                                    
                                    	BGP Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: connected_instance
                                    
                                    	Connected instance name
                                    	**type**\:  str
                                    
                                    .. attribute:: eigrp_as_number
                                    
                                    	Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: isis_instance_id
                                    
                                    	ISIS instance identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: ospf_process_id
                                    
                                    	OSPF process identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_type
                                    
                                    	ProtocolType
                                    	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, self).__init__()

                                        self.yang_name = "redistribution-protocol"
                                        self.yang_parent_name = "redistribution"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                        self.connected_instance = YLeaf(YType.str, "connected-instance")

                                        self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                        self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                        self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                        self.protocol_type = YLeaf(YType.enumeration, "protocol-type")
                                        self._segment_path = lambda: "redistribution-protocol"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProcessSummary.Redistribution.RedistributionProtocol, ['bgp_as_number', 'connected_instance', 'eigrp_as_number', 'isis_instance_id', 'ospf_process_id', 'protocol_type'], name, value)


                        class ProtocolAreas(Entity):
                            """
                            Protocol Area table
                            
                            .. attribute:: protocol_area
                            
                            	Area information
                            	**type**\: list of    :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas, self).__init__()

                                self.yang_name = "protocol-areas"
                                self.yang_parent_name = "process-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"protocol-area" : ("protocol_area", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea)}

                                self.protocol_area = YList(self)
                                self._segment_path = lambda: "protocol-areas"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas, [], name, value)


                            class ProtocolArea(Entity):
                                """
                                Area information
                                
                                .. attribute:: address
                                
                                	Area ID if in IP address format
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: area_id
                                
                                	Area ID if in integer format
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: protcol_area
                                
                                	Area ID string in decimal and dotted\-decimal format
                                	**type**\:  str
                                
                                	**length:** 0..16
                                
                                .. attribute:: protocol_area_dist_list_in
                                
                                	Distribute List In
                                	**type**\:  str
                                
                                .. attribute:: protocol_interface
                                
                                	Interface list
                                	**type**\: list of    :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                                
                                .. attribute:: protocol_mpls
                                
                                	MPLS\-TE enabled
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea, self).__init__()

                                    self.yang_name = "protocol-area"
                                    self.yang_parent_name = "protocol-areas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"protocol-interface" : ("protocol_interface", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface)}

                                    self.address = YLeaf(YType.str, "address")

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.protcol_area = YLeaf(YType.str, "protcol-area")

                                    self.protocol_area_dist_list_in = YLeaf(YType.str, "protocol-area-dist-list-in")

                                    self.protocol_mpls = YLeaf(YType.boolean, "protocol-mpls")

                                    self.protocol_interface = YList(self)
                                    self._segment_path = lambda: "protocol-area"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea, ['address', 'area_id', 'protcol_area', 'protocol_area_dist_list_in', 'protocol_mpls'], name, value)


                                class ProtocolInterface(Entity):
                                    """
                                    Interface list
                                    
                                    .. attribute:: protocol_authentication_type
                                    
                                    	Authentication type
                                    	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Authentication>`
                                    
                                    .. attribute:: protocol_interface_dist_list_in
                                    
                                    	Distribute List In
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_interface_name
                                    
                                    	Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                        self.yang_name = "protocol-interface"
                                        self.yang_parent_name = "protocol-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.protocol_authentication_type = YLeaf(YType.enumeration, "protocol-authentication-type")

                                        self.protocol_interface_dist_list_in = YLeaf(YType.str, "protocol-interface-dist-list-in")

                                        self.protocol_interface_name = YLeaf(YType.str, "protocol-interface-name")
                                        self._segment_path = lambda: "protocol-interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolAreas.ProtocolArea.ProtocolInterface, ['protocol_authentication_type', 'protocol_interface_dist_list_in', 'protocol_interface_name'], name, value)


                        class ProtocolSummary(Entity):
                            """
                            Basic OSPF protocol information
                            
                            .. attribute:: administrative_distance_external
                            
                            	Administrative Distance for External routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_inter_area
                            
                            	Administrative Distance for Inter Area routes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dist_list_in
                            
                            	Distribute List In
                            	**type**\:  str
                            
                            .. attribute:: protocol_distance
                            
                            	Administrative distance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: protocol_nsf
                            
                            	True if NSF enabled
                            	**type**\:  bool
                            
                            .. attribute:: protocol_router_id
                            
                            	Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary, self).__init__()

                                self.yang_name = "protocol-summary"
                                self.yang_parent_name = "process-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.administrative_distance_external = YLeaf(YType.uint32, "administrative-distance-external")

                                self.administrative_distance_inter_area = YLeaf(YType.uint32, "administrative-distance-inter-area")

                                self.dist_list_in = YLeaf(YType.str, "dist-list-in")

                                self.protocol_distance = YLeaf(YType.uint32, "protocol-distance")

                                self.protocol_nsf = YLeaf(YType.boolean, "protocol-nsf")

                                self.protocol_router_id = YLeaf(YType.str, "protocol-router-id")
                                self._segment_path = lambda: "protocol-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.ProtocolSummary, ['administrative_distance_external', 'administrative_distance_inter_area', 'dist_list_in', 'protocol_distance', 'protocol_nsf', 'protocol_router_id'], name, value)


                        class Redistributions(Entity):
                            """
                            Redistribution information table
                            
                            .. attribute:: redistribution
                            
                            	Redistribution information
                            	**type**\: list of    :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions, self).__init__()

                                self.yang_name = "redistributions"
                                self.yang_parent_name = "process-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"redistribution" : ("redistribution", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution)}

                                self.redistribution = YList(self)
                                self._segment_path = lambda: "redistributions"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions, [], name, value)


                            class Redistribution(Entity):
                                """
                                Redistribution information
                                
                                .. attribute:: classless
                                
                                	Whether to use CIDR
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Route metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: metric_flag
                                
                                	If true, Metric configured
                                	**type**\:  bool
                                
                                .. attribute:: nssa_only
                                
                                	To NSSA areas only
                                	**type**\:  bool
                                
                                .. attribute:: process_name
                                
                                	Process name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: protocol_name
                                
                                	Protocol name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: redistribution_protocol
                                
                                	Protocol Information
                                	**type**\:   :py:class:`RedistributionProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution, self).__init__()

                                    self.yang_name = "redistribution"
                                    self.yang_parent_name = "redistributions"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"redistribution-protocol" : ("redistribution_protocol", Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol)}
                                    self._child_list_classes = {}

                                    self.classless = YLeaf(YType.boolean, "classless")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.metric_flag = YLeaf(YType.boolean, "metric-flag")

                                    self.nssa_only = YLeaf(YType.boolean, "nssa-only")

                                    self.process_name = YLeaf(YType.str, "process-name")

                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                    self.redistribution_protocol = Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol()
                                    self.redistribution_protocol.parent = self
                                    self._children_name_map["redistribution_protocol"] = "redistribution-protocol"
                                    self._children_yang_names.add("redistribution-protocol")
                                    self._segment_path = lambda: "redistribution"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution, ['classless', 'metric', 'metric_flag', 'nssa_only', 'process_name', 'protocol_name'], name, value)


                                class RedistributionProtocol(Entity):
                                    """
                                    Protocol Information
                                    
                                    .. attribute:: bgp_as_number
                                    
                                    	BGP Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: connected_instance
                                    
                                    	Connected instance name
                                    	**type**\:  str
                                    
                                    .. attribute:: eigrp_as_number
                                    
                                    	Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: isis_instance_id
                                    
                                    	ISIS instance identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: ospf_process_id
                                    
                                    	OSPF process identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_type
                                    
                                    	ProtocolType
                                    	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, self).__init__()

                                        self.yang_name = "redistribution-protocol"
                                        self.yang_parent_name = "redistribution"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                        self.connected_instance = YLeaf(YType.str, "connected-instance")

                                        self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                        self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                        self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                        self.protocol_type = YLeaf(YType.enumeration, "protocol-type")
                                        self._segment_path = lambda: "redistribution-protocol"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.ProcessInformation.Redistributions.Redistribution.RedistributionProtocol, ['bgp_as_number', 'connected_instance', 'eigrp_as_number', 'isis_instance_id', 'ospf_process_id', 'protocol_type'], name, value)


                    class RouteInformation(Entity):
                        """
                        Container for OSPF routing tables
                        
                        .. attribute:: backup_routes
                        
                        	OSPF Route Table Including Backup Paths
                        	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes>`
                        
                        .. attribute:: connected_routes
                        
                        	OSPF Connected Route Table
                        	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes>`
                        
                        .. attribute:: external_routes
                        
                        	OSPF External Route Table
                        	**type**\:   :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes>`
                        
                        .. attribute:: local_routes
                        
                        	OSPF Local Route Table
                        	**type**\:   :py:class:`LocalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes>`
                        
                        .. attribute:: multicast_intact_backup_routes
                        
                        	OSPF Route Table Including Multicast intact Backup Paths
                        	**type**\:   :py:class:`MulticastIntactBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes>`
                        
                        .. attribute:: multicast_intact_route_table
                        
                        	OSPF Route Table including multicast\-intact routes
                        	**type**\:   :py:class:`MulticastIntactRouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable>`
                        
                        .. attribute:: route_areas
                        
                        	OSPF Area Route Table
                        	**type**\:   :py:class:`RouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas>`
                        
                        .. attribute:: route_table
                        
                        	OSPF Route Table
                        	**type**\:   :py:class:`RouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable>`
                        
                        .. attribute:: summary_information
                        
                        	OSPF route summary statistics
                        	**type**\:   :py:class:`SummaryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation, self).__init__()

                            self.yang_name = "route-information"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"backup-routes" : ("backup_routes", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes), "connected-routes" : ("connected_routes", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes), "external-routes" : ("external_routes", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes), "local-routes" : ("local_routes", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes), "multicast-intact-backup-routes" : ("multicast_intact_backup_routes", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes), "multicast-intact-route-table" : ("multicast_intact_route_table", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable), "route-areas" : ("route_areas", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas), "route-table" : ("route_table", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable), "summary-information" : ("summary_information", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation)}
                            self._child_list_classes = {}

                            self.backup_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes()
                            self.backup_routes.parent = self
                            self._children_name_map["backup_routes"] = "backup-routes"
                            self._children_yang_names.add("backup-routes")

                            self.connected_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes()
                            self.connected_routes.parent = self
                            self._children_name_map["connected_routes"] = "connected-routes"
                            self._children_yang_names.add("connected-routes")

                            self.external_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes()
                            self.external_routes.parent = self
                            self._children_name_map["external_routes"] = "external-routes"
                            self._children_yang_names.add("external-routes")

                            self.local_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes()
                            self.local_routes.parent = self
                            self._children_name_map["local_routes"] = "local-routes"
                            self._children_yang_names.add("local-routes")

                            self.multicast_intact_backup_routes = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes()
                            self.multicast_intact_backup_routes.parent = self
                            self._children_name_map["multicast_intact_backup_routes"] = "multicast-intact-backup-routes"
                            self._children_yang_names.add("multicast-intact-backup-routes")

                            self.multicast_intact_route_table = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable()
                            self.multicast_intact_route_table.parent = self
                            self._children_name_map["multicast_intact_route_table"] = "multicast-intact-route-table"
                            self._children_yang_names.add("multicast-intact-route-table")

                            self.route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas()
                            self.route_areas.parent = self
                            self._children_name_map["route_areas"] = "route-areas"
                            self._children_yang_names.add("route-areas")

                            self.route_table = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable()
                            self.route_table.parent = self
                            self._children_name_map["route_table"] = "route-table"
                            self._children_yang_names.add("route-table")

                            self.summary_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation()
                            self.summary_information.parent = self
                            self._children_name_map["summary_information"] = "summary-information"
                            self._children_yang_names.add("summary-information")
                            self._segment_path = lambda: "route-information"


                        class BackupRoutes(Entity):
                            """
                            OSPF Route Table Including Backup Paths
                            
                            .. attribute:: backup_route
                            
                            	OSPF route including backup paths
                            	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes, self).__init__()

                                self.yang_name = "backup-routes"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"backup-route" : ("backup_route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute)}

                                self.backup_route = YList(self)
                                self._segment_path = lambda: "backup-routes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes, [], name, value)


                            class BackupRoute(Entity):
                                """
                                OSPF route including backup paths
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute, self).__init__()

                                    self.yang_name = "backup-route"
                                    self.yang_parent_name = "backup-routes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "backup-route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "backup-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_backup_path
                                    
                                    	Backup Path Info
                                    	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath>`
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_id
                                    
                                    	Path ID of path
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "backup-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath()
                                        self.route_backup_path.parent = self
                                        self._children_name_map["route_backup_path"] = "route-backup-path"
                                        self._children_yang_names.add("route-backup-path")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class RouteBackupPath(Entity):
                                        """
                                        Backup Path Info
                                        
                                        .. attribute:: backup_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_remote_lfa
                                        
                                        	IP address of remote LFA
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_repair
                                        
                                        	Backup Repair List
                                        	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                        
                                        .. attribute:: backup_repair_list_size
                                        
                                        	Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: backup_route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_tunnel_interface_name
                                        
                                        	Backup Tunnel Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: downstream
                                        
                                        	Downstream
                                        	**type**\:  bool
                                        
                                        .. attribute:: line_card_disjoint
                                        
                                        	Line Card Disjoint
                                        	**type**\:  bool
                                        
                                        .. attribute:: node_protect
                                        
                                        	Node Protect
                                        	**type**\:  bool
                                        
                                        .. attribute:: primary_path
                                        
                                        	Primary Path
                                        	**type**\:  bool
                                        
                                        .. attribute:: srlg_disjoint
                                        
                                        	SRLG Disjoint
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                            self.yang_name = "route-backup-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair)}

                                            self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                            self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                            self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                            self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                            self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                            self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                            self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                            self.downstream = YLeaf(YType.boolean, "downstream")

                                            self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                            self.node_protect = YLeaf(YType.boolean, "node-protect")

                                            self.primary_path = YLeaf(YType.boolean, "primary-path")

                                            self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                            self.backup_repair = YList(self)
                                            self._segment_path = lambda: "route-backup-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                        class BackupRepair(Entity):
                                            """
                                            Backup Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                self.yang_name = "backup-repair"
                                                self.yang_parent_name = "route-backup-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "backup-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.BackupRoutes.BackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class ConnectedRoutes(Entity):
                            """
                            OSPF Connected Route Table
                            
                            .. attribute:: connected_route
                            
                            	Connected route
                            	**type**\: list of    :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes, self).__init__()

                                self.yang_name = "connected-routes"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"connected-route" : ("connected_route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute)}

                                self.connected_route = YList(self)
                                self._segment_path = lambda: "connected-routes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes, [], name, value)


                            class ConnectedRoute(Entity):
                                """
                                Connected route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute, self).__init__()

                                    self.yang_name = "connected-route"
                                    self.yang_parent_name = "connected-routes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "connected-route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "connected-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "connected-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ConnectedRoutes.ConnectedRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class ExternalRoutes(Entity):
                            """
                            OSPF External Route Table
                            
                            .. attribute:: external_route
                            
                            	OSPF external route
                            	**type**\: list of    :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes, self).__init__()

                                self.yang_name = "external-routes"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"external-route" : ("external_route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute)}

                                self.external_route = YList(self)
                                self._segment_path = lambda: "external-routes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes, [], name, value)


                            class ExternalRoute(Entity):
                                """
                                OSPF external route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: protocol_name
                                
                                	Name of protocol from which the external route was redistributed
                                	**type**\:   :py:class:`ProtocolName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName>`
                                
                                .. attribute:: route_extended_community
                                
                                	Extended communities in the route
                                	**type**\:   :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                                
                                .. attribute:: route_information
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute, self).__init__()

                                    self.yang_name = "external-route"
                                    self.yang_parent_name = "external-routes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"protocol-name" : ("protocol_name", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName), "route-extended-community" : ("route_extended_community", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity), "route-information" : ("route_information", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.protocol_name = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName()
                                    self.protocol_name.parent = self
                                    self._children_name_map["protocol_name"] = "protocol-name"
                                    self._children_yang_names.add("protocol-name")

                                    self.route_extended_community = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                    self.route_extended_community.parent = self
                                    self._children_name_map["route_extended_community"] = "route-extended-community"
                                    self._children_yang_names.add("route-extended-community")

                                    self.route_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation()
                                    self.route_information.parent = self
                                    self._children_name_map["route_information"] = "route-information"
                                    self._children_yang_names.add("route-information")
                                    self._segment_path = lambda: "external-route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute, ['prefix', 'prefix_length'], name, value)


                                class ProtocolName(Entity):
                                    """
                                    Name of protocol from which the external route
                                    was redistributed
                                    
                                    .. attribute:: bgp_as_number
                                    
                                    	BGP Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: connected_instance
                                    
                                    	Connected instance name
                                    	**type**\:  str
                                    
                                    .. attribute:: eigrp_as_number
                                    
                                    	Autonomous System Number
                                    	**type**\:  str
                                    
                                    .. attribute:: isis_instance_id
                                    
                                    	ISIS instance identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: ospf_process_id
                                    
                                    	OSPF process identifier
                                    	**type**\:  str
                                    
                                    .. attribute:: protocol_type
                                    
                                    	ProtocolType
                                    	**type**\:   :py:class:`RedistProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.RedistProtocol>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, self).__init__()

                                        self.yang_name = "protocol-name"
                                        self.yang_parent_name = "external-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_as_number = YLeaf(YType.str, "bgp-as-number")

                                        self.connected_instance = YLeaf(YType.str, "connected-instance")

                                        self.eigrp_as_number = YLeaf(YType.str, "eigrp-as-number")

                                        self.isis_instance_id = YLeaf(YType.str, "isis-instance-id")

                                        self.ospf_process_id = YLeaf(YType.str, "ospf-process-id")

                                        self.protocol_type = YLeaf(YType.enumeration, "protocol-type")
                                        self._segment_path = lambda: "protocol-name"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.ProtocolName, ['bgp_as_number', 'connected_instance', 'eigrp_as_number', 'isis_instance_id', 'ospf_process_id', 'protocol_type'], name, value)


                                class RouteExtendedCommunity(Entity):
                                    """
                                    Extended communities in the route
                                    
                                    .. attribute:: extended_community_area_id
                                    
                                    	Area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: extended_community_domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: extended_community_options
                                    
                                    	Route Options
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: extended_community_route_type
                                    
                                    	Route type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: extended_community_router_id
                                    
                                    	Router id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: extended_communityl_domain_id_type
                                    
                                    	Domain ID type
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                        self.yang_name = "route-extended-community"
                                        self.yang_parent_name = "external-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.extended_community_area_id = YLeaf(YType.uint32, "extended-community-area-id")

                                        self.extended_community_domain_id_value = YLeaf(YType.str, "extended-community-domain-id-value")

                                        self.extended_community_options = YLeaf(YType.uint8, "extended-community-options")

                                        self.extended_community_route_type = YLeaf(YType.uint8, "extended-community-route-type")

                                        self.extended_community_router_id = YLeaf(YType.str, "extended-community-router-id")

                                        self.extended_communityl_domain_id_type = YLeaf(YType.uint16, "extended-communityl-domain-id-type")
                                        self._segment_path = lambda: "route-extended-community"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, ['extended_community_area_id', 'extended_community_domain_id_value', 'extended_community_options', 'extended_community_route_type', 'extended_community_router_id', 'extended_communityl_domain_id_type'], name, value)


                                class RouteInformation(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_connected
                                    
                                    	If true, connected route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_info
                                    
                                    	Route information
                                    	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo>`
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_path
                                    
                                    	List of paths to this route
                                    	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath>`
                                    
                                    .. attribute:: route_prefix
                                    
                                    	Prefix
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_prefix_length
                                    
                                    	Prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_type
                                    
                                    	Route type
                                    	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, self).__init__()

                                        self.yang_name = "route-information"
                                        self.yang_parent_name = "external-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo)}
                                        self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath)}

                                        self.route_connected = YLeaf(YType.boolean, "route-connected")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_prefix = YLeaf(YType.str, "route-prefix")

                                        self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                        self.route_type = YLeaf(YType.enumeration, "route-type")

                                        self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo()
                                        self.route_info.parent = self
                                        self._children_name_map["route_info"] = "route-info"
                                        self._children_yang_names.add("route-info")

                                        self.route_path = YList(self)
                                        self._segment_path = lambda: "route-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation, ['route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                    class RouteInfo(Entity):
                                        """
                                        Route information
                                        
                                        .. attribute:: route_area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_auto_excluded
                                        
                                        	If true, exclude from TE paths
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_fail_time
                                        
                                        	Last time update failed
                                        	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime>`
                                        
                                        .. attribute:: route_forward_distance
                                        
                                        	Forward distance
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_rib_version
                                        
                                        	RIB version
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_source
                                        
                                        	Protocol source
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_spf_priority
                                        
                                        	SPF priority
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_spf_version
                                        
                                        	SPF version
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: route_srte_nbr_registered
                                        
                                        	SRTE registered neigbhor count on route
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: route_srte_prefix_registered
                                        
                                        	If true, SRTE registered prefix route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_te_metric
                                        
                                        	TE metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_update_time
                                        
                                        	Last time updated
                                        	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, self).__init__()

                                            self.yang_name = "route-info"
                                            self.yang_parent_name = "route-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime)}
                                            self._child_list_classes = {}

                                            self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                            self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                            self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                            self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                            self.route_source = YLeaf(YType.uint16, "route-source")

                                            self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                            self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                            self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                            self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                            self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                            self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime()
                                            self.route_fail_time.parent = self
                                            self._children_name_map["route_fail_time"] = "route-fail-time"
                                            self._children_yang_names.add("route-fail-time")

                                            self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime()
                                            self.route_update_time.parent = self
                                            self._children_name_map["route_update_time"] = "route-update-time"
                                            self._children_yang_names.add("route-update-time")
                                            self._segment_path = lambda: "route-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                        class RouteFailTime(Entity):
                                            """
                                            Last time update failed
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, self).__init__()

                                                self.yang_name = "route-fail-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-fail-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                        class RouteUpdateTime(Entity):
                                            """
                                            Last time updated
                                            
                                            .. attribute:: nanosecond
                                            
                                            	Nanosecond
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: second
                                            
                                            	Second
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                                self.yang_name = "route-update-time"
                                                self.yang_parent_name = "route-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                self.second = YLeaf(YType.uint32, "second")
                                                self._segment_path = lambda: "route-update-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                    class RoutePath(Entity):
                                        """
                                        List of paths to this route
                                        
                                        .. attribute:: area_format
                                        
                                        	Area format IP or uint32
                                        	**type**\:  bool
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type, see RFC2328 etc
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: route_lsaid
                                        
                                        	LSA ID, see RFC2328
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_path_is_mcast_intact
                                        
                                        	Multicast\-intact path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_path_is_ucmp_path
                                        
                                        	UCMP path
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sr_microloop_avoidance_path
                                        
                                        	SR Microloop avoidance Path Info
                                        	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, self).__init__()

                                            self.yang_name = "route-path"
                                            self.yang_parent_name = "route-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath)}
                                            self._child_list_classes = {}

                                            self.area_format = YLeaf(YType.boolean, "area-format")

                                            self.area_id = YLeaf(YType.uint32, "area-id")

                                            self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                            self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                            self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                            self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                            self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                            self.route_source = YLeaf(YType.str, "route-source")

                                            self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath()
                                            self.sr_microloop_avoidance_path.parent = self
                                            self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                            self._children_yang_names.add("sr-microloop-avoidance-path")
                                            self._segment_path = lambda: "route-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                        class SrMicroloopAvoidancePath(Entity):
                                            """
                                            SR Microloop avoidance Path Info
                                            
                                            .. attribute:: microloop_repair
                                            
                                            	Microloop Repair List
                                            	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                            
                                            .. attribute:: microloop_repair_list_size
                                            
                                            	Microloop Repair List Size
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: microloop_strict_spf
                                            
                                            	Strict SPF SID
                                            	**type**\:  bool
                                            
                                            .. attribute:: microloop_tunnel_interface_name
                                            
                                            	Microloop Tunnel Interface name
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                self.yang_name = "sr-microloop-avoidance-path"
                                                self.yang_parent_name = "route-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                self.microloop_repair = YList(self)
                                                self._segment_path = lambda: "sr-microloop-avoidance-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                            class MicroloopRepair(Entity):
                                                """
                                                Microloop Repair List
                                                
                                                .. attribute:: repair_element_id
                                                
                                                	Repair Element ID
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                    self.yang_name = "microloop-repair"
                                                    self.yang_parent_name = "sr-microloop-avoidance-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                    self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                    self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                    self._segment_path = lambda: "microloop-repair"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.ExternalRoutes.ExternalRoute.RouteInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class LocalRoutes(Entity):
                            """
                            OSPF Local Route Table
                            
                            .. attribute:: local_route
                            
                            	Local route
                            	**type**\: list of    :py:class:`LocalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes, self).__init__()

                                self.yang_name = "local-routes"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"local-route" : ("local_route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute)}

                                self.local_route = YList(self)
                                self._segment_path = lambda: "local-routes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes, [], name, value)


                            class LocalRoute(Entity):
                                """
                                Local route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute, self).__init__()

                                    self.yang_name = "local-route"
                                    self.yang_parent_name = "local-routes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "local-route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "local-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "local-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.LocalRoutes.LocalRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class MulticastIntactBackupRoutes(Entity):
                            """
                            OSPF Route Table Including Multicast intact
                            Backup Paths
                            
                            .. attribute:: multicast_intact_backup_route
                            
                            	OSPF route including multicast backup paths
                            	**type**\: list of    :py:class:`MulticastIntactBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes, self).__init__()

                                self.yang_name = "multicast-intact-backup-routes"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"multicast-intact-backup-route" : ("multicast_intact_backup_route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute)}

                                self.multicast_intact_backup_route = YList(self)
                                self._segment_path = lambda: "multicast-intact-backup-routes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes, [], name, value)


                            class MulticastIntactBackupRoute(Entity):
                                """
                                OSPF route including multicast backup paths
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, self).__init__()

                                    self.yang_name = "multicast-intact-backup-route"
                                    self.yang_parent_name = "multicast-intact-backup-routes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "multicast-intact-backup-route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "multicast-intact-backup-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_backup_path
                                    
                                    	Backup Path Info
                                    	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath>`
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_id
                                    
                                    	Path ID of path
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "multicast-intact-backup-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath()
                                        self.route_backup_path.parent = self
                                        self._children_name_map["route_backup_path"] = "route-backup-path"
                                        self._children_yang_names.add("route-backup-path")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class RouteBackupPath(Entity):
                                        """
                                        Backup Path Info
                                        
                                        .. attribute:: backup_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_remote_lfa
                                        
                                        	IP address of remote LFA
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_repair
                                        
                                        	Backup Repair List
                                        	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair>`
                                        
                                        .. attribute:: backup_repair_list_size
                                        
                                        	Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: backup_route_interface_name
                                        
                                        	Next hop Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: backup_route_next_hop_address
                                        
                                        	Nexthop IP address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_route_source
                                        
                                        	IP address of source of route
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: backup_tunnel_interface_name
                                        
                                        	Backup Tunnel Interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: downstream
                                        
                                        	Downstream
                                        	**type**\:  bool
                                        
                                        .. attribute:: line_card_disjoint
                                        
                                        	Line Card Disjoint
                                        	**type**\:  bool
                                        
                                        .. attribute:: node_protect
                                        
                                        	Node Protect
                                        	**type**\:  bool
                                        
                                        .. attribute:: primary_path
                                        
                                        	Primary Path
                                        	**type**\:  bool
                                        
                                        .. attribute:: srlg_disjoint
                                        
                                        	SRLG Disjoint
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, self).__init__()

                                            self.yang_name = "route-backup-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair)}

                                            self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                            self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                            self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                            self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                            self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                            self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                            self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                            self.downstream = YLeaf(YType.boolean, "downstream")

                                            self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                            self.node_protect = YLeaf(YType.boolean, "node-protect")

                                            self.primary_path = YLeaf(YType.boolean, "primary-path")

                                            self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                            self.backup_repair = YList(self)
                                            self._segment_path = lambda: "route-backup-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                        class BackupRepair(Entity):
                                            """
                                            Backup Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                self.yang_name = "backup-repair"
                                                self.yang_parent_name = "route-backup-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "backup-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactBackupRoutes.MulticastIntactBackupRoute.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class MulticastIntactRouteTable(Entity):
                            """
                            OSPF Route Table including multicast\-intact
                            routes
                            
                            .. attribute:: route
                            
                            	An OSPF route
                            	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable, self).__init__()

                                self.yang_name = "multicast-intact-route-table"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"route" : ("route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route)}

                                self.route = YList(self)
                                self._segment_path = lambda: "multicast-intact-route-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable, [], name, value)


                            class Route(Entity):
                                """
                                An OSPF route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route, self).__init__()

                                    self.yang_name = "route"
                                    self.yang_parent_name = "multicast-intact-route-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.MulticastIntactRouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class RouteAreas(Entity):
                            """
                            OSPF Area Route Table
                            
                            .. attribute:: route_area
                            
                            	OSPF Area Route
                            	**type**\: list of    :py:class:`RouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas, self).__init__()

                                self.yang_name = "route-areas"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"route-area" : ("route_area", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea)}

                                self.route_area = YList(self)
                                self._segment_path = lambda: "route-areas"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas, [], name, value)


                            class RouteArea(Entity):
                                """
                                OSPF Area Route
                                
                                .. attribute:: area_id  <key>
                                
                                	Area ID
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: backup_route_areas
                                
                                	OSPF Route Table Including Backup Paths in an area
                                	**type**\:   :py:class:`BackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas>`
                                
                                .. attribute:: connected_route_areas
                                
                                	OSPF Connected Route Table in an area
                                	**type**\:   :py:class:`ConnectedRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas>`
                                
                                .. attribute:: local_route_areas
                                
                                	OSPF Local Route Table
                                	**type**\:   :py:class:`LocalRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas>`
                                
                                .. attribute:: multicast_intact_backup_route_areas
                                
                                	OSPF Route Table Including Multicast Intace Backup Paths in an area
                                	**type**\:   :py:class:`MulticastIntactBackupRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas>`
                                
                                .. attribute:: multicast_intact_route_areas
                                
                                	OSPF Area multicast\-intact included route entry
                                	**type**\:   :py:class:`MulticastIntactRouteAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas>`
                                
                                .. attribute:: route_area_informations
                                
                                	OSPF Area Route Entry
                                	**type**\:   :py:class:`RouteAreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations>`
                                
                                .. attribute:: summary_area_information
                                
                                	OSPF route summary statistics
                                	**type**\:   :py:class:`SummaryAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea, self).__init__()

                                    self.yang_name = "route-area"
                                    self.yang_parent_name = "route-areas"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"backup-route-areas" : ("backup_route_areas", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas), "connected-route-areas" : ("connected_route_areas", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas), "local-route-areas" : ("local_route_areas", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas), "multicast-intact-backup-route-areas" : ("multicast_intact_backup_route_areas", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas), "multicast-intact-route-areas" : ("multicast_intact_route_areas", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas), "route-area-informations" : ("route_area_informations", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations), "summary-area-information" : ("summary_area_information", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation)}
                                    self._child_list_classes = {}

                                    self.area_id = YLeaf(YType.int32, "area-id")

                                    self.backup_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas()
                                    self.backup_route_areas.parent = self
                                    self._children_name_map["backup_route_areas"] = "backup-route-areas"
                                    self._children_yang_names.add("backup-route-areas")

                                    self.connected_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas()
                                    self.connected_route_areas.parent = self
                                    self._children_name_map["connected_route_areas"] = "connected-route-areas"
                                    self._children_yang_names.add("connected-route-areas")

                                    self.local_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas()
                                    self.local_route_areas.parent = self
                                    self._children_name_map["local_route_areas"] = "local-route-areas"
                                    self._children_yang_names.add("local-route-areas")

                                    self.multicast_intact_backup_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas()
                                    self.multicast_intact_backup_route_areas.parent = self
                                    self._children_name_map["multicast_intact_backup_route_areas"] = "multicast-intact-backup-route-areas"
                                    self._children_yang_names.add("multicast-intact-backup-route-areas")

                                    self.multicast_intact_route_areas = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas()
                                    self.multicast_intact_route_areas.parent = self
                                    self._children_name_map["multicast_intact_route_areas"] = "multicast-intact-route-areas"
                                    self._children_yang_names.add("multicast-intact-route-areas")

                                    self.route_area_informations = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations()
                                    self.route_area_informations.parent = self
                                    self._children_name_map["route_area_informations"] = "route-area-informations"
                                    self._children_yang_names.add("route-area-informations")

                                    self.summary_area_information = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation()
                                    self.summary_area_information.parent = self
                                    self._children_name_map["summary_area_information"] = "summary-area-information"
                                    self._children_yang_names.add("summary-area-information")
                                    self._segment_path = lambda: "route-area" + "[area-id='" + self.area_id.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea, ['area_id'], name, value)


                                class BackupRouteAreas(Entity):
                                    """
                                    OSPF Route Table Including Backup Paths in an
                                    area
                                    
                                    .. attribute:: backup_route_area
                                    
                                    	OSPF route including backup paths
                                    	**type**\: list of    :py:class:`BackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, self).__init__()

                                        self.yang_name = "backup-route-areas"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"backup-route-area" : ("backup_route_area", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea)}

                                        self.backup_route_area = YList(self)
                                        self._segment_path = lambda: "backup-route-areas"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas, [], name, value)


                                    class BackupRouteArea(Entity):
                                        """
                                        OSPF route including backup paths
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, self).__init__()

                                            self.yang_name = "backup-route-area"
                                            self.yang_parent_name = "backup-route-areas"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo)}
                                            self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath)}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)
                                            self._segment_path = lambda: "backup-route-area"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "backup-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime)}
                                                self._child_list_classes = {}

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")
                                                self._segment_path = lambda: "route-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-fail-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_backup_path
                                            
                                            	Backup Path Info
                                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath>`
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_id
                                            
                                            	Path ID of path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "backup-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                                self._child_list_classes = {}

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath()
                                                self.route_backup_path.parent = self
                                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                                self._children_yang_names.add("route-backup-path")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")
                                                self._segment_path = lambda: "route-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                            class RouteBackupPath(Entity):
                                                """
                                                Backup Path Info
                                                
                                                .. attribute:: backup_metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_remote_lfa
                                                
                                                	IP address of remote LFA
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_route_interface_name
                                                
                                                	Next hop Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: backup_route_next_hop_address
                                                
                                                	Nexthop IP address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_route_source
                                                
                                                	IP address of source of route
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_tunnel_interface_name
                                                
                                                	Backup Tunnel Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: downstream
                                                
                                                	Downstream
                                                	**type**\:  bool
                                                
                                                .. attribute:: line_card_disjoint
                                                
                                                	Line Card Disjoint
                                                	**type**\:  bool
                                                
                                                .. attribute:: node_protect
                                                
                                                	Node Protect
                                                	**type**\:  bool
                                                
                                                .. attribute:: primary_path
                                                
                                                	Primary Path
                                                	**type**\:  bool
                                                
                                                .. attribute:: srlg_disjoint
                                                
                                                	SRLG Disjoint
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                    self.yang_name = "route-backup-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair)}

                                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                    self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                    self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "route-backup-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "route-backup-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "backup-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)
                                                    self._segment_path = lambda: "sr-microloop-avoidance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "microloop-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.BackupRouteAreas.BackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class ConnectedRouteAreas(Entity):
                                    """
                                    OSPF Connected Route Table in an area
                                    
                                    .. attribute:: connected_route_area
                                    
                                    	Connected route
                                    	**type**\: list of    :py:class:`ConnectedRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, self).__init__()

                                        self.yang_name = "connected-route-areas"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"connected-route-area" : ("connected_route_area", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea)}

                                        self.connected_route_area = YList(self)
                                        self._segment_path = lambda: "connected-route-areas"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas, [], name, value)


                                    class ConnectedRouteArea(Entity):
                                        """
                                        Connected route
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, self).__init__()

                                            self.yang_name = "connected-route-area"
                                            self.yang_parent_name = "connected-route-areas"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo)}
                                            self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath)}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)
                                            self._segment_path = lambda: "connected-route-area"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "connected-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime)}
                                                self._child_list_classes = {}

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")
                                                self._segment_path = lambda: "route-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-fail-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "connected-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                                self._child_list_classes = {}

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")
                                                self._segment_path = lambda: "route-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)
                                                    self._segment_path = lambda: "sr-microloop-avoidance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "microloop-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.ConnectedRouteAreas.ConnectedRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class LocalRouteAreas(Entity):
                                    """
                                    OSPF Local Route Table
                                    
                                    .. attribute:: local_route_area
                                    
                                    	Local route
                                    	**type**\: list of    :py:class:`LocalRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, self).__init__()

                                        self.yang_name = "local-route-areas"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"local-route-area" : ("local_route_area", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea)}

                                        self.local_route_area = YList(self)
                                        self._segment_path = lambda: "local-route-areas"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas, [], name, value)


                                    class LocalRouteArea(Entity):
                                        """
                                        Local route
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, self).__init__()

                                            self.yang_name = "local-route-area"
                                            self.yang_parent_name = "local-route-areas"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo)}
                                            self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath)}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)
                                            self._segment_path = lambda: "local-route-area"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "local-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime)}
                                                self._child_list_classes = {}

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")
                                                self._segment_path = lambda: "route-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-fail-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "local-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                                self._child_list_classes = {}

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")
                                                self._segment_path = lambda: "route-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)
                                                    self._segment_path = lambda: "sr-microloop-avoidance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "microloop-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.LocalRouteAreas.LocalRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class MulticastIntactBackupRouteAreas(Entity):
                                    """
                                    OSPF Route Table Including Multicast Intace
                                    Backup Paths in an area
                                    
                                    .. attribute:: multicast_intact_backup_route_area
                                    
                                    	OSPF route including Multicast intact backup paths
                                    	**type**\: list of    :py:class:`MulticastIntactBackupRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, self).__init__()

                                        self.yang_name = "multicast-intact-backup-route-areas"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"multicast-intact-backup-route-area" : ("multicast_intact_backup_route_area", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea)}

                                        self.multicast_intact_backup_route_area = YList(self)
                                        self._segment_path = lambda: "multicast-intact-backup-route-areas"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas, [], name, value)


                                    class MulticastIntactBackupRouteArea(Entity):
                                        """
                                        OSPF route including Multicast intact backup
                                        paths
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, self).__init__()

                                            self.yang_name = "multicast-intact-backup-route-area"
                                            self.yang_parent_name = "multicast-intact-backup-route-areas"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo)}
                                            self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath)}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)
                                            self._segment_path = lambda: "multicast-intact-backup-route-area"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "multicast-intact-backup-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime)}
                                                self._child_list_classes = {}

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")
                                                self._segment_path = lambda: "route-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-fail-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_backup_path
                                            
                                            	Backup Path Info
                                            	**type**\:   :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath>`
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_id
                                            
                                            	Path ID of path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "multicast-intact-backup-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-backup-path" : ("route_backup_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath), "sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                                self._child_list_classes = {}

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_id = YLeaf(YType.uint16, "route-path-id")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.route_backup_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath()
                                                self.route_backup_path.parent = self
                                                self._children_name_map["route_backup_path"] = "route-backup-path"
                                                self._children_yang_names.add("route-backup-path")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")
                                                self._segment_path = lambda: "route-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath, ['lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_id', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                            class RouteBackupPath(Entity):
                                                """
                                                Backup Path Info
                                                
                                                .. attribute:: backup_metric
                                                
                                                	Metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_remote_lfa
                                                
                                                	IP address of remote LFA
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of    :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair>`
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_route_interface_name
                                                
                                                	Next hop Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: backup_route_next_hop_address
                                                
                                                	Nexthop IP address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_route_source
                                                
                                                	IP address of source of route
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: backup_tunnel_interface_name
                                                
                                                	Backup Tunnel Interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: downstream
                                                
                                                	Downstream
                                                	**type**\:  bool
                                                
                                                .. attribute:: line_card_disjoint
                                                
                                                	Line Card Disjoint
                                                	**type**\:  bool
                                                
                                                .. attribute:: node_protect
                                                
                                                	Node Protect
                                                	**type**\:  bool
                                                
                                                .. attribute:: primary_path
                                                
                                                	Primary Path
                                                	**type**\:  bool
                                                
                                                .. attribute:: srlg_disjoint
                                                
                                                	SRLG Disjoint
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, self).__init__()

                                                    self.yang_name = "route-backup-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"backup-repair" : ("backup_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair)}

                                                    self.backup_metric = YLeaf(YType.uint32, "backup-metric")

                                                    self.backup_remote_lfa = YLeaf(YType.str, "backup-remote-lfa")

                                                    self.backup_repair_list_size = YLeaf(YType.uint32, "backup-repair-list-size")

                                                    self.backup_route_interface_name = YLeaf(YType.str, "backup-route-interface-name")

                                                    self.backup_route_next_hop_address = YLeaf(YType.str, "backup-route-next-hop-address")

                                                    self.backup_route_source = YLeaf(YType.str, "backup-route-source")

                                                    self.backup_tunnel_interface_name = YLeaf(YType.str, "backup-tunnel-interface-name")

                                                    self.downstream = YLeaf(YType.boolean, "downstream")

                                                    self.line_card_disjoint = YLeaf(YType.boolean, "line-card-disjoint")

                                                    self.node_protect = YLeaf(YType.boolean, "node-protect")

                                                    self.primary_path = YLeaf(YType.boolean, "primary-path")

                                                    self.srlg_disjoint = YLeaf(YType.boolean, "srlg-disjoint")

                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "route-backup-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath, ['backup_metric', 'backup_remote_lfa', 'backup_repair_list_size', 'backup_route_interface_name', 'backup_route_next_hop_address', 'backup_route_source', 'backup_tunnel_interface_name', 'downstream', 'line_card_disjoint', 'node_protect', 'primary_path', 'srlg_disjoint'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "route-backup-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "backup-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.RouteBackupPath.BackupRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)
                                                    self._segment_path = lambda: "sr-microloop-avoidance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "microloop-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactBackupRouteAreas.MulticastIntactBackupRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class MulticastIntactRouteAreas(Entity):
                                    """
                                    OSPF Area multicast\-intact included route
                                    entry
                                    
                                    .. attribute:: multicast_intact_route_area
                                    
                                    	A Muliticast OSPF route in an area
                                    	**type**\: list of    :py:class:`MulticastIntactRouteArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, self).__init__()

                                        self.yang_name = "multicast-intact-route-areas"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"multicast-intact-route-area" : ("multicast_intact_route_area", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea)}

                                        self.multicast_intact_route_area = YList(self)
                                        self._segment_path = lambda: "multicast-intact-route-areas"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas, [], name, value)


                                    class MulticastIntactRouteArea(Entity):
                                        """
                                        A Muliticast OSPF route in an area
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, self).__init__()

                                            self.yang_name = "multicast-intact-route-area"
                                            self.yang_parent_name = "multicast-intact-route-areas"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo)}
                                            self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath)}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)
                                            self._segment_path = lambda: "multicast-intact-route-area"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "multicast-intact-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime)}
                                                self._child_list_classes = {}

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")
                                                self._segment_path = lambda: "route-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-fail-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "multicast-intact-route-area"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath)}
                                                self._child_list_classes = {}

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")
                                                self._segment_path = lambda: "route-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)
                                                    self._segment_path = lambda: "sr-microloop-avoidance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "microloop-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.MulticastIntactRouteAreas.MulticastIntactRouteArea.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class RouteAreaInformations(Entity):
                                    """
                                    OSPF Area Route Entry
                                    
                                    .. attribute:: route_area_information
                                    
                                    	An OSPF route
                                    	**type**\: list of    :py:class:`RouteAreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, self).__init__()

                                        self.yang_name = "route-area-informations"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"route-area-information" : ("route_area_information", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation)}

                                        self.route_area_information = YList(self)
                                        self._segment_path = lambda: "route-area-informations"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations, [], name, value)


                                    class RouteAreaInformation(Entity):
                                        """
                                        An OSPF route
                                        
                                        .. attribute:: prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix Length
                                        	**type**\:  int
                                        
                                        	**range:** 0..32
                                        
                                        .. attribute:: route_connected
                                        
                                        	If true, connected route
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_info
                                        
                                        	Route information
                                        	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo>`
                                        
                                        .. attribute:: route_metric
                                        
                                        	Metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_path
                                        
                                        	List of paths to this route
                                        	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath>`
                                        
                                        .. attribute:: route_prefix
                                        
                                        	Prefix
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: route_prefix_length
                                        
                                        	Prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_type
                                        
                                        	Route type
                                        	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, self).__init__()

                                            self.yang_name = "route-area-information"
                                            self.yang_parent_name = "route-area-informations"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo)}
                                            self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath)}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.route_connected = YLeaf(YType.boolean, "route-connected")

                                            self.route_metric = YLeaf(YType.uint32, "route-metric")

                                            self.route_prefix = YLeaf(YType.str, "route-prefix")

                                            self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                            self.route_type = YLeaf(YType.enumeration, "route-type")

                                            self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo()
                                            self.route_info.parent = self
                                            self._children_name_map["route_info"] = "route-info"
                                            self._children_yang_names.add("route-info")

                                            self.route_path = YList(self)
                                            self._segment_path = lambda: "route-area-information"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                        class RouteInfo(Entity):
                                            """
                                            Route information
                                            
                                            .. attribute:: route_area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_auto_excluded
                                            
                                            	If true, exclude from TE paths
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_fail_time
                                            
                                            	Last time update failed
                                            	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime>`
                                            
                                            .. attribute:: route_forward_distance
                                            
                                            	Forward distance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_rib_version
                                            
                                            	RIB version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_source
                                            
                                            	Protocol source
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_spf_priority
                                            
                                            	SPF priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_spf_version
                                            
                                            	SPF version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: route_srte_nbr_registered
                                            
                                            	SRTE registered neigbhor count on route
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_srte_prefix_registered
                                            
                                            	If true, SRTE registered prefix route
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_te_metric
                                            
                                            	TE metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_update_time
                                            
                                            	Last time updated
                                            	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, self).__init__()

                                                self.yang_name = "route-info"
                                                self.yang_parent_name = "route-area-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime)}
                                                self._child_list_classes = {}

                                                self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                                self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                                self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                                self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                                self.route_source = YLeaf(YType.uint16, "route-source")

                                                self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                                self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                                self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                                self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                                self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                                self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime()
                                                self.route_fail_time.parent = self
                                                self._children_name_map["route_fail_time"] = "route-fail-time"
                                                self._children_yang_names.add("route-fail-time")

                                                self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime()
                                                self.route_update_time.parent = self
                                                self._children_name_map["route_update_time"] = "route-update-time"
                                                self._children_yang_names.add("route-update-time")
                                                self._segment_path = lambda: "route-info"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                            class RouteFailTime(Entity):
                                                """
                                                Last time update failed
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, self).__init__()

                                                    self.yang_name = "route-fail-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-fail-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                            class RouteUpdateTime(Entity):
                                                """
                                                Last time updated
                                                
                                                .. attribute:: nanosecond
                                                
                                                	Nanosecond
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: second
                                                
                                                	Second
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, self).__init__()

                                                    self.yang_name = "route-update-time"
                                                    self.yang_parent_name = "route-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                                    self.second = YLeaf(YType.uint32, "second")
                                                    self._segment_path = lambda: "route-update-time"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                        class RoutePath(Entity):
                                            """
                                            List of paths to this route
                                            
                                            .. attribute:: area_format
                                            
                                            	Area format IP or uint32
                                            	**type**\:  bool
                                            
                                            .. attribute:: area_id
                                            
                                            	Area ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type, see RFC2328 etc
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_interface_name
                                            
                                            	Next hop Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: route_lsaid
                                            
                                            	LSA ID, see RFC2328
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_metric
                                            
                                            	Metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_next_hop_address
                                            
                                            	Nexthop IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: route_path_is_mcast_intact
                                            
                                            	Multicast\-intact path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_path_is_ucmp_path
                                            
                                            	UCMP path
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_source
                                            
                                            	IP address of source of route
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sr_microloop_avoidance_path
                                            
                                            	SR Microloop avoidance Path Info
                                            	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, self).__init__()

                                                self.yang_name = "route-path"
                                                self.yang_parent_name = "route-area-information"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath)}
                                                self._child_list_classes = {}

                                                self.area_format = YLeaf(YType.boolean, "area-format")

                                                self.area_id = YLeaf(YType.uint32, "area-id")

                                                self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                                self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                                self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                                self.route_metric = YLeaf(YType.uint32, "route-metric")

                                                self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                                self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                                self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                                self.route_source = YLeaf(YType.str, "route-source")

                                                self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath()
                                                self.sr_microloop_avoidance_path.parent = self
                                                self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                                self._children_yang_names.add("sr-microloop-avoidance-path")
                                                self._segment_path = lambda: "route-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                            class SrMicroloopAvoidancePath(Entity):
                                                """
                                                SR Microloop avoidance Path Info
                                                
                                                .. attribute:: microloop_repair
                                                
                                                	Microloop Repair List
                                                	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                                
                                                .. attribute:: microloop_repair_list_size
                                                
                                                	Microloop Repair List Size
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: microloop_strict_spf
                                                
                                                	Strict SPF SID
                                                	**type**\:  bool
                                                
                                                .. attribute:: microloop_tunnel_interface_name
                                                
                                                	Microloop Tunnel Interface name
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv4-ospf-oper'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                                    self.yang_name = "sr-microloop-avoidance-path"
                                                    self.yang_parent_name = "route-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                                    self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                                    self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                                    self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                                    self.microloop_repair = YList(self)
                                                    self._segment_path = lambda: "sr-microloop-avoidance-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                                class MicroloopRepair(Entity):
                                                    """
                                                    Microloop Repair List
                                                    
                                                    .. attribute:: repair_element_id
                                                    
                                                    	Repair Element ID
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv4-ospf-oper'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                        self.yang_name = "microloop-repair"
                                                        self.yang_parent_name = "sr-microloop-avoidance-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                        self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                        self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                        self._segment_path = lambda: "microloop-repair"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.RouteAreaInformations.RouteAreaInformation.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                                class SummaryAreaInformation(Entity):
                                    """
                                    OSPF route summary statistics
                                    
                                    .. attribute:: common
                                    
                                    	OSPF route summary Information
                                    	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common>`
                                    
                                    .. attribute:: failure_address
                                    
                                    	Last failed address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: failure_time
                                    
                                    	Last time failed
                                    	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime>`
                                    
                                    .. attribute:: failures
                                    
                                    	RIB failure count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, self).__init__()

                                        self.yang_name = "summary-area-information"
                                        self.yang_parent_name = "route-area"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"common" : ("common", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common), "failure-time" : ("failure_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime)}
                                        self._child_list_classes = {}

                                        self.failure_address = YLeaf(YType.str, "failure-address")

                                        self.failures = YLeaf(YType.uint32, "failures")

                                        self.common = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common()
                                        self.common.parent = self
                                        self._children_name_map["common"] = "common"
                                        self._children_yang_names.add("common")

                                        self.failure_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime()
                                        self.failure_time.parent = self
                                        self._children_name_map["failure_time"] = "failure-time"
                                        self._children_yang_names.add("failure-time")
                                        self._segment_path = lambda: "summary-area-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation, ['failure_address', 'failures'], name, value)


                                    class Common(Entity):
                                        """
                                        OSPF route summary Information
                                        
                                        .. attribute:: external_nssa_type1s
                                        
                                        	External NSSA type 1 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_nssa_type2s
                                        
                                        	External NSSA type 2 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_type1s
                                        
                                        	External type 1 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_type2s
                                        
                                        	External type 2 count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_areas
                                        
                                        	Inter\-area count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_areas
                                        
                                        	Intra\-area count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: total
                                        
                                        	Total count
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, self).__init__()

                                            self.yang_name = "common"
                                            self.yang_parent_name = "summary-area-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                            self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                            self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                            self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                            self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                            self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                            self.total = YLeaf(YType.uint32, "total")
                                            self._segment_path = lambda: "common"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.Common, ['external_nssa_type1s', 'external_nssa_type2s', 'external_type1s', 'external_type2s', 'inter_areas', 'intra_areas', 'total'], name, value)


                                    class FailureTime(Entity):
                                        """
                                        Last time failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, self).__init__()

                                            self.yang_name = "failure-time"
                                            self.yang_parent_name = "summary-area-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "failure-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteAreas.RouteArea.SummaryAreaInformation.FailureTime, ['nanosecond', 'second'], name, value)


                        class RouteTable(Entity):
                            """
                            OSPF Route Table
                            
                            .. attribute:: route
                            
                            	An OSPF route
                            	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable, self).__init__()

                                self.yang_name = "route-table"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"route" : ("route", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route)}

                                self.route = YList(self)
                                self._segment_path = lambda: "route-table"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable, [], name, value)


                            class Route(Entity):
                                """
                                An OSPF route
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\:  int
                                
                                	**range:** 0..32
                                
                                .. attribute:: route_connected
                                
                                	If true, connected route
                                	**type**\:  bool
                                
                                .. attribute:: route_info
                                
                                	Route information
                                	**type**\:   :py:class:`RouteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo>`
                                
                                .. attribute:: route_metric
                                
                                	Metric
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path
                                
                                	List of paths to this route
                                	**type**\: list of    :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath>`
                                
                                .. attribute:: route_prefix
                                
                                	Prefix
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_prefix_length
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\:   :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.OspfRoute>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route, self).__init__()

                                    self.yang_name = "route"
                                    self.yang_parent_name = "route-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"route-info" : ("route_info", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo)}
                                    self._child_list_classes = {"route-path" : ("route_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath)}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.route_connected = YLeaf(YType.boolean, "route-connected")

                                    self.route_metric = YLeaf(YType.uint32, "route-metric")

                                    self.route_prefix = YLeaf(YType.str, "route-prefix")

                                    self.route_prefix_length = YLeaf(YType.uint32, "route-prefix-length")

                                    self.route_type = YLeaf(YType.enumeration, "route-type")

                                    self.route_info = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo()
                                    self.route_info.parent = self
                                    self._children_name_map["route_info"] = "route-info"
                                    self._children_yang_names.add("route-info")

                                    self.route_path = YList(self)
                                    self._segment_path = lambda: "route"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route, ['prefix', 'prefix_length', 'route_connected', 'route_metric', 'route_prefix', 'route_prefix_length', 'route_type'], name, value)


                                class RouteInfo(Entity):
                                    """
                                    Route information
                                    
                                    .. attribute:: route_area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_auto_excluded
                                    
                                    	If true, exclude from TE paths
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_fail_time
                                    
                                    	Last time update failed
                                    	**type**\:   :py:class:`RouteFailTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime>`
                                    
                                    .. attribute:: route_forward_distance
                                    
                                    	Forward distance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_rib_version
                                    
                                    	RIB version
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_source
                                    
                                    	Protocol source
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_spf_priority
                                    
                                    	SPF priority
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_spf_version
                                    
                                    	SPF version
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: route_srte_nbr_registered
                                    
                                    	SRTE registered neigbhor count on route
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: route_srte_prefix_registered
                                    
                                    	If true, SRTE registered prefix route
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_te_metric
                                    
                                    	TE metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_update_time
                                    
                                    	Last time updated
                                    	**type**\:   :py:class:`RouteUpdateTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo, self).__init__()

                                        self.yang_name = "route-info"
                                        self.yang_parent_name = "route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"route-fail-time" : ("route_fail_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime), "route-update-time" : ("route_update_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime)}
                                        self._child_list_classes = {}

                                        self.route_area_id = YLeaf(YType.uint32, "route-area-id")

                                        self.route_auto_excluded = YLeaf(YType.boolean, "route-auto-excluded")

                                        self.route_forward_distance = YLeaf(YType.uint32, "route-forward-distance")

                                        self.route_rib_version = YLeaf(YType.uint32, "route-rib-version")

                                        self.route_source = YLeaf(YType.uint16, "route-source")

                                        self.route_spf_priority = YLeaf(YType.uint8, "route-spf-priority")

                                        self.route_spf_version = YLeaf(YType.uint64, "route-spf-version")

                                        self.route_srte_nbr_registered = YLeaf(YType.uint16, "route-srte-nbr-registered")

                                        self.route_srte_prefix_registered = YLeaf(YType.boolean, "route-srte-prefix-registered")

                                        self.route_te_metric = YLeaf(YType.uint32, "route-te-metric")

                                        self.route_fail_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime()
                                        self.route_fail_time.parent = self
                                        self._children_name_map["route_fail_time"] = "route-fail-time"
                                        self._children_yang_names.add("route-fail-time")

                                        self.route_update_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime()
                                        self.route_update_time.parent = self
                                        self._children_name_map["route_update_time"] = "route-update-time"
                                        self._children_yang_names.add("route-update-time")
                                        self._segment_path = lambda: "route-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo, ['route_area_id', 'route_auto_excluded', 'route_forward_distance', 'route_rib_version', 'route_source', 'route_spf_priority', 'route_spf_version', 'route_srte_nbr_registered', 'route_srte_prefix_registered', 'route_te_metric'], name, value)


                                    class RouteFailTime(Entity):
                                        """
                                        Last time update failed
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, self).__init__()

                                            self.yang_name = "route-fail-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-fail-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteFailTime, ['nanosecond', 'second'], name, value)


                                    class RouteUpdateTime(Entity):
                                        """
                                        Last time updated
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nanosecond
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: second
                                        
                                        	Second
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, self).__init__()

                                            self.yang_name = "route-update-time"
                                            self.yang_parent_name = "route-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                            self.second = YLeaf(YType.uint32, "second")
                                            self._segment_path = lambda: "route-update-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RouteInfo.RouteUpdateTime, ['nanosecond', 'second'], name, value)


                                class RoutePath(Entity):
                                    """
                                    List of paths to this route
                                    
                                    .. attribute:: area_format
                                    
                                    	Area format IP or uint32
                                    	**type**\:  bool
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type, see RFC2328 etc
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: route_lsaid
                                    
                                    	LSA ID, see RFC2328
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_metric
                                    
                                    	Metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: route_path_is_mcast_intact
                                    
                                    	Multicast\-intact path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_path_is_ucmp_path
                                    
                                    	UCMP path
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_source
                                    
                                    	IP address of source of route
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sr_microloop_avoidance_path
                                    
                                    	SR Microloop avoidance Path Info
                                    	**type**\:   :py:class:`SrMicroloopAvoidancePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath, self).__init__()

                                        self.yang_name = "route-path"
                                        self.yang_parent_name = "route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"sr-microloop-avoidance-path" : ("sr_microloop_avoidance_path", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath)}
                                        self._child_list_classes = {}

                                        self.area_format = YLeaf(YType.boolean, "area-format")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.lsa_type = YLeaf(YType.uint8, "lsa-type")

                                        self.route_interface_name = YLeaf(YType.str, "route-interface-name")

                                        self.route_lsaid = YLeaf(YType.str, "route-lsaid")

                                        self.route_metric = YLeaf(YType.uint32, "route-metric")

                                        self.route_next_hop_address = YLeaf(YType.str, "route-next-hop-address")

                                        self.route_path_is_mcast_intact = YLeaf(YType.boolean, "route-path-is-mcast-intact")

                                        self.route_path_is_ucmp_path = YLeaf(YType.boolean, "route-path-is-ucmp-path")

                                        self.route_source = YLeaf(YType.str, "route-source")

                                        self.sr_microloop_avoidance_path = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath()
                                        self.sr_microloop_avoidance_path.parent = self
                                        self._children_name_map["sr_microloop_avoidance_path"] = "sr-microloop-avoidance-path"
                                        self._children_yang_names.add("sr-microloop-avoidance-path")
                                        self._segment_path = lambda: "route-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath, ['area_format', 'area_id', 'lsa_type', 'route_interface_name', 'route_lsaid', 'route_metric', 'route_next_hop_address', 'route_path_is_mcast_intact', 'route_path_is_ucmp_path', 'route_source'], name, value)


                                    class SrMicroloopAvoidancePath(Entity):
                                        """
                                        SR Microloop avoidance Path Info
                                        
                                        .. attribute:: microloop_repair
                                        
                                        	Microloop Repair List
                                        	**type**\: list of    :py:class:`MicroloopRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair>`
                                        
                                        .. attribute:: microloop_repair_list_size
                                        
                                        	Microloop Repair List Size
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: microloop_strict_spf
                                        
                                        	Strict SPF SID
                                        	**type**\:  bool
                                        
                                        .. attribute:: microloop_tunnel_interface_name
                                        
                                        	Microloop Tunnel Interface name
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, self).__init__()

                                            self.yang_name = "sr-microloop-avoidance-path"
                                            self.yang_parent_name = "route-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"microloop-repair" : ("microloop_repair", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair)}

                                            self.microloop_repair_list_size = YLeaf(YType.uint32, "microloop-repair-list-size")

                                            self.microloop_strict_spf = YLeaf(YType.boolean, "microloop-strict-spf")

                                            self.microloop_tunnel_interface_name = YLeaf(YType.str, "microloop-tunnel-interface-name")

                                            self.microloop_repair = YList(self)
                                            self._segment_path = lambda: "sr-microloop-avoidance-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath, ['microloop_repair_list_size', 'microloop_strict_spf', 'microloop_tunnel_interface_name'], name, value)


                                        class MicroloopRepair(Entity):
                                            """
                                            Microloop Repair List
                                            
                                            .. attribute:: repair_element_id
                                            
                                            	Repair Element ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: repair_element_type
                                            
                                            	Repair Element Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: repair_label
                                            
                                            	Repair Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-ospf-oper'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, self).__init__()

                                                self.yang_name = "microloop-repair"
                                                self.yang_parent_name = "sr-microloop-avoidance-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.repair_element_id = YLeaf(YType.str, "repair-element-id")

                                                self.repair_element_type = YLeaf(YType.uint32, "repair-element-type")

                                                self.repair_label = YLeaf(YType.uint32, "repair-label")
                                                self._segment_path = lambda: "microloop-repair"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.RouteTable.Route.RoutePath.SrMicroloopAvoidancePath.MicroloopRepair, ['repair_element_id', 'repair_element_type', 'repair_label'], name, value)


                        class SummaryInformation(Entity):
                            """
                            OSPF route summary statistics
                            
                            .. attribute:: common
                            
                            	OSPF route summary Information
                            	**type**\:   :py:class:`Common <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common>`
                            
                            .. attribute:: failure_address
                            
                            	Last failed address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: failure_time
                            
                            	Last time failed
                            	**type**\:   :py:class:`FailureTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime>`
                            
                            .. attribute:: failures
                            
                            	RIB failure count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation, self).__init__()

                                self.yang_name = "summary-information"
                                self.yang_parent_name = "route-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"common" : ("common", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common), "failure-time" : ("failure_time", Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime)}
                                self._child_list_classes = {}

                                self.failure_address = YLeaf(YType.str, "failure-address")

                                self.failures = YLeaf(YType.uint32, "failures")

                                self.common = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common()
                                self.common.parent = self
                                self._children_name_map["common"] = "common"
                                self._children_yang_names.add("common")

                                self.failure_time = Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime()
                                self.failure_time.parent = self
                                self._children_name_map["failure_time"] = "failure-time"
                                self._children_yang_names.add("failure-time")
                                self._segment_path = lambda: "summary-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation, ['failure_address', 'failures'], name, value)


                            class Common(Entity):
                                """
                                OSPF route summary Information
                                
                                .. attribute:: external_nssa_type1s
                                
                                	External NSSA type 1 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_nssa_type2s
                                
                                	External NSSA type 2 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_type1s
                                
                                	External type 1 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_type2s
                                
                                	External type 2 count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_areas
                                
                                	Inter\-area count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_areas
                                
                                	Intra\-area count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: total
                                
                                	Total count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common, self).__init__()

                                    self.yang_name = "common"
                                    self.yang_parent_name = "summary-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.external_nssa_type1s = YLeaf(YType.uint32, "external-nssa-type1s")

                                    self.external_nssa_type2s = YLeaf(YType.uint32, "external-nssa-type2s")

                                    self.external_type1s = YLeaf(YType.uint32, "external-type1s")

                                    self.external_type2s = YLeaf(YType.uint32, "external-type2s")

                                    self.inter_areas = YLeaf(YType.uint32, "inter-areas")

                                    self.intra_areas = YLeaf(YType.uint32, "intra-areas")

                                    self.total = YLeaf(YType.uint32, "total")
                                    self._segment_path = lambda: "common"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.Common, ['external_nssa_type1s', 'external_nssa_type2s', 'external_type1s', 'external_type2s', 'inter_areas', 'intra_areas', 'total'], name, value)


                            class FailureTime(Entity):
                                """
                                Last time failed
                                
                                .. attribute:: nanosecond
                                
                                	Nanosecond
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: second
                                
                                	Second
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime, self).__init__()

                                    self.yang_name = "failure-time"
                                    self.yang_parent_name = "summary-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                    self.second = YLeaf(YType.uint32, "second")
                                    self._segment_path = lambda: "failure-time"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.RouteInformation.SummaryInformation.FailureTime, ['nanosecond', 'second'], name, value)


                    class Statistics(Entity):
                        """
                        Container for Statistics
                        
                        .. attribute:: frr_stats
                        
                        	OSPF fast\-reroute statistics
                        	**type**\:   :py:class:`FrrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats>`
                        
                        .. attribute:: interface_stats_entries
                        
                        	Statistics innformation Interface table
                        	**type**\:   :py:class:`InterfaceStatsEntries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries>`
                        
                        .. attribute:: issu_stats
                        
                        	OSPF ISSU statistics
                        	**type**\:   :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats>`
                        
                        .. attribute:: nsr_pl_stats
                        
                        	OSPF NSR packet library statistics
                        	**type**\:   :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats>`
                        
                        .. attribute:: nsr_stats
                        
                        	OSPF NSR thread statistics
                        	**type**\:   :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats>`
                        
                        .. attribute:: protocol_stats
                        
                        	OSPF Protocol statistics
                        	**type**\:   :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats>`
                        
                        .. attribute:: raw_io_stats
                        
                        	OSPF RAW IO statistics
                        	**type**\:   :py:class:`RawIoStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats>`
                        
                        .. attribute:: rib_batch_stats
                        
                        	Stats concerning RIB route updates using the Batching API
                        	**type**\:   :py:class:`RibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats>`
                        
                        .. attribute:: rib_thread_stats
                        
                        	OSPF RIB thread statistics
                        	**type**\:   :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats>`
                        
                        .. attribute:: spf_stats
                        
                        	OSPF SPF statistics
                        	**type**\:   :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats>`
                        
                        .. attribute:: te_stats
                        
                        	OSPF TE IO statistics
                        	**type**\:   :py:class:`TeStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"frr-stats" : ("frr_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats), "interface-stats-entries" : ("interface_stats_entries", Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries), "issu-stats" : ("issu_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats), "nsr-pl-stats" : ("nsr_pl_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats), "nsr-stats" : ("nsr_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats), "protocol-stats" : ("protocol_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats), "raw-io-stats" : ("raw_io_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats), "rib-batch-stats" : ("rib_batch_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats), "rib-thread-stats" : ("rib_thread_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats), "spf-stats" : ("spf_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats), "te-stats" : ("te_stats", Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats)}
                            self._child_list_classes = {}

                            self.frr_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats()
                            self.frr_stats.parent = self
                            self._children_name_map["frr_stats"] = "frr-stats"
                            self._children_yang_names.add("frr-stats")

                            self.interface_stats_entries = Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries()
                            self.interface_stats_entries.parent = self
                            self._children_name_map["interface_stats_entries"] = "interface-stats-entries"
                            self._children_yang_names.add("interface-stats-entries")

                            self.issu_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats()
                            self.issu_stats.parent = self
                            self._children_name_map["issu_stats"] = "issu-stats"
                            self._children_yang_names.add("issu-stats")

                            self.nsr_pl_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats()
                            self.nsr_pl_stats.parent = self
                            self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"
                            self._children_yang_names.add("nsr-pl-stats")

                            self.nsr_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats()
                            self.nsr_stats.parent = self
                            self._children_name_map["nsr_stats"] = "nsr-stats"
                            self._children_yang_names.add("nsr-stats")

                            self.protocol_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats()
                            self.protocol_stats.parent = self
                            self._children_name_map["protocol_stats"] = "protocol-stats"
                            self._children_yang_names.add("protocol-stats")

                            self.raw_io_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats()
                            self.raw_io_stats.parent = self
                            self._children_name_map["raw_io_stats"] = "raw-io-stats"
                            self._children_yang_names.add("raw-io-stats")

                            self.rib_batch_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats()
                            self.rib_batch_stats.parent = self
                            self._children_name_map["rib_batch_stats"] = "rib-batch-stats"
                            self._children_yang_names.add("rib-batch-stats")

                            self.rib_thread_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats()
                            self.rib_thread_stats.parent = self
                            self._children_name_map["rib_thread_stats"] = "rib-thread-stats"
                            self._children_yang_names.add("rib-thread-stats")

                            self.spf_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats()
                            self.spf_stats.parent = self
                            self._children_name_map["spf_stats"] = "spf-stats"
                            self._children_yang_names.add("spf-stats")

                            self.te_stats = Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats()
                            self.te_stats.parent = self
                            self._children_name_map["te_stats"] = "te-stats"
                            self._children_yang_names.add("te-stats")
                            self._segment_path = lambda: "statistics"


                        class FrrStats(Entity):
                            """
                            OSPF fast\-reroute statistics
                            
                            .. attribute:: fs_paths
                            
                            	Number of IPFRR paths
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fs_paths_eligible
                            
                            	Number of paths enabled for protection
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fs_paths_protected
                            
                            	Number of paths protected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats, self).__init__()

                                self.yang_name = "frr-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fs_paths = YLeaf(YType.uint32, "fs-paths")

                                self.fs_paths_eligible = YLeaf(YType.uint32, "fs-paths-eligible")

                                self.fs_paths_protected = YLeaf(YType.uint32, "fs-paths-protected")
                                self._segment_path = lambda: "frr-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.FrrStats, ['fs_paths', 'fs_paths_eligible', 'fs_paths_protected'], name, value)


                        class InterfaceStatsEntries(Entity):
                            """
                            Statistics innformation Interface table
                            
                            .. attribute:: interface_stats_entry
                            
                            	Statistics information for a specific interface
                            	**type**\: list of    :py:class:`InterfaceStatsEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries, self).__init__()

                                self.yang_name = "interface-stats-entries"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"interface-stats-entry" : ("interface_stats_entry", Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry)}

                                self.interface_stats_entry = YList(self)
                                self._segment_path = lambda: "interface-stats-entries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries, [], name, value)


                            class InterfaceStatsEntry(Entity):
                                """
                                Statistics information for a specific interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: handle
                                
                                	interface handle type
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: if_entry
                                
                                	interface entry
                                	**type**\: list of    :py:class:`IfEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry>`
                                
                                .. attribute:: if_name_str
                                
                                	interface name
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, self).__init__()

                                    self.yang_name = "interface-stats-entry"
                                    self.yang_parent_name = "interface-stats-entries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"if-entry" : ("if_entry", Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry)}

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.handle = YLeaf(YType.str, "handle")

                                    self.if_name_str = YLeaf(YType.str, "if-name-str")

                                    self.if_entry = YList(self)
                                    self._segment_path = lambda: "interface-stats-entry" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry, ['interface_name', 'handle', 'if_name_str'], name, value)


                                class IfEntry(Entity):
                                    """
                                    interface entry
                                    
                                    .. attribute:: area_id
                                    
                                    	OSPF area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_id_str
                                    
                                    	OSPF aread id string
                                    	**type**\:  str
                                    
                                    .. attribute:: if_stat
                                    
                                    	OSPF interface statistics
                                    	**type**\: list of    :py:class:`IfStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat>`
                                    
                                    .. attribute:: madj_intf
                                    
                                    	OSPF madj interface
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, self).__init__()

                                        self.yang_name = "if-entry"
                                        self.yang_parent_name = "interface-stats-entry"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"if-stat" : ("if_stat", Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat)}

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.area_id_str = YLeaf(YType.str, "area-id-str")

                                        self.madj_intf = YLeaf(YType.boolean, "madj-intf")

                                        self.if_stat = YList(self)
                                        self._segment_path = lambda: "if-entry"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry, ['area_id', 'area_id_str', 'madj_intf'], name, value)


                                    class IfStat(Entity):
                                        """
                                        OSPF interface statistics
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, self).__init__()

                                            self.yang_name = "if-stat"
                                            self.yang_parent_name = "if-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "if-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.InterfaceStatsEntries.InterfaceStatsEntry.IfEntry.IfStat, ['entry'], name, value)


                        class IssuStats(Entity):
                            """
                            OSPF ISSU statistics
                            
                            .. attribute:: nsr_conn_to_active_attempts
                            
                            	nsr conn to active attempts
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_closes
                            
                            	nsr conn to active closes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_errors
                            
                            	nsr conn to active errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_fails
                            
                            	nsr conn to active fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_opens
                            
                            	nsr conn to active opens
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_fsm_state
                            
                            	nsr fsm state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_intf_seq_no
                            
                            	nsr intf seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_init_sync_pend_count
                            
                            	nsr lsa init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_lsa_qad_mdata_count
                            
                            	nsr lsa qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_qad_qid
                            
                            	nsr lsa qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_mtu
                            
                            	nsr mtu
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_init_sync_pend_count
                            
                            	nsr nbr init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_nbr_qad_mdata_count
                            
                            	nsr nbr qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_qad_qid
                            
                            	nsr nbr qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_seq_no
                            
                            	nsr nbr seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nodeid
                            
                            	nsr nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_nodeid
                            
                            	nsr peer nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_version
                            
                            	nsr peer version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_rev
                            
                            	nsr rev
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_rtr_thd_sched
                            
                            	nsr rtr thd sched
                            	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched>`
                            
                            .. attribute:: nsr_thd_sched
                            
                            	nsr thd sched
                            	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched>`
                            
                            .. attribute:: nsr_tmr_quant
                            
                            	nsr tmr quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_version
                            
                            	nsr version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats, self).__init__()

                                self.yang_name = "issu-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"nsr-rtr-thd-sched" : ("nsr_rtr_thd_sched", Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched), "nsr-thd-sched" : ("nsr_thd_sched", Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched)}
                                self._child_list_classes = {}

                                self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                                self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                                self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                                self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                                self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                                self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                                self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                                self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                                self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                                self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                                self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                                self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                                self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                                self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                                self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                                self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                                self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                                self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                                self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                                self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                                self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                self.nsr_rtr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched()
                                self.nsr_rtr_thd_sched.parent = self
                                self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                self._children_yang_names.add("nsr-rtr-thd-sched")

                                self.nsr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched()
                                self.nsr_thd_sched.parent = self
                                self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                self._children_yang_names.add("nsr-thd-sched")
                                self._segment_path = lambda: "issu-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats, ['nsr_conn_to_active_attempts', 'nsr_conn_to_active_closes', 'nsr_conn_to_active_errors', 'nsr_conn_to_active_fails', 'nsr_conn_to_active_opens', 'nsr_fsm_state', 'nsr_intf_seq_no', 'nsr_lsa_init_sync_pend_count', 'nsr_lsa_qad_mdata_count', 'nsr_lsa_qad_qid', 'nsr_mtu', 'nsr_nbr_init_sync_pend_count', 'nsr_nbr_qad_mdata_count', 'nsr_nbr_qad_qid', 'nsr_nbr_seq_no', 'nsr_nodeid', 'nsr_peer_nodeid', 'nsr_peer_version', 'nsr_rev', 'nsr_tmr_quant', 'nsr_version'], name, value)


                            class NsrRtrThdSched(Entity):
                                """
                                nsr rtr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched, self).__init__()

                                    self.yang_name = "nsr-rtr-thd-sched"
                                    self.yang_parent_name = "issu-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri)}

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)
                                    self._segment_path = lambda: "nsr-rtr-thd-sched"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-rtr-thd-sched"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                        self._segment_path = lambda: "nsr-pri"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrRtrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                            class NsrThdSched(Entity):
                                """
                                nsr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched, self).__init__()

                                    self.yang_name = "nsr-thd-sched"
                                    self.yang_parent_name = "issu-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri)}

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)
                                    self._segment_path = lambda: "nsr-thd-sched"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-thd-sched"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                        self._segment_path = lambda: "nsr-pri"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.IssuStats.NsrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                        class NsrPlStats(Entity):
                            """
                            OSPF NSR packet library statistics
                            
                            .. attribute:: ncd_pri
                            
                            	ncd pri
                            	**type**\: list of    :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats, self).__init__()

                                self.yang_name = "nsr-pl-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ncd-pri" : ("ncd_pri", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri)}

                                self.ncd_pri = YList(self)
                                self._segment_path = lambda: "nsr-pl-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats, [], name, value)


                            class NcdPri(Entity):
                                """
                                ncd pri
                                
                                .. attribute:: num_recv
                                
                                	Total recvd
                                	**type**\: list of    :py:class:`NumRecv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv>`
                                
                                .. attribute:: num_recv_drop
                                
                                	Recv Errors/drops
                                	**type**\: list of    :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                                
                                .. attribute:: num_sent
                                
                                	Total sent
                                	**type**\: list of    :py:class:`NumSent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent>`
                                
                                .. attribute:: num_sent_drop
                                
                                	Sent Error/drops
                                	**type**\: list of    :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri, self).__init__()

                                    self.yang_name = "ncd-pri"
                                    self.yang_parent_name = "nsr-pl-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"num-recv" : ("num_recv", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv), "num-recv-drop" : ("num_recv_drop", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop), "num-sent" : ("num_sent", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent), "num-sent-drop" : ("num_sent_drop", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop)}

                                    self.num_recv = YList(self)
                                    self.num_recv_drop = YList(self)
                                    self.num_sent = YList(self)
                                    self.num_sent_drop = YList(self)
                                    self._segment_path = lambda: "ncd-pri"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri, [], name, value)


                                class NumRecv(Entity):
                                    """
                                    Total recvd
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv, self).__init__()

                                        self.yang_name = "num-recv"
                                        self.yang_parent_name = "ncd-pri"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint64, "entry")
                                        self._segment_path = lambda: "num-recv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecv, ['entry'], name, value)


                                class NumRecvDrop(Entity):
                                    """
                                    Recv Errors/drops
                                    
                                    .. attribute:: nsr_pl_recv_drop_array
                                    
                                    	nsr pl recv drop array
                                    	**type**\: list of    :py:class:`NsrPlRecvDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__init__()

                                        self.yang_name = "num-recv-drop"
                                        self.yang_parent_name = "ncd-pri"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"nsr-pl-recv-drop-array" : ("nsr_pl_recv_drop_array", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray)}

                                        self.nsr_pl_recv_drop_array = YList(self)
                                        self._segment_path = lambda: "num-recv-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop, [], name, value)


                                    class NsrPlRecvDropArray(Entity):
                                        """
                                        nsr pl recv drop array
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, self).__init__()

                                            self.yang_name = "nsr-pl-recv-drop-array"
                                            self.yang_parent_name = "num-recv-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "nsr-pl-recv-drop-array"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumRecvDrop.NsrPlRecvDropArray, ['entry'], name, value)


                                class NumSent(Entity):
                                    """
                                    Total sent
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent, self).__init__()

                                        self.yang_name = "num-sent"
                                        self.yang_parent_name = "ncd-pri"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint64, "entry")
                                        self._segment_path = lambda: "num-sent"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSent, ['entry'], name, value)


                                class NumSentDrop(Entity):
                                    """
                                    Sent Error/drops
                                    
                                    .. attribute:: nsr_pl_send_drop_array
                                    
                                    	nsr pl send drop array
                                    	**type**\: list of    :py:class:`NsrPlSendDropArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__init__()

                                        self.yang_name = "num-sent-drop"
                                        self.yang_parent_name = "ncd-pri"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"nsr-pl-send-drop-array" : ("nsr_pl_send_drop_array", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray)}

                                        self.nsr_pl_send_drop_array = YList(self)
                                        self._segment_path = lambda: "num-sent-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop, [], name, value)


                                    class NsrPlSendDropArray(Entity):
                                        """
                                        nsr pl send drop array
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, self).__init__()

                                            self.yang_name = "nsr-pl-send-drop-array"
                                            self.yang_parent_name = "num-sent-drop"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "nsr-pl-send-drop-array"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrPlStats.NcdPri.NumSentDrop.NsrPlSendDropArray, ['entry'], name, value)


                        class NsrStats(Entity):
                            """
                            OSPF NSR thread statistics
                            
                            .. attribute:: nsr_conn_to_active_attempts
                            
                            	nsr conn to active attempts
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_closes
                            
                            	nsr conn to active closes
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_errors
                            
                            	nsr conn to active errors
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_fails
                            
                            	nsr conn to active fails
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_conn_to_active_opens
                            
                            	nsr conn to active opens
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_fsm_state
                            
                            	nsr fsm state
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_intf_seq_no
                            
                            	nsr intf seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_init_sync_pend_count
                            
                            	nsr lsa init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_lsa_qad_mdata_count
                            
                            	nsr lsa qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_lsa_qad_qid
                            
                            	nsr lsa qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_mtu
                            
                            	nsr mtu
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_init_sync_pend_count
                            
                            	nsr nbr init sync pend count
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_nbr_qad_mdata_count
                            
                            	nsr nbr qad mdata count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_qad_qid
                            
                            	nsr nbr qad qid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nbr_seq_no
                            
                            	nsr nbr seq no
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_nodeid
                            
                            	nsr nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_nodeid
                            
                            	nsr peer nodeid
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_peer_version
                            
                            	nsr peer version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_rev
                            
                            	nsr rev
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_rtr_thd_sched
                            
                            	nsr rtr thd sched
                            	**type**\:   :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched>`
                            
                            .. attribute:: nsr_thd_sched
                            
                            	nsr thd sched
                            	**type**\:   :py:class:`NsrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched>`
                            
                            .. attribute:: nsr_tmr_quant
                            
                            	nsr tmr quant
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: nsr_version
                            
                            	nsr version
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats, self).__init__()

                                self.yang_name = "nsr-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"nsr-rtr-thd-sched" : ("nsr_rtr_thd_sched", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched), "nsr-thd-sched" : ("nsr_thd_sched", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched)}
                                self._child_list_classes = {}

                                self.nsr_conn_to_active_attempts = YLeaf(YType.uint64, "nsr-conn-to-active-attempts")

                                self.nsr_conn_to_active_closes = YLeaf(YType.uint64, "nsr-conn-to-active-closes")

                                self.nsr_conn_to_active_errors = YLeaf(YType.uint64, "nsr-conn-to-active-errors")

                                self.nsr_conn_to_active_fails = YLeaf(YType.uint64, "nsr-conn-to-active-fails")

                                self.nsr_conn_to_active_opens = YLeaf(YType.uint64, "nsr-conn-to-active-opens")

                                self.nsr_fsm_state = YLeaf(YType.int32, "nsr-fsm-state")

                                self.nsr_intf_seq_no = YLeaf(YType.uint32, "nsr-intf-seq-no")

                                self.nsr_lsa_init_sync_pend_count = YLeaf(YType.int32, "nsr-lsa-init-sync-pend-count")

                                self.nsr_lsa_qad_mdata_count = YLeaf(YType.uint32, "nsr-lsa-qad-mdata-count")

                                self.nsr_lsa_qad_qid = YLeaf(YType.uint32, "nsr-lsa-qad-qid")

                                self.nsr_mtu = YLeaf(YType.uint32, "nsr-mtu")

                                self.nsr_nbr_init_sync_pend_count = YLeaf(YType.int32, "nsr-nbr-init-sync-pend-count")

                                self.nsr_nbr_qad_mdata_count = YLeaf(YType.uint32, "nsr-nbr-qad-mdata-count")

                                self.nsr_nbr_qad_qid = YLeaf(YType.uint32, "nsr-nbr-qad-qid")

                                self.nsr_nbr_seq_no = YLeaf(YType.uint32, "nsr-nbr-seq-no")

                                self.nsr_nodeid = YLeaf(YType.uint32, "nsr-nodeid")

                                self.nsr_peer_nodeid = YLeaf(YType.uint32, "nsr-peer-nodeid")

                                self.nsr_peer_version = YLeaf(YType.uint32, "nsr-peer-version")

                                self.nsr_rev = YLeaf(YType.int32, "nsr-rev")

                                self.nsr_tmr_quant = YLeaf(YType.int32, "nsr-tmr-quant")

                                self.nsr_version = YLeaf(YType.uint32, "nsr-version")

                                self.nsr_rtr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched()
                                self.nsr_rtr_thd_sched.parent = self
                                self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"
                                self._children_yang_names.add("nsr-rtr-thd-sched")

                                self.nsr_thd_sched = Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched()
                                self.nsr_thd_sched.parent = self
                                self._children_name_map["nsr_thd_sched"] = "nsr-thd-sched"
                                self._children_yang_names.add("nsr-thd-sched")
                                self._segment_path = lambda: "nsr-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats, ['nsr_conn_to_active_attempts', 'nsr_conn_to_active_closes', 'nsr_conn_to_active_errors', 'nsr_conn_to_active_fails', 'nsr_conn_to_active_opens', 'nsr_fsm_state', 'nsr_intf_seq_no', 'nsr_lsa_init_sync_pend_count', 'nsr_lsa_qad_mdata_count', 'nsr_lsa_qad_qid', 'nsr_mtu', 'nsr_nbr_init_sync_pend_count', 'nsr_nbr_qad_mdata_count', 'nsr_nbr_qad_qid', 'nsr_nbr_seq_no', 'nsr_nodeid', 'nsr_peer_nodeid', 'nsr_peer_version', 'nsr_rev', 'nsr_tmr_quant', 'nsr_version'], name, value)


                            class NsrRtrThdSched(Entity):
                                """
                                nsr rtr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched, self).__init__()

                                    self.yang_name = "nsr-rtr-thd-sched"
                                    self.yang_parent_name = "nsr-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri)}

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)
                                    self._segment_path = lambda: "nsr-rtr-thd-sched"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-rtr-thd-sched"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                        self._segment_path = lambda: "nsr-pri"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrRtrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                            class NsrThdSched(Entity):
                                """
                                nsr thd sched
                                
                                .. attribute:: nsr_bad_pulses_rx
                                
                                	nsr bad pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_in_q
                                
                                	nsr events in q
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: nsr_events_rx
                                
                                	nsr events rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_events_tx
                                
                                	nsr events tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_good_pulses_rx
                                
                                	nsr good pulses rx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pri
                                
                                	nsr pri
                                	**type**\: list of    :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri>`
                                
                                .. attribute:: nsr_pulse_quant
                                
                                	nsr pulse quant
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: nsr_pulse_tx_fails
                                
                                	nsr pulse tx fails
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: nsr_pulses_tx
                                
                                	nsr pulses tx
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched, self).__init__()

                                    self.yang_name = "nsr-thd-sched"
                                    self.yang_parent_name = "nsr-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"nsr-pri" : ("nsr_pri", Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri)}

                                    self.nsr_bad_pulses_rx = YLeaf(YType.uint64, "nsr-bad-pulses-rx")

                                    self.nsr_events_in_q = YLeaf(YType.uint32, "nsr-events-in-q")

                                    self.nsr_events_rx = YLeaf(YType.uint64, "nsr-events-rx")

                                    self.nsr_events_tx = YLeaf(YType.uint64, "nsr-events-tx")

                                    self.nsr_good_pulses_rx = YLeaf(YType.uint64, "nsr-good-pulses-rx")

                                    self.nsr_pulse_quant = YLeaf(YType.int32, "nsr-pulse-quant")

                                    self.nsr_pulse_tx_fails = YLeaf(YType.uint64, "nsr-pulse-tx-fails")

                                    self.nsr_pulses_tx = YLeaf(YType.uint64, "nsr-pulses-tx")

                                    self.nsr_pri = YList(self)
                                    self._segment_path = lambda: "nsr-thd-sched"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched, ['nsr_bad_pulses_rx', 'nsr_events_in_q', 'nsr_events_rx', 'nsr_events_tx', 'nsr_good_pulses_rx', 'nsr_pulse_quant', 'nsr_pulse_tx_fails', 'nsr_pulses_tx'], name, value)


                                class NsrPri(Entity):
                                    """
                                    nsr pri
                                    
                                    .. attribute:: nsr_sched_enq_fails
                                    
                                    	nsr sched enq fails
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_deqd
                                    
                                    	nsr sched evs deqd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_evs_in_q
                                    
                                    	nsr sched evs in q
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_evs_qd
                                    
                                    	nsr sched evs qd
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: nsr_sched_max_evs
                                    
                                    	nsr sched max evs
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_peak_q_len
                                    
                                    	nsr sched peak q len
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: nsr_sched_pri
                                    
                                    	nsr sched pri
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nsr_sched_quant
                                    
                                    	nsr sched quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nsr_sched_remain_quant
                                    
                                    	nsr sched remain quant
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri, self).__init__()

                                        self.yang_name = "nsr-pri"
                                        self.yang_parent_name = "nsr-thd-sched"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nsr_sched_enq_fails = YLeaf(YType.uint64, "nsr-sched-enq-fails")

                                        self.nsr_sched_evs_deqd = YLeaf(YType.uint64, "nsr-sched-evs-deqd")

                                        self.nsr_sched_evs_in_q = YLeaf(YType.uint16, "nsr-sched-evs-in-q")

                                        self.nsr_sched_evs_qd = YLeaf(YType.uint64, "nsr-sched-evs-qd")

                                        self.nsr_sched_max_evs = YLeaf(YType.uint16, "nsr-sched-max-evs")

                                        self.nsr_sched_peak_q_len = YLeaf(YType.uint16, "nsr-sched-peak-q-len")

                                        self.nsr_sched_pri = YLeaf(YType.uint32, "nsr-sched-pri")

                                        self.nsr_sched_quant = YLeaf(YType.uint8, "nsr-sched-quant")

                                        self.nsr_sched_remain_quant = YLeaf(YType.uint8, "nsr-sched-remain-quant")
                                        self._segment_path = lambda: "nsr-pri"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.NsrStats.NsrThdSched.NsrPri, ['nsr_sched_enq_fails', 'nsr_sched_evs_deqd', 'nsr_sched_evs_in_q', 'nsr_sched_evs_qd', 'nsr_sched_max_evs', 'nsr_sched_peak_q_len', 'nsr_sched_pri', 'nsr_sched_quant', 'nsr_sched_remain_quant'], name, value)


                        class ProtocolStats(Entity):
                            """
                            OSPF Protocol statistics
                            
                            .. attribute:: checksumerr
                            
                            	checksumerr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_ack
                            
                            	h input ack
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_dbdes
                            
                            	h input dbdes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_lsupd
                            
                            	h input lsupd
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: h_input_req
                            
                            	h input req
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_ack
                            
                            	input ack
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_ack_lsa
                            
                            	input ack lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_autherr
                            
                            	input autherr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_dbdes
                            
                            	input dbdes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_dbdes_lsa
                            
                            	input dbdes lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_hello
                            
                            	input hello
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_lsupd
                            
                            	input lsupd
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_lsupd_lsa
                            
                            	input lsupd lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_req
                            
                            	input req
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: input_req_lsa
                            
                            	input req lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inputs
                            
                            	inputs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_ack
                            
                            	output ack
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_ack_lsa
                            
                            	output ack lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_autherr
                            
                            	output autherr
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_dbdes
                            
                            	output dbdes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_dbdes_lsa
                            
                            	output dbdes lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_hello
                            
                            	output hello
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_lsupd
                            
                            	output lsupd
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_lsupd_lsa
                            
                            	output lsupd lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_req
                            
                            	output req
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: output_req_lsa
                            
                            	output req lsa
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: outputs
                            
                            	outputs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats, self).__init__()

                                self.yang_name = "protocol-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.checksumerr = YLeaf(YType.uint32, "checksumerr")

                                self.h_input_ack = YLeaf(YType.uint32, "h-input-ack")

                                self.h_input_dbdes = YLeaf(YType.uint32, "h-input-dbdes")

                                self.h_input_lsupd = YLeaf(YType.uint32, "h-input-lsupd")

                                self.h_input_req = YLeaf(YType.uint32, "h-input-req")

                                self.input_ack = YLeaf(YType.uint32, "input-ack")

                                self.input_ack_lsa = YLeaf(YType.uint32, "input-ack-lsa")

                                self.input_autherr = YLeaf(YType.uint32, "input-autherr")

                                self.input_dbdes = YLeaf(YType.uint32, "input-dbdes")

                                self.input_dbdes_lsa = YLeaf(YType.uint32, "input-dbdes-lsa")

                                self.input_hello = YLeaf(YType.uint32, "input-hello")

                                self.input_lsupd = YLeaf(YType.uint32, "input-lsupd")

                                self.input_lsupd_lsa = YLeaf(YType.uint32, "input-lsupd-lsa")

                                self.input_req = YLeaf(YType.uint32, "input-req")

                                self.input_req_lsa = YLeaf(YType.uint32, "input-req-lsa")

                                self.inputs = YLeaf(YType.uint32, "inputs")

                                self.output_ack = YLeaf(YType.uint32, "output-ack")

                                self.output_ack_lsa = YLeaf(YType.uint32, "output-ack-lsa")

                                self.output_autherr = YLeaf(YType.uint32, "output-autherr")

                                self.output_dbdes = YLeaf(YType.uint32, "output-dbdes")

                                self.output_dbdes_lsa = YLeaf(YType.uint32, "output-dbdes-lsa")

                                self.output_hello = YLeaf(YType.uint32, "output-hello")

                                self.output_lsupd = YLeaf(YType.uint32, "output-lsupd")

                                self.output_lsupd_lsa = YLeaf(YType.uint32, "output-lsupd-lsa")

                                self.output_req = YLeaf(YType.uint32, "output-req")

                                self.output_req_lsa = YLeaf(YType.uint32, "output-req-lsa")

                                self.outputs = YLeaf(YType.uint32, "outputs")
                                self._segment_path = lambda: "protocol-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.ProtocolStats, ['checksumerr', 'h_input_ack', 'h_input_dbdes', 'h_input_lsupd', 'h_input_req', 'input_ack', 'input_ack_lsa', 'input_autherr', 'input_dbdes', 'input_dbdes_lsa', 'input_hello', 'input_lsupd', 'input_lsupd_lsa', 'input_req', 'input_req_lsa', 'inputs', 'output_ack', 'output_ack_lsa', 'output_autherr', 'output_dbdes', 'output_dbdes_lsa', 'output_hello', 'output_lsupd', 'output_lsupd_lsa', 'output_req', 'output_req_lsa', 'outputs'], name, value)


                        class RawIoStats(Entity):
                            """
                            OSPF RAW IO statistics
                            
                            .. attribute:: disconnects
                            
                            	disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_bytes_rcv
                            
                            	in bytes rcv
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_no_mem_discarded
                            
                            	in no mem discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_raw_event
                            
                            	in raw event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_rcv
                            
                            	in rcv
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_short_msg_discarded
                            
                            	in short msg discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: in_standby_discarded
                            
                            	in standby discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nsr_not_ready_discarded
                            
                            	nsr not ready discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_bytes_sent
                            
                            	out bytes sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_ipv4_hdr_err_discarded
                            
                            	out ipv4 hdr err discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_no_conn_discarded
                            
                            	out no conn discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_no_pak_discarded
                            
                            	out no pak discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_null_src_discarded
                            
                            	out null src discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_send_pak_err_discarded
                            
                            	out send pak err discarded
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_sent
                            
                            	out sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: raw_connected
                            
                            	raw connected
                            	**type**\:  bool
                            
                            .. attribute:: sl_raw_connected
                            
                            	sl raw connected
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats, self).__init__()

                                self.yang_name = "raw-io-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.disconnects = YLeaf(YType.uint32, "disconnects")

                                self.in_bytes_rcv = YLeaf(YType.uint32, "in-bytes-rcv")

                                self.in_no_mem_discarded = YLeaf(YType.uint32, "in-no-mem-discarded")

                                self.in_raw_event = YLeaf(YType.uint32, "in-raw-event")

                                self.in_rcv = YLeaf(YType.uint32, "in-rcv")

                                self.in_short_msg_discarded = YLeaf(YType.uint32, "in-short-msg-discarded")

                                self.in_standby_discarded = YLeaf(YType.uint32, "in-standby-discarded")

                                self.nsr_not_ready_discarded = YLeaf(YType.uint32, "nsr-not-ready-discarded")

                                self.out_bytes_sent = YLeaf(YType.uint32, "out-bytes-sent")

                                self.out_ipv4_hdr_err_discarded = YLeaf(YType.uint32, "out-ipv4-hdr-err-discarded")

                                self.out_no_conn_discarded = YLeaf(YType.uint32, "out-no-conn-discarded")

                                self.out_no_pak_discarded = YLeaf(YType.uint32, "out-no-pak-discarded")

                                self.out_null_src_discarded = YLeaf(YType.uint32, "out-null-src-discarded")

                                self.out_send_pak_err_discarded = YLeaf(YType.uint32, "out-send-pak-err-discarded")

                                self.out_sent = YLeaf(YType.uint32, "out-sent")

                                self.raw_connected = YLeaf(YType.boolean, "raw-connected")

                                self.sl_raw_connected = YLeaf(YType.boolean, "sl-raw-connected")
                                self._segment_path = lambda: "raw-io-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RawIoStats, ['disconnects', 'in_bytes_rcv', 'in_no_mem_discarded', 'in_raw_event', 'in_rcv', 'in_short_msg_discarded', 'in_standby_discarded', 'nsr_not_ready_discarded', 'out_bytes_sent', 'out_ipv4_hdr_err_discarded', 'out_no_conn_discarded', 'out_no_pak_discarded', 'out_null_src_discarded', 'out_send_pak_err_discarded', 'out_sent', 'raw_connected', 'sl_raw_connected'], name, value)


                        class RibBatchStats(Entity):
                            """
                            Stats concerning RIB route updates using the
                            Batching API
                            
                            .. attribute:: priority_batch
                            
                            	priority batch
                            	**type**\: list of    :py:class:`PriorityBatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats, self).__init__()

                                self.yang_name = "rib-batch-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"priority-batch" : ("priority_batch", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch)}

                                self.priority_batch = YList(self)
                                self._segment_path = lambda: "rib-batch-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats, [], name, value)


                            class PriorityBatch(Entity):
                                """
                                priority batch
                                
                                .. attribute:: batches_sent
                                
                                	batches sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_add
                                
                                	lfas add
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_del
                                
                                	lfas del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_pending
                                
                                	lfas pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lfas_sent
                                
                                	lfas sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_routes
                                
                                	max routes
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_add
                                
                                	paths add
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_add_errs
                                
                                	paths add errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_del
                                
                                	paths del
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_del_errs
                                
                                	paths del errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_pending
                                
                                	paths pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: paths_sent
                                
                                	paths sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: priority_level
                                
                                	priority level
                                	**type**\:  str
                                
                                	**length:** 0..40
                                
                                .. attribute:: routes_pending
                                
                                	routes pending
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: routes_sent
                                
                                	routes sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch, self).__init__()

                                    self.yang_name = "priority-batch"
                                    self.yang_parent_name = "rib-batch-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.batches_sent = YLeaf(YType.uint32, "batches-sent")

                                    self.lfas_add = YLeaf(YType.uint32, "lfas-add")

                                    self.lfas_del = YLeaf(YType.uint32, "lfas-del")

                                    self.lfas_pending = YLeaf(YType.uint32, "lfas-pending")

                                    self.lfas_sent = YLeaf(YType.uint32, "lfas-sent")

                                    self.max_routes = YLeaf(YType.uint32, "max-routes")

                                    self.paths_add = YLeaf(YType.uint32, "paths-add")

                                    self.paths_add_errs = YLeaf(YType.uint32, "paths-add-errs")

                                    self.paths_del = YLeaf(YType.uint32, "paths-del")

                                    self.paths_del_errs = YLeaf(YType.uint32, "paths-del-errs")

                                    self.paths_pending = YLeaf(YType.uint32, "paths-pending")

                                    self.paths_sent = YLeaf(YType.uint32, "paths-sent")

                                    self.priority_level = YLeaf(YType.str, "priority-level")

                                    self.routes_pending = YLeaf(YType.uint32, "routes-pending")

                                    self.routes_sent = YLeaf(YType.uint32, "routes-sent")
                                    self._segment_path = lambda: "priority-batch"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibBatchStats.PriorityBatch, ['batches_sent', 'lfas_add', 'lfas_del', 'lfas_pending', 'lfas_sent', 'max_routes', 'paths_add', 'paths_add_errs', 'paths_del', 'paths_del_errs', 'paths_pending', 'paths_sent', 'priority_level', 'routes_pending', 'routes_sent'], name, value)


                        class RibThreadStats(Entity):
                            """
                            OSPF RIB thread statistics
                            
                            .. attribute:: internalwq
                            
                            	internalwq
                            	**type**\:   :py:class:`Internalwq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq>`
                            
                            .. attribute:: ribqueue
                            
                            	ribqueue
                            	**type**\: list of    :py:class:`Ribqueue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats, self).__init__()

                                self.yang_name = "rib-thread-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"internalwq" : ("internalwq", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq)}
                                self._child_list_classes = {"ribqueue" : ("ribqueue", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue)}

                                self.internalwq = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq()
                                self.internalwq.parent = self
                                self._children_name_map["internalwq"] = "internalwq"
                                self._children_yang_names.add("internalwq")

                                self.ribqueue = YList(self)
                                self._segment_path = lambda: "rib-thread-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats, [], name, value)


                            class Internalwq(Entity):
                                """
                                internalwq
                                
                                .. attribute:: priority_level
                                
                                	priority level
                                	**type**\:  str
                                
                                	**length:** 0..40
                                
                                .. attribute:: rib_base_clock
                                
                                	rib base clock
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: rib_base_time
                                
                                	rib base time
                                	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime>`
                                
                                .. attribute:: rib_dequeue_errs
                                
                                	rib dequeue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_after
                                
                                	rib drop after
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_before
                                
                                	rib drop before
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_conn
                                
                                	rib drop conn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_empty_batches
                                
                                	rib empty batches
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pfx_limit_errs
                                
                                	rib pfx limit errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pkts_sent
                                
                                	rib pkts sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_queue_errs
                                
                                	rib queue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_send_errs
                                
                                	rib send errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_signals
                                
                                	rib signals
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_table_not_created
                                
                                	rib table not created
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_version
                                
                                	rib version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_dqtime
                                
                                	wq dqtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: wq_len_cur
                                
                                	wq len cur
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_len_max
                                
                                	wq len max
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_thread_active
                                
                                	wq thread active
                                	**type**\:  bool
                                
                                .. attribute:: wq_total_dequeued
                                
                                	wq total dequeued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_total_queued
                                
                                	wq total queued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wqe_qtime
                                
                                	wqe qtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq, self).__init__()

                                    self.yang_name = "internalwq"
                                    self.yang_parent_name = "rib-thread-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rib-base-time" : ("rib_base_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime)}
                                    self._child_list_classes = {}

                                    self.priority_level = YLeaf(YType.str, "priority-level")

                                    self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                    self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                    self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                    self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                    self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                    self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                    self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                    self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                    self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                    self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                    self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                    self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                    self.rib_version = YLeaf(YType.uint32, "rib-version")

                                    self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                    self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                    self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                    self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                    self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                    self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                    self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                    self.rib_base_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime()
                                    self.rib_base_time.parent = self
                                    self._children_name_map["rib_base_time"] = "rib-base-time"
                                    self._children_yang_names.add("rib-base-time")
                                    self._segment_path = lambda: "internalwq"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq, ['priority_level', 'rib_base_clock', 'rib_dequeue_errs', 'rib_drop_after', 'rib_drop_before', 'rib_drop_conn', 'rib_empty_batches', 'rib_pfx_limit_errs', 'rib_pkts_sent', 'rib_queue_errs', 'rib_send_errs', 'rib_signals', 'rib_table_not_created', 'rib_version', 'wq_dqtime', 'wq_len_cur', 'wq_len_max', 'wq_thread_active', 'wq_total_dequeued', 'wq_total_queued', 'wqe_qtime'], name, value)


                                class RibBaseTime(Entity):
                                    """
                                    rib base time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, self).__init__()

                                        self.yang_name = "rib-base-time"
                                        self.yang_parent_name = "internalwq"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "rib-base-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Internalwq.RibBaseTime, ['nanosecond', 'second'], name, value)


                            class Ribqueue(Entity):
                                """
                                ribqueue
                                
                                .. attribute:: priority_level
                                
                                	priority level
                                	**type**\:  str
                                
                                	**length:** 0..40
                                
                                .. attribute:: rib_base_clock
                                
                                	rib base clock
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: rib_base_time
                                
                                	rib base time
                                	**type**\:   :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime>`
                                
                                .. attribute:: rib_dequeue_errs
                                
                                	rib dequeue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_after
                                
                                	rib drop after
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_before
                                
                                	rib drop before
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_drop_conn
                                
                                	rib drop conn
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_empty_batches
                                
                                	rib empty batches
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pfx_limit_errs
                                
                                	rib pfx limit errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_pkts_sent
                                
                                	rib pkts sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_queue_errs
                                
                                	rib queue errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_send_errs
                                
                                	rib send errs
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_signals
                                
                                	rib signals
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_table_not_created
                                
                                	rib table not created
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_version
                                
                                	rib version
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_dqtime
                                
                                	wq dqtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: wq_len_cur
                                
                                	wq len cur
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_len_max
                                
                                	wq len max
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: wq_thread_active
                                
                                	wq thread active
                                	**type**\:  bool
                                
                                .. attribute:: wq_total_dequeued
                                
                                	wq total dequeued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wq_total_queued
                                
                                	wq total queued
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wqe_qtime
                                
                                	wqe qtime
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue, self).__init__()

                                    self.yang_name = "ribqueue"
                                    self.yang_parent_name = "rib-thread-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"rib-base-time" : ("rib_base_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime)}
                                    self._child_list_classes = {}

                                    self.priority_level = YLeaf(YType.str, "priority-level")

                                    self.rib_base_clock = YLeaf(YType.uint64, "rib-base-clock")

                                    self.rib_dequeue_errs = YLeaf(YType.uint32, "rib-dequeue-errs")

                                    self.rib_drop_after = YLeaf(YType.uint32, "rib-drop-after")

                                    self.rib_drop_before = YLeaf(YType.uint32, "rib-drop-before")

                                    self.rib_drop_conn = YLeaf(YType.uint32, "rib-drop-conn")

                                    self.rib_empty_batches = YLeaf(YType.uint32, "rib-empty-batches")

                                    self.rib_pfx_limit_errs = YLeaf(YType.uint32, "rib-pfx-limit-errs")

                                    self.rib_pkts_sent = YLeaf(YType.uint32, "rib-pkts-sent")

                                    self.rib_queue_errs = YLeaf(YType.uint32, "rib-queue-errs")

                                    self.rib_send_errs = YLeaf(YType.uint32, "rib-send-errs")

                                    self.rib_signals = YLeaf(YType.uint32, "rib-signals")

                                    self.rib_table_not_created = YLeaf(YType.uint32, "rib-table-not-created")

                                    self.rib_version = YLeaf(YType.uint32, "rib-version")

                                    self.wq_dqtime = YLeaf(YType.uint64, "wq-dqtime")

                                    self.wq_len_cur = YLeaf(YType.int32, "wq-len-cur")

                                    self.wq_len_max = YLeaf(YType.int32, "wq-len-max")

                                    self.wq_thread_active = YLeaf(YType.boolean, "wq-thread-active")

                                    self.wq_total_dequeued = YLeaf(YType.uint32, "wq-total-dequeued")

                                    self.wq_total_queued = YLeaf(YType.uint32, "wq-total-queued")

                                    self.wqe_qtime = YLeaf(YType.uint64, "wqe-qtime")

                                    self.rib_base_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime()
                                    self.rib_base_time.parent = self
                                    self._children_name_map["rib_base_time"] = "rib-base-time"
                                    self._children_yang_names.add("rib-base-time")
                                    self._segment_path = lambda: "ribqueue"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue, ['priority_level', 'rib_base_clock', 'rib_dequeue_errs', 'rib_drop_after', 'rib_drop_before', 'rib_drop_conn', 'rib_empty_batches', 'rib_pfx_limit_errs', 'rib_pkts_sent', 'rib_queue_errs', 'rib_send_errs', 'rib_signals', 'rib_table_not_created', 'rib_version', 'wq_dqtime', 'wq_len_cur', 'wq_len_max', 'wq_thread_active', 'wq_total_dequeued', 'wq_total_queued', 'wqe_qtime'], name, value)


                                class RibBaseTime(Entity):
                                    """
                                    rib base time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, self).__init__()

                                        self.yang_name = "rib-base-time"
                                        self.yang_parent_name = "ribqueue"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "rib-base-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.RibThreadStats.Ribqueue.RibBaseTime, ['nanosecond', 'second'], name, value)


                        class SpfStats(Entity):
                            """
                            OSPF SPF statistics
                            
                            .. attribute:: os_ex_runtime
                            
                            	os ex runtime
                            	**type**\: list of    :py:class:`OsExRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime>`
                            
                            .. attribute:: os_runtime
                            
                            	os runtime
                            	**type**\: list of    :py:class:`OsRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime>`
                            
                            .. attribute:: os_sum_runtime
                            
                            	os sum runtime
                            	**type**\: list of    :py:class:`OsSumRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime>`
                            
                            .. attribute:: runtime
                            
                            	runtime
                            	**type**\: list of    :py:class:`Runtime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime>`
                            
                            .. attribute:: spf_header
                            
                            	spf header
                            	**type**\:   :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader>`
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats, self).__init__()

                                self.yang_name = "spf-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"spf-header" : ("spf_header", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader)}
                                self._child_list_classes = {"os-ex-runtime" : ("os_ex_runtime", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime), "os-runtime" : ("os_runtime", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime), "os-sum-runtime" : ("os_sum_runtime", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime), "runtime" : ("runtime", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime)}

                                self.spf_header = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader()
                                self.spf_header.parent = self
                                self._children_name_map["spf_header"] = "spf-header"
                                self._children_yang_names.add("spf-header")

                                self.os_ex_runtime = YList(self)
                                self.os_runtime = YList(self)
                                self.os_sum_runtime = YList(self)
                                self.runtime = YList(self)
                                self._segment_path = lambda: "spf-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats, [], name, value)


                            class OsExRuntime(Entity):
                                """
                                os ex runtime
                                
                                .. attribute:: sp_adv_rtr_id
                                
                                	sp adv rtr id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_addr
                                
                                	sp dest addr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_count
                                
                                	sp dest count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_duration
                                
                                	sp duration
                                	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration>`
                                
                                .. attribute:: sp_start_time
                                
                                	sp start time
                                	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime, self).__init__()

                                    self.yang_name = "os-ex-runtime"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sp-duration" : ("sp_duration", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration), "sp-start-time" : ("sp_start_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime)}
                                    self._child_list_classes = {}

                                    self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                    self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                    self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                    self.sp_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration()
                                    self.sp_duration.parent = self
                                    self._children_name_map["sp_duration"] = "sp-duration"
                                    self._children_yang_names.add("sp-duration")

                                    self.sp_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime()
                                    self.sp_start_time.parent = self
                                    self._children_name_map["sp_start_time"] = "sp-start-time"
                                    self._children_yang_names.add("sp-start-time")
                                    self._segment_path = lambda: "os-ex-runtime"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime, ['sp_adv_rtr_id', 'sp_dest_addr', 'sp_dest_count'], name, value)


                                class SpDuration(Entity):
                                    """
                                    sp duration
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration, self).__init__()

                                        self.yang_name = "sp-duration"
                                        self.yang_parent_name = "os-ex-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "sp-duration"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpDuration, ['nanosecond', 'second'], name, value)


                                class SpStartTime(Entity):
                                    """
                                    sp start time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime, self).__init__()

                                        self.yang_name = "sp-start-time"
                                        self.yang_parent_name = "os-ex-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "sp-start-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsExRuntime.SpStartTime, ['nanosecond', 'second'], name, value)


                            class OsRuntime(Entity):
                                """
                                os runtime
                                
                                .. attribute:: si_area_id_str
                                
                                	si area id str
                                	**type**\:  str
                                
                                .. attribute:: si_change_flags
                                
                                	si change flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: si_duration
                                
                                	si duration
                                	**type**\:   :py:class:`SiDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration>`
                                
                                .. attribute:: si_start_time
                                
                                	si start time
                                	**type**\:   :py:class:`SiStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime, self).__init__()

                                    self.yang_name = "os-runtime"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"si-duration" : ("si_duration", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration), "si-start-time" : ("si_start_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime)}
                                    self._child_list_classes = {}

                                    self.si_area_id_str = YLeaf(YType.str, "si-area-id-str")

                                    self.si_change_flags = YLeaf(YType.uint16, "si-change-flags")

                                    self.si_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration()
                                    self.si_duration.parent = self
                                    self._children_name_map["si_duration"] = "si-duration"
                                    self._children_yang_names.add("si-duration")

                                    self.si_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime()
                                    self.si_start_time.parent = self
                                    self._children_name_map["si_start_time"] = "si-start-time"
                                    self._children_yang_names.add("si-start-time")
                                    self._segment_path = lambda: "os-runtime"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime, ['si_area_id_str', 'si_change_flags'], name, value)


                                class SiDuration(Entity):
                                    """
                                    si duration
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration, self).__init__()

                                        self.yang_name = "si-duration"
                                        self.yang_parent_name = "os-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "si-duration"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiDuration, ['nanosecond', 'second'], name, value)


                                class SiStartTime(Entity):
                                    """
                                    si start time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime, self).__init__()

                                        self.yang_name = "si-start-time"
                                        self.yang_parent_name = "os-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "si-start-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsRuntime.SiStartTime, ['nanosecond', 'second'], name, value)


                            class OsSumRuntime(Entity):
                                """
                                os sum runtime
                                
                                .. attribute:: sp_adv_rtr_id
                                
                                	sp adv rtr id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_addr
                                
                                	sp dest addr
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_dest_count
                                
                                	sp dest count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_duration
                                
                                	sp duration
                                	**type**\:   :py:class:`SpDuration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration>`
                                
                                .. attribute:: sp_start_time
                                
                                	sp start time
                                	**type**\:   :py:class:`SpStartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime>`
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime, self).__init__()

                                    self.yang_name = "os-sum-runtime"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"sp-duration" : ("sp_duration", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration), "sp-start-time" : ("sp_start_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime)}
                                    self._child_list_classes = {}

                                    self.sp_adv_rtr_id = YLeaf(YType.uint32, "sp-adv-rtr-id")

                                    self.sp_dest_addr = YLeaf(YType.uint32, "sp-dest-addr")

                                    self.sp_dest_count = YLeaf(YType.uint32, "sp-dest-count")

                                    self.sp_duration = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration()
                                    self.sp_duration.parent = self
                                    self._children_name_map["sp_duration"] = "sp-duration"
                                    self._children_yang_names.add("sp-duration")

                                    self.sp_start_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime()
                                    self.sp_start_time.parent = self
                                    self._children_name_map["sp_start_time"] = "sp-start-time"
                                    self._children_yang_names.add("sp-start-time")
                                    self._segment_path = lambda: "os-sum-runtime"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime, ['sp_adv_rtr_id', 'sp_dest_addr', 'sp_dest_count'], name, value)


                                class SpDuration(Entity):
                                    """
                                    sp duration
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration, self).__init__()

                                        self.yang_name = "sp-duration"
                                        self.yang_parent_name = "os-sum-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "sp-duration"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpDuration, ['nanosecond', 'second'], name, value)


                                class SpStartTime(Entity):
                                    """
                                    sp start time
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nanosecond
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: second
                                    
                                    	Second
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, self).__init__()

                                        self.yang_name = "sp-start-time"
                                        self.yang_parent_name = "os-sum-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.nanosecond = YLeaf(YType.uint32, "nanosecond")

                                        self.second = YLeaf(YType.uint32, "second")
                                        self._segment_path = lambda: "sp-start-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.OsSumRuntime.SpStartTime, ['nanosecond', 'second'], name, value)


                            class Runtime(Entity):
                                """
                                runtime
                                
                                .. attribute:: area_stat
                                
                                	area stat
                                	**type**\: list of    :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat>`
                                
                                .. attribute:: gbl_spf_time
                                
                                	gbl spf time
                                	**type**\:   :py:class:`GblSpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime>`
                                
                                .. attribute:: lsa_change_cnt
                                
                                	lsa change cnt
                                	**type**\:  int
                                
                                	**range:** \-32768..32767
                                
                                .. attribute:: lsa_info
                                
                                	lsa info
                                	**type**\: list of    :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo>`
                                
                                .. attribute:: spf_start_time
                                
                                	spf start time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime, self).__init__()

                                    self.yang_name = "runtime"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"gbl-spf-time" : ("gbl_spf_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime)}
                                    self._child_list_classes = {"area-stat" : ("area_stat", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat), "lsa-info" : ("lsa_info", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo)}

                                    self.lsa_change_cnt = YLeaf(YType.int16, "lsa-change-cnt")

                                    self.spf_start_time = YLeaf(YType.uint32, "spf-start-time")

                                    self.gbl_spf_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime()
                                    self.gbl_spf_time.parent = self
                                    self._children_name_map["gbl_spf_time"] = "gbl-spf-time"
                                    self._children_yang_names.add("gbl-spf-time")

                                    self.area_stat = YList(self)
                                    self.lsa_info = YList(self)
                                    self._segment_path = lambda: "runtime"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime, ['lsa_change_cnt', 'spf_start_time'], name, value)


                                class AreaStat(Entity):
                                    """
                                    area stat
                                    
                                    .. attribute:: area_id
                                    
                                    	area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_type_cnt
                                    
                                    	lsa type cnt
                                    	**type**\: list of    :py:class:`LsaTypeCnt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt>`
                                    
                                    .. attribute:: spf_time
                                    
                                    	spf time
                                    	**type**\:   :py:class:`SpfTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat, self).__init__()

                                        self.yang_name = "area-stat"
                                        self.yang_parent_name = "runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"spf-time" : ("spf_time", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime)}
                                        self._child_list_classes = {"lsa-type-cnt" : ("lsa_type_cnt", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt)}

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.spf_time = Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime()
                                        self.spf_time.parent = self
                                        self._children_name_map["spf_time"] = "spf-time"
                                        self._children_yang_names.add("spf-time")

                                        self.lsa_type_cnt = YList(self)
                                        self._segment_path = lambda: "area-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat, ['area_id'], name, value)


                                    class LsaTypeCnt(Entity):
                                        """
                                        lsa type cnt
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, self).__init__()

                                            self.yang_name = "lsa-type-cnt"
                                            self.yang_parent_name = "area-stat"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.entry = YLeaf(YType.uint32, "entry")
                                            self._segment_path = lambda: "lsa-type-cnt"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.LsaTypeCnt, ['entry'], name, value)


                                    class SpfTime(Entity):
                                        """
                                        spf time
                                        
                                        .. attribute:: spf_dijkstra
                                        
                                        	spf dijkstra
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_ext_prefix
                                        
                                        	spf ext prefix
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_ext_prefix_del
                                        
                                        	spf ext prefix del
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_inter_prefix
                                        
                                        	spf inter prefix
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_inter_prefix_del
                                        
                                        	spf inter prefix del
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_intra_prefix
                                        
                                        	spf intra prefix
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_intra_prefix_del
                                        
                                        	spf intra prefix del
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-ospf-oper'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, self).__init__()

                                            self.yang_name = "spf-time"
                                            self.yang_parent_name = "area-stat"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                            self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                            self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                            self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                            self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                            self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                            self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")
                                            self._segment_path = lambda: "spf-time"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.AreaStat.SpfTime, ['spf_dijkstra', 'spf_ext_prefix', 'spf_ext_prefix_del', 'spf_inter_prefix', 'spf_inter_prefix_del', 'spf_intra_prefix', 'spf_intra_prefix_del'], name, value)


                                class GblSpfTime(Entity):
                                    """
                                    gbl spf time
                                    
                                    .. attribute:: spf_dijkstra
                                    
                                    	spf dijkstra
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix
                                    
                                    	spf ext prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_ext_prefix_del
                                    
                                    	spf ext prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix
                                    
                                    	spf inter prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_inter_prefix_del
                                    
                                    	spf inter prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix
                                    
                                    	spf intra prefix
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_intra_prefix_del
                                    
                                    	spf intra prefix del
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime, self).__init__()

                                        self.yang_name = "gbl-spf-time"
                                        self.yang_parent_name = "runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.spf_dijkstra = YLeaf(YType.uint32, "spf-dijkstra")

                                        self.spf_ext_prefix = YLeaf(YType.uint32, "spf-ext-prefix")

                                        self.spf_ext_prefix_del = YLeaf(YType.uint32, "spf-ext-prefix-del")

                                        self.spf_inter_prefix = YLeaf(YType.uint32, "spf-inter-prefix")

                                        self.spf_inter_prefix_del = YLeaf(YType.uint32, "spf-inter-prefix-del")

                                        self.spf_intra_prefix = YLeaf(YType.uint32, "spf-intra-prefix")

                                        self.spf_intra_prefix_del = YLeaf(YType.uint32, "spf-intra-prefix-del")
                                        self._segment_path = lambda: "gbl-spf-time"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.GblSpfTime, ['spf_dijkstra', 'spf_ext_prefix', 'spf_ext_prefix_del', 'spf_inter_prefix', 'spf_inter_prefix_del', 'spf_intra_prefix', 'spf_intra_prefix_del'], name, value)


                                class LsaInfo(Entity):
                                    """
                                    lsa info
                                    
                                    .. attribute:: adv_rtr
                                    
                                    	adv rtr
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: area_id
                                    
                                    	area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flush
                                    
                                    	flush
                                    	**type**\:  bool
                                    
                                    .. attribute:: id
                                    
                                    	id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo, self).__init__()

                                        self.yang_name = "lsa-info"
                                        self.yang_parent_name = "runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.adv_rtr = YLeaf(YType.str, "adv-rtr")

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.flush = YLeaf(YType.boolean, "flush")

                                        self.id = YLeaf(YType.str, "id")

                                        self.type = YLeaf(YType.uint8, "type")
                                        self._segment_path = lambda: "lsa-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.Runtime.LsaInfo, ['adv_rtr', 'area_id', 'flush', 'id', 'type'], name, value)


                            class SpfHeader(Entity):
                                """
                                spf header
                                
                                .. attribute:: area_summ
                                
                                	area summ
                                	**type**\: list of    :py:class:`AreaSumm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm>`
                                
                                .. attribute:: router_id
                                
                                	router id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: spf_count
                                
                                	spf count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-ospf-oper'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader, self).__init__()

                                    self.yang_name = "spf-header"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"area-summ" : ("area_summ", Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm)}

                                    self.router_id = YLeaf(YType.str, "router-id")

                                    self.spf_count = YLeaf(YType.uint32, "spf-count")

                                    self.area_summ = YList(self)
                                    self._segment_path = lambda: "spf-header"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader, ['router_id', 'spf_count'], name, value)


                                class AreaSumm(Entity):
                                    """
                                    area summ
                                    
                                    .. attribute:: area_id
                                    
                                    	area id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_count
                                    
                                    	spf count
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-ospf-oper'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm, self).__init__()

                                        self.yang_name = "area-summ"
                                        self.yang_parent_name = "spf-header"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.area_id = YLeaf(YType.uint32, "area-id")

                                        self.spf_count = YLeaf(YType.uint32, "spf-count")
                                        self._segment_path = lambda: "area-summ"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.SpfStats.SpfHeader.AreaSumm, ['area_id', 'spf_count'], name, value)


                        class TeStats(Entity):
                            """
                            OSPF TE IO statistics
                            
                            .. attribute:: adj_changes
                            
                            	adj changes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_gets
                            
                            	adj gets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: control_batch_reads
                            
                            	control batch reads
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: control_batch_writes
                            
                            	control batch writes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: control_disconnects
                            
                            	control disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: data_trans_completes
                            
                            	data trans completes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fragment_announces
                            
                            	fragment announces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fragment_deletes
                            
                            	fragment deletes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_batch_reads
                            
                            	link batch reads
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_batch_writes
                            
                            	link batch writes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_floods
                            
                            	link floods
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_fragment_floods
                            
                            	link fragment floods
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsp_gets
                            
                            	lsp gets
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_br_lkup_num_dests
                            
                            	pce br lkup num dests
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_br_lookup
                            
                            	pce br lookup
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_br_resp_fails
                            
                            	pce br resp fails
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_flood
                            
                            	pce flood
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_get
                            
                            	pce get
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_listen
                            
                            	pce listen
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_node_announce_batches
                            
                            	pce node announce batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_node_delete_batches
                            
                            	pce node delete batches
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_node_send_fails
                            
                            	pce node send fails
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_num_node_announce
                            
                            	pce num node announce
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_num_node_delete
                            
                            	pce num node delete
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pce_stoplisten
                            
                            	pce stoplisten
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sr_num_area_enabled
                            
                            	sr num area enabled
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_connected
                            
                            	te connected
                            	**type**\:  bool
                            
                            .. attribute:: te_disconnects
                            
                            	te disconnects
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_sr_idt_sent
                            
                            	te sr idt sent
                            	**type**\:  bool
                            
                            .. attribute:: te_sr_path_reg_idt_recvd
                            
                            	te sr path reg idt recvd
                            	**type**\:  bool
                            
                            .. attribute:: total_tunnels
                            
                            	total tunnels
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_announces
                            
                            	tunnel announces
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats, self).__init__()

                                self.yang_name = "te-stats"
                                self.yang_parent_name = "statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.adj_changes = YLeaf(YType.uint32, "adj-changes")

                                self.adj_gets = YLeaf(YType.uint32, "adj-gets")

                                self.control_batch_reads = YLeaf(YType.uint32, "control-batch-reads")

                                self.control_batch_writes = YLeaf(YType.uint32, "control-batch-writes")

                                self.control_disconnects = YLeaf(YType.uint32, "control-disconnects")

                                self.data_trans_completes = YLeaf(YType.uint32, "data-trans-completes")

                                self.fragment_announces = YLeaf(YType.uint32, "fragment-announces")

                                self.fragment_deletes = YLeaf(YType.uint32, "fragment-deletes")

                                self.link_batch_reads = YLeaf(YType.uint32, "link-batch-reads")

                                self.link_batch_writes = YLeaf(YType.uint32, "link-batch-writes")

                                self.link_floods = YLeaf(YType.uint32, "link-floods")

                                self.link_fragment_floods = YLeaf(YType.uint32, "link-fragment-floods")

                                self.lsp_gets = YLeaf(YType.uint32, "lsp-gets")

                                self.pce_br_lkup_num_dests = YLeaf(YType.uint32, "pce-br-lkup-num-dests")

                                self.pce_br_lookup = YLeaf(YType.uint32, "pce-br-lookup")

                                self.pce_br_resp_fails = YLeaf(YType.uint32, "pce-br-resp-fails")

                                self.pce_flood = YLeaf(YType.uint32, "pce-flood")

                                self.pce_get = YLeaf(YType.uint32, "pce-get")

                                self.pce_listen = YLeaf(YType.uint32, "pce-listen")

                                self.pce_node_announce_batches = YLeaf(YType.uint32, "pce-node-announce-batches")

                                self.pce_node_delete_batches = YLeaf(YType.uint32, "pce-node-delete-batches")

                                self.pce_node_send_fails = YLeaf(YType.uint32, "pce-node-send-fails")

                                self.pce_num_node_announce = YLeaf(YType.uint32, "pce-num-node-announce")

                                self.pce_num_node_delete = YLeaf(YType.uint32, "pce-num-node-delete")

                                self.pce_stoplisten = YLeaf(YType.uint32, "pce-stoplisten")

                                self.sr_num_area_enabled = YLeaf(YType.uint32, "sr-num-area-enabled")

                                self.te_connected = YLeaf(YType.boolean, "te-connected")

                                self.te_disconnects = YLeaf(YType.uint32, "te-disconnects")

                                self.te_sr_idt_sent = YLeaf(YType.boolean, "te-sr-idt-sent")

                                self.te_sr_path_reg_idt_recvd = YLeaf(YType.boolean, "te-sr-path-reg-idt-recvd")

                                self.total_tunnels = YLeaf(YType.uint32, "total-tunnels")

                                self.tunnel_announces = YLeaf(YType.uint32, "tunnel-announces")
                                self._segment_path = lambda: "te-stats"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.Statistics.TeStats, ['adj_changes', 'adj_gets', 'control_batch_reads', 'control_batch_writes', 'control_disconnects', 'data_trans_completes', 'fragment_announces', 'fragment_deletes', 'link_batch_reads', 'link_batch_writes', 'link_floods', 'link_fragment_floods', 'lsp_gets', 'pce_br_lkup_num_dests', 'pce_br_lookup', 'pce_br_resp_fails', 'pce_flood', 'pce_get', 'pce_listen', 'pce_node_announce_batches', 'pce_node_delete_batches', 'pce_node_send_fails', 'pce_num_node_announce', 'pce_num_node_delete', 'pce_stoplisten', 'sr_num_area_enabled', 'te_connected', 'te_disconnects', 'te_sr_idt_sent', 'te_sr_path_reg_idt_recvd', 'total_tunnels', 'tunnel_announces'], name, value)


                    class SummaryPrefixes(Entity):
                        """
                        Summary prefix table
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix information
                        	**type**\: list of    :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ipv4-ospf-oper'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__init__()

                            self.yang_name = "summary-prefixes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"summary-prefix" : ("summary_prefix", Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix)}

                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "summary-prefixes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes, [], name, value)


                        class SummaryPrefix(Entity):
                            """
                            Summary prefix information
                            
                            .. attribute:: netmask
                            
                            	Summary Mask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix
                            
                            	Summary Prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: summary_mask
                            
                            	Summary Netmask
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: summary_metric
                            
                            	Cost of Summary
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: summary_metric_type
                            
                            	Type of Metric
                            	**type**\:   :py:class:`ExMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_ospf_oper.ExMetric>`
                            
                            .. attribute:: summary_prefix
                            
                            	Summary prefix
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: summary_tag
                            
                            	Tag associated with this summary prefix
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-ospf-oper'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.netmask = YLeaf(YType.str, "netmask")

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.summary_mask = YLeaf(YType.str, "summary-mask")

                                self.summary_metric = YLeaf(YType.uint32, "summary-metric")

                                self.summary_metric_type = YLeaf(YType.enumeration, "summary-metric-type")

                                self.summary_prefix = YLeaf(YType.str, "summary-prefix")

                                self.summary_tag = YLeaf(YType.uint32, "summary-tag")
                                self._segment_path = lambda: "summary-prefix"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospf.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, ['netmask', 'prefix', 'summary_mask', 'summary_metric', 'summary_metric_type', 'summary_prefix', 'summary_tag'], name, value)

    def clone_ptr(self):
        self._top_entity = Ospf()
        return self._top_entity

